@@ -1,5 +1,5 @@
 /*
- *  $Id: dialog.c 23819 2021-06-09 21:16:20Z yeti-dn $
+ *  $Id: dialog.c 24503 2021-11-10 11:15:53Z yeti-dn $
  *  Copyright (C) 2021 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -15,6 +15,7 @@
  *  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
+#include "config.h"
 #include <stdarg.h>
 #include "libgwyddion/gwymacros.h"
 #include "libprocess/gwyprocesstypes.h"
@@ -279,14 +280,15 @@ gwy_dialog_add_content(GwyDialog *dialog,
  * container widget.
  *
  * All parameters in all parameter tables in a #GwyDialog must have unique ids.  This is because parameters are
- * commonly refered to only by the id.  Whith this condition satisfied, different parameter tables corresponding to
- * different #GwyParamDef definition sets.  More commonly, however, there would be multiple tables, but each providing
- * controls for a different subset of parameters within one #GwyParams.
+ * commonly refered to only by the id.  When this condition is satisfied, different parameter tables can correspond to
+ * different #GwyParamDef definition sets.  Normally, however, multiple tables provide controls for different subsets
+ * of parameters defined by one #GwyParamDef.
  *
- * If multiple tables are added parameters in any table can be changed inside a #GwyParamTable::param-changed callback
- * without triggering infinite recursion.  This is because #GwyDialog prevents recursion also during cross-updates.
+ * If multiple tables are added, parameters in any table can be changed inside a #GwyParamTable::param-changed
+ * callback without triggering infinite recursion.  This is because #GwyDialog prevents recursion also during
+ * cross-updates.
  *
- * Usually, you can just connect all #GwyParamTable::param-changed signals to the same handler and ignore which one
+ * Usually, you can just connect all #GwyParamTable::param-changed signals to the same handler and ignore which table
  * emitted the signal.  All the useful information is in the parameter id.
  *
  * The dialog consumes the floating reference of @partable.  Usually this has the desired effect that @dialog becomes
@@ -479,6 +481,8 @@ gwy_dialog_run(GwyDialog *dialog)
             gwy_help_add_to_volume_dialog(gtkdialog, GWY_HELP_DEFAULT);
         else if (gwy_xyz_func_current())
             gwy_help_add_to_xyz_dialog(gtkdialog, GWY_HELP_DEFAULT);
+        else if (gwy_curve_map_func_current())
+            gwy_help_add_to_cmap_dialog(gtkdialog, GWY_HELP_DEFAULT);
 
         if (priv->default_response)
             gtk_dialog_set_default_response(gtkdialog, priv->default_response);
@@ -904,4 +908,13 @@ reset_all_parameters(GwyDialog *dialog)
  * Since: 2.59
  **/
 
+/**
+ * GwyDialogPreviewFunc:
+ * @user_data: User data to passed to gwy_dialog_set_preview_func().
+ *
+ * Protoype of #GwyDialog preview functions.
+ *
+ * Since: 2.59
+ **/
+
 /* vim: set cin columns=120 tw=118 et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
