@@ -1,5 +1,5 @@
 /*
- *  $Id: gwyapp.h 20678 2017-12-18 18:26:55Z yeti-dn $
+ *  $Id: gwyapp.h 23212 2021-03-11 16:25:12Z yeti-dn $
  *  Copyright (C) 2003-2013 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -27,6 +27,7 @@
 #include <app/app.h>
 #include <app/data-browser.h>
 #include <app/datachooser.h>
+#include <app/dialog.h>
 #include <app/file.h>
 #include <app/filelist.h>
 #include <app/funcuse.h>
@@ -39,6 +40,9 @@
 #include <app/logging.h>
 #include <app/menu.h>
 #include <app/meta.h>
+#include <app/param-def.h>
+#include <app/params.h>
+#include <app/param-table.h>
 #include <app/resource-editor.h>
 #include <app/gwyresultsexport.h>
 #include <app/settings.h>
