@@ -1,22 +1,18 @@
 /*
- *  $Id: gwyappfilechooser.c 23366 2021-03-25 15:37:11Z yeti-dn $
- *  Copyright (C) 2003-2018 David Necas (Yeti), Petr Klapetek.
+ *  $Id: gwyappfilechooser.c 24267 2021-10-07 08:19:51Z rsleza $
+ *  Copyright (C) 2003-2021 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
+ *  License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any
+ *  later version.
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
+ *  warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+ *  details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
+ *  You should have received a copy of the GNU General Public License along with this program; if not, write to the
+ *  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #include "config.h"
@@ -32,8 +28,8 @@
 #include <app/gwyapp.h>
 #include "gwyappinternal.h"
 
-/* Do not try to full-preview files larger than this.  100 MB is an arbitrary
- * limit but most < 100 MB files seem to be readable fairly quickly. */
+/* Do not try to full-preview files larger than this.  100 MB is an arbitrary limit but most < 100 MB files seem to be
+ * readable fairly quickly. */
 #define MAX_FILE_SIZE_FOR_PREVIEW (96UL*1024UL*1024UL)
 
 enum {
@@ -202,11 +198,10 @@ gwy_app_file_chooser_add_types(GtkListStore *store,
     tldata.list = g_slist_sort(tldata.list, gwy_app_file_chooser_type_compare);
 
     for (l = tldata.list; l; l = g_slist_next(l)) {
-        gtk_list_store_insert_with_values
-                (store, &iter, G_MAXINT,
-                 COLUMN_FILETYPE, l->data,
-                 COLUMN_LABEL, gettext(gwy_file_func_get_description(l->data)),
-                 -1);
+        gtk_list_store_insert_with_values(store, &iter, G_MAXINT,
+                                          COLUMN_FILETYPE, l->data,
+                                          COLUMN_LABEL, gettext(gwy_file_func_get_description(l->data)),
+                                          -1);
     }
 
     g_slist_free(tldata.list);
@@ -241,10 +236,7 @@ _gwy_app_file_chooser_get(GtkFileChooserAction action)
 
     ensure_gtk_recently_used();
 
-    chooser = g_object_new(GWY_TYPE_APP_FILE_CHOOSER,
-                           "title", title,
-                           "action", action,
-                           NULL);
+    chooser = g_object_new(GWY_TYPE_APP_FILE_CHOOSER, "title", title, "action", action, NULL);
     *instance = GTK_WIDGET(chooser);
     dialog = GTK_DIALOG(chooser);
     g_object_add_weak_pointer(G_OBJECT(chooser), (gpointer*)instance);
@@ -267,16 +259,14 @@ _gwy_app_file_chooser_get(GtkFileChooserAction action)
         break;
     }
 
-    gwy_help_add_to_window(GTK_WINDOW(dialog), "managing-files", NULL,
-                           GWY_HELP_DEFAULT);
+    gwy_help_add_to_window(GTK_WINDOW(dialog), "managing-files", NULL, GWY_HELP_DEFAULT);
     gtk_dialog_set_default_response(dialog, GTK_RESPONSE_OK);
     gtk_file_chooser_set_local_only(GTK_FILE_CHOOSER(dialog), TRUE);
 
     gwy_app_file_chooser_add_type_list(chooser);
     gwy_app_file_chooser_add_preview(chooser);
 
-    g_signal_connect(chooser, "response",
-                     G_CALLBACK(gwy_app_file_chooser_save_position), NULL);
+    g_signal_connect(chooser, "response", G_CALLBACK(gwy_app_file_chooser_save_position), NULL);
     gwy_app_restore_window_position(GTK_WINDOW(chooser), chooser->prefix, TRUE);
 
     /* Does not filter when initially shown without this. */
@@ -289,8 +279,7 @@ _gwy_app_file_chooser_get(GtkFileChooserAction action)
 static void
 gwy_app_file_chooser_save_position(GwyAppFileChooser *chooser)
 {
-    gwy_app_save_window_position(GTK_WINDOW(chooser), chooser->prefix,
-                                 FALSE, TRUE);
+    gwy_app_save_window_position(GTK_WINDOW(chooser), chooser->prefix, FALSE, TRUE);
 }
 
 /**
@@ -319,8 +308,7 @@ gwy_app_file_chooser_select_type(GwyAppFileChooser *chooser)
     if (!gtk_tree_model_get_iter_first(model, &first))
         return;
 
-    ok = gwy_container_gis_string(gwy_app_settings_get(), chooser->type_key,
-                                  &name);
+    ok = gwy_container_gis_string(gwy_app_settings_get(), chooser->type_key, &name);
     if (!ok) {
         gtk_tree_selection_select_iter(selection, &first);
         return;
@@ -334,8 +322,7 @@ gwy_app_file_chooser_select_type(GwyAppFileChooser *chooser)
         if (ok) {
             gtk_tree_selection_select_iter(selection, &iter);
             path = gtk_tree_model_get_path(model, &iter);
-            gtk_tree_view_scroll_to_cell(GTK_TREE_VIEW(chooser->type_list),
-                                         path, NULL, TRUE, 0.5, 0.0);
+            gtk_tree_view_scroll_to_cell(GTK_TREE_VIEW(chooser->type_list), path, NULL, TRUE, 0.5, 0.0);
             gtk_tree_path_free(path);
             return;
         }
@@ -363,8 +350,7 @@ _gwy_app_file_chooser_get_selected_type(GwyAppFileChooser *chooser)
         s = NULL;
     }
     else
-        gwy_container_set_string(gwy_app_settings_get(), chooser->type_key,
-                                 g_strdup(s));
+        gwy_container_set_string(gwy_app_settings_get(), chooser->type_key, g_strdup(s));
 
     return s;
 }
@@ -428,8 +414,7 @@ gwy_app_file_chooser_expanded(GwyAppFileChooser *chooser,
     gchar *key;
 
     key = g_strconcat(chooser->prefix, "/expanded", NULL);
-    gwy_container_set_boolean_by_name(gwy_app_settings_get(), key,
-                                      gtk_expander_get_expanded(expander));
+    gwy_container_set_boolean_by_name(gwy_app_settings_get(), key, gtk_expander_get_expanded(expander));
     g_free(key);
 }
 
@@ -482,22 +467,19 @@ gwy_app_file_chooser_add_type_list(GwyAppFileChooser *chooser)
 
     chooser->expander = gtk_expander_new(NULL);
     gtk_expander_set_use_underline(GTK_EXPANDER(chooser->expander), TRUE);
-    gtk_file_chooser_set_extra_widget(GTK_FILE_CHOOSER(chooser),
-                                      chooser->expander);
+    gtk_file_chooser_set_extra_widget(GTK_FILE_CHOOSER(chooser), chooser->expander);
     key = g_strconcat(chooser->prefix, "/expanded", NULL);
     gwy_container_gis_boolean_by_name(gwy_app_settings_get(), key, &expanded);
     g_free(key);
     gtk_expander_set_expanded(GTK_EXPANDER(chooser->expander), expanded);
     g_signal_connect_swapped(chooser->expander, "notify::expanded",
-                             G_CALLBACK(gwy_app_file_chooser_expanded),
-                             chooser);
+                             G_CALLBACK(gwy_app_file_chooser_expanded), chooser);
 
     vbox = gtk_vbox_new(FALSE, 4);
     gtk_container_add(GTK_CONTAINER(chooser->expander), vbox);
 
     scwin = gtk_scrolled_window_new(NULL, NULL);
-    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scwin),
-                                   GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
+    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scwin), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
     gtk_box_pack_start(GTK_BOX(vbox), scwin, TRUE, TRUE, 0);
 
     chooser->type_list = gtk_tree_view_new_with_model(GTK_TREE_MODEL(store));
@@ -510,23 +492,18 @@ gwy_app_file_chooser_add_type_list(GwyAppFileChooser *chooser)
     gtk_tree_view_append_column(treeview, column);
     renderer = gtk_cell_renderer_text_new();
     gtk_cell_layout_pack_start(GTK_CELL_LAYOUT(column), renderer, TRUE);
-    gtk_cell_layout_add_attribute(GTK_CELL_LAYOUT(column), renderer,
-                                  "text", COLUMN_LABEL);
+    gtk_cell_layout_add_attribute(GTK_CELL_LAYOUT(column), renderer, "text", COLUMN_LABEL);
 
     selection = gtk_tree_view_get_selection(treeview);
     gtk_tree_selection_set_mode(selection, GTK_SELECTION_BROWSE);
-    g_signal_connect_swapped(selection, "changed",
-                             G_CALLBACK(gwy_app_file_chooser_type_changed),
-                             chooser);
+    g_signal_connect_swapped(selection, "changed", G_CALLBACK(gwy_app_file_chooser_type_changed), chooser);
 
     if (action == GTK_FILE_CHOOSER_ACTION_OPEN) {
-        /* Gtk+ file chooser filter model is completely antagonistic to any
-         * parametric filter mechanism.  Also we cannot set the filter to NULL
-         * because it assumes we always choose a filter from some list.  So (1)
-         * we need an explicit no_filter object that does nothing (2) we cannot
-         * combine filters, we need a single monster-filter function that does
-         * everything (3) despite this, there is no ‘refilter’ function, so we
-         * must set filter to no_filter and then back to filter to refilter. */
+        /* Gtk+ file chooser filter model is completely antagonistic to any parametric filter mechanism.  Also we
+         * cannot set the filter to NULL because it assumes we always choose a filter from some list.  So (1) we need
+         * an explicit no_filter object that does nothing (2) we cannot combine filters, we need a single
+         * monster-filter function that does everything (3) despite this, there is no ‘refilter’ function, so we must
+         * set filter to no_filter and then back to filter to refilter. */
         chooser->filter = gtk_file_filter_new();
         g_object_ref_sink(chooser->filter);
 
@@ -537,11 +514,8 @@ gwy_app_file_chooser_add_type_list(GwyAppFileChooser *chooser)
         construct_glob_filter(chooser, GTK_BOX(vbox));
         construct_loadable_filter(chooser, GTK_BOX(vbox));
 
-        gtk_file_filter_add_custom(chooser->filter,
-                                   GTK_FILE_FILTER_FILENAME,
-                                   gwy_app_file_chooser_open_filter,
-                                   chooser,
-                                   NULL);
+        gtk_file_filter_add_custom(chooser->filter, GTK_FILE_FILTER_FILENAME,
+                                   gwy_app_file_chooser_open_filter, chooser, NULL);
     }
 
     /* Give it some reasonable size. FIXME: hack. */
@@ -552,10 +526,9 @@ gwy_app_file_chooser_add_type_list(GwyAppFileChooser *chooser)
         extraheight = 5*extraheight/3;
     gtk_widget_set_size_request(scwin, -1, req.height + extraheight);
 
-    /* Ignore the file from settings (i.e. between sessions).  Preserving it
-     * can be useful when importing lots of raw data, but it confuses people
-     * no end when they suddently cannot open files because some kind of raw
-     * data import is selected. */
+    /* Ignore the file from settings (i.e. between sessions).  Preserving it can be useful when importing lots of raw
+     * data, but it confuses people no end when they suddently cannot open files because some kind of raw data import
+     * is selected. */
     if (action != GTK_FILE_CHOOSER_ACTION_OPEN)
         gwy_app_file_chooser_select_type(chooser);
     gwy_app_file_chooser_type_changed(chooser, selection);
@@ -571,16 +544,14 @@ construct_loadable_filter(GwyAppFileChooser *chooser, GtkBox *vbox)
     gchar *key;
 
     chooser->only_loadable = FALSE;
-    chooser->loadable_check
-        = gtk_check_button_new_with_mnemonic(_("Show only loadable files"));
+    chooser->loadable_check = gtk_check_button_new_with_mnemonic(_("Show only loadable files"));
     toggle = GTK_TOGGLE_BUTTON(chooser->loadable_check);
     key = g_strconcat(chooser->prefix, "/filter", NULL);
     gwy_container_gis_boolean_by_name(settings, key, &chooser->only_loadable);
     g_free(key);
     gtk_toggle_button_set_active(toggle, chooser->only_loadable);
     gtk_box_pack_start(vbox, chooser->loadable_check, FALSE, FALSE, 0);
-    g_signal_connect_swapped(chooser->loadable_check, "toggled",
-                             G_CALLBACK(loadable_filter_toggled), chooser);
+    g_signal_connect_swapped(chooser->loadable_check, "toggled", G_CALLBACK(loadable_filter_toggled), chooser);
 }
 
 static void
@@ -610,16 +581,14 @@ construct_glob_filter(GwyAppFileChooser *chooser, GtkBox *vbox)
     gtk_box_pack_start(GTK_BOX(hbox), entry, TRUE, TRUE, 0);
     gtk_label_set_mnemonic_widget(GTK_LABEL(label), entry);
     chooser->glob_entry = entry;
-    g_signal_connect(entry, "activate",
-                     G_CALLBACK(glob_entry_updated), chooser);
+    g_signal_connect(entry, "activate", G_CALLBACK(glob_entry_updated), chooser);
 
     button = gtk_button_new();
     gtk_button_set_relief(GTK_BUTTON(button), GTK_RELIEF_NONE);
     gtk_box_pack_start(GTK_BOX(hbox), button, FALSE, FALSE, 0);
     g_signal_connect(button, "clicked", G_CALLBACK(glob_entry_clear), chooser);
 
-    image = gtk_image_new_from_stock(GTK_STOCK_CLEAR,
-                                     GTK_ICON_SIZE_SMALL_TOOLBAR);
+    image = gtk_image_new_from_stock(GTK_STOCK_CLEAR, GTK_ICON_SIZE_SMALL_TOOLBAR);
     gtk_button_set_image(GTK_BUTTON(button), image);
 
 #ifdef G_OS_WIN32
@@ -631,8 +600,7 @@ construct_glob_filter(GwyAppFileChooser *chooser, GtkBox *vbox)
     gwy_container_gis_boolean_by_name(settings, key, &chooser->glob_casesens);
 
     check = gtk_check_button_new_with_mnemonic(_("Case _sensitive"));
-    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check),
-                                 chooser->glob_casesens);
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check), chooser->glob_casesens);
     gtk_box_pack_start(GTK_BOX(hbox), check, FALSE, FALSE, 4);
     g_signal_connect(check, "toggled", G_CALLBACK(glob_case_changed), chooser);
     chooser->glob_case_check = check;
@@ -663,8 +631,7 @@ glob_entry_updated(GtkEntry *entry, GwyAppFileChooser *chooser)
     oldpattern = chooser->pattern;
 
     if (chooser->glob_casesens) {
-        if (!strchr(chooser->glob->str, '*')
-            && !strchr(chooser->glob->str, '?'))
+        if (!strchr(chooser->glob->str, '*') && !strchr(chooser->glob->str, '?'))
             s = g_strconcat("*", chooser->glob->str, "*", NULL);
         else
             s = g_strdup(chooser->glob->str);
@@ -713,8 +680,7 @@ gwy_app_file_chooser_open_filter(const GtkFileFilterInfo *filter_info,
 
     if (ok && chooser->glob->len) {
         gchar *basename = g_path_get_basename(filename);
-        gchar *filename_utf8 = g_filename_to_utf8(basename, -1,
-                                                  NULL, NULL, NULL);
+        gchar *filename_utf8 = g_filename_to_utf8(basename, -1, NULL, NULL, NULL);
 
         g_free(basename);
         if (filename_utf8) {
@@ -733,9 +699,7 @@ gwy_app_file_chooser_open_filter(const GtkFileFilterInfo *filter_info,
         const gchar *name;
         gint score = 0;
 
-        name = gwy_file_detect_with_score(filter_info->filename,
-                                          FALSE, GWY_FILE_OPERATION_LOAD,
-                                          &score);
+        name = gwy_file_detect_with_score(filter_info->filename, FALSE, GWY_FILE_OPERATION_LOAD, &score);
         /* To filter out `fallback' importers like rawfile */
         ok = (name != NULL && score >= 5);
     }
@@ -764,10 +728,8 @@ loadable_filter_toggled(GwyAppFileChooser *chooser,
 static void
 enforce_refilter(GwyAppFileChooser *chooser)
 {
-    gtk_file_chooser_set_filter(GTK_FILE_CHOOSER(chooser),
-                                chooser->no_filter);
-    gtk_file_chooser_set_filter(GTK_FILE_CHOOSER(chooser),
-                                chooser->filter);
+    gtk_file_chooser_set_filter(GTK_FILE_CHOOSER(chooser), chooser->no_filter);
+    gtk_file_chooser_set_filter(GTK_FILE_CHOOSER(chooser), chooser->filter);
 }
 
 /***** Preview *************************************************************/
@@ -786,8 +748,7 @@ gwy_app_file_chooser_add_preview(GwyAppFileChooser *chooser)
     gint w;
 
     scwin = gtk_scrolled_window_new(NULL, NULL);
-    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scwin),
-                                   GTK_POLICY_NEVER, GTK_POLICY_ALWAYS);
+    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scwin), GTK_POLICY_NEVER, GTK_POLICY_ALWAYS);
     store = gtk_list_store_new(2, G_TYPE_STRING, GDK_TYPE_PIXBUF);
     chooser->preview = gtk_icon_view_new_with_model(GTK_TREE_MODEL(store));
     g_object_unref(store);
@@ -810,9 +771,8 @@ gwy_app_file_chooser_add_preview(GwyAppFileChooser *chooser)
     chooser->renderer_fileinfo = G_OBJECT(renderer);
 
     gtk_icon_view_set_selection_mode(preview, GTK_SELECTION_NONE);
-    /* In Gtk+ 2.14 and older, things work.  2.16 adds some padding that
-     * breaks everything.  And this padding together with the usual margin
-     * means too much white space so we have to get rid of the margin in 2.16+.
+    /* In Gtk+ 2.14 and older, things work.  2.16 adds some padding that breaks everything.  And this padding together
+     * with the usual margin means too much white space so we have to get rid of the margin in 2.16+.
      */
     if (gtk_major_version == 2 && gtk_minor_version <= 14) {
         gtk_icon_view_set_item_width(preview, TMS_NORMAL_THUMB_SIZE);
@@ -831,18 +791,14 @@ gwy_app_file_chooser_add_preview(GwyAppFileChooser *chooser)
     chooser->preview_filename = gtk_label_new(NULL);
     gtk_misc_set_alignment(GTK_MISC(chooser->preview_filename), 0.0, 0.5);
     gtk_label_set_single_line_mode(GTK_LABEL(chooser->preview_filename), TRUE);
-    gtk_label_set_ellipsize(GTK_LABEL(chooser->preview_filename),
-                            PANGO_ELLIPSIZE_END);
-    gtk_box_pack_start(GTK_BOX(vbox), chooser->preview_filename,
-                       FALSE, FALSE, 0);
+    gtk_label_set_ellipsize(GTK_LABEL(chooser->preview_filename), PANGO_ELLIPSIZE_END);
+    gtk_box_pack_start(GTK_BOX(vbox), chooser->preview_filename, FALSE, FALSE, 0);
 
     chooser->preview_type = gtk_label_new(NULL);
     gtk_misc_set_alignment(GTK_MISC(chooser->preview_type), 0.0, 0.5);
     gtk_label_set_single_line_mode(GTK_LABEL(chooser->preview_type), TRUE);
-    gtk_label_set_ellipsize(GTK_LABEL(chooser->preview_type),
-                            PANGO_ELLIPSIZE_END);
-    gtk_box_pack_start(GTK_BOX(vbox), chooser->preview_type,
-                       FALSE, FALSE, 0);
+    gtk_label_set_ellipsize(GTK_LABEL(chooser->preview_type), PANGO_ELLIPSIZE_END);
+    gtk_box_pack_start(GTK_BOX(vbox), chooser->preview_type, FALSE, FALSE, 0);
 
     gtk_box_pack_start(GTK_BOX(vbox), scwin, TRUE, TRUE, 0);
 
@@ -859,37 +815,29 @@ gwy_app_file_chooser_add_preview(GwyAppFileChooser *chooser)
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), setting);
     GTK_WIDGET_UNSET_FLAGS(button, GTK_CAN_FOCUS);
     gtk_button_set_relief(GTK_BUTTON(button), GTK_RELIEF_NONE);
-    gtk_tooltips_set_tip(tips, button,
-                         _("Plane-level previewed data"), NULL);
+    gtk_tooltips_set_tip(tips, button, _("Plane-level previewed data"), NULL);
     gtk_container_add(GTK_CONTAINER(button),
-                      gtk_image_new_from_stock(GWY_STOCK_LEVEL,
-                                               GTK_ICON_SIZE_SMALL_TOOLBAR));
+                      gtk_image_new_from_stock(GWY_STOCK_LEVEL, GTK_ICON_SIZE_SMALL_TOOLBAR));
     gtk_box_pack_start(GTK_BOX(toolbar), button, FALSE, FALSE, 0);
-    g_signal_connect_swapped(button, "toggled",
-                             G_CALLBACK(plane_level_changed), chooser);
+    g_signal_connect_swapped(button, "toggled", G_CALLBACK(plane_level_changed), chooser);
 
     setting = FALSE;
-    gwy_container_gis_boolean_by_name(settings, "/app/file/preview/row-level",
-                                      &setting);
+    gwy_container_gis_boolean_by_name(settings, "/app/file/preview/row-level", &setting);
     button = gtk_toggle_button_new();
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), setting);
     GTK_WIDGET_UNSET_FLAGS(button, GTK_CAN_FOCUS);
     gtk_button_set_relief(GTK_BUTTON(button), GTK_RELIEF_NONE);
-    gtk_tooltips_set_tip(tips, button,
-                         _("Row-level previewed data"), NULL);
+    gtk_tooltips_set_tip(tips, button, _("Row-level previewed data"), NULL);
     gtk_container_add(GTK_CONTAINER(button),
-                      gtk_image_new_from_stock(GWY_STOCK_LINE_LEVEL,
-                                               GTK_ICON_SIZE_SMALL_TOOLBAR));
+                      gtk_image_new_from_stock(GWY_STOCK_LINE_LEVEL, GTK_ICON_SIZE_SMALL_TOOLBAR));
     gtk_box_pack_start(GTK_BOX(toolbar), button, FALSE, FALSE, 0);
-    g_signal_connect_swapped(button, "toggled",
-                             G_CALLBACK(row_level_changed), chooser);
+    g_signal_connect_swapped(button, "toggled", G_CALLBACK(row_level_changed), chooser);
 
     gtk_widget_show_all(vbox);
 
     gtk_file_chooser_set_preview_widget(GTK_FILE_CHOOSER(chooser), vbox);
     gtk_file_chooser_set_use_preview_label(GTK_FILE_CHOOSER(chooser), FALSE);
-    g_signal_connect(chooser, "update-preview",
-                     G_CALLBACK(gwy_app_file_chooser_update_preview), NULL);
+    g_signal_connect(chooser, "update-preview", G_CALLBACK(gwy_app_file_chooser_update_preview), NULL);
 
     toolbar = gtk_hbox_new(FALSE, 0);
     gtk_box_pack_start(GTK_BOX(vbox), toolbar, FALSE, FALSE, 0);
@@ -900,8 +848,7 @@ plane_level_changed(GwyAppFileChooser *chooser,
                     GtkToggleButton *button)
 {
     GwyContainer *settings = gwy_app_settings_get();
-    gwy_container_set_boolean_by_name(settings, "/app/file/preview/plane-level",
-                                      gtk_toggle_button_get_active(button));
+    gwy_container_set_boolean_by_name(settings, "/app/file/preview/plane-level", gtk_toggle_button_get_active(button));
     if (chooser->full_preview_id) {
         g_source_remove(chooser->full_preview_id);
         chooser->full_preview_id = 0;
@@ -914,8 +861,7 @@ row_level_changed(GwyAppFileChooser *chooser,
                   GtkToggleButton *button)
 {
     GwyContainer *settings = gwy_app_settings_get();
-    gwy_container_set_boolean_by_name(settings, "/app/file/preview/row-level",
-                                      gtk_toggle_button_get_active(button));
+    gwy_container_set_boolean_by_name(settings, "/app/file/preview/row-level", gtk_toggle_button_get_active(button));
     if (chooser->full_preview_id) {
         g_source_remove(chooser->full_preview_id);
         chooser->full_preview_id = 0;
@@ -944,8 +890,7 @@ gwy_app_file_chooser_update_preview(GwyAppFileChooser *chooser)
     /* It should be UTF-8, but don't convert it just for gwy_debug() */
     gwy_debug("%s", filename_sys);
 
-    /* Never set the preview inactive.  Gtk+ can do all kinds of silly things
-     * if you do. */
+    /* Never set the preview inactive.  Gtk+ can do all kinds of silly things if you do. */
     if (!filename_sys) {
         gtk_label_set_text(GTK_LABEL(chooser->preview_filename), "");
         gtk_label_set_text(GTK_LABEL(chooser->preview_type), "");
@@ -963,8 +908,7 @@ gwy_app_file_chooser_update_preview(GwyAppFileChooser *chooser)
 
     /* Let directories fail gracefully */
     if (g_file_test(filename_sys, G_FILE_TEST_IS_DIR)) {
-        gtk_label_set_markup(GTK_LABEL(chooser->preview_type),
-                             "<small>directory</small>");
+        gtk_label_set_markup(GTK_LABEL(chooser->preview_type), "<small>directory</small>");
         g_free(filename_sys);
         return;
     }
@@ -990,18 +934,13 @@ gwy_app_file_chooser_update_preview(GwyAppFileChooser *chooser)
                  NULL);
     gtk_list_store_insert_with_values(GTK_LIST_STORE(model), &iter, -1,
                                       COLUMN_PIXBUF, pixbuf,
-                                      COLUMN_FILEINFO,
-                                      (file_too_large
-                                       ? _("File too large for preview")
-                                       : _("…")),
+                                      COLUMN_FILEINFO, (file_too_large ? _("File too large for preview") : _("…")),
                                       -1);
     g_object_unref(pixbuf);
 
     if (!file_too_large) {
-        chooser->full_preview_id
-            = g_timeout_add_full(G_PRIORITY_LOW, 250,
-                                 gwy_app_file_chooser_do_full_preview, chooser,
-                                 NULL);
+        chooser->full_preview_id = g_timeout_add_full(G_PRIORITY_LOW, 250,
+                                                      gwy_app_file_chooser_do_full_preview, chooser, NULL);
     }
 }
 
@@ -1030,8 +969,7 @@ insert_thumbnail_row(GwyAppFileChooser *chooser,
     store = GTK_LIST_STORE(model);
 
     if (chooser->make_thumbnail) {
-        _gwy_app_recent_file_write_thumbnail(chooser->preview_name_sys,
-                                             data, pageno, id, pixbuf);
+        _gwy_app_recent_file_write_thumbnail(chooser->preview_name_sys, data, pageno, id, pixbuf);
         chooser->make_thumbnail = FALSE;
     }
 
@@ -1075,12 +1013,11 @@ describe_channel(GwyContainer *container, gint id, GString *str)
     xreal = gwy_data_field_get_xreal(dfield);
     yreal = gwy_data_field_get_yreal(dfield);
     siunit = gwy_data_field_get_si_unit_xy(dfield);
-    vf = gwy_si_unit_get_format(siunit, GWY_SI_UNIT_FORMAT_VFMARKUP,
-                                sqrt(xreal*yreal), vf);
+    vf = gwy_si_unit_get_format(siunit, GWY_SI_UNIT_FORMAT_VFMARKUP, sqrt(xreal*yreal), vf);
     g_string_append_printf(str, "%.*f×%.*f%s%s",
-                          vf->precision, xreal/vf->magnitude,
-                          vf->precision, yreal/vf->magnitude,
-                          (vf->units && *vf->units) ? " " : "", vf->units);
+                           vf->precision, xreal/vf->magnitude,
+                           vf->precision, yreal/vf->magnitude,
+                           (vf->units && *vf->units) ? " " : "", vf->units);
     gwy_si_unit_value_format_free(vf);
 }
 
@@ -1096,24 +1033,19 @@ add_channel_thumbnails(GwyAppFileChooser *chooser,
     gint id;
 
     settings = gwy_app_settings_get();
-    gwy_container_gis_boolean_by_name(settings, "/app/file/preview/plane-level",
-                                      &plane_level);
-    gwy_container_gis_boolean_by_name(settings, "/app/file/preview/row-level",
-                                      &row_level);
+    gwy_container_gis_boolean_by_name(settings, "/app/file/preview/plane-level", &plane_level);
+    gwy_container_gis_boolean_by_name(settings, "/app/file/preview/row-level", &row_level);
 
     for (i = 0; ids[i] != -1; i++) {
         id = ids[i];
         modify_channel_for_preview(data, id, plane_level, row_level);
-        pixbuf = gwy_app_get_channel_thumbnail(data, id,
-                                               TMS_NORMAL_THUMB_SIZE,
-                                               TMS_NORMAL_THUMB_SIZE);
+        pixbuf = gwy_app_get_channel_thumbnail(data, id, TMS_NORMAL_THUMB_SIZE, TMS_NORMAL_THUMB_SIZE);
         if (!pixbuf) {
             g_warning("Cannot make a pixbuf of channel %d", id);
             continue;
         }
         describe_channel(data, id, str);
-        insert_thumbnail_row(chooser, data, GWY_PAGE_CHANNELS, id,
-                             pixbuf, str->str);
+        insert_thumbnail_row(chooser, data, GWY_PAGE_CHANNELS, id, pixbuf, str->str);
     }
 }
 
@@ -1163,16 +1095,13 @@ add_graph_thumbnails(GwyAppFileChooser *chooser,
 
     for (i = 0; ids[i] != -1; i++) {
         id = ids[i];
-        pixbuf = gwy_app_get_graph_thumbnail(data, id,
-                                             TMS_NORMAL_THUMB_SIZE,
-                                             3*TMS_NORMAL_THUMB_SIZE/4);
+        pixbuf = gwy_app_get_graph_thumbnail(data, id, TMS_NORMAL_THUMB_SIZE, 3*TMS_NORMAL_THUMB_SIZE/4);
         if (!pixbuf) {
             g_warning("Cannot make a pixbuf of graph %d", id);
             continue;
         }
         describe_graph(data, id, str);
-        insert_thumbnail_row(chooser, data, GWY_PAGE_GRAPHS, id,
-                             pixbuf, str->str);
+        insert_thumbnail_row(chooser, data, GWY_PAGE_GRAPHS, id, pixbuf, str->str);
     }
 }
 
@@ -1239,8 +1168,7 @@ ensure_brick_preview(GwyContainer *container, gint id)
     GQuark pquark, bquark;
 
     pquark = gwy_app_get_brick_preview_key_for_id(id);
-    if (gwy_container_gis_object(container, pquark, (GObject**)&preview)
-        && GWY_IS_DATA_FIELD(preview))
+    if (gwy_container_gis_object(container, pquark, (GObject**)&preview) && GWY_IS_DATA_FIELD(preview))
         return;
 
     bquark = gwy_app_get_brick_key_for_id(id);
@@ -1265,16 +1193,13 @@ add_volume_thumbnails(GwyAppFileChooser *chooser,
     for (i = 0; ids[i] != -1; i++) {
         id = ids[i];
         ensure_brick_preview(data, id);
-        pixbuf = gwy_app_get_volume_thumbnail(data, id,
-                                              TMS_NORMAL_THUMB_SIZE,
-                                              TMS_NORMAL_THUMB_SIZE);
+        pixbuf = gwy_app_get_volume_thumbnail(data, id, TMS_NORMAL_THUMB_SIZE, TMS_NORMAL_THUMB_SIZE);
         if (!pixbuf) {
             g_warning("Cannot make a pixbuf of volume data %d", id);
             continue;
         }
         describe_volume(data, id, str);
-        insert_thumbnail_row(chooser, data, GWY_PAGE_VOLUMES, id,
-                             pixbuf, str->str);
+        insert_thumbnail_row(chooser, data, GWY_PAGE_VOLUMES, id, pixbuf, str->str);
     }
 }
 
@@ -1308,8 +1233,7 @@ describe_xyz(GwyContainer *container, gint id, GString *str)
     xmax -= xmin;
     ymax -= ymin;
     siunit = gwy_surface_get_si_unit_xy(surface);
-    vf = gwy_si_unit_get_format(siunit, GWY_SI_UNIT_FORMAT_VFMARKUP,
-                                sqrt(xmax*ymax), vf);
+    vf = gwy_si_unit_get_format(siunit, GWY_SI_UNIT_FORMAT_VFMARKUP, sqrt(xmax*ymax), vf);
     g_string_append_printf(str, "%.*f×%.*f%s%s",
                            vf->precision, xmax/vf->magnitude,
                            vf->precision, ymax/vf->magnitude,
@@ -1329,16 +1253,108 @@ add_xyz_thumbnails(GwyAppFileChooser *chooser,
 
     for (i = 0; ids[i] != -1; i++) {
         id = ids[i];
-        pixbuf = gwy_app_get_xyz_thumbnail(data, id,
-                                           TMS_NORMAL_THUMB_SIZE,
-                                           TMS_NORMAL_THUMB_SIZE);
+        pixbuf = gwy_app_get_xyz_thumbnail(data, id, TMS_NORMAL_THUMB_SIZE, TMS_NORMAL_THUMB_SIZE);
         if (!pixbuf) {
             g_warning("Cannot make a pixbuf of xyz data %d", id);
             continue;
         }
         describe_xyz(data, id, str);
-        insert_thumbnail_row(chooser, data, GWY_PAGE_XYZS, id,
-                             pixbuf, str->str);
+        insert_thumbnail_row(chooser, data, GWY_PAGE_XYZS, id, pixbuf, str->str);
+    }
+}
+
+static void
+describe_cmap(GwyContainer *container, gint id, GString *str)
+{
+    GwyLawn *lawn;
+    GwySIUnit *siunit;
+    GwySIValueFormat *vf = NULL;
+    GQuark quark;
+    gint xres, yres, ncurves, i;
+    gdouble real;
+    const gchar *name;
+    gchar *s;
+
+    g_string_truncate(str, 0);
+
+    quark = gwy_app_get_lawn_key_for_id(id);
+    lawn = GWY_LAWN(gwy_container_get_object(container, quark));
+    g_return_if_fail(GWY_IS_LAWN(lawn));
+
+    s = gwy_app_get_lawn_title(container, id);
+    g_string_append(str, s);
+    g_free(s);
+
+    g_string_append(str, " (");
+    ncurves = gwy_lawn_get_n_curves(lawn);
+    for (i = 0; i < ncurves; i++) {
+        if (i)
+            g_string_append(str, ", ");
+        name = gwy_lawn_get_curve_label(lawn, i);
+        g_string_append(str, name ? name : _("Untitled"));
+    }
+    g_string_append(str, ") ");
+
+    xres = gwy_lawn_get_xres(lawn);
+    yres = gwy_lawn_get_yres(lawn);
+    g_string_append_printf(str, "%d×%d %s\n", xres, yres, _("px"));
+
+    real = gwy_lawn_get_xreal(lawn);
+    siunit = gwy_lawn_get_si_unit_xy(lawn);
+    vf = gwy_si_unit_get_format(siunit, GWY_SI_UNIT_FORMAT_VFMARKUP, real, vf);
+    g_string_append_printf(str, "%.*f%s%s",
+                           vf->precision, real/vf->magnitude,
+                           (vf->units && *vf->units) ? " " : "", vf->units);
+
+    real = gwy_lawn_get_yreal(lawn);
+    vf = gwy_si_unit_get_format(siunit, GWY_SI_UNIT_FORMAT_VFMARKUP, real, vf);
+    g_string_append_printf(str, "×%.*f%s%s",
+                           vf->precision, real/vf->magnitude,
+                           (vf->units && *vf->units) ? " " : "", vf->units);
+
+    gwy_si_unit_value_format_free(vf);
+}
+
+static void
+ensure_lawn_preview(GwyContainer *container, gint id)
+{
+    GwyLawn *lawn;
+    GwyDataField *preview;
+    GQuark pquark, bquark;
+
+    pquark = gwy_app_get_lawn_preview_key_for_id(id);
+    if (gwy_container_gis_object(container, pquark, (GObject**)&preview) && GWY_IS_DATA_FIELD(preview))
+        return;
+
+    bquark = gwy_app_get_lawn_key_for_id(id);
+    lawn = gwy_container_get_object(container, bquark);
+    if (!GWY_IS_LAWN(lawn))
+        return;
+
+    preview = _gwy_app_create_lawn_preview_field(lawn);
+    gwy_container_set_object(container, pquark, preview);
+    g_object_unref(preview);
+}
+
+static void
+add_cmap_thumbnails(GwyAppFileChooser *chooser,
+                    GwyContainer *data, gint *ids,
+                    GString *str)
+{
+    GdkPixbuf *pixbuf;
+    guint i;
+    gint id;
+
+    for (i = 0; ids[i] != -1; i++) {
+        id = ids[i];
+        ensure_lawn_preview(data, id);
+        pixbuf = gwy_app_get_curve_map_thumbnail(data, id, TMS_NORMAL_THUMB_SIZE, TMS_NORMAL_THUMB_SIZE);
+        if (!pixbuf) {
+            g_warning("Cannot make a pixbuf of curve map %d", id);
+            continue;
+        }
+        describe_cmap(data, id, str);
+        insert_thumbnail_row(chooser, data, GWY_PAGE_CURVE_MAPS, id, pixbuf, str->str);
     }
 }
 
@@ -1349,7 +1365,7 @@ gwy_app_file_chooser_do_full_preview(gpointer user_data)
     GtkTreeModel *model;
     GtkListStore *store;
     GwyAppFileChooser *chooser;
-    gint *channel_ids, *graph_ids, *sps_ids, *volume_ids, *xyz_ids;
+    gint *channel_ids, *graph_ids, *sps_ids, *volume_ids, *xyz_ids, *cmap_ids;
     GwyContainer *data;
     const gchar *name;
     GtkTreeIter iter;
@@ -1374,20 +1390,16 @@ gwy_app_file_chooser_do_full_preview(gpointer user_data)
     store = GTK_LIST_STORE(model);
     gtk_list_store_clear(store);
 
-    data = gwy_file_load(chooser->preview_name_sys,
-                         GWY_RUN_NONINTERACTIVE, NULL);
+    data = gwy_file_load(chooser->preview_name_sys, GWY_RUN_NONINTERACTIVE, NULL);
     if (!data) {
         gwy_app_file_chooser_free_preview(chooser);
         gtk_list_store_append(store, &iter);
-        gtk_list_store_set(store, &iter,
-                           COLUMN_FILEINFO, _("Cannot preview"),
-                           -1);
+        gtk_list_store_set(store, &iter, COLUMN_FILEINFO, _("Cannot preview"), -1);
 
         return FALSE;
     }
 
-    gwy_data_validate(data,
-                      GWY_DATA_VALIDATE_CORRECT | GWY_DATA_VALIDATE_NO_REPORT);
+    gwy_data_validate(data, GWY_DATA_VALIDATE_CORRECT | GWY_DATA_VALIDATE_NO_REPORT);
 
     /* Since 2.45 data browser can provide the lists of unmanaged data. */
     channel_ids = gwy_app_data_browser_get_data_ids(data);
@@ -1395,6 +1407,7 @@ gwy_app_file_chooser_do_full_preview(gpointer user_data)
     sps_ids = gwy_app_data_browser_get_spectra_ids(data);
     volume_ids = gwy_app_data_browser_get_volume_ids(data);
     xyz_ids = gwy_app_data_browser_get_xyz_ids(data);
+    cmap_ids = gwy_app_data_browser_get_curve_map_ids(data);
 
     str = g_string_new(NULL);
     if (gwy_file_get_data_info(data, &name, NULL)) {
@@ -1404,6 +1417,8 @@ gwy_app_file_chooser_do_full_preview(gpointer user_data)
             g_string_append_printf(str, ", %d vol", n);
         if ((n = count_ids(xyz_ids)))
             g_string_append_printf(str, ", %d xyz", n);
+        if ((n = count_ids(cmap_ids)))
+            g_string_append_printf(str, ", %d cm", n);
         if ((n = count_ids(channel_ids)))
             g_string_append_printf(str, ", %d img", n);
         if ((n = count_ids(graph_ids)))
@@ -1419,6 +1434,7 @@ gwy_app_file_chooser_do_full_preview(gpointer user_data)
                  "wrap-width", -1,
                  NULL);
 
+    add_cmap_thumbnails(chooser, data, cmap_ids, str);
     add_xyz_thumbnails(chooser, data, xyz_ids, str);
     add_volume_thumbnails(chooser, data, volume_ids, str);
     add_channel_thumbnails(chooser, data, channel_ids, str);
@@ -1429,6 +1445,7 @@ gwy_app_file_chooser_do_full_preview(gpointer user_data)
     g_free(sps_ids);
     g_free(volume_ids);
     g_free(xyz_ids);
+    g_free(cmap_ids);
     g_string_free(str, TRUE);
     g_object_unref(data);
 
@@ -1446,8 +1463,7 @@ modify_channel_for_preview(GwyContainer *data,
     if (!plane_level && !row_level)
         return;
 
-    if (!gwy_container_gis_object(data, gwy_app_get_data_key_for_id(id), &field)
-        || !GWY_IS_DATA_FIELD(field))
+    if (!gwy_container_gis_object(data, gwy_app_get_data_key_for_id(id), &field) || !GWY_IS_DATA_FIELD(field))
         return;
 
     if (plane_level) {
@@ -1493,8 +1509,7 @@ gwy_app_file_chooser_free_preview(GwyAppFileChooser *chooser)
     chooser->preview_name_sys = NULL;
 }
 
-/* Work around crashes in the file open dialog in some Gtk+ versions if no
- * .recently-used.xbel is present. */
+/* Work around crashes in the file open dialog in some Gtk+ versions if no .recently-used.xbel is present. */
 static void
 ensure_gtk_recently_used(void)
 {
@@ -1504,8 +1519,7 @@ ensure_gtk_recently_used(void)
     if (ensured)
         return;
 
-    filename = g_build_filename(g_get_user_data_dir(), ".recently-used.xbel",
-                                NULL);
+    filename = g_build_filename(g_get_user_data_dir(), ".recently-used.xbel", NULL);
     if (!g_file_test(filename, G_FILE_TEST_EXISTS)) {
         GBookmarkFile *bookmarkfile = g_bookmark_file_new();
         GError *error = NULL;
@@ -1520,4 +1534,4 @@ ensure_gtk_recently_used(void)
     ensured = TRUE;
 }
 
-/* vim: set cin et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
+/* vim: set cin columns=120 tw=118 et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
