@@ -1,5 +1,5 @@
 /*
- *  $Id: gwymoduleutils-synth.c 23714 2021-05-16 18:27:34Z yeti-dn $
+ *  $Id: gwymoduleutils-synth.c 24506 2021-11-10 17:11:58Z yeti-dn $
  *  Copyright (C) 2021 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -25,6 +25,18 @@
 #include "gwymoduleutils-synth.h"
 #include "param-internal.h"
 
+/**
+ * gwy_synth_define_dimensions_params:
+ * @paramdef: A set of parameter definitions.
+ * @first_id: First free id for the block of dimension parameters.
+ *
+ * Defines the standard set of dimension parameters for a data synthesis module.
+ *
+ * Parameters with ids starting from @first_id will become #GwySynthDimsParam paramers.  For instance @first_id
+ * + %GWY_DIMS_PARAMS_XREAL will be the id of the standard xreal parameter.
+ *
+ * Since: 2.59
+ **/
 void
 gwy_synth_define_dimensions_params(GwyParamDef *paramdef,
                                    gint first_id)
@@ -48,12 +60,27 @@ gwy_synth_define_dimensions_params(GwyParamDef *paramdef,
                               _("_Start from the current image"), FALSE);
 }
 
+/**
+ * gwy_synth_sanitise_params:
+ * @params: A set of parameter values.
+ * @first_id: First id of the block of dimension parameters.
+ * @template_: Template data field.  Normally it is the current image, or %NULL if there is no current image.
+ *
+ * Ensures a basic consistency the standard set of dimension parameters for a data synthesis module.
+ *
+ * This function also remembers @first_id and @template_ for @params.  Other helper functions then do not take these
+ * arguments, but you need to call this function to set up the association.  If the module has constrains on possible
+ * templates it has to ensure the template is valid; if the template is not valid pass %NULL instead.
+ *
+ * Since: 2.59
+ **/
 void
 gwy_synth_sanitise_params(GwyParams *params,
                           gint first_id,
                           GwyDataField *template_)
 {
-    gint xres, yres, xreal, yreal;
+    gdouble xreal, yreal;
+    gint xres, yres;
 
     g_return_if_fail(GWY_IS_PARAMS(params));
     g_return_if_fail(first_id >= 0);
@@ -93,6 +120,20 @@ gwy_synth_update_lateral_dimensions(GwyParamTable *partable)
     gwy_si_unit_value_format_free(vf);
 }
 
+/**
+ * gwy_synth_append_dimensions_to_param_table:
+ * @partable: Set of parameter value controls.
+ * @flags: Set of flags controlling the available parameters.
+ *
+ * Appends the standard set of dimension parameters for a data synthesis module to a parameter table.
+ *
+ * Usually, this is used to fill the content of a ‘Dimensions’ tab of the dialogue.
+ *
+ * The parameter table must be created for a set of parameters defined with gwy_synth_define_dimensions_params() and
+ * set up with gwy_synth_sanitise_params().
+ *
+ * Since: 2.59
+ **/
 void
 gwy_synth_append_dimensions_to_param_table(GwyParamTable *partable,
                                            GwySynthDimsFlags flags)
@@ -147,6 +188,19 @@ gwy_synth_append_dimensions_to_param_table(GwyParamTable *partable,
 /* XXX In cases like the MFM modules the caller is responsible for pre-filtering the templates.  If the template does
  * not match the fixed units it should behave as if there was no template.  Otherwise we can mess up the units here
  * completely. */
+/**
+ * gwy_synth_use_dimensions_template:
+ * @partable: Set of parameter value controls.
+ *
+ * Updates a set of dimension parameters for a data synthesis module to match the template.
+ *
+ * This will result in invocation of #GwyParamTable::param-changed signal with id -1.
+ *
+ * The parameter table must be created for a set of parameters defined with gwy_synth_define_dimensions_params() and
+ * set up with gwy_synth_sanitise_params() – this is where the template to use was defined.
+ *
+ * Since: 2.59
+ **/
 void
 gwy_synth_use_dimensions_template(GwyParamTable *partable)
 {
@@ -235,6 +289,21 @@ gwy_synth_make_dimensions_user_set(GwyParamTable *partable, gboolean user_set)
     }
 }
 
+/**
+ * gwy_synth_update_value_unitstrs:
+ * @partable: Set of parameter value controls.
+ * @ids: Array of parameter ids (controlled by @partable).
+ * @nids: The number of items in @ids.
+ *
+ * Updates unit strings of value-like parameters in a synth module parameter table.
+ *
+ * The parameters should be free-form value-like parameters, for instance heights.
+ *
+ * The parameter table must be created for a set of parameters defined with gwy_synth_define_dimensions_params() and
+ * set up with gwy_synth_sanitise_params().
+ *
+ * Since: 2.59
+ **/
 void
 gwy_synth_update_value_unitstrs(GwyParamTable *partable,
                                 const gint *ids,
@@ -259,6 +328,21 @@ gwy_synth_update_value_unitstrs(GwyParamTable *partable,
     gwy_si_unit_value_format_free(vf);
 }
 
+/**
+ * gwy_synth_update_lateral_alts:
+ * @partable: Set of parameter value controls.
+ * @ids: Array of parameter ids (controlled by @partable).
+ * @nids: The number of items in @ids.
+ *
+ * Updates unit strings of dimension-like parameters in a synth module parameter table.
+ *
+ * The parameters should be lateral pixel dimension parameters with alternative real dimensions.
+ *
+ * The parameter table must be created for a set of parameters defined with gwy_synth_define_dimensions_params() and
+ * set up with gwy_synth_sanitise_params().
+ *
+ * Since: 2.59
+ **/
 void
 gwy_synth_update_lateral_alts(GwyParamTable *partable,
                               const gint *ids,
@@ -291,6 +375,21 @@ gwy_synth_update_lateral_alts(GwyParamTable *partable,
     gwy_si_unit_value_format_free(vf);
 }
 
+/**
+ * gwy_synth_update_like_current_button_sensitivity:
+ * @partable: Set of parameter value controls.
+ * @id: Parameter id corresponding to the Like Current Image button.
+ *
+ * Updates the sensitivity of the standard Like Current Image button in a synth module parameter table.
+ *
+ * The buttons is made sensitive if the value units of the template data field match the selected value units. If
+ * there is no template the button is usually now show at all.  It is safe to call this function even in this case.
+ *
+ * The parameter table must be created for a set of parameters defined with gwy_synth_define_dimensions_params() and
+ * set up with gwy_synth_sanitise_params().
+ *
+ * Since: 2.59
+ **/
 void
 gwy_synth_update_like_current_button_sensitivity(GwyParamTable *partable,
                                                  gint id)
@@ -315,6 +414,21 @@ gwy_synth_update_like_current_button_sensitivity(GwyParamTable *partable,
     gwy_param_table_set_sensitive(partable, id, sens);
 }
 
+/**
+ * gwy_synth_handle_param_changed:
+ * @partable: Set of parameter value controls.
+ * @id: Changed parameter id (as obtained in the signal handler).
+ *
+ * Handles changes in a set of standard dimension parameters in a data synthesis module.
+ *
+ * The parameter table must be created for a set of parameters defined with gwy_synth_define_dimensions_params() and
+ * set up with gwy_synth_sanitise_params().
+ *
+ * Returns: %TRUE if the action taken was a mass parameter update.  The caller should then proceed as if @id was -1,
+ *          whether it was originally or not.
+ *
+ * Since: 2.59
+ **/
 gboolean
 gwy_synth_handle_param_changed(GwyParamTable *partable, gint id)
 {
@@ -384,6 +498,27 @@ gwy_synth_handle_param_changed(GwyParamTable *partable, gint id)
     return reset_dims;
 }
 
+/**
+ * gwy_synth_add_result_to_file:
+ * @result: Data field with the simulation output.
+ * @data: Data container corresponding to the current file, or %NULL is there is none.
+ * @id: Id or the current image (or -1 if there is none).
+ * @params: The set of parameter values for the synth module.
+ *
+ * Adds the result of data synthesis to a file.
+ *
+ * This function takes care of handling correctly the %GWY_DIMS_PARAM_REPLACE and %GWY_DIMS_PARAM_INITIALIZE options
+ * (the latter with regard to logging and sync; actual computation input is handled by the module) in the various
+ * cases such as @data and/or @id existing or not.
+ *
+ * The parameter value set must be created for a set of parameters defined with gwy_synth_define_dimensions_params()
+ * and set up with gwy_synth_sanitise_params().
+ *
+ * Returns: Data id of the result.  It can correspond a newly created image or an existing image, depending on the
+ *          settings.
+ *
+ * Since: 2.59
+ **/
 GwyAppDataId
 gwy_synth_add_result_to_file(GwyDataField *result,
                              GwyContainer *data,
@@ -438,6 +573,24 @@ gwy_synth_add_result_to_file(GwyDataField *result,
     return dataid;
 }
 
+/**
+ * gwy_synth_make_result_data_field:
+ * @data_field: Data field to be used as template, possibly %NULL.
+ * @params: The set of parameter values for the synth module.
+ * @always_use_template: %TRUE to always prefer creating a new data field matching @data_field, unless it is %NULL.
+ *
+ * Creates a data field for the output of a data synthesis module.
+ *
+ * The new data field properties match either @data_field or values of the dimension and unit parameters, depending
+ * on %GWY_DIMS_PARAM_REPLACE and %GWY_DIMS_PARAM_INITIALIZE (and also @always_use_template).
+ *
+ * The parameter value set must be created for a set of parameters defined with gwy_synth_define_dimensions_params()
+ * and set up with gwy_synth_sanitise_params().
+ *
+ * Returns: A newly created data field.
+ *
+ * Since: 2.59
+ **/
 GwyDataField*
 gwy_synth_make_result_data_field(GwyDataField *data_field, GwyParams *params,
                                  gboolean always_use_template)
@@ -472,6 +625,23 @@ gwy_synth_make_result_data_field(GwyDataField *data_field, GwyParams *params,
     return result;
 }
 
+/**
+ * gwy_synth_make_preview_data_field:
+ * @data_field: Data field to be used as template, possibly %NULL.
+ * @size: Pixel size of the result.
+ *
+ * Creates a suitable data field running a data synthesis module in the preview mode.
+ *
+ * The preview data field is created by a combination of cutting the central part of @data_field (if too large) and
+ * resampling it to higher resolution (if too small).  It will always be square, @size by @size.
+ *
+ * For some data synthesis modules is can make more sense to run even the preview for the actual image size.  Do not
+ * use this function in such case.
+ *
+ * Returns: A newly created data field.
+ *
+ * Since: 2.59
+ **/
 GwyDataField*
 gwy_synth_make_preview_data_field(GwyDataField *data_field,
                                   gint size)
@@ -504,6 +674,22 @@ gwy_synth_make_preview_data_field(GwyDataField *data_field,
     return retval;
 }
 
+/**
+ * gwy_synth_update_progress:
+ * @timer: A timer started together with the computation.  Pass %NULL to forget the last preview time.
+ * @preview_time: Minimum time between previews, in seconds.  Pass a non-positive value if previews are not animated.
+ * @i: Current iteration/cycle.  A monotonically increasing number.
+ * @niters: The total number of iterations/cycles.
+ *
+ * Manages progress bar updates and preview animation in a data synthesis module.
+ *
+ * This helper functions updates the progress bar to @i/@niters and check whether a preview should be done when it is
+ * animated.
+ *
+ * Returns: What should happen.
+ *
+ * Since: 2.59
+ **/
 GwySynthUpdateType
 gwy_synth_update_progress(GTimer *timer,
                           gdouble preview_time,
@@ -517,7 +703,7 @@ gwy_synth_update_progress(GTimer *timer,
     if (!timer) {
         lasttime = 0.0;
         lastpreviewtime = 0.0;
-        return TRUE;
+        return GWY_SYNTH_UPDATE_NOTHING;
     }
 
     currtime = g_timer_elapsed(timer, NULL);
@@ -536,4 +722,67 @@ gwy_synth_update_progress(GTimer *timer,
     return GWY_SYNTH_UPDATE_NOTHING;
 }
 
+/**
+ * SECTION:gwymoduleutils-synth
+ * @title: synth module utils
+ * @short_description: Helper functions for data synthesis modules
+ **/
+
+/**
+ * GwySynthResponseType:
+ * @GWY_RESPONSE_SYNTH_TAKE_DIMS: Take dimensions and units from the current image.
+ * @GWY_RESPONSE_SYNTH_INIT_Z: Set value scale to match the value scale of the current image.
+ *
+ * Dialog responses for buttons created by gwy_synth_append_dimensions_to_param_table().
+ *
+ * Since: 2.59
+ **/
+
+/**
+ * GwySynthDimsParam:
+ * @GWY_DIMS_PARAM_XRES: Horizontal pixel resolution.
+ * @GWY_DIMS_PARAM_YRES: Vertical pixel resolution.
+ * @GWY_DIMS_PARAM_SQUARE_IMAGE: Whether the image is square (pixelwise).
+ * @GWY_DIMS_PARAM_XREAL: Horizontal physical dimension, in base SI units.
+ * @GWY_DIMS_PARAM_YREAL: Vertical physical dimension, in base SI units.
+ * @GWY_DIMS_PARAM_SQUARE_PIXELS: Whether pixels are physically square.
+ * @GWY_DIMS_PARAM_XYUNIT: Unit of lateral dimensions.
+ * @GWY_DIMS_PARAM_ZUNIT: Unit of values.
+ * @GWY_DIMS_PARAM_REPLACE: Whether the simulation result should replace the current image.
+ * @GWY_DIMS_PARAM_INITIALIZE: Whether the simulation should start from the current image.
+ * @GWY_DIMS_BUTTON_TAKE: Button Like Current Image.
+ * @GWY_DIMS_HEADER_PIXEL: Header for the pixel dimensions section.
+ * @GWY_DIMS_HEADER_PHYSICAL: Header for the physical dimensions section.
+ * @GWY_DIMS_HEADER_UNITS: Header for the unit section.
+ * @GWY_DIMS_HEADER_CURRENT_IMAGE: Header for the Current Image section.
+ *
+ * Ids of parameters created by gwy_synth_define_dimensions_params().
+ *
+ * The enum also includes a few GUI elements to satisfy the id uniqueness required by #GwyParamTable.
+ *
+ * Since: 2.59
+ **/
+
+/**
+ * GwySynthDimsFlags:
+ * @GWY_SYNTH_FIXED_XYUNIT: The lateral unit is fixed and cannot be set by the user.
+ * @GWY_SYNTH_FIXED_ZUNIT: The value unit is fixed and cannot be set by the user.
+ * @GWY_SYNTH_FIXED_UNITS: No units can be set by the uset.
+ *
+ * Possible flags passed to gwy_synth_append_dimensions_to_param_table().
+ *
+ * Since: 2.59
+ **/
+
+/**
+ * GwySynthUpdateType:
+ * @GWY_SYNTH_UPDATE_CANCELLED: The computation was cancelled by the user.
+ * @GWY_SYNTH_UPDATE_NOTHING: Nothing has changed; proceed with computation.
+ * @GWY_SYNTH_UPDATE_DO_PREVIEW: Render a preview of the current computation state.
+ *
+ * Possible return values from gwy_synth_update_progress().
+ *
+ * Since: 2.59
+ **/
+
 /* vim: set cin columns=120 tw=118 et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
