@@ -1,5 +1,5 @@
 /*
- *  $Id: gwymoduleutils.c 23755 2021-05-21 11:16:58Z yeti-dn $
+ *  $Id: gwymoduleutils.c 24406 2021-10-22 14:00:58Z yeti-dn $
  *  Copyright (C) 2007-2021 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -65,7 +65,7 @@ gwy_save_auxiliary_data_create(gpointer user_data,
  *
  * This is actually a simple gwy_save_auxiliary_with_callback() wrapper, see its description for details.
  *
- * Returns: %TRUE if the data was save, %FALSE if it was not saved for any reason.
+ * Returns: %TRUE if the data was saved, %FALSE if it was not saved for any reason.
  *
  * Since: 2.3
  **/
@@ -94,7 +94,7 @@ gwy_save_auxiliary_data(const gchar *title,
  *
  * Saves a report or other auxiliary data to a user specified file.
  *
- * Returns: %TRUE if the data was save, %FALSE if it was not saved for any reason (I/O error, cancellation, overwrite
+ * Returns: %TRUE if the data was saved, %FALSE if it was not saved for any reason (I/O error, cancellation, overwrite
  *          cancellation, etc.).
  *
  * Since: 2.3
@@ -241,8 +241,10 @@ ensure_module_directory(const gchar *userdir,
     gchar *path;
 
     path = g_build_filename(userdir, modname, NULL);
-    if (g_file_test(path, G_FILE_TEST_IS_DIR))
+    if (g_file_test(path, G_FILE_TEST_IS_DIR)) {
+        g_free(path);
         return TRUE;
+    }
 
     if (g_mkdir(path, 0700) == 0) {
         g_free(path);
@@ -546,6 +548,42 @@ gwy_app_data_id_verify_xyz(GwyAppDataId *id)
     return TRUE;
 }
 
+/**
+ * gwy_app_data_id_verify_curve_map:
+ * @id: Numerical identifiers of curve map data in data managed by the data browser.
+ *
+ * Checks if numerical curve map data identifiers correspond to existing curve map data.
+ *
+ * If either the data contained referenced in @id or the curve map data does not exist the structure is cleared to
+ * %GWY_APP_DATA_ID_NONE and the function returns %FALSE.  If it represents existing curve map data it is kept intact
+ * and the function returns %TRUE.
+ *
+ * Returns: Whether @id refers to existing curve map data now.
+ *
+ * Since: 2.46
+ **/
+gboolean
+gwy_app_data_id_verify_curve_map(GwyAppDataId *id)
+{
+    GwyContainer *container;
+    GObject *object;
+    GQuark quark;
+
+    g_return_val_if_fail(id, FALSE);
+
+    container = gwy_app_data_browser_get(id->datano);
+    if (!container)
+        return clear_data_id(id);
+
+    quark = gwy_app_get_lawn_key_for_id(id->id);
+    if (!gwy_container_gis_object(container, quark, &object))
+        return clear_data_id(id);
+    if (!GWY_IS_LAWN(object))
+        return clear_data_id(id);
+
+    return TRUE;
+}
+
 /**
  * gwy_app_data_id_verify_spectra:
  * @id: Numerical identifiers of spectra in data managed by the data browser.
