@@ -1,5 +1,5 @@
 /*
- *  $Id: gwymoduleutils.h 23714 2021-05-16 18:27:34Z yeti-dn $
+ *  $Id: gwymoduleutils.h 24086 2021-09-06 20:51:57Z yeti-dn $
  *  Copyright (C) 2007-2021 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -21,6 +21,7 @@
 #include <stdio.h>
 #include <gtk/gtkwindow.h>
 #include <libprocess/surface.h>
+#include <libprocess/lawn.h>
 #include <libgwydgets/gwydataview.h>
 #include <libgwydgets/gwygraphmodel.h>
 #include <app/datachooser.h>
@@ -97,6 +98,7 @@ gboolean   gwy_app_data_id_verify_channel        (GwyAppDataId *id);
 gboolean   gwy_app_data_id_verify_graph          (GwyAppDataId *id);
 gboolean   gwy_app_data_id_verify_volume         (GwyAppDataId *id);
 gboolean   gwy_app_data_id_verify_xyz            (GwyAppDataId *id);
+gboolean   gwy_app_data_id_verify_curve_map      (GwyAppDataId *id);
 gboolean   gwy_app_data_id_verify_spectra        (GwyAppDataId *id);
 
 G_END_DECLS
