@@ -1,5 +1,5 @@
 /*
- *  $Id: gwyplaintool.c 22701 2020-01-14 10:54:45Z yeti-dn $
+ *  $Id: gwyplaintool.c 23208 2021-03-08 15:55:47Z yeti-dn $
  *  Copyright (C) 2006-2019 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -620,11 +620,8 @@ gwy_plain_tool_connect_selection(GwyPlainTool *plain_tool,
     }
 
     gwy_plain_tool_selection_disconnect(plain_tool);
-    g_free(plain_tool->selection_bname);
-    plain_tool->selection_bname = NULL;
-
+    gwy_assign_string(&plain_tool->selection_bname, bname);
     plain_tool->layer_type = layer_type;
-    plain_tool->selection_bname = g_strdup(bname);
 
     if (!bname || !layer_type || !plain_tool->data_view)
         return;
