@@ -1,22 +1,18 @@
 /*
- *  $Id: gwyresultsexport.c 23208 2021-03-08 15:55:47Z yeti-dn $
- *  Copyright (C) 2017-2019 David Necas (Yeti).
+ *  $Id: gwyresultsexport.c 24267 2021-10-07 08:19:51Z rsleza $
+ *  Copyright (C) 2017-2021 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
+ *  License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any
+ *  later version.
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
+ *  warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+ *  details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
+ *  You should have received a copy of the GNU General Public License along with this program; if not, write to the
+ *  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #include "config.h"
@@ -74,9 +70,8 @@ gwy_results_export_class_init(GwyResultsExportClass *klass)
     klass->save = gwy_results_export_save_impl;
     klass->copy = gwy_results_export_copy_impl;
 
-    /* NB: "copy" and "save" signals are created with LAST flag so that user's
-     * handlers are run before save_impl() and copy_impl() and have a chance to
-     * update the results. */
+    /* NB: "copy" and "save" signals are created with LAST flag so that user's handlers are run before save_impl() and
+     * copy_impl() and have a chance to update the results. */
 
     /**
      * GwyResultsExport::copy:
@@ -139,9 +134,7 @@ create_image_button(GwyResultsExport *rexport, GtkTooltips *tips,
     button = gtk_button_new();
     gtk_button_set_relief(GTK_BUTTON(button), GTK_RELIEF_NONE);
     gtk_tooltips_set_tip(tips, button, tooltip, NULL);
-    gtk_container_add(GTK_CONTAINER(button),
-                      gtk_image_new_from_stock(stock_id,
-                                               GTK_ICON_SIZE_SMALL_TOOLBAR));
+    gtk_container_add(GTK_CONTAINER(button), gtk_image_new_from_stock(stock_id, GTK_ICON_SIZE_SMALL_TOOLBAR));
     gtk_box_pack_end(GTK_BOX(rexport), button, FALSE, FALSE, 0);
 
     return button;
@@ -173,9 +166,7 @@ create_image_toggle(GwyResultsExport *rexport, GtkTooltips *tips,
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), active);
     gtk_button_set_relief(GTK_BUTTON(button), GTK_RELIEF_NONE);
     gtk_tooltips_set_tip(tips, button, tooltip, NULL);
-    gtk_container_add(GTK_CONTAINER(button),
-                      gtk_image_new_from_stock(stock_id,
-                                               GTK_ICON_SIZE_SMALL_TOOLBAR));
+    gtk_container_add(GTK_CONTAINER(button), gtk_image_new_from_stock(stock_id, GTK_ICON_SIZE_SMALL_TOOLBAR));
     gtk_box_pack_end(GTK_BOX(rexport), button, FALSE, FALSE, 0);
 
     return button;
@@ -186,8 +177,7 @@ gwy_results_export_init(GwyResultsExport *rexport)
 {
     ResultsExportPriv *priv;
 
-    priv = G_TYPE_INSTANCE_GET_PRIVATE(rexport, GWY_TYPE_RESULTS_EXPORT,
-                                       ResultsExportPriv);
+    priv = G_TYPE_INSTANCE_GET_PRIVATE(rexport, GWY_TYPE_RESULTS_EXPORT, ResultsExportPriv);
     rexport->priv = priv;
     rexport->format = GWY_RESULTS_REPORT_COLON;
     rexport->style = GWY_RESULTS_EXPORT_PARAMETERS;
@@ -298,14 +288,10 @@ gwy_results_export_new(GwyResultsReportType format)
     priv = rexport->priv;
 
     tips = gwy_app_get_tooltips();
-    rexport->save = create_image_button(rexport, tips, GTK_STOCK_SAVE,
-                                        _("Save results to a file"));
-    rexport->copy = create_image_button(rexport, tips, GTK_STOCK_COPY,
-                                        _("Copy results to clipboard"));
-    g_signal_connect_swapped(rexport->save, "clicked",
-                             G_CALLBACK(gwy_results_export_save), rexport);
-    g_signal_connect_swapped(rexport->copy, "clicked",
-                             G_CALLBACK(gwy_results_export_copy), rexport);
+    rexport->save = create_image_button(rexport, tips, GTK_STOCK_SAVE, _("Save results to a file"));
+    rexport->copy = create_image_button(rexport, tips, GTK_STOCK_COPY, _("Copy results to clipboard"));
+    g_signal_connect_swapped(rexport->save, "clicked", G_CALLBACK(gwy_results_export_save), rexport);
+    g_signal_connect_swapped(rexport->copy, "clicked", G_CALLBACK(gwy_results_export_copy), rexport);
 
     rexport->format = format;
     priv->updating = TRUE;
@@ -347,9 +333,7 @@ update_format_controls(GwyResultsExport *rexport)
     }
 
     tips = gwy_app_get_tooltips();
-    gtk_container_child_get(GTK_CONTAINER(rexport), rexport->copy,
-                            "position", &copypos,
-                            NULL);
+    gtk_container_child_get(GTK_CONTAINER(rexport), rexport->copy, "position", &copypos, NULL);
     if (priv->format) {
         model = gtk_combo_box_get_model(GTK_COMBO_BOX(priv->format));
         nformats = gtk_tree_model_iter_n_children(model, NULL);
@@ -368,8 +352,7 @@ update_format_controls(GwyResultsExport *rexport)
         off = (wantnformats == 2) ? 1 : 0;
         if (priv->format)
             gtk_widget_destroy(priv->format);
-        combo = gwy_enum_combo_box_new(formats + off, wantnformats,
-                                       G_CALLBACK(format_changed), rexport,
+        combo = gwy_enum_combo_box_new(formats + off, wantnformats, G_CALLBACK(format_changed), rexport,
                                        base_format, TRUE);
         priv->format = combo;
         gtk_tooltips_set_tip(tips, combo, _("Result formatting"), NULL);
@@ -380,12 +363,9 @@ update_format_controls(GwyResultsExport *rexport)
 
     if (!priv->machine) {
         is_machine = rexport->format & GWY_RESULTS_REPORT_MACHINE;
-        priv->machine = create_image_toggle(rexport, tips,
-                                            GWY_STOCK_SCIENTIFIC_NUMBER_FORMAT,
-                                            _("Machine-readable format"),
-                                            is_machine);
-        g_signal_connect_swapped(priv->machine, "toggled",
-                                 G_CALLBACK(machine_changed), rexport);
+        priv->machine = create_image_toggle(rexport, tips, GWY_STOCK_SCIENTIFIC_NUMBER_FORMAT,
+                                            _("Machine-readable format"), is_machine);
+        g_signal_connect_swapped(priv->machine, "toggled", G_CALLBACK(machine_changed), rexport);
     }
 
     /* The format might not changed but was kind of undefined.  Emit a signal
@@ -424,10 +404,8 @@ gwy_results_export_set_format(GwyResultsExport *rexport,
     g_return_if_fail(!rexport->priv->updating);
     rexport->format = format;
     rexport->priv->updating = TRUE;
-    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(rexport->priv->machine),
-                                 for_machine);
-    gwy_enum_combo_box_set_active(GTK_COMBO_BOX(rexport->priv->format),
-                                  base_format);
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(rexport->priv->machine), for_machine);
+    gwy_enum_combo_box_set_active(GTK_COMBO_BOX(rexport->priv->format), base_format);
     rexport->priv->updating = FALSE;
 }
 
@@ -455,9 +433,8 @@ gwy_results_export_get_format(GwyResultsExport *rexport)
  *
  * Sets the set of scalar values to save or copy by result set export controls.
  *
- * If you supply a result set to save or copy @rexport handles the Save and
- * Copy buttons itself.  So you do not need to connect to the "copy" and "save"
- * signals, except if you need to ensure @results are updated.
+ * If you supply a result set to save or copy @rexport handles the Save and Copy buttons itself.  So you do not need
+ * to connect to the "copy" and "save" signals, except if you need to ensure @results are updated.
  *
  * Since: 2.50
  **/
@@ -521,11 +498,9 @@ gwy_results_export_set_title(GwyResultsExport *rexport,
  *
  * Sets the report style for result set export controls.
  *
- * The report style determines which controls will be shown.  For
- * %GWY_RESULTS_EXPORT_FIXED_FORMAT only the action buttons are shown.
- * Tabular data (%GWY_RESULTS_EXPORT_TABULAR_DATA) do not have the
- * %GWY_RESULTS_REPORT_COLON option.  The default style
- * %GWY_RESULTS_EXPORT_PARAMETERS have the full controls.
+ * The report style determines which controls will be shown.  For %GWY_RESULTS_EXPORT_FIXED_FORMAT only the action
+ * buttons are shown. Tabular data (%GWY_RESULTS_EXPORT_TABULAR_DATA) do not have the %GWY_RESULTS_REPORT_COLON
+ * option.  The default style %GWY_RESULTS_EXPORT_PARAMETERS have the full controls.
  *
  * Since: 2.50
  **/
@@ -553,22 +528,19 @@ gwy_results_export_set_style(GwyResultsExport *rexport,
 GwyResultsExportStyle
 gwy_results_export_get_style(GwyResultsExport *rexport)
 {
-    g_return_val_if_fail(GWY_IS_RESULTS_EXPORT(rexport),
-                         GWY_RESULTS_EXPORT_PARAMETERS);
+    g_return_val_if_fail(GWY_IS_RESULTS_EXPORT(rexport), GWY_RESULTS_EXPORT_PARAMETERS);
     return rexport->style;
 }
 
 /**
  * gwy_results_export_set_actions_sensitive:
  * @rexport: Controls for result set export.
- * @sensitive: %TRUE to make the action buttons sensitive, %FALSE to make them
- *             insensitive.
+ * @sensitive: %TRUE to make the action buttons sensitive, %FALSE to make them insensitive.
  *
  * Makes the action buttons (copy and save) sensitive or insensitive.
  *
- * This is generally preferred to making the entire widget insensitive as the
- * format can be selected independently on whether there is already anything
- * to export.
+ * This is generally preferred to making the entire widget insensitive as the format can be selected independently on
+ * whether there is already anything to export.
  *
  * Since: 2.50
  **/
@@ -614,8 +586,7 @@ gwy_results_fill_filename(GwyResults *results,
     g_return_if_fail(GWY_IS_RESULTS(results));
     g_return_if_fail(id);
     g_return_if_fail(GWY_IS_CONTAINER(container));
-    fill_result_string_from_container(results, id, container,
-                                      g_quark_from_static_string("/filename"));
+    fill_result_string_from_container(results, id, container, g_quark_from_static_string("/filename"));
 }
 
 /**
@@ -627,8 +598,7 @@ gwy_results_fill_filename(GwyResults *results,
  *
  * Fills image channel title in a set of reported scalar values.
  *
- * This is a helper function for #GwyResults.  If the image has no title the
- * associated the value @id is set to N.A.
+ * This is a helper function for #GwyResults.  If the image has no title the associated the value @id is set to N.A.
  *
  * Since: 2.50
  **/
@@ -641,8 +611,7 @@ gwy_results_fill_channel(GwyResults *results,
     g_return_if_fail(GWY_IS_RESULTS(results));
     g_return_if_fail(id);
     g_return_if_fail(GWY_IS_CONTAINER(container));
-    fill_result_string_from_container(results, id, container,
-                                      gwy_app_get_data_title_key_for_id(i));
+    fill_result_string_from_container(results, id, container, gwy_app_get_data_title_key_for_id(i));
 }
 
 /**
@@ -654,8 +623,8 @@ gwy_results_fill_channel(GwyResults *results,
  *
  * Fills volume data title in a set of reported scalar values.
  *
- * This is a helper function for #GwyResults.  If the volume data have no title
- * the associated the value @id is set to N.A.
+ * This is a helper function for #GwyResults.  If the volume data have no title the associated the value @id is set to
+ * N.A.
  *
  * Since: 2.50
  **/
@@ -668,8 +637,7 @@ gwy_results_fill_volume(GwyResults *results,
     g_return_if_fail(GWY_IS_RESULTS(results));
     g_return_if_fail(id);
     g_return_if_fail(GWY_IS_CONTAINER(container));
-    fill_result_string_from_container(results, id, container,
-                                      gwy_app_get_brick_title_key_for_id(i));
+    fill_result_string_from_container(results, id, container, gwy_app_get_brick_title_key_for_id(i));
 }
 
 /**
@@ -681,8 +649,8 @@ gwy_results_fill_volume(GwyResults *results,
  *
  * Fills XYZ data title in a set of reported scalar values.
  *
- * This is a helper function for #GwyResults.  If the XYZ data have no title
- * the associated the value @id is set to N.A.
+ * This is a helper function for #GwyResults.  If the XYZ data have no title the associated the value @id is set to
+ * N.A.
  *
  * Since: 2.50
  **/
@@ -695,8 +663,33 @@ gwy_results_fill_xyz(GwyResults *results,
     g_return_if_fail(GWY_IS_RESULTS(results));
     g_return_if_fail(id);
     g_return_if_fail(GWY_IS_CONTAINER(container));
-    fill_result_string_from_container(results, id, container,
-                                      gwy_app_get_surface_title_key_for_id(i));
+    fill_result_string_from_container(results, id, container, gwy_app_get_surface_title_key_for_id(i));
+}
+
+/**
+ * gwy_results_fill_curve_map:
+ * @results: Set of reported scalar values.
+ * @id: Value identifier.
+ * @container: Data container corresponding to a file.
+ * @i: Curve map data number.
+ *
+ * Fills curve map data title in a set of reported scalar values.
+ *
+ * This is a helper function for #GwyResults.  If the curve map data have no title the associated the value @id is set
+ * to N.A.
+ *
+ * Since: 2.60
+ **/
+void
+gwy_results_fill_curve_map(GwyResults *results,
+                           const gchar *id,
+                           GwyContainer *container,
+                           gint i)
+{
+    g_return_if_fail(GWY_IS_RESULTS(results));
+    g_return_if_fail(id);
+    g_return_if_fail(GWY_IS_CONTAINER(container));
+    fill_result_string_from_container(results, id, container, gwy_app_get_lawn_title_key_for_id(i));
 }
 
 /**
@@ -756,6 +749,42 @@ gwy_results_fill_graph_curve(GwyResults *results,
     g_free(title);
 }
 
+/**
+ * gwy_results_fill_lawn_curve:
+ * @results: Set of reported scalar values.
+ * @id: Value identifier.
+ * @lawn: Curve map data object.
+ * @i: Curve number in @lawn.
+ *
+ * Fills lawn curve description in a set of reported scalar values.
+ *
+ * This is a helper function for #GwyResults.
+ *
+ * Since: 2.60
+ **/
+void
+gwy_results_fill_lawn_curve(GwyResults *results,
+                            const gchar *id,
+                            GwyLawn *lawn,
+                            gint i)
+{
+    const gchar *title;
+    gchar *s;
+
+    g_return_if_fail(GWY_IS_LAWN(lawn));
+    g_return_if_fail(GWY_IS_RESULTS(results));
+    g_return_if_fail(id);
+    g_return_if_fail(i >= 0 && i < gwy_lawn_get_n_curves(lawn));
+
+    if ((title = gwy_lawn_get_curve_label(lawn, i)))
+        gwy_results_fill_values(results, id, title, NULL);
+    else {
+        s = g_strdup_printf("%s %d", _("Untitled"), i);
+        gwy_results_fill_values(results, id, s, NULL);
+        g_free(s);
+    }
+}
+
 /************************** Documentation ****************************/
 
 /**
@@ -764,4 +793,4 @@ gwy_results_fill_graph_curve(GwyResults *results,
  * @short_description: Controls for value set export
  **/
 
-/* vim: set cin et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
+/* vim: set cin columns=120 tw=118 et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
