@@ -1,22 +1,18 @@
 /*
- *  $Id: gwyresultsexport.h 21874 2019-02-04 07:46:10Z yeti-dn $
- *  Copyright (C) 2017-2019 David Necas (Yeti).
+ *  $Id: gwyresultsexport.h 24262 2021-10-06 15:38:12Z yeti-dn $
+ *  Copyright (C) 2017-2021 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
+ *  License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any
+ *  later version.
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
+ *  warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+ *  details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
+ *  You should have received a copy of the GNU General Public License along with this program; if not, write to the
+ *  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #ifndef __GWY_RESULTS_EXPORT_H__
@@ -26,6 +22,7 @@
 #include <libgwyddion/gwyresults.h>
 #include <libgwyddion/gwycontainer.h>
 #include <libgwydgets/gwygraphmodel.h>
+#include <libprocess/lawn.h>
 
 G_BEGIN_DECLS
 
@@ -105,16 +102,23 @@ void                  gwy_results_fill_xyz                    (GwyResults *resul
                                                                const gchar *id,
                                                                GwyContainer *container,
                                                                gint i);
+void                  gwy_results_fill_curve_map              (GwyResults *results,
+                                                               const gchar *id,
+                                                               GwyContainer *container,
+                                                               gint i);
 void                  gwy_results_fill_graph                  (GwyResults *results,
                                                                const gchar *id,
                                                                GwyGraphModel *graphmodel);
 void                  gwy_results_fill_graph_curve            (GwyResults *results,
                                                                const gchar *id,
                                                                GwyGraphCurveModel *curvemodel);
+void                  gwy_results_fill_lawn_curve             (GwyResults *results,
+                                                               const gchar *id,
+                                                               GwyLawn *lawn,
+                                                               gint i);
 
 G_END_DECLS
 
 #endif /* __GWY_RESULTS_EXPORT_H__ */
 
-/* vim: set cin et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
-
+/* vim: set cin columns=120 tw=118 et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
