@@ -1,22 +1,18 @@
 /*
- *  $Id: help.c 22534 2019-10-02 08:35:40Z yeti-dn $
- *  Copyright (C) 2014-2017 David Necas (Yeti).
+ *  $Id: help.c 24485 2021-11-07 21:02:59Z yeti-dn $
+ *  Copyright (C) 2014-2021 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
+ *  License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any
+ *  later version.
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
+ *  warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+ *  details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
+ *  You should have received a copy of the GNU General Public License along with this program; if not, write to the
+ *  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #include "config.h"
@@ -42,8 +38,7 @@ typedef struct {
     const gchar *fragment;
 } HelpURI;
 
-/* The function is expected to just return TRUE if @uri is NULL but the backend
- * seems to be available. */
+/* The function is expected to just return TRUE if @uri is NULL but the backend seems to be available. */
 typedef gboolean (*ShowUriFunc)(const gchar *uri, gboolean complain);
 
 static gboolean show_uri_win32   (const gchar *uri, gboolean complain);
@@ -76,15 +71,12 @@ show_uri_win32(G_GNUC_UNUSED const gchar *uri, gboolean complain)
         CoInitializeEx(NULL, COINIT_APARTMENTTHREADED | COINIT_DISABLE_OLE1DDE);
     }
 
-    /* XXX: The first arg is handle to the window.  May want to pass it.
-     * Apparenly gdk_win32_window_get_impl_hwnd() can provide it but this is
-     * a late addition to Gdk, must check availability properly. */
+    /* XXX: The first arg is handle to the window.  May want to pass it. Apparenly gdk_win32_window_get_impl_hwnd()
+     * can provide it but this is a late addition to Gdk, must check availability properly. */
     status = (INT_PTR)ShellExecute(NULL, NULL, uri, NULL, NULL, SW_SHOWNORMAL);
     ok = status > 32;  /* Otherwise it's the error code. */
-    if (!ok && complain) {
-        g_warning("Help ShellExecute() for URI `%s' failed with code %d.",
-                  uri, (gint)status);
-    }
+    if (!ok && complain)
+        g_warning("Help ShellExecute() for URI `%s' failed with code %d.", uri, (gint)status);
     return ok;
 #else
     if (complain)
@@ -102,17 +94,15 @@ show_uri_gtk(G_GNUC_UNUSED const gchar *uri, gboolean complain)
     GError *error = NULL;
     gboolean ok;
 
-    /* This may not be the whole story because GVfs may not support our URI
-     * scheme.  But leave this to the diagnosis when things fail to work. */
+    /* This may not be the whole story because GVfs may not support our URI scheme.  But leave this to the diagnosis
+     * when things fail to work. */
     if (!uri)
         return TRUE;
 
     ok = gtk_show_uri(NULL, uri, GDK_CURRENT_TIME, &error);
     if (!ok) {
-        if (complain) {
-            g_warning("Help gtk_show_uri() for URI `%s' failed with: %s",
-                      uri, error->message);
-        }
+        if (complain)
+            g_warning("Help gtk_show_uri() for URI `%s' failed with: %s", uri, error->message);
         g_clear_error(&error);
     }
     return ok;
@@ -160,20 +150,17 @@ show_uri_open(G_GNUC_UNUSED const gchar *uri,
 {
 #ifndef G_OS_WIN32
     static const gchar *programs[] = {
-        /* OS X has this little program called "open".  Sure, other systems
-         * have it too but it does something completely different.  So only
-         * use "open" on OS X. */
+        /* OS X has this little program called "open".  Sure, other systems have it too but it does something
+         * completely different.  So only use "open" on OS X. */
 #ifdef __APPLE__
         "open",
 #endif
         "xdg-open", "sensible-browser", "x-www-browser",
-        /* Do not run things like gnome-open, kde-open, exo-open, etc. Who
-         * knows if they belong to the active desktop environment.  Normally,
-         * people having these will also have xdg-open nowadays. */
+        /* Do not run things like gnome-open, kde-open, exo-open, etc. Who knows if they belong to the active desktop
+         * environment.  Normally, people having these will also have xdg-open nowadays. */
     };
 
-    return show_uri_spawn_program(uri, programs, G_N_ELEMENTS(programs),
-                                  complain);
+    return show_uri_spawn_program(uri, programs, G_N_ELEMENTS(programs), complain);
 #else
     return FALSE;
 #endif
@@ -185,18 +172,17 @@ show_uri_browsers(G_GNUC_UNUSED const gchar *uri,
 {
 #ifndef G_OS_WIN32
     static const gchar *programs[] = {
-        /* Not worth trying platform browsers (safari, iexplore) probably as
-         * we would get them using the platform open-mechanism. */
+        /* Not worth trying platform browsers (safari, iexplore) probably as we would get them using the platform
+         * open-mechanism. */
         "firefox", "seamonkey", "mozilla",
         "google-chrome", "chromium-browser",
+        "palemoon", "waterfox", "basilisk",
         "konqueror",
         "midori", "epiphany",
         "opera",
-        "dillo",
     };
 
-    return show_uri_spawn_program(uri, programs, G_N_ELEMENTS(programs),
-                                  complain);
+    return show_uri_spawn_program(uri, programs, G_N_ELEMENTS(programs), complain);
 #else
     return FALSE;
 #endif
@@ -243,20 +229,15 @@ show_help_uri(GtkWindow *parent, const gchar *uri)
             return TRUE;
     }
 
-    dialog = gtk_message_dialog_new(parent,
-                                    GTK_DIALOG_MODAL
-                                    | GTK_DIALOG_DESTROY_WITH_PARENT,
-                                    GTK_MESSAGE_ERROR,
-                                    GTK_BUTTONS_CLOSE,
+    dialog = gtk_message_dialog_new(parent, GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+                                    GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE,
                                     _("Cannot display the help."));
     gtk_message_dialog_format_secondary_text(GTK_MESSAGE_DIALOG(dialog),
     /* TRANSLATORS: %s will be replaced with an URL. */
                                              _("No working method to show\n"
                                                "%s\n"
-                                               "in a web browser was found. "
-                                               "Details about the attempts "
-                                               "can be found in the console "
-                                               "or gwyddion.log."),
+                                               "in a web browser was found. Details about the attempts "
+                                               "can be found in the console or gwyddion.log."),
                                              uri);
     gtk_dialog_run(GTK_DIALOG(dialog));
     gtk_widget_destroy(dialog);
@@ -352,8 +333,8 @@ get_user_guide_online_base(void)
     /* We know we have these guides available. */
     static const gchar *user_guides[] = { "en", "fr", "ru" };
 
-    /* TRANSLATORS: For user guide location.  Translate this to fr, ru, cs,
-       de, ...  even if the corresponding guide does not exist. */
+    /* TRANSLATORS: For user guide location.  Translate this to fr, ru, cs, de, ...  even if the corresponding guide
+     * does not exist. */
     const gchar *lang = gwy_sgettext("current-language-code|en");
     guint i;
 
@@ -373,8 +354,7 @@ starts_with_drive_letter(const gchar *path)
 }
 #endif
 
-/* If an URI points to a local file, check if it exists.  Otherwise just assume
- * it exists. */
+/* If an URI points to a local file, check if it exists.  Otherwise just assume it exists. */
 static gboolean
 check_local_file_uri(const gchar *uri)
 {
@@ -427,11 +407,8 @@ check_local_file_uri(const gchar *uri)
     len = strlen(uri);
     decoded = g_new(gchar, len+1);
     for (i = j = 0; i < len; i++) {
-        if (uri[i] == '%'
-            && g_ascii_isdigit(uri[i+1])
-            && g_ascii_isdigit(uri[i+2])) {
-            decoded[j++] = (16*g_ascii_xdigit_value(uri[i+1])
-                            + g_ascii_xdigit_value(uri[i+2]));
+        if (uri[i] == '%' && g_ascii_isdigit(uri[i+1]) && g_ascii_isdigit(uri[i+2])) {
+            decoded[j++] = (16*g_ascii_xdigit_value(uri[i+1]) + g_ascii_xdigit_value(uri[i+2]));
             i += 2;
         }
         else
@@ -457,9 +434,7 @@ get_user_guide_settings_base(void)
     guint len;
     gchar *base;
 
-    if (!gwy_container_gis_string_by_name(settings,
-                                          "/app/help/user-guide-base",
-                                          &settingsugbase))
+    if (!gwy_container_gis_string_by_name(settings, "/app/help/user-guide-base", &settingsugbase))
         return NULL;
 
     base = g_strdup(settingsugbase);
@@ -497,11 +472,15 @@ build_uri_for_function(const gchar *type, const gchar *funcname)
         userguidemap = build_function_module_map();
 
     qname = g_strconcat(type, "::", funcname, NULL);
-    modname = g_hash_table_lookup(userguidemap, qname);
-    g_free(qname);
-    g_return_val_if_fail(modname, NULL);
-
-    helpuri = get_uri_path_for_module(modname);
+    /* Try to look up the qualified function name directly first.  This is used to match functions which are provided
+     * by one module but have separate documentations.  In most cases the module just has an entry as a whole so we
+     * try to look up the module next. */
+    if (!(helpuri = get_uri_path_for_module(qname))) {
+        modname = g_hash_table_lookup(userguidemap, qname);
+        g_free(qname);
+        g_return_val_if_fail(modname, NULL);
+        helpuri = get_uri_path_for_module(modname);
+    }
     if (!helpuri)
         return NULL;
 
@@ -543,8 +522,7 @@ key_press_event(GtkWidget *widget,
 {
     const gchar *uri = (const gchar*)user_data;
 
-    if ((event->keyval != GDK_Help
-         && event->keyval != GDK_F1)
+    if ((event->keyval != GDK_Help && event->keyval != GDK_F1)
         || (event->state & (GDK_SHIFT_MASK | GDK_CONTROL_MASK | GDK_MOD1_MASK)))
         return FALSE;
 
@@ -567,21 +545,17 @@ add_help_to_window(GtkWindow *window,
 
     if (g_object_get_data(G_OBJECT(window), "gwy-help-uri")) {
         g_warning("Window %p already has help URI: %s",
-                  window,
-                  (gchar*)g_object_get_data(G_OBJECT(window), "gwy-help-uri"));
+                  window, (gchar*)g_object_get_data(G_OBJECT(window), "gwy-help-uri"));
         g_free(uri);
         return;
     }
     g_object_set_data(G_OBJECT(window), "gwy-help-uri", uri);
 
     if (!(flags & GWY_HELP_NO_BUTTON) && GTK_IS_DIALOG(window)) {
-        gtk_dialog_add_button(GTK_DIALOG(window),
-                              GTK_STOCK_HELP, GTK_RESPONSE_HELP);
-        g_signal_connect(window, "response",
-                         G_CALLBACK(dialog_response), uri);
+        gtk_dialog_add_button(GTK_DIALOG(window), GTK_STOCK_HELP, GTK_RESPONSE_HELP);
+        g_signal_connect(window, "response", G_CALLBACK(dialog_response), uri);
     }
-    g_signal_connect(window, "key-press-event",
-                     G_CALLBACK(key_press_event), uri);
+    g_signal_connect(window, "key-press-event", G_CALLBACK(key_press_event), uri);
     g_object_weak_ref(G_OBJECT(window), (GWeakNotify)g_free, uri);
 }
 
@@ -592,8 +566,8 @@ add_help_to_window(GtkWindow *window,
  *
  * Adds help to a data processing function dialog.
  *
- * Note the help button will not be added if no help URI is found for the
- * currently running function or help is not available.
+ * Note the help button will not be added if no help URI is found for the currently running function or help is not
+ * available.
  *
  * Since: 2.38
  **/
@@ -620,8 +594,8 @@ gwy_help_add_to_proc_dialog(GtkDialog *dialog, GwyHelpFlags flags)
  *
  * Adds help to a graph function dialog.
  *
- * Note the help button will not be added if no help URI is found for the
- * currently running function or help is not available.
+ * Note the help button will not be added if no help URI is found for the currently running function or help is not
+ * available.
  *
  * Since: 2.38
  **/
@@ -648,8 +622,8 @@ gwy_help_add_to_graph_dialog(GtkDialog *dialog, GwyHelpFlags flags)
  *
  * Adds help to a volume data processing function dialog.
  *
- * Note the help button will not be added if no help URI is found for the
- * currently running function or help is not available.
+ * Note the help button will not be added if no help URI is found for the currently running function or help is not
+ * available.
  *
  * Since: 2.38
  **/
@@ -676,8 +650,8 @@ gwy_help_add_to_volume_dialog(GtkDialog *dialog, GwyHelpFlags flags)
  *
  * Adds help to a XYZ data processing function dialog.
  *
- * Note the help button will not be added if no help URI is found for the
- * currently running function or help is not available.
+ * Note the help button will not be added if no help URI is found for the currently running function or help is not
+ * available.
  *
  * Since: 2.45
  **/
@@ -697,6 +671,34 @@ gwy_help_add_to_xyz_dialog(GtkDialog *dialog, GwyHelpFlags flags)
     add_help_to_window(GTK_WINDOW(dialog), uri, flags);
 }
 
+/**
+ * gwy_help_add_to_cmap_dialog:
+ * @dialog: Main dialog for a curve map data processing function.
+ * @flags: Flags allowing to modify the help setup.
+ *
+ * Adds help to a curve map data processing function dialog.
+ *
+ * Note the help button will not be added if no help URI is found for the currently running function or help is not
+ * available.
+ *
+ * Since: 2.60
+ **/
+void
+gwy_help_add_to_cmap_dialog(GtkDialog *dialog, GwyHelpFlags flags)
+{
+    const gchar *funcname;
+    gchar *uri;
+
+    g_return_if_fail(GTK_IS_DIALOG(dialog));
+    funcname = gwy_curve_map_func_current();
+    g_return_if_fail(funcname);
+
+    if (!(uri = build_uri_for_function("cmap", funcname)))
+        return;
+
+    add_help_to_window(GTK_WINDOW(dialog), uri, flags);
+}
+
 /**
  * gwy_help_add_to_file_dialog:
  * @dialog: Main dialog for a file function.
@@ -704,8 +706,8 @@ gwy_help_add_to_xyz_dialog(GtkDialog *dialog, GwyHelpFlags flags)
  *
  * Adds help to a file function dialog.
  *
- * Note the help button will not be added if no help URI is found for the
- * currently running function or help is not available.
+ * Note the help button will not be added if no help URI is found for the currently running function or help is not
+ * available.
  *
  * Since: 2.38
  **/
@@ -733,8 +735,8 @@ gwy_help_add_to_file_dialog(GtkDialog *dialog, GwyHelpFlags flags)
  *
  * Adds help to a tool dialog.
  *
- * Note the help button will not be added if no help URI is found for the
- * currently running function or help is not available.
+ * Note the help button will not be added if no help URI is found for the currently running function or help is not
+ * available.
  *
  * Since: 2.38
  **/
@@ -760,23 +762,19 @@ gwy_help_add_to_tool_dialog(GtkDialog *dialog,
 /**
  * gwy_help_add_to_window:
  * @window: A window.
- * @filename: Base file name in the user guide without any path or extensions,
- *            for instance "statistical-analysis".
+ * @filename: Base file name in the user guide without any path or extensions, for instance "statistical-analysis".
  * @fragment: Fragment identifier (without "#"), or possibly %NULL.
  * @flags: Flags allowing to modify the help setup.
  *
  * Adds help to a window pointing to the user guide.
  *
- * If the window is a #GtkDialog a help button will be added by default (this
- * can be modified with @flags).  Normal windows do not get help buttons.
- * No help may be added if help is not available.
+ * If the window is a #GtkDialog a help button will be added by default (this can be modified with @flags).  Normal
+ * windows do not get help buttons. No help may be added if help is not available.
  *
- * This is a relatively low-level function and should not be necessary in
- * modules.  An exception may be modules with multiple user interfaces
- * described in different parts of the guide – but this should be rare.
+ * This is a relatively low-level function and should not be necessary in modules.  An exception may be modules with
+ * multiple user interfaces described in different parts of the guide – but this should be rare.
  *
- * It is a suitable functions for adding help to base application windows,
- * such as channel or volume windows.
+ * It is a suitable functions for adding help to base application windows, such as channel or volume windows.
  *
  * Since: 2.38
  **/
@@ -805,16 +803,14 @@ gwy_help_add_to_window(GtkWindow *window,
  *
  * Adds help to a window pointing to an arbitrary URI.
  *
- * If the window is a #GtkDialog a help button will be added by default (this
- * can be modified with @flags).  Normal windows do not get help buttons.
- * No help may be added if help is not available.
+ * If the window is a #GtkDialog a help button will be added by default (this can be modified with @flags).  Normal
+ * windows do not get help buttons. No help may be added if help is not available.
  *
- * This function should not be necessary anywhere within Gwyddion itself.
- * Use the functions pointing to the user guide instead as they can handle
- * language versions or changing the user guide base location.
+ * This function should not be necessary anywhere within Gwyddion itself. Use the functions pointing to the user guide
+ * instead as they can handle language versions or changing the user guide base location.
  *
- * It may be useful for third-party modules if they wish to add a help facility
- * behaving similarly to built-in modules.
+ * It may be useful for third-party modules if they wish to add a help facility behaving similarly to built-in
+ * modules.
  *
  * Since: 2.38
  **/
@@ -830,14 +826,12 @@ gwy_help_add_to_window_uri(GtkWindow *window,
 
 /**
  * gwy_help_show:
- * @filename: Base file name in the user guide without any path or extensions,
- *            for instance "statistical-analysis".
+ * @filename: Base file name in the user guide without any path or extensions, for instance "statistical-analysis".
  * @fragment: Fragment identifier (without "#"), or possibly %NULL.
  *
  * Immediately shows a specific help location.
  *
- * This function should be rarely needed.  It may fail if help is not
- * available.
+ * This function should be rarely needed.  It may fail if help is not available.
  *
  * Since: 2.38
  **/
@@ -861,11 +855,9 @@ gwy_help_show(const gchar *filename,
  *
  * Check whether help is available.
  *
- * This is a weak check that finds if we have any help-showing backend that
- * might work at all, have the user guide module map, and if the user guide
- * locations is a local directory it checks whether it exists.  If it returns
- * %TRUE it does not guarantee help will work. If it returns %FALSE, however,
- * it means help will not work.
+ * This is a weak check that finds if we have any help-showing backend that might work at all, have the user guide
+ * module map, and if the user guide locations is a local directory it checks whether it exists.  If it returns %TRUE
+ * it does not guarantee help will work. If it returns %FALSE, however, it means help will not work.
  *
  * Returns: %TRUE if help seems available, %FALSE if it is not.
  *
@@ -900,23 +892,20 @@ gwy_help_is_available(void)
  * @title: help
  * @short_description: User guide access
  *
- * Help functions add a Help button to dialogs and install a key press handler
- * responding to Help and F1 keys to all windows.  For built-in modules,
- * invoking the help opens a web browser (using some generic and
- * system-specific means) pointing to the corresponding location in the user
- * guide.  Third-party modules can use gwy_help_add_to_window_uri() to open a
- * web browser at an arbitrary URI.
+ * Help functions add a Help button to dialogs and install a key press handler responding to Help and F1 keys to all
+ * windows.  For built-in modules, invoking the help opens a web browser (using some generic and system-specific
+ * means) pointing to the corresponding location in the user guide.  Third-party modules can use
+ * gwy_help_add_to_window_uri() to open a web browser at an arbitrary URI.
  **/
 
 /**
  * GwyHelpFlags:
  * @GWY_HELP_DEFAULT: No flags, the default behaviour.
- * @GWY_HELP_NO_BUTTON: Do not add a Help button, even to windows that are
- *                      dialogs.
+ * @GWY_HELP_NO_BUTTON: Do not add a Help button, even to windows that are dialogs.
  *
  * Flags controlling help setup and behaviour.
  *
  * Since: 2.38
  **/
 
-/* vim: set cin et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
+/* vim: set cin columns=120 tw=118 et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
