@@ -1,22 +1,18 @@
 /*
- *  $Id: log.c 23422 2021-04-01 14:36:18Z yeti-dn $
- *  Copyright (C) 2014-2016 David Necas (Yeti).
+ *  $Id: log.c 23947 2021-08-10 11:21:05Z yeti-dn $
+ *  Copyright (C) 2014-2021 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
+ *  License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any
+ *  later version.
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
+ *  warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+ *  details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
+ *  You should have received a copy of the GNU General Public License along with this program; if not, write to the
+ *  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #include "config.h"
@@ -27,6 +23,7 @@
 #include <libgwydgets/gwydgets.h>
 #include <app/gwymoduleutils.h>
 #include <app/gwyapp.h>
+#include "gwyappinternal.h"
 
 enum {
     LOG_TYPE,
@@ -39,6 +36,7 @@ typedef enum {
     BROWSER_DATA_CHANNEL,
     BROWSER_DATA_VOLUME,
     BROWSER_DATA_XYZ,
+    BROWSER_DATA_CURVE_MAP,
 } BrowserDataType;
 
 typedef GQuark (*LogKeyFync)(gint id);
@@ -71,7 +69,7 @@ static GtkWidget*     get_log_browser              (GwyContainer *data,
 static LogBrowser*    log_browser_new              (GwyContainer *data,
                                                     BrowserDataType type,
                                                     gint id,
-                                                    const gchar *key);
+                                                    GQuark quark);
 static void           log_browser_construct        (LogBrowser *browser);
 static void           log_cell_renderer            (GtkTreeViewColumn *column,
                                                     GtkCellRenderer *renderer,
@@ -91,6 +89,7 @@ static void           format_arg                   (gpointer hkey,
 static GQuark         channel_log_key              (gint id);
 static GQuark         volume_log_key               (gint id);
 static GQuark         xyz_log_key                  (gint id);
+static GQuark         curve_map_log_key            (gint id);
 static gboolean       find_settings_prefix         (const gchar *function,
                                                     const gchar *settings_name,
                                                     GString *prefix);
@@ -104,20 +103,18 @@ static gboolean log_disabled = FALSE;
  * @previd: Identifier of the previous (source) data channel in the container.
  *          Pass -1 for a no-source (or unclear source) operation.
  * @newid: Identifier of the new (target) data channel in the container.
- * @function: Quailified name of the function applied as shown by the module
- *            browser.  For instance "proc::facet-level" or
- *            "tool::GwyToolCrop".
+ * @function: Quailified name of the function applied as shown by the module browser.  For instance
+ *            "proc::facet-level" or "tool::GwyToolCrop".
  * @...: Logging options as a %NULL-terminated list of pairs name, value.
  *
  * Adds an entry to the log of data processing operations for a channel.
  *
  * See the introduction for a description of valid @previd and @newid.
  *
- * It is possible to pass %NULL as @function.  In this case the log is just
- * copied from source to target without adding any entries.  This can be useful
- * to prevent duplicate log entries in modules that modify a data field and
- * then can also create secondary outputs.  Note you still need to pass a
- * second %NULL argument as the option terminator.
+ * It is possible to pass %NULL as @function.  In this case the log is just copied from source to target without
+ * adding any entries.  This can be useful to prevent duplicate log entries in modules that modify a data field and
+ * then can also create secondary outputs.  Note you still need to pass a second %NULL argument as the option
+ * terminator.
  *
  * Since: 2.35
  **/
@@ -141,12 +138,10 @@ gwy_app_channel_log_add(GwyContainer *data,
  *          Pass -1 for a no-source (or unclear source) operation.
  * @newid: Identifier of the new (target) data channel in the container.
  *
- * Adds an entry to the log of the current data processing operations
- * for a channel.
+ * Adds an entry to the log of the current data processing operations for a channel.
  *
- * This simplified variant of gwy_app_channel_log_add() takes the currently
- * running data processing function name and constructs the qualified function
- * name from that.
+ * This simplified variant of gwy_app_channel_log_add() takes the currently running data processing function name and
+ * constructs the qualified function name from that.
  *
  * Since: 2.38
  **/
@@ -171,19 +166,18 @@ gwy_app_channel_log_add_proc(GwyContainer *data,
  * @previd: Identifier of the previous (source) volume data in the container.
  *          Pass -1 for a no-source (or unclear source) operation.
  * @newid: Identifier of the new (target) volume data in the container.
- * @function: Quailified name of the function applied as shown by the module
- *            browser.  For instance "volume::volume_invert".
+ * @function: Quailified name of the function applied as shown by the module browser.  For instance
+ *            "volume::volume_invert".
  * @...: Logging options as a %NULL-terminated list of pairs name, value.
  *
  * Adds an entry to the log of data processing operations for volume data.
  *
  * See the introduction for a description of valid @previd and @newid.
  *
- * It is possible to pass %NULL as @function.  In this case the log is just
- * copied from source to target without adding any entries.  This can be useful
- * to prevent duplicate log entries in modules that modify a data field and
- * then can also create secondary outputs.  Note you still need to pass a
- * second %NULL argument as the option terminator.
+ * It is possible to pass %NULL as @function.  In this case the log is just copied from source to target without
+ * adding any entries.  This can be useful to prevent duplicate log entries in modules that modify a data field and
+ * then can also create secondary outputs.  Note you still need to pass a second %NULL argument as the option
+ * terminator.
  *
  * Since: 2.35
  **/
@@ -207,12 +201,10 @@ gwy_app_volume_log_add(GwyContainer *data,
  *          Pass -1 for a no-source (or unclear source) operation.
  * @newid: Identifier of the new (target) volume data in the container.
  *
- * Adds an entry to the log of the current volume data processing operations
- * for volume data.
+ * Adds an entry to the log of the current volume data processing operations for volume data.
  *
- * This simplified variant of gwy_app_volume_log_add() takes the currently
- * running function volume data processing name and constructs the qualified
- * function name from that.
+ * This simplified variant of gwy_app_volume_log_add() takes the currently running function volume data processing
+ * name and constructs the qualified function name from that.
  *
  * Since: 2.38
  **/
@@ -237,19 +229,17 @@ gwy_app_volume_log_add_volume(GwyContainer *data,
  * @previd: Identifier of the previous (source) XYZ data in the container.
  *          Pass -1 for a no-source (or unclear source) operation.
  * @newid: Identifier of the new (target) XYZ data in the container.
- * @function: Quailified name of the function applied as shown by the module
- *            browser.  For instance "xyz::xyz_invert".
+ * @function: Quailified name of the function applied as shown by the module browser.  For instance "xyz::xyz_invert".
  * @...: Logging options as a %NULL-terminated list of pairs name, value.
  *
  * Adds an entry to the log of data processing operations for XYZ data.
  *
  * See the introduction for a description of valid @previd and @newid.
  *
- * It is possible to pass %NULL as @function.  In this case the log is just
- * copied from source to target without adding any entries.  This can be useful
- * to prevent duplicate log entries in modules that modify a data field and
- * then can also create secondary outputs.  Note you still need to pass a
- * second %NULL argument as the option terminator.
+ * It is possible to pass %NULL as @function.  In this case the log is just copied from source to target without
+ * adding any entries.  This can be useful to prevent duplicate log entries in modules that modify a data field and
+ * then can also create secondary outputs.  Note you still need to pass a second %NULL argument as the option
+ * terminator.
  *
  * Since: 2.45
  **/
@@ -273,12 +263,10 @@ gwy_app_xyz_log_add(GwyContainer *data,
  *          Pass -1 for a no-source (or unclear source) operation.
  * @newid: Identifier of the new (target) XYZ data in the container.
  *
- * Adds an entry to the log of the current XYZ data processing operations
- * for XYZ data.
+ * Adds an entry to the log of the current XYZ data processing operations for XYZ data.
  *
- * This simplified variant of gwy_app_xyz_log_add() takes the currently
- * running function XYZ data processing name and constructs the qualified
- * function name from that.
+ * This simplified variant of gwy_app_xyz_log_add() takes the currently running function XYZ data processing name and
+ * constructs the qualified function name from that.
  *
  * Since: 2.45
  **/
@@ -297,6 +285,68 @@ gwy_app_xyz_log_add_xyz(GwyContainer *data,
     g_free(qname);
 }
 
+/**
+ * gwy_app_curve_map_log_add:
+ * @data: A data container.
+ * @previd: Identifier of the previous (source) #GwyLawn curve map in the container.
+ *          Pass -1 for a no-source (or unclear source) operation.
+ * @newid: Identifier of the new (target) #GwyLawn curve map in the container.
+ * @function: Quailified name of the function applied as shown by the module browser.  For instance "cmap::cmap_crop".
+ * @...: Logging options as a %NULL-terminated list of pairs name, value.
+ *
+ * Adds an entry to the log of data processing operations for #GwyLawn curve map.
+ *
+ * See the introduction for a description of valid @previd and @newid.
+ *
+ * It is possible to pass %NULL as @function.  In this case the log is just copied from source to target without
+ * adding any entries.  This can be useful to prevent duplicate log entries in modules that modify a data field and
+ * then can also create secondary outputs.  Note you still need to pass a second %NULL argument as the option
+ * terminator.
+ *
+ * Since: 2.60
+ **/
+void
+gwy_app_curve_map_log_add(GwyContainer *data,
+                          gint previd,
+                          gint newid,
+                          const gchar *function,
+                          ...)
+{
+    va_list ap;
+    va_start(ap, function);
+    data_log_add_valist(data, curve_map_log_key, previd, newid, function, ap);
+    va_end(ap);
+}
+
+/**
+ * gwy_app_curve_map_log_add_curve_map:
+ * @data: A data container.
+ * @previd: Identifier of the previous (source) #GwyLawn curve map in the container.
+ *          Pass -1 for a no-source (or unclear source) operation.
+ * @newid: Identifier of the new (target) #GwyLawn curve map in the container.
+ *
+ * Adds an entry to the log of the current #GwyLawn curve map processing operations for #GwyLawn curve map.
+ *
+ * This simplified variant of gwy_app_curve_map_log_add() takes the currently running function #GwyLawn curve map
+ * processing name and constructs the qualified function name from that.
+ *
+ * Since: 2.60
+ **/
+void
+gwy_app_curve_map_log_add_curve_map(GwyContainer *data,
+                                    gint previd,
+                                    gint newid)
+{
+    const gchar *funcname;
+    gchar *qname = NULL;
+
+    funcname = current_function_name_by_type("cmap");
+    g_return_if_fail(funcname);
+    qname = g_strconcat("cmap::", funcname, NULL);
+    gwy_app_curve_map_log_add(data, previd, newid, qname, NULL);
+    g_free(qname);
+}
+
 static void
 data_log_add_valist(GwyContainer *data,
                     LogKeyFync log_key,
@@ -407,11 +457,10 @@ get_data_log(GwyContainer *data,
  *
  * Shows a simple log browser for a channel.
  *
- * If the log browser is already shown for this channel it is just raised
- * and given focus.  Otherwise, a new window is created.
+ * If the log browser is already shown for this channel it is just raised and given focus.  Otherwise, a new window is
+ * created.
  *
- * Returns: The log browser (owned by the library).  Usually, you can
- *          ignore the return value.
+ * Returns: The log browser (owned by the library).  Usually, you can ignore the return value.
  *
  * Since: 2.35
  **/
@@ -429,11 +478,10 @@ gwy_app_log_browser_for_channel(GwyContainer *data,
  *
  * Shows a simple log browser for volume data.
  *
- * If the log browser is already shown for this volume data it is just raised
- * and given focus.  Otherwise, a new window is created.
+ * If the log browser is already shown for this volume data it is just raised and given focus.  Otherwise, a new
+ * window is created.
  *
- * Returns: The log browser (owned by the library).  Usually, you can
- *          ignore the return value.
+ * Returns: The log browser (owned by the library).  Usually, you can ignore the return value.
  *
  * Since: 2.35
  **/
@@ -451,11 +499,10 @@ gwy_app_log_browser_for_volume(GwyContainer *data,
  *
  * Shows a simple log browser for XYZ data.
  *
- * If the log browser is already shown for this XYZ data it is just raised
- * and given focus.  Otherwise, a new window is created.
+ * If the log browser is already shown for this XYZ data it is just raised and given focus.  Otherwise, a new window
+ * is created.
  *
- * Returns: The log browser (owned by the library).  Usually, you can
- *          ignore the return value.
+ * Returns: The log browser (owned by the library).  Usually, you can ignore the return value.
  *
  * Since: 2.45
  **/
@@ -466,29 +513,52 @@ gwy_app_log_browser_for_xyz(GwyContainer *data,
     return get_log_browser(data, BROWSER_DATA_XYZ, id);
 }
 
+/**
+ * gwy_app_log_browser_for_curve_map:
+ * @data: A data container.
+ * @id: Id of #GwyLawn curve map in @data to show log for.
+ *
+ * Shows a simple log browser for #GwyLawn curve map.
+ *
+ * If the log browser is already shown for this #GwyLawn curve map it is just raised and given focus.  Otherwise,
+ * a new window is created.
+ *
+ * Returns: The log browser (owned by the library).  Usually, you can ignore the return value.
+ *
+ * Since: 2.60
+ **/
+GtkWidget*
+gwy_app_log_browser_for_curve_map(GwyContainer *data,
+                                  gint id)
+{
+    return get_log_browser(data, BROWSER_DATA_CURVE_MAP, id);
+}
+
 static GtkWidget*
 get_log_browser(GwyContainer *data,
                 BrowserDataType type,
                 gint id)
 {
-    gchar key[32];
     LogBrowser *browser;
     GwyStringList *slog;
+    GQuark quark;
 
     g_return_val_if_fail(GWY_IS_CONTAINER(data), NULL);
     g_return_val_if_fail(id >= 0, NULL);
 
     if (type == BROWSER_DATA_CHANNEL)
-        g_snprintf(key, sizeof(key), "/%d/data/log", id);
+        quark = channel_log_key(id);
     else if (type == BROWSER_DATA_VOLUME)
-        g_snprintf(key, sizeof(key), "/brick/%d/log", id);
+        quark = volume_log_key(id);
     else if (type == BROWSER_DATA_XYZ)
-        g_snprintf(key, sizeof(key), "/surface/%d/log", id);
+        quark = xyz_log_key(id);
+    else if (type == BROWSER_DATA_CURVE_MAP)
+        quark = curve_map_log_key(id);
     else {
         g_return_val_if_reached(NULL);
     }
 
-    if (gwy_container_gis_object_by_name(data, key, &slog)) {
+    if (gwy_container_gis_object(data, quark, &slog)) {
         browser = g_object_get_data(G_OBJECT(slog), "log-browser");
         if (browser) {
             gtk_window_present(GTK_WINDOW(browser->window));
@@ -496,7 +566,7 @@ get_log_browser(GwyContainer *data,
         }
     }
 
-    browser = log_browser_new(data, type, id, key);
+    browser = log_browser_new(data, type, id, quark);
     gtk_widget_show_all(browser->window);
     return browser->window;
 }
@@ -505,7 +575,7 @@ static LogBrowser*
 log_browser_new(GwyContainer *data,
                 BrowserDataType type,
                 gint id,
-                const gchar *key)
+                GQuark quark)
 {
     LogBrowser *browser;
     GtkWidget *scroll, *vbox, *hbox;
@@ -520,8 +590,7 @@ log_browser_new(GwyContainer *data,
     browser->buf = g_string_new(NULL);
     log_browser_construct(browser);
     browser->window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
-    gwy_help_add_to_window(GTK_WINDOW(browser->window), "logging", NULL,
-                           GWY_HELP_DEFAULT);
+    gwy_help_add_to_window(GTK_WINDOW(browser->window), "logging", NULL, GWY_HELP_DEFAULT);
 
     if (type == BROWSER_DATA_CHANNEL)
         dataname = gwy_app_get_data_field_title(data, id);
@@ -529,30 +598,28 @@ log_browser_new(GwyContainer *data,
         dataname = gwy_app_get_brick_title(data, id);
     else if (type == BROWSER_DATA_XYZ)
         dataname = gwy_app_get_surface_title(data, id);
+    else if (type == BROWSER_DATA_CURVE_MAP)
+        dataname = gwy_app_get_lawn_title(data, id);
     else {
         g_return_val_if_reached(browser);
     }
 
-    title = g_strdup_printf(_("Log of %s (%s)"),
-                            dataname, g_get_application_name());
+    title = g_strdup_printf(_("Log of %s (%s)"), dataname, g_get_application_name());
     gtk_window_set_title(GTK_WINDOW(browser->window), title);
     g_free(title);
     g_free(dataname);
 
-    if (!(gwy_container_gis_object_by_name(data, key, &slog))) {
+    if (!(gwy_container_gis_object(data, quark, &slog))) {
         slog = gwy_string_list_new();
-        gwy_container_set_object_by_name(data, key, slog);
+        gwy_container_set_object(data, quark, slog);
         g_object_unref(slog);
     }
 
     browser->log = slog;
     g_object_set_data(G_OBJECT(slog), "log-browser", browser);
-    g_object_weak_ref(G_OBJECT(slog),
-                      (GWeakNotify)&gwy_log_data_finalized,
-                      browser);
+    g_object_weak_ref(G_OBJECT(slog), (GWeakNotify)&gwy_log_data_finalized, browser);
 
-    browser->changed_id = g_signal_connect(slog, "value-changed",
-                                           G_CALLBACK(log_changed), browser);
+    browser->changed_id = g_signal_connect(slog, "value-changed", G_CALLBACK(log_changed), browser);
 
     n = gwy_string_list_get_length(slog);
     store = gwy_null_store_new(n);
@@ -565,41 +632,34 @@ log_browser_new(GwyContainer *data,
     request.height = MAX(request.height, 400);
     gtk_window_set_default_size(GTK_WINDOW(browser->window),
                                 MIN(request.width + 24, 2*gdk_screen_width()/3),
-                                MIN(request.height + 32,
-                                    2*gdk_screen_height()/3));
+                                MIN(request.height + 32, 2*gdk_screen_height()/3));
     gwy_app_add_main_accel_group(GTK_WINDOW(browser->window));
 
     vbox = gtk_vbox_new(FALSE, 0);
     gtk_container_add(GTK_CONTAINER(browser->window), vbox);
 
     scroll = gtk_scrolled_window_new(NULL, NULL);
-    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scroll),
-                                   GTK_POLICY_AUTOMATIC,
-                                   GTK_POLICY_AUTOMATIC);
+    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scroll), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
     gtk_box_pack_start(GTK_BOX(vbox), scroll, TRUE, TRUE, 0);
     gtk_container_add(GTK_CONTAINER(scroll), browser->treeview);
     browser->destroy_id
-        = g_signal_connect_swapped(browser->window, "destroy",
-                                   G_CALLBACK(gwy_log_destroy), browser);
+        = g_signal_connect_swapped(browser->window, "destroy", G_CALLBACK(gwy_log_destroy), browser);
 
     hbox = gtk_hbox_new(TRUE, 0);
     gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
 
     browser->save = gwy_stock_like_button_new(_("_Export"), GTK_STOCK_SAVE);
     gtk_box_pack_start(GTK_BOX(hbox), browser->save, TRUE, TRUE, 0);
-    g_signal_connect_swapped(browser->save, "clicked",
-                             G_CALLBACK(gwy_log_export), browser);
+    g_signal_connect_swapped(browser->save, "clicked", G_CALLBACK(gwy_log_export), browser);
     gtk_widget_set_sensitive(browser->save, n != 0);
 
     browser->clear = gwy_stock_like_button_new(_("Clea_r"), GTK_STOCK_CLEAR);
     gtk_box_pack_start(GTK_BOX(hbox), browser->clear, TRUE, TRUE, 0);
-    g_signal_connect_swapped(browser->clear, "clicked",
-                             G_CALLBACK(gwy_log_clear), browser);
+    g_signal_connect_swapped(browser->clear, "clicked", G_CALLBACK(gwy_log_clear), browser);
 
     browser->close = gwy_stock_like_button_new(_("_Close"), GTK_STOCK_CLOSE);
     gtk_box_pack_start(GTK_BOX(hbox), browser->close, TRUE, TRUE, 0);
-    g_signal_connect_swapped(browser->close, "clicked",
-                             G_CALLBACK(gtk_widget_destroy), browser->window);
+    g_signal_connect_swapped(browser->close, "clicked", G_CALLBACK(gtk_widget_destroy), browser->window);
 
     return browser;
 }
@@ -630,14 +690,10 @@ log_browser_construct(LogBrowser *browser)
 
     for (i = 0; i < G_N_ELEMENTS(columns); i++) {
         renderer = gtk_cell_renderer_text_new();
-        column = gtk_tree_view_column_new_with_attributes(_(columns[i].title),
-                                                          renderer, NULL);
-        gtk_tree_view_column_set_cell_data_func(column, renderer,
-                                                log_cell_renderer, browser,
-                                                NULL);
+        column = gtk_tree_view_column_new_with_attributes(_(columns[i].title), renderer, NULL);
+        gtk_tree_view_column_set_cell_data_func(column, renderer, log_cell_renderer, browser, NULL);
         gtk_tree_view_append_column(treeview, column);
-        g_object_set_data(G_OBJECT(renderer), "column",
-                          GUINT_TO_POINTER(columns[i].id));
+        g_object_set_data(G_OBJECT(renderer), "column", GUINT_TO_POINTER(columns[i].id));
 
         if (columns[i].id == LOG_PARAMETERS) {
             gtk_tree_view_column_set_expand(column, TRUE);
@@ -727,10 +783,7 @@ gwy_log_export(LogBrowser *browser)
     str_to_save = g_strjoinv("\n", (gchar**)entries);
     g_free(entries);
 
-    gwy_save_auxiliary_data(_("Export Log"),
-                            GTK_WINDOW(browser->window),
-                            -1,
-                            str_to_save);
+    gwy_save_auxiliary_data(_("Export Log"), GTK_WINDOW(browser->window), -1, str_to_save);
 
     g_free(str_to_save);
 }
@@ -762,9 +815,7 @@ gwy_log_destroy(LogBrowser *browser)
 {
     GWY_SIGNAL_HANDLER_DISCONNECT(browser->log, browser->changed_id);
     g_object_set_data(G_OBJECT(browser->log), "log-browser", NULL);
-    g_object_weak_unref(G_OBJECT(browser->log),
-                        (GWeakNotify)&gwy_log_data_finalized,
-                        browser);
+    g_object_weak_unref(G_OBJECT(browser->log), (GWeakNotify)&gwy_log_data_finalized, browser);
     g_string_free(browser->buf, TRUE);
     g_free(browser);
 }
@@ -824,14 +875,9 @@ format_arg(gpointer hkey, gpointer hvalue, gpointer user_data)
     else if (G_VALUE_HOLDS_INT(gvalue))
         formatted = g_strdup_printf("%s=%d", name, g_value_get_int(gvalue));
     else if (G_VALUE_HOLDS_INT64(gvalue))
-        formatted = g_strdup_printf("%s=%" G_GINT64_FORMAT, name,
-                                    g_value_get_int64(gvalue));
-    else if (G_VALUE_HOLDS_BOOLEAN(gvalue)) {
-        formatted = g_strdup_printf("%s=%s", name,
-                                    g_value_get_boolean(gvalue)
-                                    ? "True"
-                                    : "False");
-    }
+        formatted = g_strdup_printf("%s=%" G_GINT64_FORMAT, name, g_value_get_int64(gvalue));
+    else if (G_VALUE_HOLDS_BOOLEAN(gvalue))
+        formatted = g_strdup_printf("%s=%s", name, g_value_get_boolean(gvalue) ? "True" : "False");
     else if (G_VALUE_HOLDS_STRING(gvalue)) {
         gchar *s = g_strescape(g_value_get_string(gvalue), NULL);
         formatted = g_strdup_printf("%s=\"%s\"", name, s);
@@ -845,8 +891,7 @@ format_arg(gpointer hkey, gpointer hvalue, gpointer user_data)
             formatted = g_strdup_printf("%s=0x%02x", name, c);
     }
     else {
-        g_warning("Cannot format argument of type %s.",
-                  g_type_name(G_VALUE_TYPE(gvalue)));
+        g_warning("Cannot format argument of type %s.", g_type_name(G_VALUE_TYPE(gvalue)));
         return;
     }
 
@@ -865,7 +910,7 @@ static GQuark
 volume_log_key(gint id)
 {
     static gchar buf[32];
-    g_snprintf(buf, sizeof(buf), "/brick/%d/log", id);
+    g_snprintf(buf, sizeof(buf), BRICK_PREFIX "/%d/log", id);
     return g_quark_from_string(buf);
 }
 
@@ -873,7 +918,15 @@ static GQuark
 xyz_log_key(gint id)
 {
     static gchar buf[32];
-    g_snprintf(buf, sizeof(buf), "/surface/%d/log", id);
+    g_snprintf(buf, sizeof(buf), SURFACE_PREFIX "/%d/log", id);
+    return g_quark_from_string(buf);
+}
+
+static GQuark
+curve_map_log_key(gint id)
+{
+    static gchar buf[32];
+    g_snprintf(buf, sizeof(buf), LAWN_PREFIX "/%d/log", id);
     return g_quark_from_string(buf);
 }
 
@@ -887,11 +940,12 @@ find_settings_prefix(const gchar *function,
         gboolean (*func_exists)(const gchar *name);
     }
     function_types[] = {
-        { "proc::",    &gwy_process_func_exists, },
-        { "file::",    &gwy_file_func_exists,    },
-        { "graph::",   &gwy_graph_func_exists,   },
-        { "volume::",  &gwy_volume_func_exists,  },
-        { "xyz::",     &gwy_xyz_func_exists,     },
+        { "proc::",   &gwy_process_func_exists,   },
+        { "file::",   &gwy_file_func_exists,      },
+        { "graph::",  &gwy_graph_func_exists,     },
+        { "volume::", &gwy_volume_func_exists,    },
+        { "xyz::",    &gwy_xyz_func_exists,       },
+        { "cmap::",   &gwy_curve_map_func_exists, },
     };
 
     guint i;
@@ -970,14 +1024,11 @@ gwy_log_get_enabled(void)
  *
  * Globally enables or disables logging of data processing operations.
  *
- * By default, logging is enabled.  Non-GUI applications that run module
- * functions may wish to disable it.  Of course, the log will presist only if
- * the data container is saved into a GWY file.
+ * By default, logging is enabled.  Non-GUI applications that run module functions may wish to disable it.  Of course,
+ * the log will presist only if the data container is saved into a GWY file.
  *
- * If logging is disabled logging functions such as gwy_app_channel_log_add()
- * become no-op.  It is possible to run the log viewer with
- * gwy_app_log_browser_for_channel() to see log entries created when logging
- * was enabled.
+ * If logging is disabled logging functions such as gwy_app_channel_log_add() become no-op.  It is possible to run the
+ * log viewer with gwy_app_log_browser_for_channel() to see log entries created when logging was enabled.
  *
  * Since: 2.35
  **/
@@ -1002,6 +1053,8 @@ current_function_name_by_type(const gchar *type)
         funcname = gwy_volume_func_current();
     else if (gwy_strequal(type, "xyz"))
         funcname = gwy_xyz_func_current();
+    else if (gwy_strequal(type, "cmap"))
+        funcname = gwy_curve_map_func_current();
     else if (gwy_strequal(type, "tool"))
         funcname = gwy_app_current_tool_name();
 
@@ -1016,38 +1069,28 @@ current_function_name_by_type(const gchar *type)
  * @title: log
  * @short_description: Logging data processing operations
  *
- * The data processing operation log is a linear sequence of operations applied
- * to a channel or volume data.  The log is informative and not meant to
- * capture all information necessary to reply the operations, even though it
- * can be sufficient for this purpose in simple cases.
+ * The data processing operation log is a linear sequence of operations applied to a image, volume, XYZ or curve map
+ * data.  The log is informative and not meant to capture all information necessary to reply the operations, even
+ * though it can be sufficient for this purpose in simple cases.
  *
- * The log is a linear sequence.  This is only an approximation of the actual
- * flow of information in the data processing, which corresponds to an acyclic
- * directed graph (not necessarily connected as data, masks and presentations
- * can have distinct sources).  The following rules thus apply to make it
- * meaningful and useful.
+ * The log is a linear sequence.  This is only an approximation of the actual flow of information in the data
+ * processing, which corresponds to an acyclic directed graph (not necessarily connected as data, masks and
+ * presentations can have distinct sources).  The following rules thus apply to make it meaningful and useful.
  *
- * Each logging function takes two data identifiers: source and target. The
- * source corresponds to the operation input, the target corresponds to the
- * data whose log is being updated.  The target may have already a log only if
- * it is the same as the source (which corresponds to simple data modification
- * such as levelling or grain marking).  In all other cases the target must not
- * have a log yet – they represent the creation of new data either from scratch
- * or based on existing data (in the latter case the log of the existing data
- * is replicated to the new one).
+ * Each logging function takes two data identifiers: source and target. The source corresponds to the operation input,
+ * the target corresponds to the data whose log is being updated.  The target may have already a log only if it is the
+ * same as the source (which corresponds to simple data modification such as levelling or grain marking).  In all
+ * other cases the target must not have a log yet – they represent the creation of new data either from scratch or
+ * based on existing data (in the latter case the log of the existing data is replicated to the new one).
  *
- * Complex multi-data operations are approximated by one of the simple
- * operations.  For instance, data arithmetic can be treated as the
- * construction of a new channel from scratch as it is unclear which input data
- * the output channel is actually based on, if any at all.  Modifications that
- * use data from other channels, such as masking using another data or tip
- * convolution, should be represented as simple modifications of the primary
- * channel.
+ * Complex multi-data operations are approximated by one of the simple operations.  For instance, data arithmetic can
+ * be treated as the construction of a new channel from scratch as it is unclear which input data the output channel
+ * is actually based on, if any at all.  Modifications that use data from other channels, such as masking using
+ * another data or tip convolution, should be represented as simple modifications of the primary channel.
  *
- * Logging functions such as gwy_app_channel_log_add() take settings values
- * corresponding to the function name and store them in the log entry.
- * If the settings are stored under a different name, use the "settings-name"
- * logging option to set the correct name.
+ * Logging functions such as gwy_app_channel_log_add() take settings values corresponding to the function name and
+ * store them in the log entry. If the settings are stored under a different name, use the "settings-name" logging
+ * option to set the correct name.
  **/
 
-/* vim: set cin et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
+/* vim: set cin columns=120 tw=118 et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
