@@ -1,5 +1,5 @@
 /*
- *  $Id: param-def.c 23819 2021-06-09 21:16:20Z yeti-dn $
+ *  $Id: param-def.c 24330 2021-10-11 15:45:25Z yeti-dn $
  *  Copyright (C) 2021 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -15,6 +15,7 @@
  *  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
+#include "config.h"
 #include "libgwyddion/gwymacros.h"
 #include "libprocess/gwyprocesstypes.h"
 #include "libprocess/gwyprocessenums.h"
@@ -791,8 +792,14 @@ gwy_param_def_add_mask_color(GwyParamDef *pardef,
  *
  * Defines a new parameter with values that are graph ids.
  *
+ * Data identifier parameters are not stored permanently in settings.  However, they are remembered until Gwyddion
+ * exits.  Hence @name does not actually refer to settings, but it should still uniquely identify the parameter as in
+ * settings.
+ *
  * See the introduction for @name and @desc lifetime rules.
  *
+ * See gwy_param_def_add_target_graph() for a generic graph parameter.
+ *
  * Since: 2.59
  **/
 void
@@ -802,11 +809,46 @@ gwy_param_def_add_target_graph(GwyParamDef *pardef,
                                const gchar *desc)
 {
     GwyParamDefItem item;
+    GwyParamDefDataId *di = &item.def.di;
 
     item.type = GWY_PARAM_GRAPH_ID;
+    di->is_target_graph = TRUE;
     gwy_param_def_append(pardef, id, name, desc ? desc : _("Target _graph"), &item);
 }
 
+/**
+ * gwy_param_def_add_graph_id:
+ * @pardef: A set of parameter definitions.
+ * @id: Parameter identifier.
+ * @name: Parameter name for settings.  It can be %NULL for derived parameters not stored in settings.
+ * @desc: Parameter description which will be used for a label in GUI.
+ *
+ * Defines a new parameter with values that are graph ids.
+ *
+ * Data identifier parameters are not stored permanently in settings.  However, they are remembered until Gwyddion
+ * exits.  Hence @name does not actually refer to settings, but it should still uniquely identify the parameter as in
+ * settings.
+ *
+ * See the introduction for @name and @desc lifetime rules.
+ *
+ * See gwy_param_def_add_target_graph() for a specialised parameter for target graphs.
+ *
+ * Since: 2.60
+ **/
+void
+gwy_param_def_add_graph_id(GwyParamDef *pardef,
+                           gint id,
+                           const gchar *name,
+                           const gchar *desc)
+{
+    GwyParamDefItem item;
+    GwyParamDefDataId *di = &item.def.di;
+
+    item.type = GWY_PARAM_GRAPH_ID;
+    di->is_target_graph = FALSE;
+    gwy_param_def_append(pardef, id, name, desc, &item);
+}
+
 /**
  * gwy_param_def_add_image_id:
  * @pardef: A set of parameter definitions.
@@ -816,6 +858,10 @@ gwy_param_def_add_target_graph(GwyParamDef *pardef,
  *
  * Defines a new parameter with values that are image ids.
  *
+ * Data identifier parameters are not stored permanently in settings.  However, they are remembered until Gwyddion
+ * exits.  Hence @name does not actually refer to settings, but it should still uniquely identify the parameter as in
+ * settings.
+ *
  * See the introduction for @name and @desc lifetime rules.
  *
  * Since: 2.59
@@ -841,6 +887,10 @@ gwy_param_def_add_image_id(GwyParamDef *pardef,
  *
  * Defines a new parameter with values that are volume data ids.
  *
+ * Data identifier parameters are not stored permanently in settings.  However, they are remembered until Gwyddion
+ * exits.  Hence @name does not actually refer to settings, but it should still uniquely identify the parameter as in
+ * settings.
+ *
  * See the introduction for @name and @desc lifetime rules.
  *
  * Since: 2.59
@@ -866,6 +916,10 @@ gwy_param_def_add_volume_id(GwyParamDef *pardef,
  *
  * Defines a new parameter with values that are xyz data ids.
  *
+ * Data identifier parameters are not stored permanently in settings.  However, they are remembered until Gwyddion
+ * exits.  Hence @name does not actually refer to settings, but it should still uniquely identify the parameter as in
+ * settings.
+ *
  * See the introduction for @name and @desc lifetime rules.
  *
  * Since: 2.59
@@ -882,6 +936,150 @@ gwy_param_def_add_xyz_id(GwyParamDef *pardef,
     gwy_param_def_append(pardef, id, name, desc, &item);
 }
 
+/**
+ * gwy_param_def_add_curve_map_id:
+ * @pardef: A set of parameter definitions.
+ * @id: Parameter identifier.
+ * @name: Parameter name for settings.  It can be %NULL for derived parameters not stored in settings.
+ * @desc: Parameter description which will be used for a label in GUI.
+ *
+ * Defines a new parameter with values that are curve map data ids.
+ *
+ * Data identifier parameters are not stored permanently in settings.  However, they are remembered until Gwyddion
+ * exits.  Hence @name does not actually refer to settings, but it should still uniquely identify the parameter as in
+ * settings.
+ *
+ * See the introduction for @name and @desc lifetime rules.
+ *
+ * Since: 2.60
+ **/
+void
+gwy_param_def_add_curve_map_id(GwyParamDef *pardef,
+                               gint id,
+                               const gchar *name,
+                               const gchar *desc)
+{
+    GwyParamDefItem item;
+
+    item.type = GWY_PARAM_CURVE_MAP_ID;
+    gwy_param_def_append(pardef, id, name, desc, &item);
+}
+
+/**
+ * gwy_param_def_add_graph_curve:
+ * @pardef: A set of parameter definitions.
+ * @id: Parameter identifier.
+ * @name: Parameter name for settings.
+ * @desc: Parameter description which will be used for a label in GUI.  It may be %NULL for the default label.
+ *
+ * Defines a new parameter with values that are graph curve numbers.
+ *
+ * Curve numbers can be any non-negative integers.  The upper bound is determined by #GwyParamTable once the GUI for
+ * choosing a curve from specific graph model is set up.  Value -1 is also allowed for empty graph models with no
+ * curves, but this should not normally occur.
+ *
+ * Curve parameters are stored in settings as curve labels, even though they are treated integers otherwise.  This
+ * helps selecting a curve with the same function/interpretation the next time the module is invoked – or the first
+ * curve if there is none such.
+ *
+ * See the introduction for @name and @desc lifetime rules.
+ *
+ * Since: 2.60
+ **/
+void
+gwy_param_def_add_graph_curve(GwyParamDef *pardef,
+                              gint id,
+                              const gchar *name,
+                              const gchar *desc)
+{
+    GwyParamDefItem item;
+    GwyParamDefInt *i = &item.def.i;
+
+    item.type = GWY_PARAM_GRAPH_CURVE;
+    i->minimum = -1;
+    i->maximum = G_MAXINT;
+    i->default_value = 0;
+    if (!desc)
+        desc = _("C_urve");
+    gwy_param_def_append(pardef, id, name, desc, &item);
+}
+
+/**
+ * gwy_param_def_add_lawn_curve:
+ * @pardef: A set of parameter definitions.
+ * @id: Parameter identifier.
+ * @name: Parameter name for settings.
+ * @desc: Parameter description which will be used for a label in GUI.  It may be %NULL for the default label.
+ *
+ * Defines a new parameter with values that are lawn curve numbers.
+ *
+ * Curve numbers can be any non-negative integers.  The upper bound is determined by #GwyParamTable once the GUI for
+ * choosing a curve from specific lawn is set up.
+ *
+ * Curve parameters are stored in settings as curve labels, even though they are treated integers otherwise.  This
+ * helps selecting a curve with the same function/interpretation the next time the module is invoked – or the first
+ * curve if there is none such.
+ *
+ * See the introduction for @name and @desc lifetime rules.
+ *
+ * Since: 2.60
+ **/
+void
+gwy_param_def_add_lawn_curve(GwyParamDef *pardef,
+                             gint id,
+                             const gchar *name,
+                             const gchar *desc)
+{
+    GwyParamDefItem item;
+    GwyParamDefInt *i = &item.def.i;
+
+    item.type = GWY_PARAM_LAWN_CURVE;
+    i->minimum = 0;
+    i->maximum = G_MAXINT;
+    i->default_value = 0;
+    if (!desc)
+        desc = _("C_urve");
+    gwy_param_def_append(pardef, id, name, desc, &item);
+}
+
+/**
+ * gwy_param_def_add_lawn_segment:
+ * @pardef: A set of parameter definitions.
+ * @id: Parameter identifier.
+ * @name: Parameter name for settings.
+ * @desc: Parameter description which will be used for a label in GUI.  It may be %NULL for the default label.
+ *
+ * Defines a new parameter with values that are lawn segment numbers.
+ *
+ * Segment numbers can be any non-negative integers.  The upper bound is determined by #GwyParamTable once the GUI for
+ * choosing a segment from specific lawn is set up.  Value -1 is also allowed for empty lawns with no segments.
+ *
+ * Segment parameters are stored in settings as segment labels, even though they are treated integers otherwise.  This
+ * helps selecting a segment with the same function/interpretation the next time the module is invoked – or the first
+ * segment if there is none such.
+ *
+ * See the introduction for @name and @desc lifetime rules.
+ *
+ * Since: 2.60
+ **/
+void
+gwy_param_def_add_lawn_segment(GwyParamDef *pardef,
+                               gint id,
+                               const gchar *name,
+                               const gchar *desc)
+{
+    GwyParamDefItem item;
+    GwyParamDefInt *i = &item.def.i;
+
+    item.type = GWY_PARAM_LAWN_SEGMENT;
+    i->minimum = -1;
+    i->maximum = G_MAXINT;
+    i->default_value = 0;
+    if (!desc)
+        desc = _("_Segment");
+    gwy_param_def_append(pardef, id, name, desc, &item);
+}
+
 /**
  * gwy_param_def_add_report_type:
  * @pardef: A set of parameter definitions.
@@ -1099,7 +1297,7 @@ gwy_param_def_append(GwyParamDef *pardef,
     if (desc && (len = strlen(desc)) && desc[len-1] == ':') {
         gchar *s;
 
-        g_warning("Parameter descriptions (%s) should not have trailing colons.", desc);
+        g_warning("Parameter description (%s) should not have trailing colons.", desc);
         s = g_strndup(desc, len-1);
         g_strstrip(s);
         desc = g_intern_string(s);
@@ -1215,8 +1413,10 @@ _gwy_param_def_rectify_int(const GwyParamDefItem *def, gint value)
     g_return_val_if_fail(def, 0);
     if (def->type == GWY_PARAM_ACTIVE_PAGE)
         return value;
-    g_return_val_if_fail(def->type == GWY_PARAM_INT, 0);
+    g_return_val_if_fail(def->type == GWY_PARAM_INT || param_type_is_curve_no(def->type), 0);
     i = &def->def.i;
+    if ((value < 0 && i->minimum >= 0) || (value > 0 && i->maximum <= 0))
+        value = -value;
     return CLAMP(value, i->minimum, i->maximum);
 }
 
@@ -1241,6 +1441,10 @@ _gwy_param_def_rectify_double(const GwyParamDefItem *def, gdouble value)
                 value += d->maximum;
         }
     }
+    else {
+        if ((value < 0.0 && d->minimum >= 0.0) || (value > 0.0 && d->maximum <= 0.0))
+            value = -value;
+    }
     return CLAMP(value, d->minimum, d->maximum);
 }
 
