@@ -1,5 +1,5 @@
 /*
- *  $Id: param-table.h 23765 2021-05-24 15:48:01Z yeti-dn $
+ *  $Id: param-table.h 24330 2021-10-11 15:45:25Z yeti-dn $
  *  Copyright (C) 2021 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -21,6 +21,7 @@
 #include <gtk/gtk.h>
 #include <libgwyddion/gwyresults.h>
 #include <libprocess/datafield.h>
+#include <libprocess/lawn.h>
 #include <libgwydgets/gwydgets.h>
 #include <app/datachooser.h>
 #include <app/gwyresultsexport.h>
@@ -91,6 +92,9 @@ void           gwy_param_table_set_string              (GwyParamTable *partable,
 void           gwy_param_table_set_data_id             (GwyParamTable *partable,
                                                         gint id,
                                                         GwyAppDataId value);
+void           gwy_param_table_set_curve               (GwyParamTable *partable,
+                                                        gint id,
+                                                        gint value);
 void           gwy_param_table_append_header           (GwyParamTable *partable,
                                                         gint id,
                                                         const gchar *label);
@@ -134,15 +138,31 @@ void           gwy_param_table_checkboxes_set_sensitive(GwyParamTable *partable,
                                                         gint id,
                                                         guint flags,
                                                         gboolean sensitive);
+void           gwy_param_table_append_graph_id         (GwyParamTable *partable,
+                                                        gint id);
 void           gwy_param_table_append_image_id         (GwyParamTable *partable,
                                                         gint id);
 void           gwy_param_table_append_volume_id        (GwyParamTable *partable,
                                                         gint id);
 void           gwy_param_table_append_xyz_id           (GwyParamTable *partable,
                                                         gint id);
+void           gwy_param_table_append_curve_map_id     (GwyParamTable *partable,
+                                                        gint id);
 void           gwy_param_table_append_target_graph     (GwyParamTable *partable,
                                                         gint id,
                                                         GwyGraphModel *gmodel);
+void           gwy_param_table_append_graph_curve      (GwyParamTable *partable,
+                                                        gint id,
+                                                        GwyGraphModel *gmodel);
+void           gwy_param_table_graph_curve_set_model   (GwyParamTable *partable,
+                                                        gint id,
+                                                        GwyGraphModel *gmodel);
+void           gwy_param_table_append_lawn_curve       (GwyParamTable *partable,
+                                                        gint id,
+                                                        GwyLawn *lawn);
+void           gwy_param_table_append_lawn_segment     (GwyParamTable *partable,
+                                                        gint id,
+                                                        GwyLawn *lawn);
 void           gwy_param_table_data_id_set_filter      (GwyParamTable *partable,
                                                         gint id,
                                                         GwyDataChooserFilterFunc filter,
@@ -191,6 +211,14 @@ void           gwy_param_table_alt_set_linear          (GwyParamTable *partable,
                                                         gdouble q_to_gui,
                                                         gdouble off_to_gui,
                                                         const gchar *unitstr);
+void           gwy_param_table_append_entry            (GwyParamTable *partable,
+                                                        gint id);
+void           gwy_param_table_entry_set_width         (GwyParamTable *partable,
+                                                        gint id,
+                                                        gint width_chars);
+void           gwy_param_table_entry_set_value_format  (GwyParamTable *partable,
+                                                        gint id,
+                                                        GwySIValueFormat *vf);
 void           gwy_param_table_append_unit_chooser     (GwyParamTable *partable,
                                                         gint id);
 void           gwy_param_table_append_mask_color       (GwyParamTable *partable,
