@@ -1,5 +1,5 @@
 /*
- *  $Id: params.c 23819 2021-06-09 21:16:20Z yeti-dn $
+ *  $Id: params.c 24503 2021-11-10 11:15:53Z yeti-dn $
  *  Copyright (C) 2021 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -15,6 +15,7 @@
  *  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
+#include "config.h"
 #include "libgwyddion/gwymacros.h"
 #include "libprocess/gwyprocesstypes.h"
 #include "libprocess/gwyprocessenums.h"
@@ -33,6 +34,12 @@ typedef struct {
     gboolean cached_valid;
 } GwyParamValueUnit;
 
+typedef struct {
+    gchar *s;
+    gint i;
+    gboolean use_string;
+} GwyParamValueCurve;
+
 typedef union {
     gboolean b;
     gint i;
@@ -43,6 +50,7 @@ typedef union {
     GwyAppDataId di;
     GwyResultsReportType rt;
     GwyParamValueUnit si;
+    GwyParamValueCurve cu;
 } GwyParamValue;
 
 struct _GwyParamsPrivate {
@@ -51,64 +59,75 @@ struct _GwyParamsPrivate {
     guint nvalues;
 };
 
-static void        gwy_params_finalize  (GObject *gobject);
-static gboolean    set_boolean_value    (GwyParamValue *pvalue,
-                                         gboolean value);
-static gboolean    set_int_value        (GwyParamValue *pvalue,
-                                         const GwyParamDefItem *def,
-                                         gint value);
-static gboolean    set_random_seed_value(GwyParamValue *pvalue,
-                                         const GwyParamDefItem *def,
-                                         gint value);
-static gboolean    set_double_value     (GwyParamValue *pvalue,
-                                         const GwyParamDefItem *def,
-                                         gdouble value);
-static gboolean    set_enum_value       (GwyParamValue *pvalue,
-                                         const GwyParamDefItem *def,
-                                         gint value);
-static gboolean    set_flags_value      (GwyParamValue *pvalue,
-                                         const GwyParamDefItem *def,
-                                         guint value);
-static gboolean    set_report_type_value(GwyParamValue *pvalue,
-                                         const GwyParamDefItem *def,
-                                         GwyResultsReportType value);
-static gboolean    set_string_value     (GwyParamValue *pvalue,
-                                         const GwyParamDefItem *def,
-                                         const gchar *value);
-static gboolean    set_unit_value       (GwyParamValue *pvalue,
-                                         const GwyParamDefItem *def,
-                                         const gchar *value);
-static gboolean    set_color_value      (GwyParamValue *pvalue,
-                                         const GwyParamDefItem *def,
-                                         GwyRGBA value);
-static gboolean    set_data_id_value    (GwyParamValue *pvalue,
-                                         GwyAppDataId value);
-static gboolean    set_resource_value   (GwyParamValue *pvalue,
-                                         const GwyParamDefItem *def,
-                                         const gchar *value);
-static gint        get_enum_internal    (GwyParams *params,
-                                         gint id,
-                                         GType type,
-                                         gint fallback_value);
-static guint       get_flags_internal   (GwyParams *params,
-                                         gint id,
-                                         GType type);
-static gboolean    reset_param_value    (GwyParams *params,
-                                         guint i);
-static gpointer    get_data_object      (GwyParams *params,
-                                         gint id,
-                                         GwyParamType param_type,
-                                         GQuark (*get_key_func)(gint id),
-                                         GType object_type);
-static gboolean    param_find_common    (GwyParams *params,
-                                         gint id,
-                                         gint *i,
-                                         const GwyParamDefItem **def,
-                                         GwyParamType want_type);
-static GHashTable* ensure_data_ids      (void);
+static void        gwy_params_finalize   (GObject *gobject);
+static gboolean    set_boolean_value     (GwyParamValue *pvalue,
+                                          gboolean value);
+static gboolean    set_int_value         (GwyParamValue *pvalue,
+                                          const GwyParamDefItem *def,
+                                          gint value);
+static gboolean    set_random_seed_value (GwyParamValue *pvalue,
+                                          const GwyParamDefItem *def,
+                                          gint value);
+static gboolean    set_double_value      (GwyParamValue *pvalue,
+                                          const GwyParamDefItem *def,
+                                          gdouble value);
+static gboolean    set_enum_value        (GwyParamValue *pvalue,
+                                          const GwyParamDefItem *def,
+                                          gint value);
+static gboolean    set_flags_value       (GwyParamValue *pvalue,
+                                          const GwyParamDefItem *def,
+                                          guint value);
+static gboolean    set_report_type_value (GwyParamValue *pvalue,
+                                          const GwyParamDefItem *def,
+                                          GwyResultsReportType value);
+static gboolean    set_string_value      (GwyParamValue *pvalue,
+                                          const GwyParamDefItem *def,
+                                          const gchar *value);
+static gboolean    set_curve_string_value(GwyParamValue *pvalue,
+                                          const GwyParamDefItem *def,
+                                          const gchar *value);
+static gboolean    set_curve_int_value   (GwyParamValue *pvalue,
+                                          const GwyParamDefItem *def,
+                                          const gint value);
+static gboolean    set_unit_value        (GwyParamValue *pvalue,
+                                          const GwyParamDefItem *def,
+                                          const gchar *value);
+static gboolean    set_color_value       (GwyParamValue *pvalue,
+                                          const GwyParamDefItem *def,
+                                          GwyRGBA value);
+static gboolean    set_data_id_value     (GwyParamValue *pvalue,
+                                          GwyAppDataId value);
+static gboolean    set_resource_value    (GwyParamValue *pvalue,
+                                          const GwyParamDefItem *def,
+                                          const gchar *value);
+static gint        get_enum_internal     (GwyParams *params,
+                                          gint id,
+                                          GType type,
+                                          gint fallback_value);
+static guint       get_flags_internal    (GwyParams *params,
+                                          gint id,
+                                          GType type);
+static gboolean    reset_param_value     (GwyParams *params,
+                                          guint i);
+static gpointer    get_data_object       (GwyParams *params,
+                                          gint id,
+                                          GwyParamType param_type,
+                                          GQuark (*get_key_func)(gint id),
+                                          GType object_type);
+static gpointer    get_data_object_for_id(GwyAppDataId dataid,
+                                          GQuark (*get_key_func)(gint id),
+                                          GType object_type);
+static gboolean    param_find_common     (GwyParams *params,
+                                          gint id,
+                                          gint *i,
+                                          const GwyParamDefItem **def,
+                                          GwyParamType want_type);
+static GHashTable* ensure_data_ids       (void);
 
 G_LOCK_DEFINE_STATIC(data_ids);
 
+static const GwyAppDataId noid = GWY_APP_DATA_ID_NONE;
+
 G_DEFINE_TYPE(GwyParams, gwy_params, G_TYPE_OBJECT);
 
 static void
@@ -207,6 +226,8 @@ gwy_params_duplicate(GwyParams *params)
 
         if (def->type == GWY_PARAM_STRING)
             values[i].s = g_strdup(values[i].s);
+        else if (def->type == GWY_PARAM_UNIT)
+            values[i].si.s = g_strdup(values[i].si.s);
     }
 
     return copy;
@@ -350,7 +371,7 @@ gwy_params_new_from_settings(GwyParamDef *pardef)
 
 /**
  * gwy_params_load_from_settings:
- * @pardef: Set of parameter definitions.
+ * @params: A set of parameter values.
  *
  * Loads a parameter value set from settings.
  *
@@ -378,7 +399,8 @@ gwy_params_load_from_settings(GwyParams *params)
         return;
     }
     settings = gwy_app_settings_get();
-    ensure_data_ids();
+    G_LOCK(data_ids);
+    data_ids = ensure_data_ids();
 
     n = priv->nvalues;
     values = priv->values;
@@ -388,8 +410,6 @@ gwy_params_load_from_settings(GwyParams *params)
     g_string_append_c(str, '/');
     pfxlen = str->len;
 
-    G_LOCK(data_ids);
-    data_ids = ensure_data_ids();
     for (i = 0; i < n; i++) {
         GwyParamValue *value = values + i;
         const GwyParamDefItem *def = _gwy_param_def_item(priv->def, i);
@@ -447,6 +467,11 @@ gwy_params_load_from_settings(GwyParams *params)
             if (gwy_container_gis_string(settings, quark, &v))
                 set_string_value(value, def, v);
         }
+        else if (param_type_is_curve_no(type)) {
+            const guchar *v;
+            if (gwy_container_gis_string(settings, quark, &v))
+                set_curve_string_value(value, def, v);
+        }
         else if (type == GWY_PARAM_UNIT) {
             const guchar *v;
             if (gwy_container_gis_string(settings, quark, &v))
@@ -476,6 +501,8 @@ gwy_params_load_from_settings(GwyParams *params)
                     gwy_app_data_id_verify_volume(&value->di);
                 else if (type == GWY_PARAM_XYZ_ID)
                     gwy_app_data_id_verify_xyz(&value->di);
+                else if (type == GWY_PARAM_CURVE_MAP_ID)
+                    gwy_app_data_id_verify_curve_map(&value->di);
             }
         }
         else {
@@ -566,6 +593,8 @@ gwy_params_save_to_settings(GwyParams *params)
             gwy_container_set_double(settings, quark, value->d);
         else if (type == GWY_PARAM_STRING)
             gwy_container_set_const_string(settings, quark, value->s ? value->s : "");
+        else if (param_type_is_curve_no(type))
+            gwy_container_set_const_string(settings, quark, value->cu.s ? value->cu.s : "");
         else if (type == GWY_PARAM_UNIT)
             gwy_container_set_const_string(settings, quark, value->si.s ? value->si.s : "");
         else if (type == GWY_PARAM_RESOURCE) {
@@ -680,6 +709,8 @@ gwy_params_get_int(GwyParams *params,
         || def->type == GWY_PARAM_RANDOM_SEED
         || def->type == GWY_PARAM_ACTIVE_PAGE)
         return params->priv->values[i].i;
+    if (param_type_is_curve_no(def->type))
+        return params->priv->values[i].cu.i;
     if (def->type == GWY_PARAM_FLAGS)
         return params->priv->values[i].u;
     if (def->type == GWY_PARAM_REPORT_TYPE)
@@ -716,6 +747,8 @@ gwy_params_set_int(GwyParams *params,
         return FALSE;
     if (def->type == GWY_PARAM_INT || def->type == GWY_PARAM_ACTIVE_PAGE)
         return set_int_value(params->priv->values + i, def, value);
+    if (param_type_is_curve_no(def->type))
+        return set_curve_int_value(params->priv->values + i, def, value);
     if (def->type == GWY_PARAM_RANDOM_SEED)
         return set_random_seed_value(params->priv->values + i, def, value);
     g_return_val_if_reached(0);
@@ -1036,6 +1069,8 @@ gwy_params_get_string(GwyParams *params,
         return params->priv->values[i].s;
     if (def->type == GWY_PARAM_UNIT)
         return params->priv->values[i].si.s;
+    if (param_type_is_curve_no(def->type))
+        return params->priv->values[i].cu.s;
     g_return_val_if_reached("");
 }
 
@@ -1061,9 +1096,14 @@ gwy_params_set_string(GwyParams *params,
     const GwyParamDefItem *def;
     gint i;
 
-    if (!param_find_common(params, id, &i, &def, GWY_PARAM_STRING))
+    if (!param_find_common(params, id, &i, &def, GWY_PARAM_NONE))
         return FALSE;
-    return set_string_value(params->priv->values + i, def, value);
+    if (def->type == GWY_PARAM_STRING)
+        return set_string_value(params->priv->values + i, def, value);
+    if (param_type_is_curve_no(def->type))
+        return set_curve_string_value(params->priv->values + i, def, value);
+    g_assert_not_reached();
+    return FALSE;
 }
 
 /**
@@ -1206,7 +1246,6 @@ GwyAppDataId
 gwy_params_get_data_id(GwyParams *params,
                        gint id)
 {
-    GwyAppDataId noid = GWY_APP_DATA_ID_NONE;
     const GwyParamDefItem *def;
     gint i;
 
@@ -1250,7 +1289,7 @@ gwy_params_data_id_is_none(GwyParams *params,
  *
  * Gets the data field object for an image identifier parameter.
  *
- * This is a more convenient alternative to gwy_params_get_data_id() which fetches and checks the object.
+ * This is a more convenient alternative to gwy_params_get_data_id() since it fetches and checks the object.
  *
  * Returns: The image data field, or %NULL if the parameter is none (or the image no longer exists).
  *
@@ -1270,7 +1309,7 @@ gwy_params_get_image(GwyParams *params,
  *
  * Gets the data field object for an mask identifier parameter.
  *
- * This is a more convenient alternative to gwy_params_get_data_id() which fetches and checks the object.
+ * This is a more convenient alternative to gwy_params_get_data_id() since it fetches and checks the object.
  *
  * Returns: The mask data field, or %NULL if the parameter is none (or the image no longer exists).
  *
@@ -1290,7 +1329,7 @@ gwy_params_get_mask(GwyParams *params,
  *
  * Gets the graph model object for a graph identifier parameter.
  *
- * This is a more convenient alternative to gwy_params_get_data_id() which fetches and checks the object.
+ * This is a more convenient alternative to gwy_params_get_data_id() since it fetches and checks the object.
  *
  * Returns: The graph model of the graph, or %NULL if the parameter is none (or the graph no longer exists).
  *
@@ -1310,7 +1349,7 @@ gwy_params_get_graph(GwyParams *params,
  *
  * Gets the brick object for a volume data identifier parameter.
  *
- * This is a more convenient alternative to gwy_params_get_data_id() which fetches and checks the object.
+ * This is a more convenient alternative to gwy_params_get_data_id() since it fetches and checks the object.
  *
  * Returns: The volume data brick, or %NULL if the parameter is none (or the volume data no longer exist).
  *
@@ -1330,7 +1369,7 @@ gwy_params_get_volume(GwyParams *params,
  *
  * Gets the surface object for a xyz data identifier parameter.
  *
- * This is a more convenient alternative to gwy_params_get_data_id() which fetches and checks the object.
+ * This is a more convenient alternative to gwy_params_get_data_id() since it fetches and checks the object.
  *
  * Returns: The xyz data surface, or %NULL if the parameter is none (or the xyz data no longer exist).
  *
@@ -1343,6 +1382,26 @@ gwy_params_get_xyz(GwyParams *params,
     return get_data_object(params, id, GWY_PARAM_XYZ_ID, gwy_app_get_surface_key_for_id, GWY_TYPE_SURFACE);
 }
 
+/**
+ * gwy_params_get_curve_map:
+ * @params: A parameter value set.
+ * @id: Parameter identifier.
+ *
+ * Gets the lawn object for a curve map data identifier parameter.
+ *
+ * This is a more convenient alternative to gwy_params_get_data_id() since it fetches and checks the object.
+ *
+ * Returns: The curve map data lawn, or %NULL if the parameter is none (or the curve map data no longer exist).
+ *
+ * Since: 2.60
+ **/
+GwyLawn*
+gwy_params_get_curve_map(GwyParams *params,
+                         gint id)
+{
+    return get_data_object(params, id, GWY_PARAM_CURVE_MAP_ID, gwy_app_get_lawn_key_for_id, GWY_TYPE_LAWN);
+}
+
 /**
  * gwy_params_set_image_id:
  * @params: A set of parameter values.
@@ -1353,7 +1412,7 @@ gwy_params_get_xyz(GwyParams *params,
  *
  * This function is seldom needed.  See the introduction for discussion.
  *
- * The image identified by @value must currently exist.
+ * If @value is not %GWY_APP_DATA_ID_NONE then the image identified by @value must currently exist.
  *
  * Returns: %TRUE if parameter value has changed.
  *
@@ -1382,7 +1441,7 @@ gwy_params_set_image_id(GwyParams *params,
  *
  * This function is seldom needed.  See the introduction for discussion.
  *
- * The graph identified by @value must currently exist.
+ * If @value is not %GWY_APP_DATA_ID_NONE then the graph identified by @value must currently exist.
  *
  * Returns: %TRUE if parameter value has changed.
  *
@@ -1409,7 +1468,7 @@ gwy_params_set_graph_id(GwyParams *params,
  *
  * Sets the value of a volume data identifier parameter.
  *
- * The volume data identified by @value must currently exist.
+ * If @value is not %GWY_APP_DATA_ID_NONE then the volume data identified by @value must currently exist.
  *
  * This function is seldom needed.  See the introduction for discussion.
  *
@@ -1438,7 +1497,7 @@ gwy_params_set_volume_id(GwyParams *params,
  *
  * This function is seldom needed.  See the introduction for discussion.
  *
- * The xyz data identified by @value must currently exist.
+ * If @value is not %GWY_APP_DATA_ID_NONE then the XYZ data identified by @value must currently exist.
  *
  * Returns: %TRUE if parameter value has changed.
  *
@@ -1457,6 +1516,63 @@ gwy_params_set_xyz_id(GwyParams *params,
     return set_data_id_value(params->priv->values + i, value);
 }
 
+/**
+ * gwy_params_set_curve_map_id:
+ * @params: A set of parameter values.
+ * @id: Parameter identifier.
+ * @value: Value to set.
+ *
+ * Sets the value of a curve map data identifier parameter.
+ *
+ * This function is seldom needed.  See the introduction for discussion.
+ *
+ * If @value is not %GWY_APP_DATA_ID_NONE then the curve map data identified by @value must currently exist.
+ *
+ * Returns: %TRUE if parameter value has changed.
+ *
+ * Since: 2.60
+ **/
+gboolean
+gwy_params_set_curve_map_id(GwyParams *params,
+                            gint id,
+                            GwyAppDataId value)
+{
+    gint i;
+
+    if (!param_find_common(params, id, &i, NULL, GWY_PARAM_CURVE_MAP_ID))
+        return FALSE;
+    g_return_val_if_fail((value.datano == 0 && value.id == -1) || gwy_app_data_id_verify_curve_map(&value), FALSE);
+    return set_data_id_value(params->priv->values + i, value);
+}
+
+/**
+ * gwy_params_set_curve:
+ * @params: A set of parameter values.
+ * @id: Parameter identifier.
+ * @value: Value to set (a non-negative integer or -1).
+ *
+ * Sets the value of a graph or lawn curve number parameter.
+ *
+ * This function is seldom needed.  See the introduction for discussion.
+ *
+ * Returns: %TRUE if parameter value has changed.
+ *
+ * Since: 2.60
+ **/
+gboolean
+gwy_params_set_curve(GwyParams *params,
+                     gint id,
+                     gint value)
+{
+    const GwyParamDefItem *def;
+    gint i;
+
+    if (!param_find_common(params, id, &i, &def, GWY_PARAM_NONE))
+        return FALSE;
+    g_return_val_if_fail(param_type_is_curve_no(def->type), FALSE);
+    return set_curve_int_value(params->priv->values + i, def, value);
+}
+
 /**
  * gwy_params_randomize_seed:
  * @params: A set of parameter values.
@@ -1626,6 +1742,41 @@ set_string_value(GwyParamValue *pvalue, const GwyParamDefItem *def, const gchar
     return TRUE;
 }
 
+static gboolean
+set_curve_string_value(GwyParamValue *pvalue, const GwyParamDefItem *def, const gchar *value)
+{
+    g_return_val_if_fail(param_type_is_curve_no(def->type), FALSE);
+    pvalue->cu.use_string = TRUE;
+    return gwy_assign_string(&pvalue->cu.s, value);
+}
+
+static gboolean
+set_curve_int_value(GwyParamValue *pvalue, const GwyParamDefItem *def, gint value)
+{
+    gint goodvalue = MAX(value, 0);
+    if (value != goodvalue) {
+        g_warning("Value %d is not a valid curve number in id=%d.", value, def->id);
+        return FALSE;
+    }
+    pvalue->cu.use_string = FALSE;
+    if (pvalue->cu.i == value)
+        return FALSE;
+    pvalue->cu.i = value;
+    return TRUE;
+}
+
+gboolean
+_gwy_params_curve_get_use_string(GwyParams *params, gint id)
+{
+    const GwyParamDefItem *def;
+    gint i;
+
+    if (!param_find_common(params, id, &i, &def, GWY_PARAM_NONE))
+        return 0;
+    g_return_val_if_fail(param_type_is_curve_no(def->type), FALSE);
+    return params->priv->values[i].cu.use_string;
+}
+
 static gboolean
 set_unit_value(GwyParamValue *pvalue, const GwyParamDefItem *def, const gchar *value)
 {
@@ -1750,33 +1901,37 @@ reset_param_value(GwyParams *params, guint i)
         return set_resource_value(value, def, def->def.res.default_value);
     if (type == GWY_PARAM_COLOR)
         return set_color_value(value, def, def->def.c.default_value);
-    if (param_type_is_data_id(type)) {
-        GwyAppDataId noid = GWY_APP_DATA_ID_NONE;
+    if (param_type_is_data_id(type))
         return set_data_id_value(value, noid);
-    }
+    if (param_type_is_curve_no(type))
+        return set_curve_int_value(value, def, def->def.i.default_value);
     g_return_val_if_reached(FALSE);
 }
 
+/* This also works for curve parameters, by getting the parent object. */
 static gpointer
 get_data_object(GwyParams *params, gint id,
                 GwyParamType param_type, GQuark (*get_key_func)(gint id), GType object_type)
 {
-    GwyContainer *container;
-    GwyAppDataId dataid;
-    GObject *object;
     gint i;
 
     if (!param_find_common(params, id, &i, NULL, param_type))
         return NULL;
+    return get_data_object_for_id(params->priv->values[i].di, get_key_func, object_type);
+}
+
+static gpointer
+get_data_object_for_id(GwyAppDataId dataid, GQuark (*get_key_func)(gint id), GType object_type)
+{
+    GwyContainer *container;
+    GObject *object;
 
-    dataid = params->priv->values[i].di;
     if (dataid.datano < 1
         || dataid.id < 0
         || !(container = gwy_app_data_browser_get(dataid.datano))
         || !gwy_container_gis_object(container, get_key_func(dataid.id), &object)
         || !g_type_is_a(G_TYPE_FROM_INSTANCE(object), object_type))
         return NULL;
-
     return object;
 }
 
@@ -1802,6 +1957,8 @@ param_find_common(GwyParams *params, gint id, gint *i, const GwyParamDefItem **d
     return TRUE;
 }
 
+/* NB: This keeps both data id and curve id parameter values.  This is OK as long as modules do not try something
+ * silly.  Then we can get mixed DataId and CurveId params – and probably crash. */
 static GHashTable*
 ensure_data_ids(void)
 {
