@@ -1,5 +1,5 @@
 /*
- *  $Id: settings.c 20678 2017-12-18 18:26:55Z yeti-dn $
+ *  $Id: settings.c 23986 2021-08-16 13:15:36Z yeti-dn $
  *  Copyright (C) 2003-2006 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -494,7 +494,7 @@ gchar**
 gwy_app_settings_get_module_dirs(void)
 {
     const gchar *module_types[] = {
-        "layer", "file", "process", "graph", "tool", "volume", "xyz",
+        "cmap", "layer", "file", "process", "graph", "tool", "volume", "xyz",
     };
     gchar **module_dirs;
     gchar *p;
