@@ -1,5 +1,5 @@
 /*
- *  $Id: about.c 22445 2019-08-27 13:17:36Z yeti-dn $
+ *  $Id: about.c 24207 2021-09-28 09:00:55Z yeti-dn $
  *  Copyright (C) 2003-2018 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -49,7 +49,7 @@ gwy_app_about(void)
     GtkWidget *vbox, *hbox, *widget, *credits, *text, *notebook;
     GtkTextBuffer *buff;
     GtkTextIter iter;
-    GString *str = g_string_new(NULL);
+    GString *str;
     const gchar *verextra = "";
     gint size;
 
@@ -57,6 +57,7 @@ gwy_app_about(void)
         gtk_window_present(GTK_WINDOW(about));
         return;
     }
+    str = g_string_new(NULL);
     g_string_printf(str, _("About %s"), g_get_application_name());
     about = gtk_dialog_new_with_buttons(str->str,
                                         GTK_WINDOW(gwy_app_main_window_get()),
