@@ -1,22 +1,18 @@
 /*
- *  $Id: gwyddion.c 22534 2019-10-02 08:35:40Z yeti-dn $
- *  Copyright (C) 2003-2019 David Necas (Yeti), Petr Klapetek.
+ *  $Id: gwyddion.c 24403 2021-10-22 12:56:03Z yeti-dn $
+ *  Copyright (C) 2003-2021 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
+ *  License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any
+ *  later version.
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
+ *  warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+ *  details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
+ *  You should have received a copy of the GNU General Public License along with this program; if not, write to the
+ *  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #include "config.h"
@@ -50,13 +46,19 @@
 #define LOG_TO_CONSOLE_DEFAULT TRUE
 #endif
 
+typedef enum {
+    MODE_NORMAL,
+    MODE_CHECK,
+    MODE_IDENTIFY,
+} GwyAppMode;
+
 typedef struct {
     gboolean no_splash;
     gboolean startup_time;
-    gboolean check;
     gboolean disable_gl;
     gboolean log_to_file;
     gboolean log_to_console;
+    GwyAppMode mode;
     GwyAppRemoteType remote;
 } GwyAppOptions;
 
@@ -65,9 +67,14 @@ static gboolean open_command_line_files         (gint n,
 static gboolean open_directory_at_startup       (gpointer user_data);
 static void     block_modules                   (const gchar *modules_to_block);
 static gboolean show_tip_at_startup             (gpointer user_data);
+static gint     identify_command_line_files     (gint n,
+                                                 gchar **args);
 static gint     check_command_line_files        (gint n,
                                                  gchar **args);
-static void     print_help                      (void);
+static void     print_help_and_exit             (void);
+static void     print_version_and_exit          (void);
+static void     extend_disabled_modules_arg     (const gchar *arg,
+                                                 gchar **modules_to_block);
 static void     process_preinit_options         (int *argc,
                                                  char ***argv,
                                                  GwyAppOptions *options,
@@ -85,9 +92,9 @@ static void     gwy_app_set_window_icon         (void);
 static void     gwy_app_check_version           (void);
 
 static GwyAppOptions app_options = {
-    FALSE, FALSE, FALSE, FALSE,
+    FALSE, FALSE, FALSE,
     LOG_TO_FILE_DEFAULT, LOG_TO_CONSOLE_DEFAULT,
-    GWY_APP_REMOTE_DEFAULT,
+    MODE_NORMAL, GWY_APP_REMOTE_DEFAULT,
 };
 
 # ifdef __MINGW64__
@@ -112,26 +119,20 @@ main(int argc, char *argv[])
     timer = g_timer_new();
 
     process_preinit_options(&argc, &argv, &app_options, &modules_to_block);
-    gwy_app_setup_logging((app_options.log_to_file
-                           ? GWY_APP_LOGGING_TO_FILE : 0)
-                          | (app_options.log_to_console
-                             ? GWY_APP_LOGGING_TO_CONSOLE : 0));
+    gwy_app_setup_logging((app_options.log_to_file ? GWY_APP_LOGGING_TO_FILE : 0)
+                          | (app_options.log_to_console ? GWY_APP_LOGGING_TO_CONSOLE : 0));
     gwy_app_check_version();
 
     gwy_osx_init_handler(&argc);
     gwy_osx_set_locale();
 
-    /* If we are given some files to open *and* we are not run from a terminal,
-     * we are almost surely run from some kind of file association.  So behave
-     * as if --remote-new was the default because various ‘Open this with that’
-     * selectors often allow selecting a program, but passing options is much
-     * more difficult.  Otherwise behave normally, i.e. as if --new-instance
-     * was the default.  */
+    /* If we are given some files to open *and* we are not run from a terminal, we are almost surely run from some
+     * kind of file association.  So behave as if --remote-new was the default because various ‘Open this with that’
+     * selectors often allow selecting a program, but passing options is much more difficult.  Otherwise behave
+     * normally, i.e. as if --new-instance was the default.  */
 #ifdef HAVE_UNISTD_H
     if (app_options.remote == GWY_APP_REMOTE_DEFAULT) {
-        if (isatty(fileno(stdin))
-            || isatty(fileno(stdout))
-            || isatty(fileno(stderr)))
+        if (isatty(fileno(stdin)) || isatty(fileno(stdout)) || isatty(fileno(stderr)))
             app_options.remote = GWY_APP_REMOTE_NONE;
     }
 #endif
@@ -154,10 +155,9 @@ main(int argc, char *argv[])
 
     settings_file = gwy_app_settings_get_settings_filename();
     has_settings = g_file_test(settings_file, G_FILE_TEST_IS_REGULAR);
-    gwy_debug("Text settings file is `%s'. Do we have it: %s",
-              settings_file, has_settings ? "TRUE" : "FALSE");
+    gwy_debug("Text settings file is `%s'. Do we have it: %s", settings_file, has_settings ? "TRUE" : "FALSE");
 
-    gwy_app_splash_start(!app_options.no_splash && !app_options.check);
+    gwy_app_splash_start(!app_options.no_splash && app_options.mode == MODE_NORMAL);
     debug_time(timer, "create splash");
 
     accel_file = g_build_filename(gwy_get_user_dir(), "ui", "accel_map", NULL);
@@ -193,47 +193,43 @@ main(int argc, char *argv[])
     debug_time(timer, "load settings");
 
     /* Modules load pretty fast with bundling.  Most time is taken by:
-     * 1) pygwy, but only if it registers some Python modules; when it is no-op
-     *    it is fast, so you only pay the price when you get the benefit
-     * 2) a few external libraries are noticeably slow to init, in particular
-     *    cfitsio (we do not call any its function during registration, so it
-     *    is its internal init)
-     * Running gwyddion --disable-modules=pygwy,fitsfile
-     * can take module registration down to ~6 ms. */
+     * 1) pygwy, but only if it registers some Python modules; when it is no-op it is fast, so you only pay the price
+     *    when you get the benefits
+     * 2) a few external libraries that are noticeably slow to init, in particular cfitsio (we do not call any its
+     *    function during registration, so it is its internal init)
+     * Running gwyddion --disable-modules=pygwy,fitsfile can take module registration down to ~6 ms. */
     gwy_app_splash_set_message(_("Registering modules"));
+    if (app_options.mode == MODE_IDENTIFY)
+        extend_disabled_modules_arg("rawfile", &modules_to_block);
     block_modules(modules_to_block);
     GWY_FREE(modules_to_block);
+
     module_dirs = gwy_app_settings_get_module_dirs();
     gwy_module_register_modules((const gchar**)module_dirs);
-    /* The Python initialisation somehow overrides SIGINT and Gwyddion can no
-     * longer be terminated with Ctrl-C.  Fix it. */
+    /* The Python initialisation overrides SIGINT and Gwyddion can no longer be terminated with Ctrl-C.  Fix it. */
     signal(SIGINT, SIG_DFL);
-    /* TODO: The Python initialisation also overrides where the warnings go.
-     * Restore the handlers. */
+    /* TODO: The Python initialisation also overrides where the warnings go. Restore the handlers. */
     debug_time(timer, "register modules");
 
-    if (app_options.check) {
-        gint nfailures;
-
-        gwy_app_splash_finish();
-        debug_time(timer, "destroy splash");
-
-        nfailures = check_command_line_files(argc - 1, argv + 1);
-        debug_time(timer, "check files");
-
-        return !nfailures;
-    }
-
-    /* Destroy splash before creating UI.  Opposite order of actions can
-     * apparently lead to strange errors. */
+    /* Destroy splash before creating UI.  Opposite order of actions can apparently lead to strange errors. */
     gwy_app_splash_finish();
     debug_time(timer, "destroy splash");
 
+    if (app_options.mode == MODE_IDENTIFY) {
+        gint nfailures = identify_command_line_files(argc - 1, argv + 1);
+        debug_time(timer, "identify files");
+        return !!nfailures;
+    }
+    if (app_options.mode == MODE_CHECK) {
+        gint nfailures = check_command_line_files(argc - 1, argv + 1);
+        debug_time(timer, "check files");
+        return !!nfailures;
+    }
+
     /* Toolbox creation is one of the most time-consuming parts of startup.
      *
-     * Most of the time, about 2/3, is taken by show-all on the toolbox widget
-     * (this is likely also theme-dependent, etc.).  There may not be much we
-     * can do to speed it up -- it is the price of having a GUI at all. */
+     * Most of the time, about 2/3, is taken by show-all on the toolbox widget (this is likely also theme-dependent,
+     * etc.).  There may not be much we can do to speed it up -- it is the price of having a GUI at all. */
     toolbox = gwy_app_toolbox_window_create();
     debug_time(timer, "create toolbox");
     gwy_app_data_browser_restore();
@@ -242,18 +238,15 @@ main(int argc, char *argv[])
     gwy_app_recent_file_list_update(NULL, NULL, NULL, 0);
     debug_time(timer, "create recent files menu");
 
-    /* Win32 does not give programs a reasonable physical cwd.  So try to set
-     * something reasonable here.  Do it before opening files from arguments
-     * because that can set the directory. */
+    /* Win32 does not give programs a reasonable physical cwd.  So try to set something reasonable here.  Do it before
+     * opening files from arguments because that can set the directory. */
 #ifdef G_OS_WIN32
     {
         const gchar *cwd;
 
-        if ((cwd = g_get_user_special_dir(G_USER_DIRECTORY_DOCUMENTS))
-             && g_file_test(cwd, G_FILE_TEST_IS_DIR))
+        if ((cwd = g_get_user_special_dir(G_USER_DIRECTORY_DOCUMENTS)) && g_file_test(cwd, G_FILE_TEST_IS_DIR))
             gwy_app_set_current_directory(cwd);
-        else if ((cwd = g_get_home_dir())
-             && g_file_test(cwd, G_FILE_TEST_IS_DIR))
+        else if ((cwd = g_get_home_dir()) && g_file_test(cwd, G_FILE_TEST_IS_DIR))
             gwy_app_set_current_directory(cwd);
         else if (g_file_test("c:\\", G_FILE_TEST_IS_DIR))
             gwy_app_set_current_directory("c:\\");
@@ -261,11 +254,8 @@ main(int argc, char *argv[])
 #endif
 
     if (has_settings && !settings_ok) {
-        if (!(settings_err->domain == GWY_APP_SETTINGS_ERROR
-              && settings_err->code == GWY_APP_SETTINGS_ERROR_EMPTY)) {
-            warn_broken_settings_file(toolbox,
-                                      settings_file, settings_err->message);
-        }
+        if (!(settings_err->domain == GWY_APP_SETTINGS_ERROR && settings_err->code == GWY_APP_SETTINGS_ERROR_EMPTY))
+            warn_broken_settings_file(toolbox, settings_file, settings_err->message);
         g_clear_error(&settings_err);
     }
 
@@ -282,8 +272,7 @@ main(int argc, char *argv[])
     g_timer_destroy(timer);
     debug_time(NULL, "STARTUP");
 
-    gwy_container_gis_boolean_by_name(settings, "/app/tips/show-at-startup",
-                                      &show_tips);
+    gwy_container_gis_boolean_by_name(settings, "/app/tips/show-at-startup", &show_tips);
     if (show_tips && !opening_files)
         g_idle_add(show_tip_at_startup, NULL);
 
@@ -323,114 +312,69 @@ process_preinit_options(int *argc,
                         GwyAppOptions *options,
                         gchar **modules_to_block)
 {
+    gboolean ignore, handled;
+    const gchar *arg;
     int i, j;
-    gboolean ignore = FALSE;
-
-    if (*argc == 1)
-        return;
-
-    if (gwy_strequal((*argv)[1], "--help")
-        || gwy_strequal((*argv)[1], "-h")) {
-        print_help();
-        exit(0);
-    }
-
-    if (gwy_strequal((*argv)[1], "--version")
-        || gwy_strequal((*argv)[1], "-v")) {
-        const gchar *verextra = "";
-        gchar *s;
-
-        s = gwy_version_date_info();
-        if (!RELEASEDATE && strlen(GWY_VERSION_STRING) < 9)
-            verextra = "+SVN";
-
-        printf("%s %s%s (%s)\n", PACKAGE_NAME, GWY_VERSION_STRING, verextra, s);
-        g_free(s);
-        exit(0);
-    }
 
+    ignore = FALSE;
     for (i = j = 1; i < *argc; i++) {
         if (gwy_strequal((*argv)[i], "--"))
             ignore = TRUE;
 
         (*argv)[j] = (*argv)[i];
-
-        if (!ignore) {
-            if (gwy_strequal((*argv)[i], "--no-splash")) {
-                options->no_splash = TRUE;
-                continue;
-            }
-            if (gwy_strequal((*argv)[i], "--remote-existing")) {
-                options->remote = GWY_APP_REMOTE_EXISTING;
-                continue;
-            }
-            if (gwy_strequal((*argv)[i], "--remote-new")) {
-                options->remote = GWY_APP_REMOTE_NEW;
-                continue;
-            }
-            if (gwy_strequal((*argv)[i], "--remote-query")) {
-                options->remote = GWY_APP_REMOTE_QUERY;
-                continue;
-            }
-            if (gwy_strequal((*argv)[i], "--new-instance")) {
-                options->remote = GWY_APP_REMOTE_NONE;
-                continue;
-            }
-            if (gwy_strequal((*argv)[i], "--debug-objects")) {
-                /* Silently ignore it. */
-                continue;
-            }
-            if (gwy_strequal((*argv)[i], "--startup-time")) {
-                options->startup_time = TRUE;
-                continue;
-            }
-            if (gwy_strequal((*argv)[i], "--log-to-file")) {
-                options->log_to_file = TRUE;
-                continue;
-            }
-            if (gwy_strequal((*argv)[i], "--no-log-to-file")) {
-                options->log_to_file = FALSE;
-                continue;
-            }
-            if (gwy_strequal((*argv)[i], "--log-to-console")) {
-                options->log_to_console = TRUE;
-                continue;
-            }
-            if (gwy_strequal((*argv)[i], "--no-log-to-console")) {
-                options->log_to_console = FALSE;
-                continue;
-            }
-            if (gwy_strequal((*argv)[i], "--disable-gl")) {
-                options->disable_gl = TRUE;
-                continue;
-            }
-            if (gwy_strequal((*argv)[i], "--check")) {
-                options->check = TRUE;
-                continue;
-            }
-            if (g_str_has_prefix((*argv)[i], "--disable-modules=")) {
-                const gchar *v = (*argv)[i] + strlen("--disable-modules=");
-                if (strlen(v)) {
-                    if (*modules_to_block) {
-                        gchar *s = g_strconcat(*modules_to_block, ",", v, NULL);
-                        g_free(*modules_to_block);
-                        *modules_to_block = s;
-                    }
-                    else
-                        *modules_to_block = g_strdup(v);
-                }
-                continue;
-            }
+        if (ignore) {
+            j++;
+            continue;
         }
+        arg = (*argv)[i];
+        handled = TRUE;
+        if (gwy_stramong(arg, "--help", "-h", NULL))
+            print_help_and_exit();
+        if (gwy_stramong(arg, "--version", "-v", NULL))
+            print_version_and_exit();
+        else if (gwy_strequal(arg, "--no-splash"))
+            options->no_splash = TRUE;
+        else if (gwy_strequal(arg, "--remote-existing"))
+            options->remote = GWY_APP_REMOTE_EXISTING;
+        else if (gwy_strequal(arg, "--remote-new"))
+            options->remote = GWY_APP_REMOTE_NEW;
+        else if (gwy_strequal(arg, "--remote-query"))
+            options->remote = GWY_APP_REMOTE_QUERY;
+        else if (gwy_strequal(arg, "--new-instance"))
+            options->remote = GWY_APP_REMOTE_NONE;
+        else if (gwy_strequal(arg, "--debug-objects")) {
+            /* Silently ignore it. */
+        }
+        else if (gwy_strequal(arg, "--startup-time"))
+            options->startup_time = TRUE;
+        else if (gwy_strequal(arg, "--log-to-file"))
+            options->log_to_file = TRUE;
+        else if (gwy_strequal(arg, "--no-log-to-file"))
+            options->log_to_file = FALSE;
+        else if (gwy_strequal(arg, "--log-to-console"))
+            options->log_to_console = TRUE;
+        else if (gwy_strequal(arg, "--no-log-to-console"))
+            options->log_to_console = FALSE;
+        else if (gwy_strequal(arg, "--disable-gl"))
+            options->disable_gl = TRUE;
+        else if (gwy_strequal(arg, "--check"))
+            options->mode = MODE_CHECK;
+        else if (gwy_strequal(arg, "--identify"))
+            options->mode = MODE_IDENTIFY;
+        else if (g_str_has_prefix(arg, "--disable-modules="))
+            extend_disabled_modules_arg(arg + strlen("--disable-modules="), modules_to_block);
+        else
+            handled = FALSE;
 
-        j++;
+        if (!handled)
+            j++;
     }
     (*argv)[j] = NULL;
     *argc = j;
 }
 
 static void
-print_help(void)
+print_help_and_exit(void)
 {
     puts(
 "Usage: gwyddion [OPTIONS...] FILES...\n"
@@ -445,6 +389,7 @@ print_help(void)
 "     --remote-new           Load FILES to a running instance or run a new one.\n"
 "     --remote-existing      Load FILES to a running instance or fail.\n"
 "     --new-instance         Run a new instance, ignoring any already running.\n"
+"     --identify             Identify and print the type of SPM data FILES.\n"
 "     --check                Check FILES, print problems and terminate.\n"
 "     --disable-gl           Disable OpenGL, including any availability checks.\n"
 "     --log-to-file          Write messages to file set in GWYDDION_LOGFILE.\n"
@@ -467,11 +412,41 @@ print_help(void)
 "how it was compiled, and on loaded modules.  Please see Gtk+ documentation.\n"
         );
     puts("Please report bugs to <" PACKAGE_BUGREPORT ">.");
+    exit(0);
 }
 
 static void
-debug_time(GTimer *timer,
-           const gchar *task)
+print_version_and_exit(void)
+{
+    const gchar *verextra = "";
+    gchar *s;
+
+    s = gwy_version_date_info();
+    if (!RELEASEDATE && strlen(GWY_VERSION_STRING) < 9)
+        verextra = "+SVN";
+
+    printf("%s %s%s (%s)\n", PACKAGE_NAME, GWY_VERSION_STRING, verextra, s);
+    g_free(s);
+    exit(0);
+}
+
+static void
+extend_disabled_modules_arg(const gchar *arg, gchar **modules_to_block)
+{
+    if (!strlen(arg))
+        return;
+
+    if (*modules_to_block) {
+        gchar *s = g_strconcat(*modules_to_block, ",", arg, NULL);
+        g_free(*modules_to_block);
+        *modules_to_block = s;
+    }
+    else
+        *modules_to_block = g_strdup(arg);
+}
+
+static void
+debug_time(GTimer *timer, const gchar *task)
 {
     static gdouble total = 0.0;
 
@@ -498,17 +473,14 @@ warn_broken_settings_file(GtkWidget *parent,
 {
     GtkWidget *dialog;
 
-    dialog = gtk_message_dialog_new(GTK_WINDOW(parent),
-                                    GTK_DIALOG_DESTROY_WITH_PARENT,
-                                    GTK_MESSAGE_WARNING,
-                                    GTK_BUTTONS_OK,
+    dialog = gtk_message_dialog_new(GTK_WINDOW(parent), GTK_DIALOG_DESTROY_WITH_PARENT,
+                                    GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,
                                     _("Could not read settings."));
-    gtk_message_dialog_format_secondary_text
-        (GTK_MESSAGE_DIALOG(dialog),
-         _("Settings file `%s' cannot be read: %s\n\n"
-           "To prevent loss of saved settings no attempt to update it will "
-           "be made until it is repaired or removed."),
-         settings_file, reason);
+    gtk_message_dialog_format_secondary_text(GTK_MESSAGE_DIALOG(dialog),
+                                             _("Settings file `%s' cannot be read: %s\n\n"
+                                               "To prevent loss of saved settings no attempt to update it will "
+                                               "be made until it is repaired or removed."),
+                                             settings_file, reason);
     /* parent is usually in a screen corner, centering on it looks ugly */
     gtk_window_set_position(GTK_WINDOW(dialog), GTK_WIN_POS_CENTER);
     gtk_window_present(GTK_WINDOW(dialog));
@@ -539,23 +511,19 @@ check_broken_modules(GtkWidget *parent)
     if (n < 8)
         return;
 
-    dialog = gtk_message_dialog_new(GTK_WINDOW(parent),
-                                    GTK_DIALOG_DESTROY_WITH_PARENT,
-                                    GTK_MESSAGE_WARNING,
-                                    GTK_BUTTONS_OK,
-                                    _("Many modules (%u) failed to register."),
-                                    n);
+    dialog = gtk_message_dialog_new(GTK_WINDOW(parent), GTK_DIALOG_DESTROY_WITH_PARENT,
+                                    GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,
+                                    _("Many modules (%u) failed to register."), n);
     moduledir = gwy_find_self_dir("modules");
-    gtk_message_dialog_format_secondary_text
-        (GTK_MESSAGE_DIALOG(dialog),
-         _("Most likely Gwyddion was not upgraded correctly.  "
-           "Instead, one installation was just overwritten with another, "
-           "and now it is a mess.\n\n"
-           "Please remove completely the module directory\n\n"
-           "%s\n\n"
-           "and reinstall Gwyddion.\n\n"
-           "See Info → Module Browser for specific errors."),
-         moduledir);
+    gtk_message_dialog_format_secondary_text(GTK_MESSAGE_DIALOG(dialog),
+                                             _("Most likely Gwyddion was not upgraded correctly.  "
+                                               "Instead, one installation was just overwritten with another, "
+                                               "and now it is a mess.\n\n"
+                                               "Please remove completely the module directory\n\n"
+                                               "%s\n\n"
+                                               "and reinstall Gwyddion.\n\n"
+                                               "See Info → Module Browser for specific errors."),
+                                             moduledir);
     g_free(moduledir);
     /* parent is usually in a screen corner, centering on it looks ugly */
     gtk_window_set_position(GTK_WINDOW(dialog), GTK_WIN_POS_CENTER);
@@ -573,20 +541,16 @@ setup_locale_from_win32_registry(void)
     HKEY reg_key;
 
     gwy_clear(locale, sizeof(locale));
-    if (RegOpenKeyEx(HKEY_CURRENT_USER, TEXT(gwyddion_key),
-                     0, KEY_READ, &reg_key) == ERROR_SUCCESS) {
-        if (RegQueryValueEx(reg_key, TEXT("Locale"), NULL, NULL,
-                            locale, &size) == ERROR_SUCCESS) {
+    if (RegOpenKeyEx(HKEY_CURRENT_USER, TEXT(gwyddion_key), 0, KEY_READ, &reg_key) == ERROR_SUCCESS) {
+        if (RegQueryValueEx(reg_key, TEXT("Locale"), NULL, NULL, locale, &size) == ERROR_SUCCESS) {
             g_setenv("LANG", locale, TRUE);
             RegCloseKey(reg_key);
             return;
         }
         RegCloseKey(reg_key);
     }
-    if (RegOpenKeyEx(HKEY_LOCAL_MACHINE, TEXT(gwyddion_key),
-                     0, KEY_READ, &reg_key) == ERROR_SUCCESS) {
-        if (RegQueryValueEx(reg_key, TEXT("Locale"), NULL, NULL,
-                            locale, &size) == ERROR_SUCCESS)
+    if (RegOpenKeyEx(HKEY_LOCAL_MACHINE, TEXT(gwyddion_key), 0, KEY_READ, &reg_key) == ERROR_SUCCESS) {
+        if (RegQueryValueEx(reg_key, TEXT("Locale"), NULL, NULL, locale, &size) == ERROR_SUCCESS)
             g_setenv("LANG", locale, TRUE);
         RegCloseKey(reg_key);
     }
@@ -682,8 +646,29 @@ open_directory_at_startup(gpointer user_data)
 }
 
 static gint
-check_command_line_files(gint n,
-                         gchar **args)
+identify_command_line_files(gint n, gchar **args)
+{
+    gint i, nfailures;
+
+    /* FIXME: cwd is in GLib encoding. And args? */
+    for (i = nfailures = 0; i < n; i++) {
+        const gchar *filename = args[i], *name;
+        gint score;
+
+        name = gwy_file_detect_with_score(filename, FALSE, GWY_FILE_OPERATION_LOAD, &score);
+        if (name)
+            g_print("%s: %s [%s, %d]\n", filename, gwy_file_func_get_description(name), name, score);
+        else {
+            g_print("%s: %s\n", filename, _("Unknown"));
+            nfailures++;
+        }
+    }
+
+    return nfailures;
+}
+
+static gint
+check_command_line_files(gint n, gchar **args)
 {
     gint i, nfailures;
 
@@ -697,8 +682,7 @@ check_command_line_files(gint n,
 
         if (!(data = gwy_file_load(filename, GWY_RUN_NONINTERACTIVE, &error))) {
             if (!error)
-                g_printerr("%s: Loader failed to report error properly!\n",
-                           filename);
+                g_printerr("%s: Loader failed to report error properly!\n", filename);
             else {
                 g_printerr("%s: %s\n", filename, error->message);
                 g_clear_error(&error);
@@ -710,13 +694,9 @@ check_command_line_files(gint n,
         gwy_file_get_data_info(data, &name, NULL);
         g_assert(name);
         for (f = failures; f; f = g_slist_next(f)) {
-            GwyDataValidationFailure *failure;
-
-            failure = (GwyDataValidationFailure*)f->data;
+            GwyDataValidationFailure *failure = (GwyDataValidationFailure*)f->data;
             g_printerr("%s: %s, %s: %s",
-                       filename, name,
-                       g_quark_to_string(failure->key),
-                       gwy_data_error_desrcibe(failure->error));
+                       filename, name, g_quark_to_string(failure->key), gwy_data_error_desrcibe(failure->error));
             if (failure->details)
                 g_printerr(" (%s)", failure->details);
             g_printerr("\n");
@@ -756,21 +736,19 @@ show_tip_at_startup(G_GNUC_UNUSED gpointer user_data)
  * @argc: Address of the argc parameter of main(). Passed to gwy_app_gl_init().
  * @argv: Address of the argv parameter of main(). Passed to gwy_app_gl_init().
  *
- * Initializes all Gwyddion data types, i.e. types that may appear in
- * serialized data. GObject has to know about them when g_type_from_name()
- * is called.
+ * Initializes all Gwyddion data types, i.e. types that may appear in serialized data. GObject has to know about them
+ * when g_type_from_name() is called.
  *
- * It registeres stock items, initializes tooltip class resources, sets
- * application icon, sets Gwyddion specific widget resources.
+ * It registeres stock items, initializes tooltip class resources, sets application icon, sets Gwyddion specific
+ * widget resources.
  *
  * If NLS is compiled in, it sets it up and binds text domains.
  *
- * If OpenGL is compiled in, it checks whether it's really available (calling
- * gtk_gl_init_check() and gwy_widgets_gl_init()).
+ * If OpenGL is compiled in, it checks whether it's really available (calling gtk_gl_init_check() and
+ * gwy_widgets_gl_init()).
  **/
 static void
-gwy_app_init(int *argc,
-             char ***argv)
+gwy_app_init(int *argc, char ***argv)
 {
     gwy_widgets_type_init();
     /* Dump core on Critical errors in development versions. */
@@ -809,10 +787,8 @@ gwy_app_set_window_icon(void)
 static void
 gwy_app_check_version(void)
 {
-    if (!gwy_strequal(GWY_VERSION_STRING, gwy_version_string())) {
-        g_warning("Application and library versions do not match: %s vs. %s",
-                  GWY_VERSION_STRING, gwy_version_string());
-    }
+    if (!gwy_strequal(GWY_VERSION_STRING, gwy_version_string()))
+        g_warning("Application and library versions do not match: %s vs. %s", GWY_VERSION_STRING, gwy_version_string());
 }
 
 gboolean
@@ -821,4 +797,4 @@ gwy_app_gl_disabled(void)
     return app_options.disable_gl;
 }
 
-/* vim: set cin et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
+/* vim: set cin columns=120 tw=118 et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
