@@ -1,22 +1,18 @@
 /*
- *  $Id: toolbox.c 22629 2019-10-30 13:47:21Z yeti-dn $
- *  Copyright (C) 2003-2019 David Necas (Yeti), Petr Klapetek.
+ *  $Id: toolbox.c 23951 2021-08-10 12:18:16Z yeti-dn $
+ *  Copyright (C) 2003-2021 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
+ *  License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any
+ *  later version.
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
+ *  warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+ *  details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
+ *  You should have received a copy of the GNU General Public License along with this program; if not, write to the
+ *  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #include "config.h"
@@ -109,11 +105,7 @@ static gulong toolbox_map_event_id = 0;
 
 /* Translatability hack, intltool seems overkill at this point. */
 #define GWY_TOOLBOX_IGNORE(x) /* */
-GWY_TOOLBOX_IGNORE((_("View"),
-                    _("Data Process"),
-                    _("Graph"),
-                    _("Tools"),
-                    _("Volume")))
+GWY_TOOLBOX_IGNORE((_("View"), _("Data Process"), _("Graph"), _("Tools"), _("Volume")))
 
 /* FIXME: A temporary hack. */
 static void
@@ -149,8 +141,7 @@ toolbox_add_menubar(GtkWidget *container,
 
     menubar = gtk_menu_bar_new();
     direction = gtk_widget_get_direction(menubar);
-    alignment = gtk_alignment_new(direction == GTK_TEXT_DIR_RTL ? 1.0 : 0.0,
-                                  0.0, 1.0, 0.0);
+    alignment = gtk_alignment_new(direction == GTK_TEXT_DIR_RTL ? 1.0 : 0.0, 0.0, 1.0, 0.0);
     gtk_container_add(GTK_CONTAINER(container), alignment);
     gtk_container_add(GTK_CONTAINER(alignment), menubar);
     gtk_widget_set_name(menubar, "toolboxmenubar");
@@ -174,8 +165,7 @@ toolbox_start_group(GwyAppToolboxBuilder *builder,
     builder->group = gtk_table_new(1, builder->width, TRUE);
 
     settings = gwy_app_settings_get();
-    key = g_strconcat("/app/toolbox/visible/", g_quark_to_string(gspec->id),
-                      NULL);
+    key = g_strconcat("/app/toolbox/visible/", g_quark_to_string(gspec->id), NULL);
     quark = g_quark_from_string(key);
     g_free(key);
     gwy_container_gis_boolean(settings, quark, &visible);
@@ -186,13 +176,11 @@ toolbox_start_group(GwyAppToolboxBuilder *builder,
     gtk_expander_set_use_markup(GTK_EXPANDER(expander), TRUE);
     g_free(s);
     g_object_set_data(G_OBJECT(expander), "key", GUINT_TO_POINTER(quark));
-    g_object_set_data(G_OBJECT(expander),
-                      "gwy-toolbox-ui-constructed", GUINT_TO_POINTER(TRUE));
+    g_object_set_data(G_OBJECT(expander), "gwy-toolbox-ui-constructed", GUINT_TO_POINTER(TRUE));
     gtk_container_add(GTK_CONTAINER(expander), builder->group);
     gtk_expander_set_expanded(GTK_EXPANDER(expander), visible);
     gtk_box_pack_start(builder->box, expander, FALSE, FALSE, 0);
-    g_signal_connect_after(expander, "activate",
-                           G_CALLBACK(gwy_app_toolbox_showhide), NULL);
+    g_signal_connect_after(expander, "activate", G_CALLBACK(gwy_app_toolbox_showhide), NULL);
     builder->pos = 0;
 }
 
@@ -214,8 +202,7 @@ toolbox_make_tool_button(GwyAppToolboxBuilder *builder,
         builder->first_tool = GTK_RADIO_BUTTON(button);
         builder->first_tool_func = name;
     }
-    if (builder->current_tool_func && gwy_strequal(name,
-                                                   builder->current_tool_func))
+    if (builder->current_tool_func && gwy_strequal(name, builder->current_tool_func))
         builder->current_tool = GTK_RADIO_BUTTON(button);
     gtk_toggle_button_set_mode(GTK_TOGGLE_BUTTON(button), FALSE);
     accel_path = g_strconcat("<tool>/", name, NULL);
@@ -244,6 +231,8 @@ toolbox_action_run(Action *action, GtkButton *button)
         gwy_app_run_volume_func_in_mode(name, action->mode);
     else if (action->type == GWY_APP_ACTION_TYPE_XYZ)
         gwy_app_run_xyz_func_in_mode(name, action->mode);
+    else if (action->type == GWY_APP_ACTION_TYPE_CMAP)
+        gwy_app_run_curve_map_func_in_mode(name, action->mode);
     else {
         g_assert_not_reached();
     }
@@ -276,8 +265,7 @@ check_run_mode(GwyAppActionType type, const gchar *name,
     if (available_modes & *mode)
         return;
 
-    g_warning("Function %s::%s cannot be run in mode %d",
-              gwy_toolbox_action_type_name(type), name, *mode);
+    g_warning("Function %s::%s cannot be run in mode %d", gwy_toolbox_action_type_name(type), name, *mode);
     *mode = first_mode;
 }
 
@@ -326,8 +314,7 @@ toolbox_start_item(GwyAppToolboxBuilder *builder,
         stock_id = gwy_process_func_get_stock_id(func);
         action.tooltip = gwy_process_func_get_tooltip(func);
         action.sens = gwy_process_func_get_sensitivity_mask(func);
-        check_run_mode(action.type, func,
-                       gwy_process_func_get_run_types(func), &action.mode);
+        check_run_mode(action.type, func, gwy_process_func_get_run_types(func), &action.mode);
         break;
 
         case GWY_APP_ACTION_TYPE_GRAPH:
@@ -350,8 +337,7 @@ toolbox_start_item(GwyAppToolboxBuilder *builder,
         stock_id = gwy_volume_func_get_stock_id(func);
         action.tooltip = gwy_volume_func_get_tooltip(func);
         action.sens = gwy_volume_func_get_sensitivity_mask(func);
-        check_run_mode(action.type, func,
-                       gwy_volume_func_get_run_types(func), &action.mode);
+        check_run_mode(action.type, func, gwy_volume_func_get_run_types(func), &action.mode);
         break;
 
         case GWY_APP_ACTION_TYPE_XYZ:
@@ -362,8 +348,18 @@ toolbox_start_item(GwyAppToolboxBuilder *builder,
         stock_id = gwy_xyz_func_get_stock_id(func);
         action.tooltip = gwy_xyz_func_get_tooltip(func);
         action.sens = gwy_xyz_func_get_sensitivity_mask(func);
-        check_run_mode(action.type, func,
-                       gwy_xyz_func_get_run_types(func), &action.mode);
+        check_run_mode(action.type, func, gwy_xyz_func_get_run_types(func), &action.mode);
+        break;
+
+        case GWY_APP_ACTION_TYPE_CMAP:
+        if (!gwy_curve_map_func_exists(func)) {
+            g_warning("Function cmap::%s does not exist", func);
+            return FALSE;
+        }
+        stock_id = gwy_curve_map_func_get_stock_id(func);
+        action.tooltip = gwy_curve_map_func_get_tooltip(func);
+        action.sens = gwy_curve_map_func_get_sensitivity_mask(func);
+        check_run_mode(action.type, func, gwy_curve_map_func_get_run_types(func), &action.mode);
         break;
 
         case GWY_APP_ACTION_TYPE_TOOL:
@@ -415,8 +411,7 @@ toolbox_start_item(GwyAppToolboxBuilder *builder,
     }
 
     if (!action.stock_id) {
-        g_warning("Function %s::%s has no icon set",
-                  gwy_toolbox_action_type_name(action.type), func);
+        g_warning("Function %s::%s has no icon set", gwy_toolbox_action_type_name(action.type), func);
         stock_id = GTK_STOCK_MISSING_IMAGE;
         action.stock_id = g_quark_from_static_string(stock_id);
     }
@@ -424,8 +419,7 @@ toolbox_start_item(GwyAppToolboxBuilder *builder,
         stock_id = g_quark_to_string(action.stock_id);
         if (!gtk_icon_factory_lookup_default(stock_id)) {
             g_warning("Function %s::%s icon %s not found",
-                      gwy_toolbox_action_type_name(action.type), func,
-                      g_quark_to_string(action.stock_id));
+                      gwy_toolbox_action_type_name(action.type), func, g_quark_to_string(action.stock_id));
             stock_id = GTK_STOCK_MISSING_IMAGE;
             action.stock_id = g_quark_from_static_string(stock_id);
         }
@@ -436,21 +430,15 @@ toolbox_start_item(GwyAppToolboxBuilder *builder,
     gtk_container_set_border_width(GTK_CONTAINER(button), 0);
     gtk_widget_set_name(button, "toolboxbutton");
     gtk_table_attach_defaults(GTK_TABLE(builder->group), button,
-                              builder->pos % builder->width,
-                              builder->pos % builder->width + 1,
-                              builder->pos/builder->width,
-                              builder->pos/builder->width + 1);
-    gtk_container_add(GTK_CONTAINER(button),
-                      gtk_image_new_from_stock(stock_id,
-                                               GTK_ICON_SIZE_LARGE_TOOLBAR));
+                              builder->pos % builder->width, builder->pos % builder->width + 1,
+                              builder->pos/builder->width, builder->pos/builder->width + 1);
+    gtk_container_add(GTK_CONTAINER(button), gtk_image_new_from_stock(stock_id, GTK_ICON_SIZE_LARGE_TOOLBAR));
     if (action.tooltip)
         gtk_tooltips_set_tip(builder->tips, button, _(action.tooltip), NULL);
 
     a = g_slice_dup(Action, &action);
-    g_signal_connect_swapped(button, "clicked",
-                             G_CALLBACK(toolbox_action_run), a);
-    g_signal_connect_swapped(button, "destroy",
-                             G_CALLBACK(toolbox_action_free), a);
+    g_signal_connect_swapped(button, "clicked", G_CALLBACK(toolbox_action_run), a);
+    g_signal_connect_swapped(button, "destroy", G_CALLBACK(toolbox_action_free), a);
 
     if (action.sens != (GwyMenuSensFlags)-1)
         gwy_app_sensitivity_add_widget(button, action.sens);
@@ -467,8 +455,7 @@ gather_tools(const gchar *name,
     g_ptr_array_add(tools, (gpointer)name);
 }
 
-/* XXX: Move to toolbox-spec probably.  It can keep the file name for
- * itself... */
+/* XXX: Move to toolbox-spec probably.  It can keep the file name for itself... */
 static void
 remove_seen_unseen_tools(GwyAppToolboxBuilder *builder,
                          const GwyToolboxSpec *spec)
@@ -540,8 +527,8 @@ gwy_app_toolbox_build(GwyToolboxSpec *spec,
         item = gspec->item;
         for (j = 0; j < item->len; j++) {
             ispec = &g_array_index(item, GwyToolboxItemSpec, j);
-            /* When the construction fails remove the item also from the spec
-             * so *if* we edit and save the spec it is corrected. */
+            /* When the construction fails remove the item also from the spec so *if* we edit and save the spec it is
+             * corrected. */
             if (!toolbox_start_item(&builder, ispec))
                 gwy_toolbox_spec_remove_item(spec, i, j);
         }
@@ -549,13 +536,10 @@ gwy_app_toolbox_build(GwyToolboxSpec *spec,
     }
 
     if (builder.current_tool) {
-        guint handler_id = g_signal_handler_find(builder.current_tool,
-                                                 G_SIGNAL_MATCH_FUNC,
-                                                 0, 0, NULL,
-                                                 toolbox_action_run, NULL);
+        guint handler_id = g_signal_handler_find(builder.current_tool, G_SIGNAL_MATCH_FUNC,
+                                                 0, 0, NULL, toolbox_action_run, NULL);
         g_signal_handler_block(builder.current_tool, handler_id);
-        gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(builder.current_tool),
-                                     TRUE);
+        gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(builder.current_tool), TRUE);
         g_signal_handler_unblock(builder.current_tool, handler_id);
         important_widget = GTK_WIDGET(builder.current_tool);
     }
@@ -565,20 +549,16 @@ gwy_app_toolbox_build(GwyToolboxSpec *spec,
         important_widget = GTK_WIDGET(builder.first_tool);
     }
 
-    /* XXX: Start the expander with the first tool as expanded and collapse it
-     * only after it has been realised.  Otherwise we get CRITICAL GTK+ error
-     * gtk_widget_event: assertion 'WIDGET_REALIZED_FOR_EVENT (widget, event)' failed
-     */
+    /* XXX: Start the expander with the first tool as expanded and collapse it only after it has been realised.
+     * Otherwise we get CRITICAL GTK+ error gtk_widget_event: assertion 'WIDGET_REALIZED_FOR_EVENT (widget, event)'
+     * failed */
     if (important_widget) {
-        expander = GTK_EXPANDER(gtk_widget_get_ancestor(important_widget,
-                                                        GTK_TYPE_EXPANDER));
+        expander = GTK_EXPANDER(gtk_widget_get_ancestor(important_widget, GTK_TYPE_EXPANDER));
         if (!gtk_expander_get_expanded(GTK_EXPANDER(expander))) {
             gulong *p = g_new(gulong, 1);
 
             gtk_expander_set_expanded(expander, TRUE);
-            *p = g_signal_connect_after(expander, "realize",
-                                        G_CALLBACK(closed_expander_realized),
-                                        p);
+            *p = g_signal_connect_after(expander, "realize", G_CALLBACK(closed_expander_realized), p);
         }
     }
 
@@ -603,8 +583,7 @@ gwy_app_toolbox_window_create(void)
     gtk_window_set_title(GTK_WINDOW(toolbox), g_get_application_name());
     gtk_window_set_role(GTK_WINDOW(toolbox), GWY_TOOLBOX_WM_ROLE);
     gtk_window_set_resizable(GTK_WINDOW(toolbox), FALSE);
-    gwy_help_add_to_window(GTK_WINDOW(toolbox), "main-window", NULL,
-                           GWY_HELP_DEFAULT);
+    gwy_help_add_to_window(GTK_WINDOW(toolbox), "main-window", NULL, GWY_HELP_DEFAULT);
     gwy_app_main_window_set(toolbox);
 
     accel_group = gtk_accel_group_new();
@@ -615,10 +594,8 @@ gwy_app_toolbox_window_create(void)
     container = GTK_WIDGET(vbox);
     gtk_container_add(GTK_CONTAINER(toolbox), container);
 
-    toolbox_add_menubar(container,
-                        gwy_app_menu_create_file_menu(accel_group), _("_File"));
-    toolbox_add_menubar(container,
-                        gwy_app_menu_create_edit_menu(accel_group), _("_Edit"));
+    toolbox_add_menubar(container, gwy_app_menu_create_file_menu(accel_group), _("_File"));
+    toolbox_add_menubar(container, gwy_app_menu_create_edit_menu(accel_group), _("_Edit"));
 
     menu = gwy_app_build_process_menu(accel_group);
     gwy_app_process_menu_add_run_last(menu);
@@ -633,8 +610,10 @@ gwy_app_toolbox_window_create(void)
     menu = gwy_app_build_xyz_menu(accel_group);
     toolbox_add_menubar(container, menu, _("_XYZ Data"));
 
-    toolbox_add_menubar(container,
-                        gwy_app_menu_create_info_menu(accel_group), _("_Info"));
+    menu = gwy_app_build_curve_map_menu(accel_group);
+    toolbox_add_menubar(container, menu, _("_Curve Maps"));
+
+    toolbox_add_menubar(container, gwy_app_menu_create_info_menu(accel_group), _("_Info"));
 
     /***************************************************************/
 
@@ -645,21 +624,15 @@ gwy_app_toolbox_window_create(void)
     }
 
     /***************************************************************/
-    gtk_drag_dest_set(toolbox, GTK_DEST_DEFAULT_ALL,
-                      dnd_target_table, G_N_ELEMENTS(dnd_target_table),
-                      GDK_ACTION_COPY);
-    g_signal_connect(toolbox, "drag-data-received",
-                     G_CALLBACK(toolbox_dnd_data_received), NULL);
+    gtk_drag_dest_set(toolbox, GTK_DEST_DEFAULT_ALL, dnd_target_table, G_N_ELEMENTS(dnd_target_table), GDK_ACTION_COPY);
+    g_signal_connect(toolbox, "drag-data-received", G_CALLBACK(toolbox_dnd_data_received), NULL);
 
     /***************************************************************/
     /* XXX */
     g_signal_connect(toolbox, "delete-event", G_CALLBACK(gwy_app_quit), NULL);
-    g_signal_connect(toolbox, "key-press-event",
-                     G_CALLBACK(toolbox_key_pressed), NULL);
+    g_signal_connect(toolbox, "key-press-event", G_CALLBACK(toolbox_key_pressed), NULL);
     g_signal_connect(toolbox, "destroy", G_CALLBACK(finalise_toolbox), NULL);
-    toolbox_map_event_id = g_signal_connect_after(toolbox, "map-event",
-                                                  G_CALLBACK(toolbox_mapped),
-                                                  NULL);
+    toolbox_map_event_id = g_signal_connect_after(toolbox, "map-event", G_CALLBACK(toolbox_mapped), NULL);
     gtk_widget_show_all(toolbox);
 
     gwy_osx_get_menu_from_widget(container);
@@ -682,8 +655,7 @@ toolbox_key_pressed(G_GNUC_UNUSED GtkWidget *toolbox, GdkEventKey *event)
 {
     GwyTool *current_tool;
 
-    if (event->keyval != GDK_F3
-        || (event->state & (GDK_SHIFT_MASK | GDK_CONTROL_MASK | GDK_MOD1_MASK)))
+    if (event->keyval != GDK_F3 || (event->state & (GDK_SHIFT_MASK | GDK_CONTROL_MASK | GDK_MOD1_MASK)))
         return FALSE;
 
     current_tool = gwy_app_current_tool();
@@ -810,9 +782,9 @@ gwy_toolbox_builtin_accel_path(const gchar *name)
 {
     static const gchar *paths[] = {
         "display_3d", "<builtin>/Display 3D",
-        "zoom_in", "<builtin>/Zoom In",
-        "zoom_out", "<builtin>/Zoom Out",
-        "zoom_1_1", "<builtin>/Zoom 1:1",
+        "zoom_in",    "<builtin>/Zoom In",
+        "zoom_out",   "<builtin>/Zoom Out",
+        "zoom_1_1",   "<builtin>/Zoom 1:1",
     };
     guint i;
 
@@ -829,77 +801,44 @@ gwy_app_menu_create_info_menu(GtkAccelGroup *accel_group)
 {
     static GtkItemFactoryEntry menu_items[] = {
         {
-            N_("/Show _Data Browser"),
-            NULL,
-            gwy_app_data_browser_show,
-            0,
-            "<Item>",
-            NULL
+            N_("/Show _Data Browser"), NULL,
+            gwy_app_data_browser_show, 0, "<Item>", NULL
         },
         {
-            N_("/Module _Browser"),
-            NULL,
-            gwy_module_browser,
-            0,
-            "<Item>",
-            NULL
+            N_("/Module _Browser"), NULL,
+            gwy_module_browser, 0, "<Item>", NULL
         },
         {
-            N_("/Program _Messages"),
-            NULL,
-            show_message_log,
-            0,
-            "<Item>",
-            NULL
+            N_("/Program _Messages"), NULL,
+            show_message_log, 0, "<Item>", NULL
         },
         {
-            "/---",
-            NULL,
-            NULL,
-            0,
-            "<Separator>",
-            NULL },
+            "/---", NULL,
+            NULL, 0, "<Separator>", NULL },
         {
-            N_("/_User Guide"),
-            "",
-            show_user_guide,
-            0,
-            "<StockItem>",
-            GTK_STOCK_HELP
+            N_("/_User Guide"), "",
+            show_user_guide, 0, "<StockItem>", GTK_STOCK_HELP
         },
         {
-            N_("/_Tip of the Day"),
-            NULL,
-            gwy_app_tip_of_the_day,
-            0,
-            "<StockItem>",
-            GTK_STOCK_DIALOG_INFO
+            N_("/_Tip of the Day"), NULL,
+            gwy_app_tip_of_the_day, 0, "<StockItem>", GTK_STOCK_DIALOG_INFO
         },
         {
-            N_("/_About Gwyddion"),
-            NULL,
-            gwy_app_about,
-            0,
-            "<StockItem>",
-            GTK_STOCK_ABOUT
+            N_("/_About Gwyddion"), NULL,
+            gwy_app_about, 0, "<StockItem>", GTK_STOCK_ABOUT
         },
     };
     GtkItemFactory *item_factory;
 
-    /* The menu used to be called Meta.  Keep acceleteror paths and do not
-     * change the name here */
+    /* The menu used to be called Meta.  Keep acceleteror paths and do not change the name here */
     item_factory = gtk_item_factory_new(GTK_TYPE_MENU, "<meta>", accel_group);
 #ifdef ENABLE_NLS
-    gtk_item_factory_set_translate_func(item_factory,
-                                        (GtkTranslateFunc)&gettext,
-                                        NULL, NULL);
+    gtk_item_factory_set_translate_func(item_factory, (GtkTranslateFunc)&gettext, NULL, NULL);
 #endif
-    gtk_item_factory_create_items(item_factory,
-                                  G_N_ELEMENTS(menu_items), menu_items, NULL);
+    gtk_item_factory_create_items(item_factory, G_N_ELEMENTS(menu_items), menu_items, NULL);
 
-    /* Don't do this.  We hide all other help access options if help does not
-     * seem available.  But if it happens the user should have means to provoke
-     * Gwyddion into telling him why it thinks help is not available. */
+    /* Don't do this.  We hide all other help access options if help does not seem available.  But if it happens the
+     * user should have means to provoke Gwyddion into telling him why it thinks help is not available. */
     /*
     if (!gwy_help_is_available())
         gtk_item_factory_delete_item(item_factory, "<meta>/User Guide");
@@ -913,76 +852,40 @@ gwy_app_menu_create_file_menu(GtkAccelGroup *accel_group)
 {
     static GtkItemFactoryEntry menu_items[] = {
         {
-            N_("/_Open..."),
-            "<control>O",
-            gwy_app_file_open,
-            0,
-            "<StockItem>",
-            GTK_STOCK_OPEN
+            N_("/_Open..."), "<control>O",
+            gwy_app_file_open, 0, "<StockItem>", GTK_STOCK_OPEN
         },
         {
-            N_("/_Merge..."),
-            "<control><shift>M",
-            gwy_app_file_merge,
-            0,
-            NULL,
-            NULL
+            N_("/_Merge..."), "<control><shift>M",
+            gwy_app_file_merge, 0, NULL, NULL
         },
         {
-            N_("/Open _Recent"),
-            NULL,
-            NULL,
-            0,
-            "<Branch>",
-            NULL
+            N_("/Open _Recent"), NULL,
+            NULL, 0, "<Branch>", NULL
         },
         {
-            N_("/_Save"),
-            "<control>S",
-            gwy_app_file_save,
-            0,
-            "<StockItem>",
-            GTK_STOCK_SAVE
+            N_("/_Save"), "<control>S",
+            gwy_app_file_save, 0, "<StockItem>", GTK_STOCK_SAVE
         },
         {
-            N_("/Save _As..."),
-            "<control><shift>S",
-            gwy_app_file_save_as,
-            0,
-            "<StockItem>",
-            GTK_STOCK_SAVE_AS
+            N_("/Save _As..."), "<control><shift>S",
+            gwy_app_file_save_as, 0, "<StockItem>", GTK_STOCK_SAVE_AS
         },
         {
-            N_("/_Close"),
-            "<control>W",
-            gwy_app_file_close,
-            0,
-            "<StockItem>",
-            GTK_STOCK_CLOSE
+            N_("/_Close"), "<control>W",
+            gwy_app_file_close, 0, "<StockItem>", GTK_STOCK_CLOSE
         },
         {
-            N_("/Remo_ve All Logs"),
-            NULL,
-            remove_all_logs,
-            0,
-            NULL,
-            NULL
+            N_("/Remo_ve All Logs"), NULL,
+            remove_all_logs, 0, NULL, NULL
         },
         {
-            "/---",
-            NULL,
-            NULL,
-            0,
-            "<Separator>",
-            NULL
+            "/---", NULL,
+            NULL, 0, "<Separator>", NULL
         },
         {
-            N_("/_Quit"),
-            "<control>Q",
-            delete_app_window,
-            0,
-            "<StockItem>",
-            GTK_STOCK_QUIT
+            N_("/_Quit"), "<control>Q",
+            delete_app_window, 0, "<StockItem>", GTK_STOCK_QUIT
         },
     };
     GtkItemFactory *item_factory;
@@ -990,12 +893,9 @@ gwy_app_menu_create_file_menu(GtkAccelGroup *accel_group)
 
     item_factory = gtk_item_factory_new(GTK_TYPE_MENU, "<file>", accel_group);
 #ifdef ENABLE_NLS
-    gtk_item_factory_set_translate_func(item_factory,
-                                        (GtkTranslateFunc)&gettext,
-                                        NULL, NULL);
+    gtk_item_factory_set_translate_func(item_factory, (GtkTranslateFunc)&gettext, NULL, NULL);
 #endif
-    gtk_item_factory_create_items(item_factory,
-                                  G_N_ELEMENTS(menu_items), menu_items, NULL);
+    gtk_item_factory_create_items(item_factory, G_N_ELEMENTS(menu_items), menu_items, NULL);
 
     set_sensitivity(item_factory,
                     "<file>/Save",            GWY_MENU_FLAG_FILE,
@@ -1017,76 +917,40 @@ gwy_app_menu_create_edit_menu(GtkAccelGroup *accel_group)
 {
     static GtkItemFactoryEntry menu_items[] = {
         {
-            N_("/_Undo"),
-            "<control>Z",
-            action_undo,
-            0,
-            "<StockItem>",
-            GTK_STOCK_UNDO
+            N_("/_Undo"), "<control>Z",
+            action_undo, 0, "<StockItem>", GTK_STOCK_UNDO
         },
         {
-            N_("/_Redo"),
-            "<control>Y",
-            action_redo,
-            0,
-            "<StockItem>",
-            GTK_STOCK_REDO
+            N_("/_Redo"), "<control>Y",
+            action_redo, 0, "<StockItem>", GTK_STOCK_REDO
         },
         {
-            "/---",
-            NULL,
-            NULL,
-            0,
-            "<Separator>",
-            NULL
+            "/---", NULL,
+            NULL, 0, "<Separator>", NULL
         },
         {
-            N_("/Default Mask _Color..."),
-            NULL,
-            gwy_app_change_default_mask_color,
-            0,
-            "<StockItem>",
-            GWY_STOCK_MASK
+            N_("/Default Mask _Color..."), NULL,
+            gwy_app_change_default_mask_color, 0, "<StockItem>", GWY_STOCK_MASK
         },
         {
-            N_("/Color _Gradients..."),
-            NULL,
-            gwy_app_gradient_editor,
-            0,
-            "<StockItem>",
-            GWY_STOCK_PALETTES
+            N_("/Color _Gradients..."), NULL,
+            gwy_app_gradient_editor, 0, "<StockItem>", GWY_STOCK_PALETTES
         },
         {
-            N_("/G_L Materials..."),
-            NULL,
-            gwy_app_gl_material_editor,
-            0,
-            "<StockItem>",
-            GWY_STOCK_GL_MATERIAL
+            N_("/G_L Materials..."), NULL,
+            gwy_app_gl_material_editor, 0, "<StockItem>", GWY_STOCK_GL_MATERIAL
         },
         {
-            N_("/_Toolbox..."),
-            NULL,
-            gwy_toolbox_editor,
-            0,
-            NULL,
-            NULL
+            N_("/_Toolbox..."), NULL,
+            gwy_toolbox_editor, 0, NULL, NULL
         },
         {
-            N_("/_Keyboard Shortcuts"),
-            NULL,
-            toggle_edit_accelerators,
-            0,
-            "<CheckItem>",
-            NULL
+            N_("/_Keyboard Shortcuts"), NULL,
+            toggle_edit_accelerators, 0, "<CheckItem>", NULL
         },
         {
-            N_("/_Logging Enabled"),
-            NULL,
-            toggle_logging_enabled,
-            0,
-            "<CheckItem>",
-            NULL
+            N_("/_Logging Enabled"), NULL,
+            toggle_logging_enabled, 0, "<CheckItem>", NULL
         },
     };
     GtkItemFactory *item_factory;
@@ -1096,12 +960,9 @@ gwy_app_menu_create_edit_menu(GtkAccelGroup *accel_group)
 
     item_factory = gtk_item_factory_new(GTK_TYPE_MENU, "<edit>", accel_group);
 #ifdef ENABLE_NLS
-    gtk_item_factory_set_translate_func(item_factory,
-                                        (GtkTranslateFunc)&gettext,
-                                        NULL, NULL);
+    gtk_item_factory_set_translate_func(item_factory, (GtkTranslateFunc)&gettext, NULL, NULL);
 #endif
-    gtk_item_factory_create_items(item_factory,
-                                  G_N_ELEMENTS(menu_items), menu_items, NULL);
+    gtk_item_factory_create_items(item_factory, G_N_ELEMENTS(menu_items), menu_items, NULL);
 
     set_sensitivity(item_factory,
                     "<edit>/Undo", GWY_MENU_FLAG_UNDO,
@@ -1110,16 +971,13 @@ gwy_app_menu_create_edit_menu(GtkAccelGroup *accel_group)
 
     settings = gwy_app_settings_get();
 
-    gwy_container_gis_boolean_by_name(settings,
-                                      "/app/edit-accelerators", &enable_edit);
-    item = gtk_item_factory_get_widget(item_factory,
-                                       "<edit>/Keyboard Shortcuts");
+    gwy_container_gis_boolean_by_name(settings, "/app/edit-accelerators", &enable_edit);
+    item = gtk_item_factory_get_widget(item_factory, "<edit>/Keyboard Shortcuts");
     gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(item), enable_edit);
     enable_edit_accelerators(enable_edit);
 
     enable_logging = gwy_log_get_enabled();
-    item = gtk_item_factory_get_widget(item_factory,
-                                       "<edit>/Logging Enabled");
+    item = gtk_item_factory_get_widget(item_factory, "<edit>/Logging Enabled");
     gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(item), enable_logging);
 
     return gtk_item_factory_get_widget(item_factory, "<edit>");
@@ -1174,8 +1032,7 @@ message_log_deleted(GtkWidget *window)
 static gboolean
 message_log_key_pressed(GtkWidget *window, GdkEventKey *event)
 {
-    if (event->keyval != GDK_Escape
-        || (event->state & (GDK_SHIFT_MASK | GDK_CONTROL_MASK | GDK_MOD1_MASK)))
+    if (event->keyval != GDK_Escape || (event->state & (GDK_SHIFT_MASK | GDK_CONTROL_MASK | GDK_MOD1_MASK)))
         return FALSE;
 
     gtk_widget_hide(window);
@@ -1198,20 +1055,16 @@ create_message_log_window(void)
     gtk_text_view_set_editable(GTK_TEXT_VIEW(logview), FALSE);
 
     scwin = gtk_scrolled_window_new(NULL, NULL);
-    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scwin),
-                                   GTK_POLICY_AUTOMATIC, GTK_POLICY_ALWAYS);
+    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scwin), GTK_POLICY_AUTOMATIC, GTK_POLICY_ALWAYS);
     gtk_container_add(GTK_CONTAINER(scwin), logview);
     gtk_widget_show_all(scwin);
 
     gtk_container_add(GTK_CONTAINER(window), scwin);
 
     gwy_app_add_main_accel_group(window);
-    g_signal_connect(textbuf, "changed",
-                     G_CALLBACK(message_log_updated), logview);
-    g_signal_connect(window, "delete-event",
-                     G_CALLBACK(message_log_deleted), NULL);
-    g_signal_connect(window, "key-press-event",
-                     G_CALLBACK(message_log_key_pressed), NULL);
+    g_signal_connect(textbuf, "changed", G_CALLBACK(message_log_updated), logview);
+    g_signal_connect(window, "delete-event", G_CALLBACK(message_log_deleted), NULL);
+    g_signal_connect(window, "key-press-event", G_CALLBACK(message_log_key_pressed), NULL);
 
     return window;
 }
@@ -1293,8 +1146,7 @@ delete_app_window(void)
 {
     gboolean boo;
 
-    g_signal_emit_by_name(gwy_app_main_window_get(), "delete-event",
-                          NULL, &boo);
+    g_signal_emit_by_name(gwy_app_main_window_get(), "delete-event", NULL, &boo);
 }
 
 /* FIXME: we should zoom whatever is currently active: datawindow, 3dwindow,
@@ -1388,8 +1240,7 @@ toggle_edit_accelerators(G_GNUC_UNUSED gpointer callback_data,
 {
     gboolean active = gtk_check_menu_item_get_active(item);
 
-    gwy_container_set_boolean_by_name(gwy_app_settings_get(),
-                                      "/app/edit-accelerators", active);
+    gwy_container_set_boolean_by_name(gwy_app_settings_get(), "/app/edit-accelerators", active);
     enable_edit_accelerators(active);
 }
 
@@ -1400,17 +1251,14 @@ toggle_logging_enabled(G_GNUC_UNUSED gpointer callback_data,
 {
     gboolean active = gtk_check_menu_item_get_active(item);
 
-    gwy_container_set_boolean_by_name(gwy_app_settings_get(),
-                                      "/app/log/disable", !active);
+    gwy_container_set_boolean_by_name(gwy_app_settings_get(), "/app/log/disable", !active);
     gwy_log_set_enabled(active);
 }
 
 static void
 enable_edit_accelerators(gboolean enable)
 {
-    g_object_set(gtk_settings_get_default(),
-                 "gtk-can-change-accels", enable,
-                 NULL);
+    g_object_set(gtk_settings_get_default(), "gtk-can-change-accels", enable, NULL);
 }
 
 static void
@@ -1427,8 +1275,7 @@ gwy_app_tool_use(const gchar *toolname, GtkToggleButton *button)
 static void
 gwy_app_change_default_mask_color(void)
 {
-    gwy_color_selector_for_mask(_("Change Default Mask Color"),
-                                NULL, gwy_app_settings_get(), "/mask");
+    gwy_color_selector_for_mask(_("Change Default Mask Color"), NULL, gwy_app_settings_get(), "/mask");
 }
 
 static void
@@ -1453,33 +1300,29 @@ action_display_3d(void)
         return;
     }
 
-    dialog = gtk_message_dialog_new(NULL, 0, GTK_MESSAGE_INFO,
-                                    GTK_BUTTONS_CLOSE,
+    dialog = gtk_message_dialog_new(NULL, 0, GTK_MESSAGE_INFO, GTK_BUTTONS_CLOSE,
                                     _("OpenGL 3D graphics not available"));
 #ifdef GWYDDION_HAS_OPENGL
     if (gwy_app_gl_disabled()) {
-        gtk_message_dialog_format_secondary_markup
-            (GTK_MESSAGE_DIALOG(dialog),
-             _("OpenGL was disabled with a command-line option."));
+        gtk_message_dialog_format_secondary_markup(GTK_MESSAGE_DIALOG(dialog),
+                                                   _("OpenGL was disabled with a command-line option."));
     }
     else {
-        gtk_message_dialog_format_secondary_markup
-            (GTK_MESSAGE_DIALOG(dialog),
+        gtk_message_dialog_format_secondary_markup(GTK_MESSAGE_DIALOG(dialog),
              /* FIXME: Makes sense only on Unix */
-             /* FIXME: It would be nice to give a more helpful message, but the
-              * trouble is we don't know why the silly thing failed either. */
-             _("Initialization of OpenGL failed.  Check output of "
-               "<tt>glxinfo</tt> and warning messages printed to console "
-               "during Gwyddion startup."));
+             /* FIXME: It would be nice to give a more helpful message, but the trouble is we don't know why the silly
+              * thing failed either. */
+                                                   _("Initialization of OpenGL failed.  Check output of "
+                                                     "<tt>glxinfo</tt> and warning messages printed to console "
+                                                     "during Gwyddion startup."));
     }
 #else
-    gtk_message_dialog_format_secondary_markup
-        (GTK_MESSAGE_DIALOG(dialog),
-         _("This version of Gwyddion was built without OpenGL support."));
+    gtk_message_dialog_format_secondary_markup(GTK_MESSAGE_DIALOG(dialog),
+                                               _("This version of Gwyddion was built without OpenGL support."));
 #endif
     g_signal_connect(dialog, "response", G_CALLBACK(gtk_widget_destroy), NULL);
     g_object_add_weak_pointer(G_OBJECT(dialog), (gpointer*)&dialog);
     gtk_widget_show(dialog);
 }
 
-/* vim: set cin et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
+/* vim: set cin columns=120 tw=118 et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
