@@ -1,5 +1,5 @@
 /*
- *  $Id: gwycontainer.c 21680 2018-11-26 10:39:39Z yeti-dn $
+ *  $Id: gwycontainer.c 23909 2021-08-02 12:26:16Z yeti-dn $
  *  Copyright (C) 2003,2004,2014 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -2479,12 +2479,12 @@ gwy_container_transfer(GwyContainer *source,
     }
 
     spflen = strlen(source_prefix);
-    if (prefix_is_closed(source_prefix, spflen))
+    if (spflen && prefix_is_closed(source_prefix, spflen))
         spflen--;
 
     key = g_string_new(dest_prefix);
     dpflen = key->len;
-    if (dest_prefix[dpflen - 1] == GWY_CONTAINER_PATHSEP)
+    if (dpflen && dest_prefix[dpflen - 1] == GWY_CONTAINER_PATHSEP)
         dpflen--;
 
     count = 0;
