@@ -1,5 +1,5 @@
 /*
- *  $Id: gwyfdcurvepreset.c 21680 2018-11-26 10:39:39Z yeti-dn $
+ *  $Id: gwyfdcurvepreset.c 24422 2021-10-24 13:48:20Z klapetek $
  *  Copyright (C) 2000-2003 Martin Siler.
  *  Copyright (C) 2004 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
@@ -57,8 +57,10 @@ sszanette_guess(gint n_dat,
     param[1] = y[0]/n_dat;
 
     for (i = 1; i < n_dat; i++) {
-        if (x[i] < xmin) xmin = x[i];
-        if (x[i] > xmax) xmax = x[i];
+        if (x[i] < xmin)
+            xmin = x[i];
+        if (x[i] > xmax)
+            xmax = x[i];
         param[1] += y[i]/n_dat;
     }
     param[0] = xmin - (xmax-xmin)/20;
@@ -93,8 +95,10 @@ pyrzanette_guess(gint n_dat,
     param[1] = y[0]/n_dat;
 
     for (i = 1; i < n_dat; i++) {
-        if (x[i] < xmin) xmin = x[i];
-        if (x[i] > xmax) xmax = x[i];
+        if (x[i] < xmin)
+            xmin = x[i];
+        if (x[i] > xmax)
+            xmax = x[i];
         param[1] += y[i]/n_dat;
     }
     param[0] = xmin - (xmax-xmin)/100;
@@ -115,8 +119,8 @@ tpyrzanette_func(gdouble x,
     /*xc, R, H, gamma, L, */
     *fres = TRUE;
     return b[1] - 2*b[2]*b[4]*b[4]/(x-b[0])*(x-b[0])*(x-b[0])
-           * (1 + (tan(b[3])*(x-b[0]))/b[4] +
-           (tan(b[3])*(x-b[0])*tan(b[3])*(x-b[0]))/b[4]/b[4]);
+           * (1 + (tan(b[3])*(x-b[0]))/b[4]
+              + (tan(b[3])*(x-b[0])*tan(b[3])*(x-b[0]))/b[4]/b[4]);
 }
 
 static void
@@ -132,8 +136,10 @@ tpyrzanette_guess(gint n_dat,
     param[1] = y[0]/n_dat;
 
     for (i = 1; i < n_dat; i++) {
-        if (x[i] < xmin) xmin = x[i];
-        if (x[i] > xmax) xmax = x[i];
+        if (x[i] < xmin)
+            xmin = x[i];
+        if (x[i] > xmax)
+            xmax = x[i];
         param[1] += y[i]/n_dat;
     }
     param[0] = xmin - (xmax-xmin)/100;
@@ -154,7 +160,7 @@ sphcapella_func(gdouble x,
 {
     /*xc, R, H */
     *fres = TRUE;
-    return b[1] -b[3]*b[2]/6/(x-b[0])/(x-b[0]) ;
+    return b[1] -b[3]*b[2]/6/(x-b[0])/(x-b[0]);
 }
 
 static void
@@ -170,8 +176,10 @@ sphcapella_guess(gint n_dat,
     param[1] = y[0]/n_dat;
 
     for (i = 1; i < n_dat; i++) {
-        if (x[i] < xmin) xmin = x[i];
-        if (x[i] > xmax) xmax = x[i];
+        if (x[i] < xmin)
+            xmin = x[i];
+        if (x[i] > xmax)
+            xmax = x[i];
         param[1] += y[i]/n_dat;
     }
     param[0] = xmin - (xmax-xmin)/20;
@@ -207,8 +215,10 @@ sphsphcapella_guess(gint n_dat,
     param[1] = y[0]/n_dat;
 
     for (i = 1; i < n_dat; i++) {
-        if (x[i] < xmin) xmin = x[i];
-        if (x[i] > xmax) xmax = x[i];
+        if (x[i] < xmin)
+            xmin = x[i];
+        if (x[i] > xmax)
+            xmax = x[i];
         param[1] += y[i]/n_dat;
     }
     param[0] = xmin - (xmax-xmin)/20;
@@ -245,8 +255,10 @@ conecapella_guess(gint n_dat,
     param[1] = y[0]/n_dat;
 
     for (i = 1; i < n_dat; i++) {
-        if (x[i] < xmin) xmin = x[i];
-        if (x[i] > xmax) xmax = x[i];
+        if (x[i] < xmin)
+            xmin = x[i];
+        if (x[i] > xmax)
+            xmax = x[i];
         param[1] += y[i]/n_dat;
     }
     param[0] = xmin - (xmax-xmin)/20;
@@ -282,8 +294,10 @@ cylindercapella_guess(gint n_dat,
     param[1] = y[0]/n_dat;
 
     for (i = 1; i < n_dat; i++) {
-        if (x[i] < xmin) xmin = x[i];
-        if (x[i] > xmax) xmax = x[i];
+        if (x[i] < xmin)
+            xmin = x[i];
+        if (x[i] > xmax)
+            xmax = x[i];
         param[1] += y[i]/n_dat;
     }
     param[0] = xmin - (xmax-xmin)/20;
@@ -319,8 +333,10 @@ parcapella_guess(gint n_dat,
     param[1] = y[0]/n_dat;
 
     for (i = 1; i < n_dat; i++) {
-        if (x[i] < xmin) xmin = x[i];
-        if (x[i] > xmax) xmax = x[i];
+        if (x[i] < xmin)
+            xmin = x[i];
+        if (x[i] > xmax)
+            xmax = x[i];
         param[1] += y[i]/n_dat;
     }
     param[0] = xmin - (xmax-xmin)/20;
@@ -331,40 +347,369 @@ parcapella_guess(gint n_dat,
     *fres = TRUE;
 }
 
-/******************* hertz paraboloid ********************************/
+
+/******************* hertz spherical ********************************/
 static gdouble
-hertzpar_func(gdouble x,
+hertzsph_func(gdouble x,
               G_GNUC_UNUSED gint n_param,
-              const gdouble *b,
+              const gdouble *param,
               G_GNUC_UNUSED gpointer user_data,
               gboolean *fres)
 {
-    /*xc, R, E */
+    /*xc, R, E, nu */
+    double xr = (param[0] - x);
     *fres = TRUE;
-    if ((b[0]-x)>0) return 1.3333333*b[2]*sqrt(b[1]*(b[0]-x)*(b[0]-x)*(b[0]-x));
-    else return 0;
+    if (xr > 0)
+        return 4.0*param[2]/3.0/(1-param[3]*param[3])*sqrt(param[1]*xr*xr*xr);
+    else
+        return 0;
 }
 
 static void
-hertzpar_guess(gint n_dat,
+hertzsph_guess(gint n_dat,
                const gdouble *x,
                G_GNUC_UNUSED const gdouble *y,
                gdouble *param,
                gboolean *fres)
 {
     gint i;
-    gdouble xmax = x[n_dat - 1];
+    gdouble ymin = G_MAXDOUBLE;
+    gdouble xmin = 0;
 
-    for (i = 1; i < n_dat; i++) {
-        if (x[i] > xmax) xmax = x[i];
+    for (i = 0; i < n_dat; i++) {
+        if (y[i] < ymin) {
+            ymin = y[i];
+            xmin = x[i];
+        }
     }
-    param[0] = xmax;
-    param[1] = 10e-9;
-    param[2] = 10e6;
+
+    param[0] = xmin;
+    param[1] = 20e-9;
+    param[2] = 5e7;
+    param[3] = 0.25;
 
     *fres = TRUE;
 }
 
+static GwySIUnit*
+hertzsph_get_units(G_GNUC_UNUSED GwyNLFitPreset *preset,
+                   guint param,
+                   GwySIUnit *siunit_x,
+                   G_GNUC_UNUSED GwySIUnit *siunit_y)
+{
+    switch (param) {
+        case 0:
+        return gwy_si_unit_duplicate(siunit_x);
+        break;
+
+        case 1:
+        return gwy_si_unit_new("m");
+        break;
+
+        case 2:
+        return gwy_si_unit_new("Pa");
+        break;
+
+        case 3:
+        return gwy_si_unit_new(NULL);
+        break;
+
+        default:
+        g_return_val_if_reached(NULL);
+        break;
+    }
+}
+
+
+/******************* hertz spherical with fixed thin film correction********************************/
+static gdouble
+hertzsphhfix_func(gdouble x,
+                  G_GNUC_UNUSED gint n_param,
+                  const gdouble *param,
+                  G_GNUC_UNUSED gpointer user_data,
+                  gboolean *fres)
+{
+    /*xc, R, E, nu, h */
+    double xr = (param[0] - x);
+    double xi = sqrt(param[1]*xr)/param[4];
+    double alpha = -(1.2876 - 1.4678*param[4] + 1.3442*param[4]*param[4])/(1-param[4]);
+    double beta = (0.6387 - 1.0277*param[4] + 1.5164*param[4]*param[4])/(1-param[4]);
+    double xp = xi/M_PI;
+
+    double fc = 1 - 2*alpha*xp + 4*alpha*alpha*xp*xp
+                - 8*(alpha*alpha*alpha + 4*M_PI*M_PI*beta/15)*xp*xp*xp
+                + 16*(alpha*alpha*alpha + 3*M_PI*M_PI*beta/5)*xp*xp*xp*xp;
+
+    *fres = TRUE;
+    if (xr > 0)
+        return 4.0*param[2]/3.0/(1-param[3]*param[3])*sqrt(param[1]*xr*xr*xr)*fc;
+    else
+        return 0;
+}
+
+static void
+hertzsphhfix_guess(gint n_dat,
+                   const gdouble *x,
+                   G_GNUC_UNUSED const gdouble *y,
+                   gdouble *param,
+                   gboolean *fres)
+{
+    gint i;
+    gdouble ymin = G_MAXDOUBLE;
+    gdouble xmin = 0;
+
+    for (i = 0; i < n_dat; i++) {
+        if (y[i] < ymin) {
+            ymin = y[i];
+            xmin = x[i];
+        }
+    }
+
+    param[0] = xmin;
+    param[1] = 20e-9;
+    param[2] = 5e7;
+    param[3] = 0.25;
+    param[4] = 100e-9;
+
+    *fres = TRUE;
+}
+
+static GwySIUnit*
+hertzsphfilm_get_units(G_GNUC_UNUSED GwyNLFitPreset *preset,
+                       guint param,
+                       GwySIUnit *siunit_x,
+                       G_GNUC_UNUSED GwySIUnit *siunit_y)
+{
+    switch (param) {
+        case 0:
+        return gwy_si_unit_duplicate(siunit_x);
+        break;
+
+        case 1:
+        return gwy_si_unit_new("m");
+        break;
+
+        case 2:
+        return gwy_si_unit_new("Pa");
+        break;
+
+        case 3:
+        return gwy_si_unit_new(NULL);
+        break;
+
+        case 4:
+        return gwy_si_unit_new("m");
+        break;
+
+        default:
+        g_return_val_if_reached(NULL);
+        break;
+    }
+}
+
+
+/******************* hertz spherical with free thin film correction********************************/
+static gdouble
+hertzsphhfree_func(gdouble x,
+                   G_GNUC_UNUSED gint n_param,
+                   const gdouble *param,
+                   G_GNUC_UNUSED gpointer user_data,
+                   gboolean *fres)
+{
+    /*xc, R, E, nu, h */
+    double xr = (param[0] - x);
+    double xi = sqrt(param[1]*xr)/param[4];
+    double alpha = -0.347*(3 - 2*param[4])/(1-param[4]);
+    double beta = -0.056*(5 - 2*param[4])/(1-param[4]);
+    double xp = xi/M_PI;
+
+    double fc = 1 - 2*alpha*xp + 4*alpha*alpha*xp*xp
+                - 8*(alpha*alpha*alpha + 4*M_PI*M_PI*beta/15)*xp*xp*xp
+                + 16*(alpha*alpha*alpha + 3*M_PI*M_PI*beta/5)*xp*xp*xp*xp;
+
+    *fres = TRUE;
+    if (xr > 0)
+        return 4.0*param[2]/3.0/(1-param[3]*param[3])*sqrt(param[1]*xr*xr*xr)*fc;
+    else
+        return 0;
+}
+
+static void
+hertzsphhfree_guess(gint n_dat,
+                    const gdouble *x,
+                    G_GNUC_UNUSED const gdouble *y,
+                    gdouble *param,
+                    gboolean *fres)
+{
+    gint i;
+    gdouble ymin = G_MAXDOUBLE;
+    gdouble xmin = 0;
+
+    for (i = 0; i < n_dat; i++) {
+        if (y[i] < ymin) {
+            ymin = y[i];
+            xmin = x[i];
+        }
+    }
+
+    param[0] = xmin;
+    param[1] = 20e-9;
+    param[2] = 5e7;
+    param[3] = 0.25;
+    param[4] = 100e-9;
+
+    *fres = TRUE;
+}
+
+/******************* DMT  ********************************/
+static gdouble
+dmt_func(gdouble x,
+         G_GNUC_UNUSED gint n_param,
+         const gdouble *param,
+         G_GNUC_UNUSED gpointer user_data,
+         gboolean *fres)
+{
+    /*xc, F_ad, R, E, nu*/
+    double xr = (param[0] - x); //this should be deformation and should be already entered only positive
+    *fres = TRUE;
+    if (xr > 0)
+        return 4.0*param[3]/3.0/(1-param[4]*param[4])*sqrt(param[2]*xr*xr*xr) + param[1];
+    else
+        return param[1];
+}
+
+static void
+dmt_guess(gint n_dat,
+          const gdouble *x,
+          const gdouble *y,
+          gdouble *param,
+          gboolean *fres)
+{
+    gint i;
+    gdouble ymin = G_MAXDOUBLE;
+    gdouble xmin = 0;
+
+    for (i = 0; i < n_dat; i++) {
+        if (y[i] < ymin) {
+            ymin = y[i];
+            xmin = x[i];
+        }
+    }
+    param[0] = xmin;
+    param[1] = ymin;
+    param[2] = 20e-9;
+    param[3] = 5e7;
+    param[4] = 0.25;
+
+    *fres = TRUE;
+}
+
+static GwySIUnit*
+dmt_get_units(G_GNUC_UNUSED GwyNLFitPreset *preset,
+              guint param,
+              GwySIUnit *siunit_x,
+              GwySIUnit *siunit_y)
+{
+    switch (param) {
+        case 0:
+        return gwy_si_unit_duplicate(siunit_x);
+        break;
+
+        case 1:
+        return gwy_si_unit_duplicate(siunit_y);
+        break;
+
+        case 2:
+        return gwy_si_unit_new("m");
+        break;
+
+        case 3:
+        return gwy_si_unit_new("Pa");
+        break;
+
+        case 4:
+        return gwy_si_unit_new(NULL);
+        break;
+
+        default:
+        g_return_val_if_reached(NULL);
+        break;
+    }
+}
+
+
+
+/******************* Sneddon ********************************/
+static gdouble
+sneddon_func(gdouble x,
+             G_GNUC_UNUSED gint n_param,
+             const gdouble *param,
+             G_GNUC_UNUSED gpointer user_data,
+             gboolean *fres)
+{
+    /*xc, alpha, E, nu*/
+    double xr = (param[0] - x); //this should be deformation and should be already entered only positive
+    *fres = TRUE;
+    if (xr > 0)
+        return 2.0*param[2]/M_PI/(1-param[3]*param[3])*tan(param[1])*xr*xr;
+    else
+        return 0;
+}
+
+static void
+sneddon_guess(gint n_dat,
+              const gdouble *x,
+              const gdouble *y,
+              gdouble *param,
+              gboolean *fres)
+{
+    gint i;
+    gdouble ymin = G_MAXDOUBLE;
+    gdouble xmin = 0;
+
+    for (i = 0; i < n_dat; i++) {
+        if (y[i] < ymin) {
+            ymin = y[i];
+            xmin = x[i];
+        }
+    }
+    param[0] = xmin;
+    param[1] = 0.25;
+    param[2] = 5e7;
+    param[3] = 0.25;
+
+    *fres = TRUE;
+}
+
+static GwySIUnit*
+sneddon_get_units(G_GNUC_UNUSED GwyNLFitPreset *preset,
+                  guint param,
+                  GwySIUnit *siunit_x,
+                  G_GNUC_UNUSED GwySIUnit *siunit_y)
+{
+    switch (param) {
+        case 0:
+        return gwy_si_unit_duplicate(siunit_x);
+        break;
+
+        case 1:
+        return gwy_si_unit_new("rad");
+        break;
+
+        case 2:
+        return gwy_si_unit_new("Pa");
+        break;
+
+        case 3:
+        return gwy_si_unit_new(NULL);
+        break;
+
+        default:
+        g_return_val_if_reached(NULL);
+        break;
+    }
+}
+
 
 /******************* sphtiptap ********************************/
 static gdouble
@@ -392,8 +737,10 @@ sphtiptap_guess(gint n_dat,
     param[1] = y[0]/n_dat;
 
     for (i = 1; i < n_dat; i++) {
-        if (x[i] < xmin) xmin = x[i];
-        if (x[i] > xmax) xmax = x[i];
+        if (x[i] < xmin)
+            xmin = x[i];
+        if (x[i] > xmax)
+            xmax = x[i];
         param[1] += y[i]/n_dat;
     }
     param[0] = xmin - (xmax-xmin)/20;
@@ -430,8 +777,10 @@ sphxu_guess(gint n_dat,
     param[1] = y[0]/n_dat;
 
     for (i = 1; i < n_dat; i++) {
-        if (x[i] < xmin) xmin = x[i];
-        if (x[i] > xmax) xmax = x[i];
+        if (x[i] < xmin)
+            xmin = x[i];
+        if (x[i] > xmax)
+            xmax = x[i];
         param[1] += y[i]/n_dat;
     }
     param[0] = xmin - (xmax-xmin)/20;
@@ -587,6 +936,44 @@ hsphhertz_guess(gint n_dat,
     for (i = 0; i < n_dat; i++)
         param[1] += y[i]/n_dat;
 }
+
+/******************* hertz paraboloid ********************************/
+static gdouble
+hertzpar_func(gdouble x,
+              G_GNUC_UNUSED gint n_param,
+              const gdouble *b,
+              G_GNUC_UNUSED gpointer user_data,
+              gboolean *fres)
+{
+    /*xc, R, E */
+    *fres = TRUE;
+    if ((b[0]-x) > 0)
+        return 1.3333333*b[2]*sqrt(b[1]*(b[0]-x)*(b[0]-x)*(b[0]-x));
+    else
+        return 0;
+}
+
+static void
+hertzpar_guess(gint n_dat,
+               const gdouble *x,
+               G_GNUC_UNUSED const gdouble *y,
+               gdouble *param,
+               gboolean *fres)
+{
+    gint i;
+    gdouble xmax = x[n_dat - 1];
+
+    for (i = 1; i < n_dat; i++) {
+        if (x[i] > xmax)
+            xmax = x[i];
+    }
+    param[0] = xmax;
+    param[1] = 10e-9;
+    param[2] = 10e6;
+
+    *fres = TRUE;
+}
+
 #endif
 
 /******************* electrostatic sphere capella ********************************/
@@ -614,8 +1001,10 @@ esphcapella_guess(gint n_dat,
     param[1] = y[0]/n_dat;
 
     for (i = 1; i < n_dat; i++) {
-        if (x[i] < xmin) xmin = x[i];
-        if (x[i] > xmax) xmax = x[i];
+        if (x[i] < xmin)
+           xmin = x[i];
+        if (x[i] > xmax)
+           xmax = x[i];
         param[1] += y[i]/n_dat;
     }
     param[0] = xmin - (xmax-xmin)/20;
@@ -714,7 +1103,51 @@ static const GwyNLFitParam sphtiptap_params[] = {
     { "xi", 1, 0, },
 };
 
+static const GwyNLFitParam hertzsph_params[] = {
+    { "xc", 1, 0, },
+    { "R", 1, 0, },
+    { "E", -2, 1, },
+    { "ν", 0, 0, },
+};
+
+static const GwyNLFitParam hertzsphhfix_params[] = {
+    { "xc", 1, 0, },
+    { "R", 1, 0, },
+    { "E", -2, 1, },
+    { "ν", 0, 0, },
+    { "h", 1, 0, },
+};
+
+static const GwyNLFitParam hertzsphhfree_params[] = {
+    { "xc", 1, 0, },
+    { "R", 1, 0, },
+    { "E", -2, 1, },
+    { "ν", 0, 0, },
+    { "h", 1, 0, },
+};
+
+static const GwyNLFitParam dmt_params[] = {
+    { "xc", 1, 0, },
+    { "Fad", 0, 1, },
+    { "R", 1, 0, },
+    { "E", -2, 1, },
+    { "ν", 0, 0, },
+};
+
+static const GwyNLFitParam sneddon_params[] = {
+    { "xc", 1, 0, },
+    { "α", 0, 0, },
+    { "E", -2, 1, },
+    { "ν", 0, 0, },
+};
+
+
 /*
+static const GwyNLFitParam hertzpar_params[] = {
+    { "xc", 1, 0, },
+    { "R", -1, 0, },
+    { "Er", -1, 1, },
+};
 static const GwyNLFitParam sphxu_params[] = {
     { "xc", 1, 0, },
     { "yc", 0, 1, },
@@ -771,16 +1204,10 @@ static const GwyNLFitParam hsphhertz_params[] = {
     { "yc", 0, 1, },
     { "R", 1, 0, },
     { "E", 1, 0, },
-    { "nu", 1, 0, },
+    { "ν", 1, 0, },
 };
 */
 
-static const GwyNLFitParam hertzpar_params[] = {
-    { "xc", 1, 0, },
-    { "R", -1, 0, },
-    { "Er", -1, 1, },
-};
-
 
 static const GwyNLFitPresetBuiltin fitting_presets[] = {
     {
@@ -848,7 +1275,8 @@ static const GwyNLFitPresetBuiltin fitting_presets[] = {
      {
         N_("vdW: two spheres"),
         "<i>f</i>(<i>x</i>) "
-        "= -<i>HR<sub>1</sub>R<sub>2</sub></i>/6/(<i>x</i>-<i>x<sub>c</sub></i>)(R<sub>1</sub> + R<sub>2</sub>)<sup>2</sup> ",
+        "= -<i>HR<sub>1</sub>R<sub>2</sub></i>/6/(<i>x</i>-<i>x<sub>c</sub></i>)(R<sub>1</sub>"
+        "+ R<sub>2</sub>)<sup>2</sup> ",
         &sphsphcapella_func,
         NULL,
         &sphsphcapella_guess,
@@ -894,18 +1322,66 @@ static const GwyNLFitPresetBuiltin fitting_presets[] = {
         parcapella_params,
     },
      {
-        N_("contact: Hertz (paraboloid)"),
+        N_("Hertz: spherical"),
         "<i>f</i>(<i>x</i>) "
-        "= 4/3 E sqrt(R(<i>x</i>-<i>x<sub>c</sub></i>)<sup>3</sup>) ",
-        &hertzpar_func,
+        "= 4/3 E/(1-ν<sup>2</sup>) √(R(<i>x</i>-<i>x<sub>c</sub></i>)<sup>3</sup>) ",
+        &hertzsph_func,
         NULL,
-        &hertzpar_guess,
+        &hertzsph_guess,
+        &hertzsph_get_units,
         NULL,
-        NULL,
-        G_N_ELEMENTS(hertzpar_params),
-        hertzpar_params,
+        G_N_ELEMENTS(hertzsph_params),
+        hertzsph_params,
     },
-     /*    {
+     {
+        N_("Hertz: spherical, fixed film"),
+        "<i>f</i>(<i>x</i>) "
+        "= 4/3 E/(1-ν<sup>2</sup>) √(R(<i>x</i>-<i>x<sub>c</sub></i>)<sup>3</sup>)f<sub>c,fix</sub> ",
+        &hertzsphhfix_func,
+        NULL,
+        &hertzsphhfix_guess,
+        &hertzsphfilm_get_units,
+        NULL,
+        G_N_ELEMENTS(hertzsphhfix_params),
+        hertzsphhfix_params,
+    },
+     {
+        N_("Hertz: spherical, free film"),
+        "<i>f</i>(<i>x</i>) "
+        "= 4/3 E/(1-ν<sup>2</sup>) √(R(<i>x</i>-<i>x<sub>c</sub></i>)<sup>3</sup>)f<sub>c,free</sub> ",
+        &hertzsphhfree_func,
+        NULL,
+        &hertzsphhfree_guess,
+        &hertzsphfilm_get_units,
+        NULL,
+        G_N_ELEMENTS(hertzsphhfree_params),
+        hertzsphhfree_params,
+    },
+      {
+        N_("DMT: spherical"),
+        "<i>f</i>(<i>x</i>) "
+        "= 4/3 E/(1-ν<sup>2</sup>) √(R(<i>x</i>-<i>x<sub>c</sub></i>)<sup>3</sup>) + F<sub>ad</sub>",
+        &dmt_func,
+        NULL,
+        &dmt_guess,
+        &dmt_get_units,
+        NULL,
+        G_N_ELEMENTS(dmt_params),
+        dmt_params,
+    },
+    {
+        N_("Sneddon: conical"),
+        "<i>f</i>(<i>x</i>) "
+        "= 2/π E/(1-ν<sup>2</sup>) tan(α) (<i>x</i>-<i>x<sub>c</sub></i>)<sup>2</sup>",
+        &sneddon_func,
+        NULL,
+        &sneddon_guess,
+        &sneddon_get_units,
+        NULL,
+        G_N_ELEMENTS(sneddon_params),
+        sneddon_params,
+    },
+       /*    {
         "vdW: sphere3",
         "<i>f</i>(<i>x</i>) "
         "= -<i>HR</i>/12 (1/(<i>x</i>-<i>x<sub>c</sub></i>)<sup>2</sup>"
@@ -969,7 +1445,8 @@ static const GwyNLFitPresetBuiltin fitting_presets[] = {
     /* {
         "electrostatic: sphere",
         "<i>f</i>(<i>x</i>) "
-        "= -<i>Pi e<sub>0</sub>(VR)<sup>2</sup></i>/(<i>x</i>-<i>x<sub>c</sub></i>)/(<i>x</i>-<i>x<sub>c</sub></i> + R) ",
+        "= -<i>Pi e<sub>0</sub>(VR)<sup>2</sup></i>/(<i>x</i>-<i>x<sub>c</sub></i>)"
+        "/(<i>x</i>-<i>x<sub>c</sub></i> + R) ",
         &esphcapella_func,
         NULL,
         &esphcapella_guess,
