@@ -1,5 +1,5 @@
 /*
- *  $Id: gwymath.c 22938 2020-09-03 15:19:50Z yeti-dn $
+ *  $Id: gwymath.c 23650 2021-05-09 19:39:32Z yeti-dn $
  *  Copyright (C) 2003-2018 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -1946,13 +1946,18 @@ gwy_check_regular_2d_grid(const gdouble *coords, guint stride, guint n,
     else
         return NULL;
 
-    dx = (xmax - xmin)/(xres - 1);
-    dy = (ymax - ymin)/(yres - 1);
+    if (!xres || !yres)
+        return NULL;
+
+    dx = (xmax - xmin)/xres;
+    dy = (ymax - ymin)/yres;
     xmin -= 0.5*dx;
     xmax += 0.5*dx;
     ymin -= 0.5*dy;
     ymax += 0.5*dy;
 
+    gwy_debug("x: [%g..%g] step %g", xmin, xmax, dx);
+    gwy_debug("y: [%g..%g] step %g", ymin, ymax, dy);
     map = g_new(guint, n);
     encountered = g_new0(gboolean, n);
     for (k = 0; k < n; k++) {
