@@ -1,5 +1,5 @@
 /*
- *  $Id: gwynlfit.c 22835 2020-06-02 13:44:35Z yeti-dn $
+ *  $Id: gwynlfit.c 24367 2021-10-13 15:05:16Z yeti-dn $
  *  Copyright (C) 2000-2003 Martin Siler.
  *  Copyright (C) 2004-2020 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
@@ -773,7 +773,7 @@ gwy_math_nlfit_fit_real(GwyNLFitter *nlfit,
 
     for (i = 0; i < nparam; i++) {
         if (gwy_isinf(param[i]) || gwy_isnan(param[i])) {
-            sumr_best = -1.0;
+            sumr_best = nlfit->dispersion = -1.0;
             GWY_FREE(nlfit->covar);
             gwy_assign(param, origparam, nparam);
             gwy_debug("final params are Inf/NaN");
@@ -787,7 +787,7 @@ gwy_math_nlfit_fit_real(GwyNLFitter *nlfit,
         for (i = 0; i < nparam*(nparam + 1)/2; i++) {
              if (gwy_isinf(covar[i]) || gwy_isnan(covar[i])) {
                  priv->nparam = 0;
-                 sumr_best = -1.0;
+                 sumr_best = nlfit->dispersion = -1.0;
                  GWY_FREE(nlfit->covar);
                  gwy_assign(param, origparam, nparam);
                  gwy_debug("covariance matrix items are Inf/NaN");
