@@ -1,22 +1,18 @@
 /*
- *  $Id: gwyutils.h 23201 2021-03-07 11:54:21Z yeti-dn $
- *  Copyright (C) 2003-2011 David Necas (Yeti), Petr Klapetek.
+ *  $Id: gwyutils.h 24011 2021-08-17 15:05:29Z yeti-dn $
+ *  Copyright (C) 2003-2021 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
+ *  License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any
+ *  later version.
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
+ *  warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+ *  details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
+ *  You should have received a copy of the GNU General Public License along with this program; if not, write to the
+ *  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #ifndef __GWY_UTILS_H__
@@ -46,6 +42,7 @@ typedef enum {
     GWY_BYTE_ORDER_NATIVE        = 0,
     GWY_BYTE_ORDER_LITTLE_ENDIAN = G_LITTLE_ENDIAN,
     GWY_BYTE_ORDER_BIG_ENDIAN    = G_BIG_ENDIAN,
+    GWY_BYTE_ORDER_IMPLICIT      = 9999,
 } GwyByteOrder;
 
 typedef gboolean (*GwySetFractionFunc)(gdouble fraction);
@@ -111,6 +108,9 @@ void         gwy_convert_raw_data      (gconstpointer data,
                                         gdouble scale,
                                         gdouble offset);
 guint        gwy_raw_data_size         (GwyRawDataType datatype);
+gchar*       gwy_utf16_to_utf8         (const gunichar2 *str,
+                                        glong len,
+                                        GwyByteOrder byteorder);
 gboolean     gwy_assign_string         (gchar **target,
                                         const gchar *newvalue);
 void         gwy_object_set_or_reset   (gpointer object,
@@ -122,7 +122,7 @@ gboolean     gwy_set_member_object     (gpointer instance,
                                         gpointer member_field,
                                         ...)                        G_GNUC_NULL_TERMINATED;
 #ifdef G_OS_WIN32
-FILE*        gwy_fopen                 (const gchar *filename, 
+FILE*        gwy_fopen                 (const gchar *filename,
                                         const gchar *mode);
 gint         gwy_fprintf               (FILE *file,
                                         gchar const *format,
@@ -136,5 +136,4 @@ G_END_DECLS
 
 #endif /* __GWY_UTILS_H__ */
 
-/* vim: set cin et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
-
+/* vim: set cin columns=120 tw=118 et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
