@@ -1,5 +1,5 @@
 /*
- *  $Id: gwyaxis.c 21435 2018-09-11 12:39:53Z yeti-dn $
+ *  $Id: gwyaxis.c 21781 2019-01-03 12:33:06Z yeti-dn $
  *  Copyright (C) 2003-2006 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -92,8 +92,6 @@ static gboolean gwy_axis_expose        (GtkWidget *widget,
 static gboolean gwy_axis_button_press  (GtkWidget *widget,
                                         GdkEventButton *event);
 
-static gdouble gwy_axis_dbl_raise           (gdouble x,
-                                             gint y);
 static gdouble gwy_axis_quantize_normal_tics(gdouble arg,
                                              gint guide);
 static gboolean gwy_axis_normalscale         (GwyAxis *a);
@@ -1189,24 +1187,10 @@ gwy_axis_entry(GwySciText *sci_text, GwyAxis *axis)
     g_object_notify(G_OBJECT(axis), "label");
 }
 
-static gdouble
-gwy_axis_dbl_raise(gdouble x, gint y)
-{
-    gint i = abs(y);
-    gdouble val = 1.0;
-
-    while (--i >= 0)
-        val *= x;
-
-    if (y < 0)
-        return (1.0 / val);
-    return (val);
-}
-
 static gdouble
 gwy_axis_quantize_normal_tics(gdouble arg, gint guide)
 {
-    gdouble power = gwy_axis_dbl_raise(10.0, (gint)floor(log10(arg)));
+    gdouble power = gwy_powi(10.0, (gint)floor(log10(arg)));
     gdouble xnorm = arg / power;        /* approx number of decades */
     gdouble posns = guide / xnorm; /* approx number of tic posns per decade */
     gdouble tics;
@@ -1347,8 +1331,8 @@ gwy_axis_logscale(GwyAxis *a)
     } while (i < 2 || ((base - tickstep) < logmax
                        && i < a->par.major_maxticks));
     logmax = base - tickstep;
-    min = gwy_axis_dbl_raise(10.0, logmin);
-    max = gwy_axis_dbl_raise(10.0, logmax);
+    min = gwy_powi(10.0, logmin);
+    max = gwy_powi(10.0, logmax);
 
     /* Minor ticks - will be equally distributed in the normal domain 1,2,3...
      * if the major tick step is only one order, otherwise distribute them in
@@ -1359,7 +1343,7 @@ gwy_axis_logscale(GwyAxis *a)
         i = 0;
         do {
             /* Here, tickstep must be adapted do scale */
-            tickstep = gwy_axis_dbl_raise(10.0, (gint)floor(log10(base*1.001)));
+            tickstep = gwy_powi(10.0, (gint)floor(log10(base*1.001)));
             mit.value = log10(base);
             g_array_append_val(a->miticks, mit);
             base += tickstep;
@@ -2138,7 +2122,7 @@ gwy_axis_get_major_ticks(GwyAxis *axis,
         if (!axis->is_logarithmic)
             *pvalue = pmji->t.value;
         else
-            *pvalue = gwy_axis_dbl_raise(10.0, pmji->t.value);
+            *pvalue = gwy_powi(10.0, pmji->t.value);
     }
 
     if (nticks)
