@@ -1,5 +1,5 @@
 /*
- *  $Id: gwyradiobuttons.c 20678 2017-12-18 18:26:55Z yeti-dn $
+ *  $Id: gwyradiobuttons.c 21106 2018-05-27 10:20:06Z yeti-dn $
  *  Copyright (C) 2003 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -45,7 +45,9 @@ gwy_radio_buttons_create_real(const GwyEnum *entries,
                               gboolean translate)
 {
     GtkWidget *button, *curbutton;
+    GtkRadioButton *grb;
     GSList *group;
+    const gchar *name;
     gint i;
 
     if (nentries < 0) {
@@ -58,13 +60,9 @@ gwy_radio_buttons_create_real(const GwyEnum *entries,
     /* FIXME: this relies on undocumented GtkRadioButton behaviour;
      * we assume it puts the items into the group in reverse order */
     for (i = nentries-1; i >= 0; i--) {
-        if (translate)
-            button = gtk_radio_button_new_with_mnemonic_from_widget
-                                (GTK_RADIO_BUTTON(button),
-                                 gwy_sgettext(entries[i].name));
-        else
-            button = gtk_radio_button_new_with_mnemonic_from_widget
-                                   (GTK_RADIO_BUTTON(button), entries[i].name);
+        name = translate ? gwy_sgettext(entries[i].name) : entries[i].name;
+        grb = GTK_RADIO_BUTTON(button);
+        button = gtk_radio_button_new_with_mnemonic_from_widget(grb, name);
         g_object_set_qdata(G_OBJECT(button), gwyrb_quark,
                            GINT_TO_POINTER(entries[i].value));
         if (entries[i].value == current)
@@ -90,8 +88,8 @@ gwy_radio_buttons_create_real(const GwyEnum *entries,
  * @entries: Radio button group items.
  * @nentries: The number of items.  Since 2.18 negative value means that
  *            @entries is terminated with a %NULL-named item.
- * @callback: A callback called when a menu item is activated (or %NULL for
- *            no callback).
+ * @callback: A callback called when a button is selected (or %NULL for no
+ *            callback).
  * @cbdata: User data passed to the callback.
  * @current: Value to be shown as currently selected (-1 to use what happens
  *           to be first).
@@ -118,8 +116,8 @@ gwy_radio_buttons_create(const GwyEnum *entries,
 
 /**
  * gwy_radio_buttons_createl:
- * @callback: A callback called when a menu item is activated (or %NULL for
- *            no callback).
+ * @callback: A callback called when a button is selected (or %NULL for no
+ *            callback).
  * @cbdata: User data passed to the callback.
  * @current: Value to be shown as currently selected (-1 to use what happens
  *           to be first).
@@ -219,6 +217,7 @@ gwy_radio_buttons_set_current(GSList *group,
 {
     GtkWidget *button;
 
+    setup_quark();
     if (!(button = gwy_radio_buttons_find(group, current)))
         return FALSE;
 
@@ -264,7 +263,6 @@ GtkWidget*
 gwy_radio_buttons_find(GSList *group,
                        gint value)
 {
-    g_return_val_if_fail(group, NULL);
     setup_quark();
     while (group) {
         g_return_val_if_fail(GTK_IS_RADIO_BUTTON(group->data), FALSE);
@@ -277,6 +275,32 @@ gwy_radio_buttons_find(GSList *group,
     return NULL;
 }
 
+/**
+ * gwy_radio_buttons_set_sensitive:
+ * @group: A radio button group.  Not necessarily created by
+ *         gwy_radio_buttons_create().
+ * @sensitive: %TRUE to make all choices sensitive, %FALSE to make all
+ *             insensitive.
+ *
+ * Sets the sensitivity of all radio buttons in a group.
+ *
+ * This function is useful to make the choice as a whole available/unavailable.
+ * Use gwy_radio_buttons_find() combined with gtk_widget_set_sensitive() to
+ * manage sensitivity of individual options.
+ *
+ * Since: 2.51
+ **/
+void
+gwy_radio_buttons_set_sensitive(GSList *group,
+                                gboolean sensitive)
+{
+    while (group) {
+        g_return_if_fail(GTK_IS_RADIO_BUTTON(group->data));
+        gtk_widget_set_sensitive(GTK_WIDGET(group->data), sensitive);
+        group = g_slist_next(group);
+    }
+}
+
 /**
  * gwy_radio_button_get_value:
  * @button: A radio button belonging to a group created by
@@ -320,9 +344,11 @@ gwy_radio_button_set_value(GtkWidget *button,
  * @title: gwyradiobuttons
  * @short_description: Radio button constructors for enums
  * @see_also: <link linkend="libgwydgets-gwycombobox">gwycombobox</link>
- *            -- combo box constructors
+ *            -- combo box constructors;
+ *            <link linkend="libgwydgets-gwycheckboxes">gwycheckboxes</link>
+ *            -- check box constructors
  *
- * Groups of button associated with some integers can be easily constructed
+ * Groups of buttons associated with some integers can be easily constructed
  * from #GwyEnum's with gwy_radio_buttons_create().
  **/
 
