@@ -1,22 +1,18 @@
 /*
- *  $Id: gwymoduleloader.h 20678 2017-12-18 18:26:55Z yeti-dn $
+ *  $Id: gwymoduleloader.h 23946 2021-08-10 11:16:22Z yeti-dn $
  *  Copyright (C) 2003,2004,2017 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
+ *  License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any
+ *  later version.
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
+ *  warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+ *  details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
+ *  You should have received a copy of the GNU General Public License along with this program; if not, write to the
+ *  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #ifndef __GWY_MODULE_LOADER_H__
@@ -36,13 +32,11 @@ G_BEGIN_DECLS
 #endif
 
 #define GWY_MODULE_QUERY(mod_info) \
-    __GWY_MODULE_QUERY_EXTERN_C G_MODULE_EXPORT GwyModuleInfo* \
-    _gwy_module_query(void) { return &mod_info; }
+    __GWY_MODULE_QUERY_EXTERN_C G_MODULE_EXPORT GwyModuleInfo* _gwy_module_query(void) { return &mod_info; }
 
 #ifdef GWY_MODULE_BUNDLING
 #define GWY_MODULE_QUERY2(mod_info,mod_name) \
-    __GWY_MODULE_QUERY_EXTERN_C G_GNUC_INTERNAL GwyModuleInfo* \
-    _gwy_module_query__##mod_name(void) { return &mod_info; }
+    __GWY_MODULE_QUERY_EXTERN_C G_GNUC_INTERNAL GwyModuleInfo* _gwy_module_query__##mod_name(void) { return &mod_info; }
 #else
 #define GWY_MODULE_QUERY2(mod_info,mod_name) GWY_MODULE_QUERY(mod_info)
 #endif
@@ -109,4 +103,4 @@ G_END_DECLS
 
 #endif /* __GWY_MODULE_LOADER_H__ */
 
-/* vim: set cin et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
+/* vim: set cin columns=120 tw=118 et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
