@@ -1,5 +1,5 @@
 /*
- *  $Id: cdline.c 22332 2019-07-25 07:33:37Z yeti-dn $
+ *  $Id: cdline.c 22783 2020-04-28 20:59:13Z klapetek $
  *  Copyright (C) 2004 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -414,8 +414,9 @@ static gdouble
                 G_GNUC_UNUSED gint n_param,
                 const gdouble *param,
                 G_GNUC_UNUSED gpointer user_data,
-                G_GNUC_UNUSED gboolean *fres)
+                gboolean *fres)
 {
+  *fres = TRUE;
   if ( (param[0]*param[0] - (x-param[1])*(x-param[1])) > 0.0)
      return param[2] - sqrt(param[0]*param[0] - (x-param[1])*(x-param[1]));
   else
@@ -481,8 +482,9 @@ func_circle_up(gdouble x,
                G_GNUC_UNUSED gint n_param,
                const gdouble *param,
                G_GNUC_UNUSED gpointer user_data,
-               G_GNUC_UNUSED gboolean *fres)
+               gboolean *fres)
 {
+  *fres = TRUE;
   if ( (param[0]*param[0] - (x-param[1])*(x-param[1])) > 0.0)
     return param[2] + sqrt(param[0]*param[0] - (x-param[1])*(x-param[1]));
   else
