@@ -1,5 +1,5 @@
 /*
- *  $Id: correct.c 22838 2020-06-03 14:18:55Z yeti-dn $
+ *  $Id: correct.c 23824 2021-06-10 13:19:16Z yeti-dn $
  *  Copyright (C) 2004-2018 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -1235,9 +1235,9 @@ guess_lattice(GwyDataField *dfield, gdouble *a1a2, gboolean is_psdf)
 
 static gdouble
 refine_from_multiple(GwyDataField *dfield, gdouble *a1a2,
-                     gint range, gint limit, gint xwinsize, gint ywinsize)
+                     gint peakrange, gint dist2limit, gint xwinsize, gint ywinsize)
 {
-    gint i, j, n, nex, xres, yres;
+    gint i, j, n, nex, xres, yres, ii, jj;
     gdouble sii, sij, sjj, six, sjx, siy, sjy, xytmp[2];
     gdouble w, D, dx, dy, xoff, yoff;
 
@@ -1249,10 +1249,10 @@ refine_from_multiple(GwyDataField *dfield, gdouble *a1a2,
     dy = dfield->yreal/yres;
     n = nex = 0;
     sii = sij = sjj = six = sjx = siy = sjy = 0.0;
-    for (i = -range; i <= range; i++) {
-        for (j = -range; j <= range; j++) {
+    for (i = -peakrange; i <= peakrange; i++) {
+        for (j = -peakrange; j <= peakrange; j++) {
             w = i*i + j*j;
-            if (w > limit || w == 0)
+            if (w > dist2limit || w == 0)
                 continue;
 
             xytmp[0] = i*a1a2[0] + j*a1a2[2];
@@ -1271,10 +1271,15 @@ refine_from_multiple(GwyDataField *dfield, gdouble *a1a2,
                                               xwinsize, ywinsize))
                 continue;
 
+            jj = GWY_ROUND(xytmp[0]);
+            ii = GWY_ROUND(xytmp[1]);
+            if (jj < 0 || jj >= xres || ii < 0 || ii >= yres)
+                continue;
+
             xytmp[0] = (xytmp[0] + 0.5)*dx + xoff;
             xytmp[1] = (xytmp[1] + 0.5)*dy + yoff;
 
-            w = 1.0/w;
+            w = dfield->data[ii*xres + jj]/w;
             sii += i*i*w;
             sij += i*j*w;
             sjj += j*j*w;
@@ -1437,6 +1442,7 @@ gwy_data_field_measure_lattice_psdf(GwyDataField *psdf2d, gdouble *a1a2)
     gdouble dx, dy;
     guint i;
 
+    gwy_debug("input: (%g, %g) (%g, %g)", a1a2[0], a1a2[1], a1a2[2], a1a2[3]);
     if ((a1a2[0] == 0.0 && a1a2[1] == 0.0)
         || (a1a2[2] == 0.0 && a1a2[3] == 0.0)) {
         if (!guess_lattice(psdf2d, a1a2, TRUE))
@@ -1446,6 +1452,7 @@ gwy_data_field_measure_lattice_psdf(GwyDataField *psdf2d, gdouble *a1a2)
     }
 
     transform_vectors_real_freq(a1a2);
+    gwy_debug("freq: (%g, %g) (%g, %g)", a1a2[0], a1a2[1], a1a2[2], a1a2[3]);
     for (i = 0; i < 4; i++) {
         if (gwy_isnan(a1a2[i]) || gwy_isinf(a1a2[i]))
             return FALSE;
@@ -1454,6 +1461,7 @@ gwy_data_field_measure_lattice_psdf(GwyDataField *psdf2d, gdouble *a1a2)
     if (!refine_lattice(psdf2d, a1a2, TRUE))
         return FALSE;
 
+    gwy_debug("refined: (%g, %g) (%g, %g)", a1a2[0], a1a2[1], a1a2[2], a1a2[3]);
     transform_vectors_real_freq(a1a2);
     gwy_debug("real: (%g, %g) (%g, %g)", a1a2[0], a1a2[1], a1a2[2], a1a2[3]);
     for (i = 0; i < 4; i++) {
