@@ -1,5 +1,5 @@
 /*
- *  $Id: dataline.c 22792 2020-05-03 09:22:40Z yeti-dn $
+ *  $Id: dataline.c 23261 2021-03-15 14:10:56Z yeti-dn $
  *  Copyright (C) 2003-2020 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -476,8 +476,13 @@ gwy_data_line_part_extract(GwyDataLine *data_line,
 void
 gwy_data_line_copy(GwyDataLine *a, GwyDataLine *b)
 {
+    g_return_if_fail(GWY_IS_DATA_LINE(a));
+    g_return_if_fail(GWY_IS_DATA_LINE(b));
     g_return_if_fail(a->res == b->res);
 
+    if (a == b)
+        return;
+
     gwy_assign(b->data, a->data, a->res);
 }
 
@@ -968,7 +973,7 @@ gwy_data_line_get_dval_real(GwyDataLine *a, gdouble x, gint interpolation)
  * @x: Whether to invert data point order.
  * @z: Whether to invert in Z direction (i.e., invert values).
  *
- * Reflects amd/or inverts a data line.
+ * Reflects and/or inverts a data line.
  *
  * In the case of value reflection, it's inverted about mean value.
  **/
