@@ -1,6 +1,6 @@
 /*
- *  $Id: grains-values.c 20678 2017-12-18 18:26:55Z yeti-dn $
- *  Copyright (C) 2003-2017 David Necas (Yeti), Petr Klapetek.
+ *  $Id: grains-values.c 21403 2018-09-07 12:12:47Z yeti-dn $
+ *  Copyright (C) 2003-2018 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -1271,7 +1271,7 @@ gwy_data_field_grains_get_quantities(GwyDataField *data_field,
         NEED_SIZES,                   /* pixel area */
         NEED_MIN | NEED_MAX,          /* half-height area */
         0,                            /* flat boundary length */
-        INVALID,
+        NEED_ZVALUE,                  /* rms */
         NEED_BOUNDPOS,                /* min bounding size */
         NEED_BOUNDPOS,                /* min bounding direction */
         NEED_BOUNDPOS,                /* max bounding size */
@@ -1421,8 +1421,8 @@ gwy_data_field_grains_get_quantities(GwyDataField *data_field,
                         min, max, xvalue, yvalue, zvalue, linear, quadratic);
 
     d = data_field->data;
-    qh = gwy_data_field_get_xmeasure(data_field);
-    qv = gwy_data_field_get_ymeasure(data_field);
+    qh = gwy_data_field_get_dx(data_field);
+    qv = gwy_data_field_get_dy(data_field);
     qdiag = hypot(qh, qv);
     qarea = qh*qv;
     qgeom = sqrt(qarea);
@@ -1540,6 +1540,15 @@ gwy_data_field_grains_get_quantities(GwyDataField *data_field,
         g_free(zhalf);
         g_free(zhsizes);
     }
+    if ((p = quantity_data[GWY_GRAIN_VALUE_RMS])) {
+        gwy_clear(p, ngrains + 1);
+        for (k = 0; k < nn; k++) {
+            gno = grains[k];
+            p[gno] += (d[k] - zvalue[gno])*(d[k] - zvalue[gno]);
+        }
+        for (gno = 0; gno <= ngrains; gno++)
+            p[gno] = sqrt(p[gno]/sizes[gno]);
+    }
     if ((p = quantity_data[GWY_GRAIN_VALUE_FLAT_BOUNDARY_LENGTH])) {
         gwy_clear(p, ngrains + 1);
         /* Note the cycles go to xres and yres inclusive as we calculate the
@@ -2201,6 +2210,7 @@ gwy_grain_quantity_needs_same_units(GwyGrainQuantity quantity)
                          | (ONE << GWY_GRAIN_VALUE_MEAN)
                          | (ONE << GWY_GRAIN_VALUE_MEDIAN)
                          | (ONE << GWY_GRAIN_VALUE_HALF_HEIGHT_AREA)
+                         | (ONE << GWY_GRAIN_VALUE_RMS)
                          | (ONE << GWY_GRAIN_VALUE_FLAT_BOUNDARY_LENGTH)
                          | (ONE << GWY_GRAIN_VALUE_MINIMUM_BOUND_SIZE)
                          | (ONE << GWY_GRAIN_VALUE_MINIMUM_BOUND_ANGLE)
@@ -2224,7 +2234,14 @@ gwy_grain_quantity_needs_same_units(GwyGrainQuantity quantity)
                          | (ONE << GWY_GRAIN_VALUE_CIRCUMCIRCLE_R)
                          | (ONE << GWY_GRAIN_VALUE_CIRCUMCIRCLE_X)
                          | (ONE << GWY_GRAIN_VALUE_CIRCUMCIRCLE_Y)
-                         | (ONE << GWY_GRAIN_VALUE_MEAN_RADIUS)),
+                         | (ONE << GWY_GRAIN_VALUE_MEAN_RADIUS)
+                         | (ONE << GWY_GRAIN_VALUE_EQUIV_ELLIPSE_MAJOR)
+                         | (ONE << GWY_GRAIN_VALUE_EQUIV_ELLIPSE_MINOR)
+                         | (ONE << GWY_GRAIN_VALUE_EQUIV_ELLIPSE_ANGLE)
+                         | (ONE << GWY_GRAIN_VALUE_MINIMUM_MARTIN_DIAMETER)
+                         | (ONE << GWY_GRAIN_VALUE_MINIMUM_MARTIN_ANGLE)
+                         | (ONE << GWY_GRAIN_VALUE_MAXIMUM_MARTIN_DIAMETER)
+                         | (ONE << GWY_GRAIN_VALUE_MAXIMUM_MARTIN_ANGLE)),
         same_units = ((ONE << GWY_GRAIN_VALUE_SLOPE_THETA)
                       | (ONE << GWY_GRAIN_VALUE_SURFACE_AREA)
                       | (ONE << GWY_GRAIN_VALUE_CURVATURE1)
@@ -2276,13 +2293,18 @@ gwy_grain_quantity_get_units(GwyGrainQuantity quantity,
                        | (ONE << GWY_GRAIN_VALUE_CIRCUMCIRCLE_R)
                        | (ONE << GWY_GRAIN_VALUE_CIRCUMCIRCLE_X)
                        | (ONE << GWY_GRAIN_VALUE_CIRCUMCIRCLE_Y)
-                       | (ONE << GWY_GRAIN_VALUE_MEAN_RADIUS)),
+                       | (ONE << GWY_GRAIN_VALUE_MEAN_RADIUS)
+                       | (ONE << GWY_GRAIN_VALUE_EQUIV_ELLIPSE_MAJOR)
+                       | (ONE << GWY_GRAIN_VALUE_EQUIV_ELLIPSE_MINOR)
+                       | (ONE << GWY_GRAIN_VALUE_MINIMUM_MARTIN_DIAMETER)
+                       | (ONE << GWY_GRAIN_VALUE_MAXIMUM_MARTIN_DIAMETER)),
         icoord_units = ((ONE << GWY_GRAIN_VALUE_CURVATURE1)
                        | (ONE << GWY_GRAIN_VALUE_CURVATURE2)),
         value_units = ((ONE << GWY_GRAIN_VALUE_MAXIMUM)
                        | (ONE << GWY_GRAIN_VALUE_MINIMUM)
                        | (ONE << GWY_GRAIN_VALUE_MEAN)
                        | (ONE << GWY_GRAIN_VALUE_MEDIAN)
+                       | (ONE << GWY_GRAIN_VALUE_RMS)
                        | (ONE << GWY_GRAIN_VALUE_CURVATURE_CENTER_Z)),
         area_units = ((ONE << GWY_GRAIN_VALUE_PROJECTED_AREA)
                       | (ONE << GWY_GRAIN_VALUE_HALF_HEIGHT_AREA)
@@ -2296,7 +2318,10 @@ gwy_grain_quantity_get_units(GwyGrainQuantity quantity,
                        | (ONE << GWY_GRAIN_VALUE_SLOPE_PHI)
                        | (ONE << GWY_GRAIN_VALUE_SLOPE_THETA)
                        | (ONE << GWY_GRAIN_VALUE_CURVATURE_ANGLE1)
-                       | (ONE << GWY_GRAIN_VALUE_CURVATURE_ANGLE2))
+                       | (ONE << GWY_GRAIN_VALUE_CURVATURE_ANGLE2)
+                       | (ONE << GWY_GRAIN_VALUE_EQUIV_ELLIPSE_ANGLE)
+                       | (ONE << GWY_GRAIN_VALUE_MINIMUM_MARTIN_ANGLE)
+                       | (ONE << GWY_GRAIN_VALUE_MAXIMUM_MARTIN_ANGLE))
     };
 
     g_return_val_if_fail(GWY_IS_SI_UNIT(siunitxy), result);
