@@ -1,5 +1,5 @@
 /*
- *  $Id: grains-wshed.c 21670 2018-11-23 14:38:03Z yeti-dn $
+ *  $Id: grains-wshed.c 22335 2019-07-25 08:23:38Z yeti-dn $
  *  Copyright (C) 2003-2017 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -25,10 +25,11 @@
 
 #include "config.h"
 #include <string.h>
-#include <libgwyddion/gwyddion.h>
+#include <libgwyddion/gwymacros.h>
 #include <libprocess/filters.h>
 #include <libprocess/stats.h>
 #include <libprocess/grains.h>
+#include "libgwyddion/gwyomp.h"
 #include "gwyprocessinternal.h"
 
 #define GRAIN_BARRIER G_MAXINT
