@@ -1,5 +1,5 @@
 /*
- *  $Id: gwycalibration.c 22332 2019-07-25 07:33:37Z yeti-dn $
+ *  $Id: gwycalibration.c 23204 2021-03-08 15:31:59Z yeti-dn $
  *  Copyright (C) 2010,2011 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -183,7 +183,8 @@ gwy_calibration_new(const gchar *name,
     g_return_val_if_fail(name, NULL);
 
     calibration = g_object_new(GWY_TYPE_CALIBRATION, "is-const", is_const, NULL);
-    if (filename) calibration->filename = g_strdup(filename);
+    if (filename)
+        calibration->filename = g_strdup(filename);
     g_string_assign(GWY_RESOURCE(calibration)->name, name);
 
     calibration->caldata = NULL;
