@@ -1,6 +1,6 @@
 /*
- *  $Id: gwyprocessinternal.h 21661 2018-11-21 13:28:44Z yeti-dn $
- *  Copyright (C) 2003-2018 David Necas (Yeti), Petr Klapetek.
+ *  $Id: gwyprocessinternal.h 22332 2019-07-25 07:33:37Z yeti-dn $
+ *  Copyright (C) 2003-2019 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -24,17 +24,9 @@
 #ifndef __GWYPROCESS_INTERNAL_H__
 #define __GWYPROCESS_INTERNAL_H__
 
-#include <fftw3.h>
-#include <string.h>
 #include <libprocess/gwyprocessenums.h>
 #include <libprocess/datafield.h>
 
-/* Do not require FFTW 3.3 just for a couple of trivial macros. */
-#define gwy_fftw_new_real(n) \
-    (gdouble*)fftw_malloc((n)*sizeof(gdouble))
-#define gwy_fftw_new_complex(n) \
-    (fftw_complex*)fftw_malloc((n)*sizeof(fftw_complex))
-
 /* Cache operations */
 #define CVAL(datafield, b)  ((datafield)->cache[GWY_DATA_FIELD_CACHE_##b])
 #define CBIT(b)             (1 << GWY_DATA_FIELD_CACHE_##b)
@@ -282,4 +274,3 @@ G_END_DECLS
 #endif /* __GWYPROCESS_INTERNAL_H__ */
 
 /* vim: set cin et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
-
