@@ -1,22 +1,18 @@
 /*
- *  $Id: hough.c 21671 2018-11-23 14:46:49Z yeti-dn $
- *  Copyright (C) 2003 David Necas (Yeti), Petr Klapetek.
+ *  $Id: hough.c 23652 2021-05-10 11:33:03Z yeti-dn $
+ *  Copyright (C) 2003-2021 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
+ *  License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any
+ *  later version.
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
+ *  warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+ *  details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
+ *  You should have received a copy of the GNU General Public License along with this program; if not, write to the
+ *  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #include <libgwyddion/gwymacros.h>
@@ -107,8 +103,7 @@ gwy_data_field_hough_line(GwyDataField *dfield,
         for (row = 0; row < yres; row++) {
             if (dfield->data[col + row*xres] > 0.0) {
                 if (x_gradient && y_gradient) {
-                    gradangle = atan2(y_gradient->data[col + row*xres],
-                                      x_gradient->data[col + row*xres]);
+                    gradangle = atan2(y_gradient->data[col + row*xres], x_gradient->data[col + row*xres]);
                     if (gradangle < 0.0)
                         gradangle += G_PI;
                     if (!overlapping)
@@ -124,15 +119,8 @@ gwy_data_field_hough_line(GwyDataField *dfield,
                     if (data[col + row*xres]) printf("%g %g\n", theta, gradangle);
                     if (x_gradient && y_gradient && !(fabs(theta-gradangle)<threshold)) continue;*/
 
-
                     rho = col*cos(theta) + row*sin(theta);
-
-                    add_point(result,
-                              (gint)((rho/rhostep) + rxres/2.0),
-                              k,
-                              data[col + row*xres],
-                              hwidth);
-
+                    add_point(result, (gint)((rho/rhostep) + rxres/2.0), k, data[col + row*xres], hwidth);
                 }
             }
         }
@@ -159,38 +147,32 @@ gwy_data_field_hough_line_strenghten(GwyDataField *dfield,
     gdouble xdata[20], ydata[20];
     gdouble dx;
 
-    result = gwy_data_field_new(3*hypot(dfield->xres, dfield->yres),
-                                360, 0, 10,
-                                FALSE);
+    result = gwy_data_field_new(3*hypot(dfield->xres, dfield->yres), 360, 0, 10, FALSE);
 
-    gwy_data_field_hough_line(dfield, x_gradient, y_gradient, result, hwidth,
-                              FALSE);
+    gwy_data_field_hough_line(dfield, x_gradient, y_gradient, result, hwidth, FALSE);
 
     water = gwy_data_field_duplicate(result);
     gwy_data_field_grains_splash_water(result, water, 2,
-                                       0.005*(gwy_data_field_get_max(result)
-                                              - gwy_data_field_get_min(result)));
+                                       0.005*(gwy_data_field_get_max(result) - gwy_data_field_get_min(result)));
 
-   gwy_debug("%d %d, %g, %g",
-             gwy_data_field_get_xres(result),
-             gwy_data_field_get_yres(result),
-             gwy_data_field_get_min(result),
-             gwy_data_field_get_max(result));
+    gwy_debug("%d %d, %g, %g",
+              gwy_data_field_get_xres(result),
+              gwy_data_field_get_yres(result),
+              gwy_data_field_get_min(result),
+              gwy_data_field_get_max(result));
 
     gwy_data_field_get_min_max(water, &hmin, &hmax);
 
-    threshval = hmin + (hmax - hmin)*threshold; /*FIXME do GUI for this parameter*/
-    gwy_data_field_get_local_maxima_list(water, xdata, ydata, zdata, 20, 10,
-                                         threshval, TRUE);
+    threshval = hmin + (hmax - hmin)*threshold;
+    gwy_data_field_get_local_maxima_list(water, xdata, ydata, zdata, 20, 10, threshval, TRUE);
     dx = gwy_data_field_get_dx(result);
     for (i = 0; i < 20; i++) {
-       if (zdata[i] > threshval) {
-           gwy_debug("point: %g %g (of %d %d), xreal: %g  yreal: %g\n",
-                     xdata[i], ydata[i],
-                     result->xres, result->yres, result->xreal, result->yreal);
-           bresenhams_line_polar(dfield, xdata[i]*dx - result->xreal/2.0,
-                                 ydata[i]*G_PI/result->yres + G_PI/4,
-                                 1);
+        if (zdata[i] > threshval) {
+            gwy_debug("point: %g %g (of %d %d), xreal: %g  yreal: %g\n",
+                      xdata[i], ydata[i], result->xres, result->yres, result->xreal, result->yreal);
+            bresenhams_line_polar(dfield, xdata[i]*dx - result->xreal/2.0,
+                                  ydata[i]*G_PI/result->yres + G_PI/4,
+                                  1);
         }
     }
     g_object_unref(water);
@@ -222,12 +204,10 @@ gwy_data_field_hough_circle(GwyDataField *dfield,
         for (row = 0; row < yres; row++) {
             if (dfield->data[col + row*xres] > 0) {
                 if (x_gradient && y_gradient)
-                    angle = atan2(y_gradient->data[col + row*xres],
-                                  x_gradient->data[col + row*xres]);
+                    angle = atan2(y_gradient->data[col + row*xres], x_gradient->data[col + row*xres]);
 
                 if (x_gradient && y_gradient)
-                    bresenhams_circle_gradient(result, radius, col, row, 1,
-                                               angle);
+                    bresenhams_circle_gradient(result, radius, col, row, 1, angle);
                 else
                     bresenhams_circle(result, radius, col, row, 1);
             }
@@ -253,25 +233,19 @@ gwy_data_field_hough_circle_strenghten(GwyDataField *dfield,
 
     gwy_data_field_hough_circle(dfield, x_gradient, y_gradient, result, radius);
 
-
-
-
     gwy_data_field_get_min_max(result, &hmin, &hmax);
-    threshval = hmax + (hmax - hmin)*threshold; /*FIXME do GUI for this parameter*/
-    gwy_data_field_get_local_maxima_list(result, xdata, ydata, zdata, 200, 2,
-                                         threshval, TRUE);
+    threshval = hmax + (hmax - hmin)*threshold;
+    gwy_data_field_get_local_maxima_list(result, xdata, ydata, zdata, 200, 2, threshval, TRUE);
 
     buffer = gwy_data_field_duplicate(dfield);
     gwy_data_field_fill(buffer, 0);
 
     for (i = 0; i < 200; i++) {
-        if (zdata[i] > threshval) {
-                bresenhams_circle(buffer, (gint)radius, xdata[i], ydata[i], 1);
-        }
+        if (zdata[i] > threshval)
+            bresenhams_circle(buffer, (gint)radius, xdata[i], ydata[i], 1);
     }
     gwy_data_field_threshold(buffer, 1, 0, 2);
     gwy_data_field_sum_fields(dfield, dfield, buffer);
-
 }
 
 static inline gint
@@ -343,8 +317,7 @@ bresenhams_line_polar(GwyDataField *dfield,
 {
      gint px1, px2, py1, py2;
 
-     gwy_data_field_hough_polar_line_to_datafield(dfield, rho, theta,
-                                                  &px1, &px2, &py1, &py2);
+     gwy_data_field_hough_polar_line_to_datafield(dfield, rho, theta, &px1, &px2, &py1, &py2);
      bresenhams_line(dfield, px1, px2, py1, py2, value);
 }
 
@@ -407,7 +380,7 @@ bresenhams_circle(GwyDataField *dfield,
                   gint col, gint row,
                   gdouble value)
 {
-    gdouble n = 0.0, invradius=1.0/r;
+    gdouble n = 0.0, invradius = 1.0/r;
     gint dx = 0, dy = r-1;
     gint dxoffset, dyoffset;
     gint offset = col + row*dfield->xres;
@@ -464,41 +437,76 @@ bresenhams_circle_gradient(GwyDataField *dfield, gdouble r, gint col, gint row,
      }
 }
 
-
 static gint
-find_smallest_index(gdouble *data, gint n)
+replace_existing_maxima(gdouble *xdata, gdouble *ydata, gdouble *zdata,
+                        gint j, gint i, gdouble value, gdouble skip2, gint *count, gint ndata)
 {
-    gint i, imin = 0;
-    gdouble valmin = G_MAXDOUBLE;
+    gint k, n, m = -1;
 
-    for (i = 0; i < n; i++) {
-        if (data[i] < valmin) {
-            imin = i;
-            valmin = data[i];
+    /* If it cannot replace any existing maximum, skip.  The array is kept sorted so we just check the last item. */
+    if (*count == ndata && value <= zdata[ndata-1])
+        return -1;
+
+    for (k = n = 0; n < *count; n++) {
+        gdouble dx = xdata[n] - j, dy = ydata[n] - i;
+        if (dx*dx + dy*dy < skip2) {
+            /* If we find a maximum which is too close and larger, then the new one can be discarded. */
+            if (zdata[n] >= value)
+                return -1;
+            /* Replace the first maximum which is too close if it is smaller. */
+            if (m == -1) {
+                xdata[k] = j;
+                ydata[k] = i;
+                zdata[k] = value;
+                m = k;
+                k++;
+            }
+            /* Otherwise item n gets skipped (overwritten). */
+        }
+        else {
+            xdata[k] = xdata[n];
+            ydata[k] = ydata[n];
+            zdata[k] = zdata[n];
+            k++;
         }
     }
-    return imin;
-
-}
-
-static gint
-find_isthere(gdouble *xdata, gdouble *ydata,
-             gint mcol, gint mrow, gdouble skip, gint n)
-{
-    gint i;
-
-    for (i = 0; i < n; i++) {
-        if (sqrt((xdata[i]-mcol)*(xdata[i]-mcol)
-                 + (ydata[i]-mrow)*(ydata[i]-mrow)) < skip)
-            return i;
+    /* If the new maximum is not too close to anything find the insertion position normally.  Search from the end;
+     * that is where we are likely to find the right position.*/
+    if (m == -1) {
+        for (k = *count; k && zdata[k-1] < value; k--)
+            ;
+        g_assert(k < ndata);
+        *count = MAX(*count, k+1);
+        n = (*count-1 - k);
+        memmove(xdata+k+1, xdata+k, n*sizeof(gdouble));
+        memmove(ydata+k+1, ydata+k, n*sizeof(gdouble));
+        memmove(zdata+k+1, zdata+k, n*sizeof(gdouble));
+        xdata[k] = j;
+        ydata[k] = i;
+        zdata[k] = value;
+        return k;
     }
-    return -1;
+
+    /* We replaced something and it could have been more than one item. */
+    *count = k;
+
+    /* Ensure the arrays are still sorted.  Removal does not break the order, but item m is larger than the previous
+     * item at that position and may have to be moved up. */
+    k = m;
+    while (m > 0 && zdata[m-1] < zdata[m]) {
+        GWY_SWAP(gdouble, xdata[m], xdata[m-1]);
+        GWY_SWAP(gdouble, ydata[m], ydata[m-1]);
+        GWY_SWAP(gdouble, zdata[m], zdata[m-1]);
+        m--;
+    }
+
+    return k;
 }
 
 static void
-get_local_maximum(GwyDataField *dfield,
-                  gint mcol, gint mrow,
-                  gdouble *xval, gdouble *yval)
+refine_local_maximum(GwyDataField *dfield,
+                     gint mcol, gint mrow,
+                     gdouble *xval, gdouble *yval)
 {
     *xval = mcol;
     *yval = mrow;
@@ -532,45 +540,43 @@ gwy_data_field_get_local_maxima_list(GwyDataField *dfield,
                                      gdouble threshold,
                                      gboolean subpixel)
 {
-    gint col, row, mcol, mrow, i, count, xres, yres;
-    gdouble xval, yval;
-    gdouble value;
+    gint j, i, k, m, count, xres, yres, skip2;
+    gdouble xval, yval, value;
+    gdouble *d;
 
-    for (i = 0; i < ndata; i++) {
-        xdata[i] = 0;
-        ydata[i] = 0;
+    g_return_val_if_fail(GWY_IS_DATA_FIELD(dfield), 0);
+
+    gwy_clear(xdata, ndata);
+    gwy_clear(ydata, ndata);
+    for (i = 0; i < ndata; i++)
         zdata[i] = -G_MAXDOUBLE;
-    }
 
     count = 0;
+    skip2 = skip*skip;
     xres = dfield->xres;
     yres = dfield->yres;
-    for (row = 0; row < yres; row++) {
-        for (col = 0; col < xres; col++) {
-            if ((value = dfield->data[row*xres + col]) > threshold) {
-                mcol = col;
-                mrow = row;
+    d = dfield->data;
+    for (i = 1; i < yres-1; i++) {
+        k = i*xres + 1;
+        for (j = 1; j < xres-1; j++, k++) {
+            if ((value = d[k]) < threshold)
+                continue;
+            /* Ensure it is actually a local maximum. */
+            if (value < d[k-1] || value < d[k+1]
+                || value < d[k-xres-1] || value < d[k-xres] || value < d[k-xres+1]
+                || value < d[k+xres-1] || value < d[k+xres] || value < d[k+xres+1])
+                continue;
 
-                i = find_isthere(xdata, ydata, mcol, mrow, skip, count);
-                if (i == -1)
-                    i = find_smallest_index(zdata, ndata);
+            /* If there are other maxima too close we either replace some of them or skip this one.  Or just replace
+             * the smallest if the new minimum is far from all others.  */
+            m = replace_existing_maxima(xdata, ydata, zdata, j, i, value, skip2, &count, ndata);
+            if (m < 0)
+                continue;
 
-                if (zdata[i] < value)  {
-                    if (subpixel) {
-                        get_local_maximum(dfield, mcol, mrow, &xval, &yval);
-                        zdata[i] = value;
-                        xdata[i] = xval;
-                        ydata[i] = yval;
-                        count = MAX(i + 1, count);
-                    }
-                    else {
-                        zdata[i] = value;
-                        xdata[i] = mcol;
-                        ydata[i] = mrow;
-                        count = MAX(i + 1, count);
-                    }
-                    continue;
-                }
+            if (subpixel) {
+                refine_local_maximum(dfield, j, i, &xval, &yval);
+                xdata[m] = xval;
+                ydata[m] = yval;
             }
         }
     }
@@ -578,6 +584,49 @@ gwy_data_field_get_local_maxima_list(GwyDataField *dfield,
     return count;
 }
 
+/**
+ * gwy_data_field_get_local_minima_list:
+ * @dfield: A two-dimensional data field.
+ * @xdata: Array of @ndata elements where the columns should be stored.
+ * @ydata: Array of @ndata elements where the rows should be stored.
+ * @zdata: Array of @ndata elements where the values should be stored.
+ * @ndata: Number of items in @xdata, @ydata and @zdata.
+ * @skip: Minimum pixel distance between minima.
+ * @threshold: Minimum value to be considered a minimum.
+ * @subpixel: %TRUE for subpixel refinement.
+ *
+ * Locates local minima in a data field.
+ *
+ * At most @ndata minima are located.
+ *
+ * Returns: The actual number of minima found.
+ *
+ * Since: 2.59
+ **/
+gint
+gwy_data_field_get_local_minima_list(GwyDataField *dfield,
+                                     gdouble *xdata,
+                                     gdouble *ydata,
+                                     gdouble *zdata,
+                                     gint ndata,
+                                     gint skip,
+                                     gdouble threshold,
+                                     gboolean subpixel)
+{
+    GwyDataField *inverted;
+    gint n, i;
+
+    g_return_val_if_fail(GWY_IS_DATA_FIELD(dfield), 0);
+    inverted = gwy_data_field_duplicate(dfield);
+    gwy_data_field_multiply(inverted, -1.0);
+    n = gwy_data_field_get_local_maxima_list(inverted, xdata, ydata, zdata, ndata, skip, threshold, subpixel);
+    g_object_unref(inverted);
+    for (i = 0; i < n; i++)
+        zdata[i] *= -1.0;
+
+    return n;
+}
+
 void
 gwy_data_field_hough_datafield_line_to_polar(gint px1,
                                              gint px2,
@@ -607,4 +656,4 @@ gwy_data_field_hough_datafield_line_to_polar(gint px1,
  * @short_description: Hough transform
  **/
 
-/* vim: set cin et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
+/* vim: set cin columns=120 tw=118 et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
