@@ -1,22 +1,18 @@
 /*
- *  $Id: peaks.c 21809 2019-01-07 16:45:36Z yeti-dn $
- *  Copyright (C) 2016-2018 David Necas (Yeti).
+ *  $Id: peaks.c 24429 2021-10-26 15:42:26Z yeti-dn $
+ *  Copyright (C) 2016-2021 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
+ *  License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any
+ *  later version.
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
+ *  warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+ *  details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
+ *  You should have received a copy of the GNU General Public License along with this program; if not, write to the
+ *  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #include <libgwyddion/gwymacros.h>
@@ -124,9 +120,8 @@ gwy_peaks_free(GwyPeaks *peaks)
  *
  * Sets the background type a peak analyser will use.
  *
- * The default background is %GWY_PEAK_BACKGROUND_MMSTEP.  Note that the new
- * background type will only be used in future analyses; it does not change the
- * results of the already performed analysis.
+ * The default background is %GWY_PEAK_BACKGROUND_MMSTEP.  Note that the new background type will only be used in
+ * future analyses; it does not change the results of the already performed analysis.
  *
  * Since: 2.46
  **/
@@ -145,9 +140,8 @@ gwy_peaks_set_background(GwyPeaks *peaks,
  *
  * Sets the order type a peak analyser will use.
  *
- * The default order is %GWY_PEAK_ORDER_ABSCISSA.  Note that the new order will
- * only be effective in future analyses; it does not change the results of the
- * already performed analysis.
+ * The default order is %GWY_PEAK_ORDER_ABSCISSA.  Note that the new order will only be effective in future analyses;
+ * it does not change the results of the already performed analysis.
  *
  * Since: 2.46
  **/
@@ -162,15 +156,14 @@ gwy_peaks_set_order(GwyPeaks *peaks,
 /**
  * gwy_peaks_analyze_xy:
  * @peaks: A peak analyser.
- * @xydata: Curve points (array with @n items) that must be ordered by @x
- *          values in ascending order.
+ * @xydata: Curve points (array with @n items) that must be ordered by @x values in ascending order.
  * @n: Number of data points in the curve.
  * @maxpeaks: Maximum number of the most prominent peaks to locate.
  *
  * Finds peaks a graph curve given as GwyXY data.
  *
- * The peaks are remembered by the analyser and their properties can be
- * subsequently requested using gwy_peaks_get_quantity().
+ * The peaks are remembered by the analyser and their properties can be subsequently requested using
+ * gwy_peaks_get_quantity().
  *
  * Returns: The number of peaks found.
  *
@@ -206,8 +199,8 @@ gwy_peaks_analyze_xy(GwyPeaks *peaks,
  *
  * Finds peaks a graph curve given as GwyDataLine.
  *
- * The peaks are remembered by the analyser and their properties can be
- * subsequently requested using gwy_peaks_get_quantity().
+ * The peaks are remembered by the analyser and their properties can be subsequently requested using
+ * gwy_peaks_get_quantity().
  *
  * Returns: The number of peaks found.
  *
@@ -231,8 +224,7 @@ gwy_peaks_analyze_dataline(GwyPeaks *peaks,
     xdata = g_new(gdouble, n);
     for (i = 0; i < n; i++)
         xdata[i] = (i + 0.5)*dx + xoff;
-    retval = gwy_peaks_analyze(peaks, xdata, gwy_data_line_get_data(dline), n,
-                               maxpeaks);
+    retval = gwy_peaks_analyze(peaks, xdata, gwy_data_line_get_data(dline), n, maxpeaks);
     g_free(xdata);
 
     return retval;
@@ -242,16 +234,15 @@ gwy_peaks_analyze_dataline(GwyPeaks *peaks,
 /**
  * gwy_peaks_analyze:
  * @peaks: A peak analyser.
- * @xdata: Abscissa values (array with @n items), must be ordered in ascending
- *         order.
+ * @xdata: Abscissa values (array with @n items), must be ordered in ascending order.
  * @ydata: Ordinate values corresponding to @xdata.
  * @n: Number of data points in the curve.
  * @maxpeaks: Maximum number of the most prominent peaks to locate.
  *
  * Finds peaks a graph curve given as separated @x and @y data.
  *
- * The peaks are remembered by the analyser and their properties can be
- * subsequently requested using gwy_peaks_get_quantity().
+ * The peaks are remembered by the analyser and their properties can be subsequently requested using
+ * gwy_peaks_get_quantity().
  *
  * Returns: The number of peaks found.
  *
@@ -266,7 +257,7 @@ gwy_peaks_analyze(GwyPeaks *peaks,
 {
     GArray *p;
     gint i, k, flatsize;
-    gdouble *ydata_filtered;
+    gdouble *ydata_filtered, *ydata_filtered2;
 
     g_return_val_if_fail(peaks, 0);
     g_return_val_if_fail(xdata, 0);
@@ -279,13 +270,19 @@ gwy_peaks_analyze(GwyPeaks *peaks,
 
     /* Perform simple closing. */
     ydata_filtered = g_new(gdouble, n);
-    ydata_filtered[0] = ydata[0];
-    for (i = 1; i+1 < n; i++) {
-        gdouble y = ydata[i];
-        gdouble yl = 0.5*(ydata[i+1] + ydata[i-1]);
-        ydata_filtered[i] = MAX(y, yl);
+    ydata_filtered2 = g_new(gdouble, n);
+    gwy_assign(ydata_filtered, ydata, n);
+    for (k = 1; k < log(n) - 1.4; k++) {
+        ydata_filtered2[0] = ydata_filtered[0];
+        for (i = 1; i+1 < n; i++) {
+            gdouble y = ydata_filtered[i];
+            gdouble yl = 0.5*(ydata_filtered[i+1] + ydata_filtered[i-1]);
+            ydata_filtered2[i] = MAX(y, yl);
+        }
+        ydata_filtered2[n-1] = ydata_filtered[n-1];
+        GWY_SWAP(gdouble*, ydata_filtered2, ydata_filtered);
     }
-    ydata_filtered[n-1] = ydata[n-1];
+    g_free(ydata_filtered2);
 
     /* Find local maxima. */
     flatsize = 0;
@@ -315,7 +312,6 @@ gwy_peaks_analyze(GwyPeaks *peaks,
             g_array_append_val(p, peak);
         }
     }
-
     g_free(ydata_filtered);
 
     /* Analyse prominence. */
@@ -325,42 +321,34 @@ gwy_peaks_analyze(GwyPeaks *peaks,
         gdouble yleft, yright, arealeft, arearight, disp2left, disp2right;
 
         /* Find the peak extents. */
-        for (ileft = peak->i - 1;
-             ileft && ydata[ileft] == ydata[ileft+1];
-             ileft--)
+        for (ileft = peak->i - 1; ileft && ydata_filtered[ileft] == ydata_filtered[ileft+1]; ileft--)
             ;
 
         if (peaks->background == GWY_PEAK_BACKGROUND_ZERO) {
-            while (ileft
-                   && ydata[ileft] > ydata[ileft-1]
-                   && ydata[ileft] > 0.0)
+            while (ileft && ydata_filtered[ileft] > ydata_filtered[ileft-1] && ydata[ileft] > 0.0)
                 ileft--;
             if (ydata[ileft] < 0.0)
                 ileft++;
             yleft = 0.0;
         }
         else {
-            while (ileft && ydata[ileft] > ydata[ileft-1])
+            while (ileft && ydata_filtered[ileft] > ydata_filtered[ileft-1])
                 ileft--;
             yleft = ydata[ileft];
         }
 
-        for (iright = peak->i + 1;
-             iright+1 < n && ydata[iright] == ydata[iright-1];
-             iright++)
+        for (iright = peak->i + 1; iright+1 < n && ydata_filtered[iright] == ydata_filtered[iright-1]; iright++)
             ;
 
         if (peaks->background == GWY_PEAK_BACKGROUND_ZERO) {
-            while (iright+1 < n
-                   && ydata[iright] > ydata[iright+1]
-                   && ydata[iright] > 0.0)
+            while (iright+1 < n && ydata_filtered[iright] > ydata_filtered[iright+1] && ydata[iright] > 0.0)
                 iright++;
             if (ydata[iright] < 0.0)
                 iright--;
             yright = 0.0;
         }
         else {
-            while (iright+1 < n && ydata[iright] > ydata[iright+1])
+            while (iright+1 < n && ydata_filtered[iright] > ydata_filtered[iright+1])
                 iright++;
             yright = ydata[iright];
         }
@@ -373,26 +361,22 @@ gwy_peaks_analyze(GwyPeaks *peaks,
             gdouble xl = xdata[i] - peak->x, xr = xdata[i+1] - peak->x,
                     yl = ydata[i] - yleft, yr = ydata[i+1] - yleft;
             arealeft += (xr - xl)*(yl + yr)/2.0;
-            disp2left += (xr - xl)*((3.0*yr + yl)*xr*xr
-                                     + 2.0*(yl + yl)*xr*xl
-                                     + (yr + 3.0*yl)*xl*xl)/12.0;
+            disp2left += (xr - xl)*((3.0*yr + yl)*xr*xr + 2.0*(yl + yl)*xr*xl + (yr + 3.0*yl)*xl*xl)/12.0;
         }
         for (i = iright; i > peak->i; i--) {
             gdouble xl = xdata[i-1] - peak->x, xr = xdata[i] - peak->x,
                     yl = ydata[i-1] - yright, yr = ydata[i] - yright;
             arearight += (xr - xl)*(yl + yr)/2.0;
-            disp2right += (xr - xl)*((3.0*yr + yl)*xr*xr
-                                     + 2.0*(yl + yl)*xr*xl
-                                     + (yr + 3.0*yl)*xl*xl)/12.0;
+            disp2right += (xr - xl)*((3.0*yr + yl)*xr*xr + 2.0*(yl + yl)*xr*xl + (yr + 3.0*yl)*xl*xl)/12.0;
         }
 
         peak->area = arealeft + arearight;
         if (arealeft > 0.0 && arearight > 0.0)
             peak->width = sqrt(0.5*(disp2left/arealeft + disp2right/arearight));
         else if (arealeft > 0.0)
-            peak->width = sqrt(0.5*(disp2left/arealeft));
+            peak->width = sqrt(disp2left/arealeft);
         else if (arearight > 0.0)
-            peak->width = sqrt(0.5*(disp2right/arearight));
+            peak->width = sqrt(disp2right/arearight);
         else
             peak->width = 0.0;
 
@@ -410,19 +394,12 @@ gwy_peaks_analyze(GwyPeaks *peaks,
     for (k = 0; k < p->len; ) {
         Peak *peak = &g_array_index(p, Peak, k);
         gdouble xleft = (k > 0 ? g_array_index(p, Peak, k-1).x : xdata[0]);
-        gdouble xright = (k+1 < p->len
-                          ? g_array_index(p, Peak, k+1).x
-                          : xdata[n-1]);
+        gdouble xright = (k+1 < p->len ? g_array_index(p, Peak, k+1).x : xdata[n-1]);
 
-        if (peak->height <= 0.0
-            || peak->area <= 0.0
-            || peak->x >= xright
-            || peak->x <= xleft) {
+        if (peak->height <= 0.0 || peak->area <= 0.0 || peak->x >= xright || peak->x <= xleft)
             g_array_remove_index(p, k);
-        }
         else {
-            peak->prominence = log(peak->height * peak->area
-                                   * (xright - peak->x) * (peak->x - xleft));
+            peak->prominence = log(peak->height * peak->area * (xright - peak->x) * (peak->x - xleft));
             k++;
         }
     }
@@ -458,8 +435,7 @@ gwy_peaks_n_peaks(GwyPeaks *peaks)
  * gwy_peaks_get_quantity:
  * @peaks: A peak analyser.
  * @quantity: Peak property to return.
- * @data: Array of sufficient length to hold values for all peaks (their
- *        number is returned by gwy_peaks_n_peaks()).
+ * @data: Array of sufficient length to hold values for all peaks (their number is returned by gwy_peaks_n_peaks()).
  *
  * Obtaines values of a given quantity for all found peaks.
  *
@@ -526,16 +502,12 @@ compare_abscissa_ascending(gconstpointer a, gconstpointer b)
  * @title: GwyPeaks
  * @short_description: Graph peak analyser
  *
- * One #GwyPeaks analyser can be used repeatedly to find and characterise
- * peaks in several data sets.
+ * One #GwyPeaks analyser can be used repeatedly to find and characterise peaks in several data sets.
  *
- * Feed the curve data to the analyser using functions such as
- * gwy_peaks_analyze(), gwy_peaks_analyze_dataline() or gwy_peaks_analyze_xy().
- * It will process the data, locate peaks and remember their various
- * characteristics that you can subsequently obtain using
- * gwy_peaks_get_quantity().  The results are static; if you change the
- * analyser settings (or the curve data) you need to re-run the analysis
- * function.
+ * Feed the curve data to the analyser using functions such as gwy_peaks_analyze(), gwy_peaks_analyze_dataline() or
+ * gwy_peaks_analyze_xy(). It will process the data, locate peaks and remember their various characteristics that you
+ * can subsequently obtain using gwy_peaks_get_quantity().  The results are static; if you change the analyser
+ * settings (or the curve data) you need to re-run the analysis function.
  **/
 
 /**
@@ -550,8 +522,8 @@ compare_abscissa_ascending(gconstpointer a, gconstpointer b)
 /**
  * GwyPeakBackgroundType:
  * @GWY_PEAK_BACKGROUND_ZERO: The background is fixed at zero value.
- * @GWY_PEAK_BACKGROUND_MMSTEP: The background is a step function connecting
- *                              the nearest minima on the left and right side.
+ * @GWY_PEAK_BACKGROUND_MMSTEP: The background is a step function connecting the nearest minima on the left and right
+ *                              side.
  *
  * Type of background available in graph peak analysers.
  *
@@ -560,10 +532,8 @@ compare_abscissa_ascending(gconstpointer a, gconstpointer b)
 
 /**
  * GwyPeakOrderType:
- * @GWY_PEAK_ORDER_ABSCISSA: Peaks are ordered by abscissa values, from
- *                           left to right.
- * @GWY_PEAK_ORDER_PROMINENCE: Peaks are ordered by prominence, from most
- *                             to least prominent.
+ * @GWY_PEAK_ORDER_ABSCISSA: Peaks are ordered by abscissa values, from left to right.
+ * @GWY_PEAK_ORDER_PROMINENCE: Peaks are ordered by prominence, from most to least prominent.
  *
  * Type of peak ordering by in the graph peak analyser results.
  *
@@ -572,20 +542,16 @@ compare_abscissa_ascending(gconstpointer a, gconstpointer b)
 
 /**
  * GwyPeakQuantity:
- * @GWY_PEAK_PROMINENCE: Compound quantity characteristing the overall peak
- *                       prominence (taking into account height, area,
- *                       distance from other peaks, ...).
+ * @GWY_PEAK_PROMINENCE: Compound quantity characteristing the overall peak prominence (taking into account height,
+ *                       area, distance from other peaks, ...).
  * @GWY_PEAK_ABSCISSA: Position of peak maximum.
- * @GWY_PEAK_HEIGHT: Peak height (with respect to the chosen background
- *                   function).
- * @GWY_PEAK_AREA: Peak area (with respect to the chosen background
- *                 function).
- * @GWY_PEAK_WIDTH: Peak width, more or less corresponding to standard
- *                  deviation.
+ * @GWY_PEAK_HEIGHT: Peak height (with respect to the chosen background function).
+ * @GWY_PEAK_AREA: Peak area (with respect to the chosen background function).
+ * @GWY_PEAK_WIDTH: Peak width, more or less corresponding to standard deviation.
  *
- * Type of pcharacteristics graph peak analysers can provide.
+ * Type of characteristics graph peak analysers can provide.
  *
  * Since: 2.46
  **/
 
-/* vim: set cin et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
+/* vim: set cin columns=120 tw=118 et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
