@@ -1,5 +1,5 @@
 /*
- *  $Id: stats-acfpsdf.c 22797 2020-05-05 14:32:37Z yeti-dn $
+ *  $Id: stats-acfpsdf.c 23565 2021-04-25 13:39:21Z yeti-dn $
  *  Copyright (C) 2003-2020 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -2302,7 +2302,7 @@ gwy_data_field_area_row_psdf(GwyDataField *field,
     g_free(accum_data);
 
     gwy_data_line_multiply(line, gwy_data_field_get_dx(field)/(2*G_PI));
-    line->real = line->res * 2.0*G_PI/field->xreal;
+    line->real = 2.0*G_PI/gwy_data_field_get_dx(field);
     /* line->off = -0.5*line->real/line->res; */
 
     gwy_si_unit_power(gwy_data_field_get_si_unit_xy(field),
