@@ -1,5 +1,5 @@
 /*
- *  $Id: surface.c 23194 2021-03-03 23:31:44Z yeti-dn $
+ *  $Id: surface.c 24188 2021-09-23 15:43:53Z yeti-dn $
  *  Copyright (C) 2011-2017 David Nečas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -48,8 +48,8 @@ static GObject*    gwy_surface_deserialize      (const guchar *buffer,
                                                  gsize size,
                                                  gsize *position);
 static GObject*    gwy_surface_duplicate_real   (GObject *serializable);
-static void        gwy_surface_clone_real       (GObject *destination,
-                                                 GObject *source);
+static void        gwy_surface_clone_real       (GObject *source,
+                                                 GObject *copy);
 static void        copy_info                    (GwySurface *dest,
                                                  GwySurface *src);
 static void        ensure_ranges                (GwySurface *surface);
