@@ -1,5 +1,5 @@
 /*
- *  $Id: apedaxfile.c 21783 2019-01-03 12:58:14Z yeti-dn $
+ *  $Id: apedaxfile.c 22001 2019-04-16 13:58:04Z yeti-dn $
  *  Copyright (C) 2005 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -262,7 +262,7 @@ static GwyModuleInfo module_info = {
     "Andrea Cervesato <infos@aperesearch.com>, "
         "Gianfranco Gallizia <infos@aperesearch.com>, "
         "Samo Ziberna <infos@aperesearch.com>",
-    "0.8",
+    "0.8.1",
     "A.P.E. Research srl",
     "2015"
 };
@@ -313,8 +313,8 @@ apedax_detect(const GwyFileDetectInfo *fileinfo,
     if (!apedax_is_plausible_file(fileinfo->head, fileinfo->buffer_len))
         return 0;
 
-    gwy_debug("Opening the file with MiniZIP");
-    uFile = gwyzip_open(fileinfo->name);
+    gwy_debug("Opening the file with MiniZIP/libzip");
+    uFile = gwyzip_open(fileinfo->name, NULL);
 
     if (uFile == NULL) {
         return 0;
@@ -386,12 +386,11 @@ apedax_load(const gchar *filename,
     apdt_flag = g_str_has_suffix(lowercaseFilename, APDT_EXTENSION);
     g_free(lowercaseFilename);
 
-    gwy_debug("Opening the file with MiniZIP");
-    uFile = gwyzip_open(filename);
+    gwy_debug("Opening the file with MiniZIP/libzip");
+    uFile = gwyzip_open(filename, error);
 
-    if (uFile == NULL) {
-        goto fail;
-    }
+    if (uFile == NULL)
+        return NULL;
 
     gwy_debug("Locating the XML file");
 
