@@ -1,5 +1,5 @@
 /*
- *  $Id: apefile.c 20788 2018-02-02 09:41:17Z yeti-dn $
+ *  $Id: apefile.c 22665 2019-11-10 10:11:19Z yeti-dn $
  *  Copyright (C) 2005 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -195,7 +195,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Imports APE (Applied Physics and Engineering) data files."),
     "Yeti <yeti@gwyddion.net>",
-    "0.12",
+    "0.13",
     "David Nečas (Yeti) & Petr Klapetek",
     "2005",
 };
@@ -496,7 +496,7 @@ fill_data_fields(APEFile *apefile,
     GwySIUnit *unit;
     gdouble *data;
     const gchar *zunit;
-    guint b, n, i, j, k;
+    guint b, n, i, k;
     gdouble q;
 
     apefile->data = g_new0(GwyDataField*, apefile->ndata);
@@ -541,12 +541,13 @@ fill_data_fields(APEFile *apefile,
         for (i = 0; i < apefile->res; i++) {
             /* There is always one ignored record, do not ask me why... */
             buffer += sizeof(float);
-            for (j = 0; j < apefile->res; j++) {
-                *(data++) = q*gwy_get_gfloat_le(&buffer);
-            }
+            gwy_convert_raw_data(buffer, apefile->res, 1,
+                                 GWY_RAW_DATA_FLOAT,
+                                 GWY_BYTE_ORDER_LITTLE_ENDIAN,
+                                 data + i*apefile->res, q, 0.0);
+            buffer += apefile->res*sizeof(float);
         }
-        apefile->data[n] = dfield;
-        n++;
+        apefile->data[n++] = dfield;
     }
 }
 
