@@ -1,21 +1,17 @@
 /*
- *  $Id: dm3file.c 22821 2020-05-15 12:11:48Z yeti-dn $
- *  Copyright (C) 2012-2020 David Necas (Yeti).
+ *  $Id: dm3file.c 24137 2021-09-15 12:27:46Z yeti-dn $
+ *  Copyright (C) 2012-2021 David Necas (Yeti).
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
+ *  License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any
+ *  later version.
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
+ *  warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+ *  details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
+ *  You should have received a copy of the GNU General Public License along with this program; if not, write to the
+ *  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 /**
@@ -67,7 +63,8 @@
 #define EXTENSION4 ".dm4"
 
 enum {
-    REPORTED_FILE_SIZE_OFF3 = 16,
+    REPORTED_FILE_SIZE_OFF3_MIN = 16,
+    REPORTED_FILE_SIZE_OFF3_MAX = 24,
     REPORTED_FILE_SIZE_OFF4 = 24,
     MIN_FILE_SIZE3 = 3*4 + 1 + 1 + 4,
     MIN_FILE_SIZE4 = 2*4 + 8 + 1 + 1 + 4,
@@ -109,43 +106,43 @@ enum {
 };
 
 typedef enum {
-    DM3_DATA_NULL = 0,
-    DM3_DATA_SIGNED_INT16 = 1,
-    DM3_DATA_REAL4 = 2,
-    DM3_DATA_COMPLEX8 = 3,
-    DM3_DATA_OBSELETE = 4,
-    DM3_DATA_PACKED = 5,
-    DM3_DATA_UNSIGNED_INT8 = 6,
-    DM3_DATA_SIGNED_INT32 = 7,
-    DM3_DATA_RGB = 8,
-    DM3_DATA_SIGNED_INT8 = 9,
-    DM3_DATA_UNSIGNED_INT16 = 10,
-    DM3_DATA_UNSIGNED_INT32 = 11,
-    DM3_DATA_REAL8 = 12,
-    DM3_DATA_COMPLEX16 = 13,
-    DM3_DATA_BINARY = 14,
-    DM3_DATA_RGB_UINT8_0 = 15,
-    DM3_DATA_RGB_UINT8_1 = 16,
-    DM3_DATA_RGB_UINT16 = 17,
-    DM3_DATA_RGB_FLOAT32 = 18,
-    DM3_DATA_RGB_FLOAT64 = 19,
-    DM3_DATA_RGBA_UINT8_0 = 20,
-    DM3_DATA_RGBA_UINT8_1 = 21,
-    DM3_DATA_RGBA_UINT8_2 = 22,
-    DM3_DATA_RGBA_UINT8_3 = 23,
-    DM3_DATA_RGBA_UINT16 = 24,
-    DM3_DATA_RGBA_FLOAT32 = 25,
-    DM3_DATA_RGBA_FLOAT64 = 26,
-    DM3_DATA_POINT2_SINT16_0 = 27,
-    DM3_DATA_POINT2_SINT16_1 = 28,
-    DM3_DATA_POINT2_SINT32_0 = 29,
+    DM3_DATA_NULL             = 0,
+    DM3_DATA_SIGNED_INT16     = 1,
+    DM3_DATA_REAL4            = 2,
+    DM3_DATA_COMPLEX8         = 3,
+    DM3_DATA_OBSELETE         = 4,
+    DM3_DATA_PACKED           = 5,
+    DM3_DATA_UNSIGNED_INT8    = 6,
+    DM3_DATA_SIGNED_INT32     = 7,
+    DM3_DATA_RGB              = 8,
+    DM3_DATA_SIGNED_INT8      = 9,
+    DM3_DATA_UNSIGNED_INT16   = 10,
+    DM3_DATA_UNSIGNED_INT32   = 11,
+    DM3_DATA_REAL8            = 12,
+    DM3_DATA_COMPLEX16        = 13,
+    DM3_DATA_BINARY           = 14,
+    DM3_DATA_RGB_UINT8_0      = 15,
+    DM3_DATA_RGB_UINT8_1      = 16,
+    DM3_DATA_RGB_UINT16       = 17,
+    DM3_DATA_RGB_FLOAT32      = 18,
+    DM3_DATA_RGB_FLOAT64      = 19,
+    DM3_DATA_RGBA_UINT8_0     = 20,
+    DM3_DATA_RGBA_UINT8_1     = 21,
+    DM3_DATA_RGBA_UINT8_2     = 22,
+    DM3_DATA_RGBA_UINT8_3     = 23,
+    DM3_DATA_RGBA_UINT16      = 24,
+    DM3_DATA_RGBA_FLOAT32     = 25,
+    DM3_DATA_RGBA_FLOAT64     = 26,
+    DM3_DATA_POINT2_SINT16_0  = 27,
+    DM3_DATA_POINT2_SINT16_1  = 28,
+    DM3_DATA_POINT2_SINT32_0  = 29,
     DM3_DATA_POINT2_FLOAT32_0 = 30,
-    DM3_DATA_RECT_SINT16_1 = 31,
-    DM3_DATA_RECT_SINT32_1 = 32,
-    DM3_DATA_RECT_FLOAT32_1 = 33,
-    DM3_DATA_RECT_FLOAT32_0 = 34,
-    DM3_DATA_SIGNED_INT64 = 35,
-    DM3_DATA_UNSIGNED_INT64 = 36,
+    DM3_DATA_RECT_SINT16_1    = 31,
+    DM3_DATA_RECT_SINT32_1    = 32,
+    DM3_DATA_RECT_FLOAT32_1   = 33,
+    DM3_DATA_RECT_FLOAT32_0   = 34,
+    DM3_DATA_SIGNED_INT64     = 35,
+    DM3_DATA_UNSIGNED_INT64   = 36,
     DM3_DATA_LAST
 } DM3DataType;
 
@@ -285,7 +282,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Reads Digital Micrograph DM3 and DM4 files."),
     "Yeti <yeti@gwyddion.net>",
-    "2.2",
+    "2.4",
     "David Nečas (Yeti)",
     "2012",
 };
@@ -334,7 +331,8 @@ dm3_detect(const GwyFileDetectInfo *fileinfo,
     is_open = *(p++);
     gwy_debug("%u %u %u %u %u", version, size, ordering, is_sorted, is_open);
     if (version != 3
-        || size + REPORTED_FILE_SIZE_OFF3 != fileinfo->file_size
+        || size + REPORTED_FILE_SIZE_OFF3_MAX < fileinfo->file_size
+        || size + REPORTED_FILE_SIZE_OFF3_MIN > fileinfo->file_size
         || ordering > 1
         || is_sorted > 1
         || is_open > 1)
@@ -365,8 +363,7 @@ dm4_detect(const GwyFileDetectInfo *fileinfo,
     ordering = gwy_get_guint32_be(&p);
     is_sorted = *(p++);
     is_open = *(p++);
-    gwy_debug("%u %lu %u %u %u", version, (gulong)size,
-              ordering, is_sorted, is_open);
+    gwy_debug("%u %lu %u %u %u", version, (gulong)size, ordering, is_sorted, is_open);
     /* XXX: This fails if the file is larger than 4GB anyway. */
     if (version != 4
         || size + REPORTED_FILE_SIZE_OFF4 != fileinfo->file_size
@@ -406,8 +403,7 @@ dm3_load(const gchar *filename,
     dm3file.filename = filename;
     dm3file.root_entry.is_group = TRUE;
     dm3file.root_entry.label = (gchar*)"";
-    if (!(dm3file.root_entry.group
-          = dm3_read_group(&dm3file.root_entry, &p, &remaining, error)))
+    if (!(dm3file.root_entry.group = dm3_read_group(&dm3file.root_entry, &p, &remaining, error)))
         goto fail;
 
     dm3file.hash = g_hash_table_new_full(g_str_hash, g_str_equal, g_free, NULL);
@@ -468,8 +464,7 @@ dm4_load(const gchar *filename,
     dm4file.filename = filename;
     dm4file.root_entry.is_group = TRUE;
     dm4file.root_entry.label = (gchar*)"";
-    if (!(dm4file.root_entry.group
-          = dm4_read_group(&dm4file.root_entry, &p, &remaining, error)))
+    if (!(dm4file.root_entry.group = dm4_read_group(&dm4file.root_entry, &p, &remaining, error)))
         goto fail;
 
     dm4file.hash = g_hash_table_new_full(g_str_hash, g_str_equal, g_free, NULL);
@@ -510,28 +505,20 @@ dm3_read_image(DM3File *dm3file,
                guint *id,
                GError **error)
 {
-    static const gchar res_fmt[]
-        = "/ImageList/#%u/ImageData/Dimensions/#%u";
-    static const gchar name_fmt[]
-        = "/ImageList/#%u/Name";
-    static const gchar img_fmt[]
-        = "/ImageList/#%u/ImageData/%s";
-    static const gchar calib_fmt[]
-        = "/ImageList/#%u/ImageData/Calibrations/Dimension/#%u/%s";
-
+    static const gchar res_fmt[]   = "/ImageList/#%u/ImageData/Dimensions/#%u";
+    static const gchar name_fmt[]  = "/ImageList/#%u/Name";
+    static const gchar img_fmt[]   = "/ImageList/#%u/ImageData/%s";
+    static const gchar calib_fmt[] = "/ImageList/#%u/ImageData/Calibrations/Dimension/#%u/%s";
     static const gchar *rgb_channels[] = { "R", "G", "B", "Alpha" };
 
     DM3DataType datatype;
     DM3TagType *type;
     DM3ImgResult retval = DM3_IMG_NOT_FOUND;
-    GwyByteOrder byteorder = (dm3file->little_endian
-                              ? GWY_BYTE_ORDER_LITTLE_ENDIAN
-                              : GWY_BYTE_ORDER_BIG_ENDIAN);
+    GwyByteOrder byteorder = (dm3file->little_endian ? GWY_BYTE_ORDER_LITTLE_ENDIAN : GWY_BYTE_ORDER_BIG_ENDIAN);
     GwyRawDataType rawdatatype;
     gdouble xreal, yreal, xoff, yoff;
     guint xres, yres, pixeldepth, itemsize;
     gchar *xunit = NULL, *yunit = NULL, *title = NULL, *key;
-    GQuark quark;
     GwySIUnit *unit;
     gint power10;
     guint nfields = 1, stride = 1, j;
@@ -550,8 +537,7 @@ dm3_read_image(DM3File *dm3file,
         || !dm3_get_uint(dm3file, &pixeldepth, img_fmt, i, "PixelDepth"))
         goto fail;
 
-    gwy_debug("image #%u: xres %u, yres %u xreal %g [%s] yreal %g [%s], "
-              "datatype %u",
+    gwy_debug("image #%u: xres %u, yres %u xreal %g [%s] yreal %g [%s], datatype %u",
               i, xres, yres, xreal, xunit, yreal, yunit, datatype);
 
     if (!(type = dm3_get_leaf_entry(dm3file, NULL, 0, img_fmt, i, "Data")))
@@ -567,27 +553,21 @@ dm3_read_image(DM3File *dm3file,
         rawdatatype = GWY_RAW_DATA_UINT8;
     else if (datatype == DM3_DATA_SIGNED_INT8)
         rawdatatype = GWY_RAW_DATA_SINT8;
-    else if (datatype == DM3_DATA_UNSIGNED_INT16
-             || (datatype == DM3_DATA_PACKED && type->types[1] == DM3_USHORT))
+    else if (datatype == DM3_DATA_UNSIGNED_INT16 || (datatype == DM3_DATA_PACKED && type->types[1] == DM3_USHORT))
         rawdatatype = GWY_RAW_DATA_UINT16;
-    else if (datatype == DM3_DATA_SIGNED_INT16
-             || (datatype == DM3_DATA_PACKED && type->types[1] == DM3_SHORT))
+    else if (datatype == DM3_DATA_SIGNED_INT16 || (datatype == DM3_DATA_PACKED && type->types[1] == DM3_SHORT))
         rawdatatype = GWY_RAW_DATA_SINT16;
-    else if (datatype == DM3_DATA_UNSIGNED_INT32
-             || (datatype == DM3_DATA_PACKED && type->types[1] == DM3_ULONG))
+    else if (datatype == DM3_DATA_UNSIGNED_INT32 || (datatype == DM3_DATA_PACKED && type->types[1] == DM3_ULONG))
         rawdatatype = GWY_RAW_DATA_UINT32;
-    else if (datatype == DM3_DATA_SIGNED_INT32
-             || (datatype == DM3_DATA_PACKED && type->types[1] == DM3_LONG))
+    else if (datatype == DM3_DATA_SIGNED_INT32 || (datatype == DM3_DATA_PACKED && type->types[1] == DM3_LONG))
         rawdatatype = GWY_RAW_DATA_SINT32;
     else if (datatype == DM3_DATA_UNSIGNED_INT64)
         rawdatatype = GWY_RAW_DATA_UINT64;
     else if (datatype == DM3_DATA_SIGNED_INT64)
         rawdatatype = GWY_RAW_DATA_SINT64;
-    else if (datatype == DM3_DATA_REAL4
-             || (datatype == DM3_DATA_PACKED && type->types[1] == DM3_FLOAT))
+    else if (datatype == DM3_DATA_REAL4 || (datatype == DM3_DATA_PACKED && type->types[1] == DM3_FLOAT))
         rawdatatype = GWY_RAW_DATA_FLOAT;
-    else if (datatype == DM3_DATA_REAL8
-             || (datatype == DM3_DATA_PACKED && type->types[1] == DM3_DOUBLE))
+    else if (datatype == DM3_DATA_REAL8 || (datatype == DM3_DATA_PACKED && type->types[1] == DM3_DOUBLE))
         rawdatatype = GWY_RAW_DATA_DOUBLE;
     /* XXX: This is apparently used only for previews which the user unlikely
      * wants imported as four additional channels.
@@ -605,8 +585,7 @@ dm3_read_image(DM3File *dm3file,
 
     itemsize = gwy_raw_data_size(rawdatatype);
     gwy_debug("gwy raw data type %u (item size %u)", rawdatatype, itemsize);
-    if (err_SIZE_MISMATCH(error, itemsize*xres*yres*stride, type->typesize,
-                          TRUE)) {
+    if (err_SIZE_MISMATCH(error, itemsize*xres*yres*stride, type->typesize, TRUE)) {
         retval = DM3_IMG_ERROR;
         goto fail;
     }
@@ -628,12 +607,10 @@ dm3_read_image(DM3File *dm3file,
         gwy_data_field_set_si_unit_xy(field, unit);
         gwy_si_unit_assign(gwy_data_field_get_si_unit_xy(field), unit);
 
-        gwy_convert_raw_data((const guchar*)type->data + itemsize*j,
-                             xres*yres, stride, rawdatatype, byteorder,
+        gwy_convert_raw_data((const guchar*)type->data + itemsize*j, xres*yres, stride, rawdatatype, byteorder,
                              gwy_data_field_get_data(field), 1.0, 0.0);
 
-        quark = gwy_app_get_data_key_for_id(*id);
-        gwy_container_set_object(container, quark, field);
+        gwy_container_set_object(container, gwy_app_get_data_key_for_id(*id), field);
         g_object_unref(field);
 
         title = NULL;
@@ -656,13 +633,11 @@ dm3_read_image(DM3File *dm3file,
 
         if (meta) {
             GwyContainer *mymeta = gwy_container_duplicate(meta);
-            quark = gwy_app_get_data_meta_key_for_id(*id);
-            gwy_container_set_object(container, quark, mymeta);
+            gwy_container_set_object(container, gwy_app_get_data_meta_key_for_id(*id), mymeta);
             g_object_unref(mymeta);
         }
 
-        gwy_file_channel_import_log_add(container, *id, NULL,
-                                        dm3file->filename);
+        gwy_file_channel_import_log_add(container, *id, NULL, dm3file->filename);
 
         (*id)++;
     }
@@ -917,7 +892,7 @@ dm3_get_string(DM3File *dm3file,
                const gchar *keyfmt,
                ...)
 {
-    const gchar *encoding = dm3file->little_endian ? "UTF-16LE" : "UTF16-BE";
+    GwyByteOrder byteorder = (dm3file->little_endian ? GWY_BYTE_ORDER_LITTLE_ENDIAN : GWY_BYTE_ORDER_BIG_ENDIAN);
     DM3TagType *type;
     gchar *key;
     va_list ap;
@@ -934,12 +909,9 @@ dm3_get_string(DM3File *dm3file,
         return FALSE;
 
     if (type->ntypes == 2 && type->types[0] == DM3_STRING)
-        *value = g_convert(type->data, 2*type->types[1], "UTF-8", encoding,
-                           NULL, NULL, NULL);
-    else if (type->ntypes == 3 && type->types[0] == DM3_ARRAY
-             && type->types[1] == DM3_USHORT)
-        *value = g_convert(type->data, 2*type->types[2], "UTF-8", encoding,
-                           NULL, NULL, NULL);
+        *value = gwy_utf16_to_utf8(type->data, type->types[1], byteorder);
+    else if (type->ntypes == 3 && type->types[0] == DM3_ARRAY && type->types[1] == DM3_USHORT)
+        *value = gwy_utf16_to_utf8(type->data, type->types[2], byteorder);
 
     return !!*value;
 }
@@ -988,8 +960,7 @@ dm3_get_leaf_entry_lit(DM3File *dm3file,
     }
 
     if (type->ntypes != typespeclen) {
-        gwy_debug("found, wrong typespec length (%u instead of %u)",
-                  type->ntypes, typespeclen);
+        gwy_debug("found, wrong typespec length (%u instead of %u)", type->ntypes, typespeclen);
         return NULL;
     }
 
@@ -1023,8 +994,7 @@ dm3_read_header(DM3File *dm3file,
         return FALSE;
     }
 
-    if (err_SIZE_MISMATCH(error, dm3file->size + REPORTED_FILE_SIZE_OFF3, *size,
-                          TRUE))
+    if (err_SIZE_MISMATCH(error, dm3file->size + REPORTED_FILE_SIZE_OFF3_MIN, *size, FALSE))
         return FALSE;
 
     *size -= 3*4;
@@ -1050,8 +1020,7 @@ dm4_read_header(DM3File *dm4file,
         return FALSE;
     }
 
-    if (err_SIZE_MISMATCH(error, dm4file->size + REPORTED_FILE_SIZE_OFF4, *size,
-                          TRUE))
+    if (err_SIZE_MISMATCH(error, dm4file->size + REPORTED_FILE_SIZE_OFF4, *size, TRUE))
         return FALSE;
 
     *size -= 2*4 + 8;
@@ -1085,9 +1054,7 @@ format_path(const DM3TagEntry *entry)
     }
 
     for (i = 0; i < path->len/2; i++)
-        GWY_SWAP(gpointer,
-                 g_ptr_array_index(path, i),
-                 g_ptr_array_index(path, path->len-1 - i));
+        GWY_SWAP(gpointer, g_ptr_array_index(path, i), g_ptr_array_index(path, path->len-1 - i));
     g_ptr_array_add(path, NULL);
 
     retval = g_strjoinv("/", (gchar**)path->pdata);
@@ -1156,8 +1123,7 @@ dm3_read_group(DM3TagEntry *parent,
     group->ntags = gwy_get_guint32_be(p);
     *size -= TAG_GROUP_MIN_SIZE3;
     gwy_debug("[%u] Entering a group of %lu tags (%u, %u)",
-              dm3_entry_depth(parent),
-              (gulong)group->ntags, group->is_sorted, group->is_open);
+              dm3_entry_depth(parent), (gulong)group->ntags, group->is_sorted, group->is_open);
 
     group->entries = g_new0(DM3TagEntry, group->ntags);
     for (i = 0; i < group->ntags; i++) {
@@ -1168,8 +1134,7 @@ dm3_read_group(DM3TagEntry *parent,
         }
     }
 
-    gwy_debug("[%u] Leaving group of %lu tags read",
-              dm3_entry_depth(parent), (gulong)group->ntags);
+    gwy_debug("[%u] Leaving group of %lu tags read", dm3_entry_depth(parent), (gulong)group->ntags);
 
     return group;
 }
@@ -1191,8 +1156,7 @@ dm4_read_group(DM3TagEntry *parent,
     group->ntags = gwy_get_guint64_be(p);
     *size -= TAG_GROUP_MIN_SIZE4;
     gwy_debug("[%u] Entering a group of %lu tags (%u, %u)",
-              dm3_entry_depth(parent),
-              (gulong)group->ntags, group->is_sorted, group->is_open);
+              dm3_entry_depth(parent), (gulong)group->ntags, group->is_sorted, group->is_open);
 
     group->entries = g_new0(DM3TagEntry, group->ntags);
     for (i = 0; i < group->ntags; i++) {
@@ -1234,8 +1198,7 @@ dm3_read_entry(DM3TagEntry *parent,
     entry->is_group = (kind == 20);
     lab_len = gwy_get_guint16_be(p);
     *size -= TAG_ENTRY_MIN_SIZE3;
-    gwy_debug("[%u] Entry is %s",
-              dm3_entry_depth(entry), entry->is_group ? "group" : "type");
+    gwy_debug("[%u] Entry is %s", dm3_entry_depth(entry), entry->is_group ? "group" : "type");
 
     if (*size < lab_len) {
         err_TRUNCATED(entry, error);
@@ -1294,8 +1257,7 @@ dm4_read_entry(DM3TagEntry *parent,
     entry->is_group = (kind == 20);
     lab_len = gwy_get_guint16_be(p);
     *size -= TAG_ENTRY_MIN_SIZE4;
-    gwy_debug("[%u] Entry is %s",
-              dm3_entry_depth(entry), entry->is_group ? "group" : "type");
+    gwy_debug("[%u] Entry is %s", dm3_entry_depth(entry), entry->is_group ? "group" : "type");
 
     if (*size < lab_len) {
         err_TRUNCATED(entry, error);
@@ -1353,8 +1315,7 @@ dm3_read_type(DM3TagEntry *parent,
     type = g_new0(DM3TagType, 1);
     type->ntypes = gwy_get_guint32_be(p);
     *size -= TAG_TYPE_MIN_SIZE3;
-    gwy_debug("[%u] Entering a typespec of %lu items",
-              dm3_entry_depth(parent), (gulong)type->ntypes);
+    gwy_debug("[%u] Entering a typespec of %lu items", dm3_entry_depth(parent), (gulong)type->ntypes);
 
     if (*size < sizeof(guint32)*type->ntypes) {
         g_free(type);
@@ -1365,23 +1326,19 @@ dm3_read_type(DM3TagEntry *parent,
     for (i = 0; i < type->ntypes; i++) {
         type->types[i] = gwy_get_guint32_be(p);
         *size -= sizeof(guint32);
-        gwy_debug("[%u] Typespec #%lu is %lu",
-                  dm3_entry_depth(parent), (gulong)i, (gulong)type->types[i]);
+        gwy_debug("[%u] Typespec #%lu is %lu", dm3_entry_depth(parent), (gulong)i, (gulong)type->types[i]);
     }
-    gwy_debug("[%u] Leaving a typespec of %lu items",
-              dm3_entry_depth(parent), (gulong)type->ntypes);
+    gwy_debug("[%u] Leaving a typespec of %lu items", dm3_entry_depth(parent), (gulong)type->ntypes);
 
     consumed_ntypes = type->ntypes;
-    if ((type->typesize = dm3_type_size(parent, type->types, &consumed_ntypes,
-                                        0, error)) == G_MAXUINT)
+    if ((type->typesize = dm3_type_size(parent, type->types, &consumed_ntypes, 0, error)) == G_MAXUINT)
         goto fail;
     if (consumed_ntypes != 0) {
         err_INVALID_TAG(parent, error);
         goto fail;
     }
 
-    gwy_debug("[%u] Type size: %lu",
-              dm3_entry_depth(parent), (gulong)type->typesize);
+    gwy_debug("[%u] Type size: %lu", dm3_entry_depth(parent), (gulong)type->typesize);
     if (*size < type->typesize) {
         err_TRUNCATED(parent, error);
         goto fail;
@@ -1418,8 +1375,7 @@ dm4_read_type(DM3TagEntry *parent,
     type = g_new0(DM3TagType, 1);
     type->ntypes = gwy_get_guint64_be(p);
     *size -= TAG_TYPE_MIN_SIZE4;
-    gwy_debug("[%u] Entering a typespec of %lu items",
-              dm3_entry_depth(parent), (gulong)type->ntypes);
+    gwy_debug("[%u] Entering a typespec of %lu items", dm3_entry_depth(parent), (gulong)type->ntypes);
 
     if (*size < sizeof(guint64)*type->ntypes) {
         g_free(type);
@@ -1430,24 +1386,20 @@ dm4_read_type(DM3TagEntry *parent,
     for (i = 0; i < type->ntypes; i++) {
         type->types[i] = gwy_get_guint64_be(p);
         *size -= sizeof(guint64);
-        gwy_debug("[%u] Typespec #%lu is %lu",
-                  dm3_entry_depth(parent), (gulong)i, (gulong)type->types[i]);
+        gwy_debug("[%u] Typespec #%lu is %lu", dm3_entry_depth(parent), (gulong)i, (gulong)type->types[i]);
     }
-    gwy_debug("[%u] Leaving a typespec of %lu items",
-              dm3_entry_depth(parent), (gulong)type->ntypes);
+    gwy_debug("[%u] Leaving a typespec of %lu items", dm3_entry_depth(parent), (gulong)type->ntypes);
 
     consumed_ntypes = type->ntypes;
     /* TODO: Can do this generically in DM4 as a fallback. */
-    if ((type->typesize = dm3_type_size(parent, type->types, &consumed_ntypes,
-                                        0, error)) == G_MAXUINT)
+    if ((type->typesize = dm3_type_size(parent, type->types, &consumed_ntypes, 0, error)) == G_MAXUINT)
         goto fail;
     if (consumed_ntypes != 0) {
         err_INVALID_TAG(parent, error);
         goto fail;
     }
 
-    gwy_debug("[%u] Type size: %lu",
-              dm3_entry_depth(parent), (gulong)type->typesize);
+    gwy_debug("[%u] Type size: %lu", dm3_entry_depth(parent), (gulong)type->typesize);
     if (*size < type->typesize) {
         err_TRUNCATED(parent, error);
         goto fail;
@@ -1469,9 +1421,7 @@ dm3_type_size(DM3TagEntry *parent,
               guint level,
               GError **error)
 {
-    static const guint atomic_type_sizes[] = {
-        0, 0, 2, 4, 2, 4, 4, 8, 1, 1, 1, 8, 8,
-    };
+    static const guint atomic_type_sizes[] = { 0, 0, 2, 4, 2, 4, 4, 8, 1, 1, 1, 8, 8, };
     guint primary_type;
 
     if (!*n)
@@ -1495,8 +1445,7 @@ dm3_type_size(DM3TagEntry *parent,
             return err_INVALID_TAG(parent, error);
         *n -= 2;
         /* The second item is the length, presumably in characters (2byte) */
-        gwy_debug("<%u> string length %lu",
-                  level, (gulong)types[1]);
+        gwy_debug("<%u> string length %lu", level, (gulong)types[1]);
         return 2*types[1];
     }
 
@@ -1509,17 +1458,14 @@ dm3_type_size(DM3TagEntry *parent,
         *n -= 1;
         types += 1;
         oldn = *n;
-        gwy_debug("<%u> recusring to figure out item type",
-                  level);
-        if ((item_size = dm3_type_size(parent, types, n,
-                                       level+1, error)) == G_MAXUINT)
+        gwy_debug("<%u> recusring to figure out item type", level);
+        if ((item_size = dm3_type_size(parent, types, n, level+1, error)) == G_MAXUINT)
             return G_MAXUINT;
         gwy_debug("<%u> item type found", level);
         types += oldn - *n;
         if (*n < 1)
             return err_INVALID_TAG(parent, error);
-        gwy_debug("<%u> array length %lu",
-                  level, (gulong)types[0]);
+        gwy_debug("<%u> array length %lu", level, (gulong)types[0]);
         *n -= 1;
         return types[0]*item_size;
     }
@@ -1535,8 +1481,7 @@ dm3_type_size(DM3TagEntry *parent,
         nfields = types[2];
         types += 3;
         *n -= 3;
-        gwy_debug("<%u> namelength: %u, nfields: %u",
-                  level, namelength, nfields);
+        gwy_debug("<%u> namelength: %u, nfields: %u", level, namelength, nfields);
         structsize = namelength;
 
         for (i = 0; i < nfields; i++) {
@@ -1550,10 +1495,8 @@ dm3_type_size(DM3TagEntry *parent,
             *n -= 1;
             oldn = *n;
             structsize += fieldnamelength;
-            gwy_debug("<%u> recusring to figure out field type",
-                      level);
-            if ((field_size = dm3_type_size(parent, types, n,
-                                            level+1, error)) == G_MAXUINT)
+            gwy_debug("<%u> recusring to figure out field type", level);
+            if ((field_size = dm3_type_size(parent, types, n, level+1, error)) == G_MAXUINT)
                 return G_MAXUINT;
             gwy_debug("<%u> field type found", level);
             types += oldn - *n;
@@ -1592,4 +1535,4 @@ dm3_free_group(DM3TagGroup *group)
     g_free(group);
 }
 
-/* vim: set cin et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
+/* vim: set cin columns=120 tw=118 et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
