@@ -18,6 +18,7 @@ GwyModuleInfo* _gwy_module_query__aistfile(void);
 GwyModuleInfo* _gwy_module_query__alicona(void);
 GwyModuleInfo* _gwy_module_query__ambfile(void);
 GwyModuleInfo* _gwy_module_query__ambprofile(void);
+GwyModuleInfo* _gwy_module_query__wrustfile(void);
 GwyModuleInfo* _gwy_module_query__anfatec(void);
 GwyModuleInfo* _gwy_module_query__apefile(void);
 GwyModuleInfo* _gwy_module_query__asciiexport(void);
@@ -55,7 +56,6 @@ GwyModuleInfo* _gwy_module_query__iso28600(void);
 GwyModuleInfo* _gwy_module_query__jeol(void);
 GwyModuleInfo* _gwy_module_query__jeoltem(void);
 GwyModuleInfo* _gwy_module_query__jspmfile(void);
-GwyModuleInfo* _gwy_module_query__keyence(void);
 GwyModuleInfo* _gwy_module_query__leica(void);
 GwyModuleInfo* _gwy_module_query__lextfile(void);
 GwyModuleInfo* _gwy_module_query__magellan(void);
@@ -137,6 +137,7 @@ static const GwyModuleRecord modules[] = {
   { _gwy_module_query__alicona, "alicona", },
   { _gwy_module_query__ambfile, "ambfile", },
   { _gwy_module_query__ambprofile, "ambprofile", },
+  { _gwy_module_query__wrustfile, "wrustfile", },
   { _gwy_module_query__anfatec, "anfatec", },
   { _gwy_module_query__apefile, "apefile", },
   { _gwy_module_query__asciiexport, "asciiexport", },
@@ -174,7 +175,6 @@ static const GwyModuleRecord modules[] = {
   { _gwy_module_query__jeol, "jeol", },
   { _gwy_module_query__jeoltem, "jeoltem", },
   { _gwy_module_query__jspmfile, "jspmfile", },
-  { _gwy_module_query__keyence, "keyence", },
   { _gwy_module_query__leica, "leica", },
   { _gwy_module_query__lextfile, "lextfile", },
   { _gwy_module_query__magellan, "magellan", },
