@@ -1,5 +1,5 @@
 /*
- *  $Id: formats3d.c 22829 2020-05-19 08:53:44Z yeti-dn $
+ *  $Id: formats3d.c 22935 2020-09-03 11:02:13Z yeti-dn $
  *  Copyright (C) 2009-2020 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -339,7 +339,7 @@ static GwyModuleInfo module_info = {
     N_("Exports images as miscellaneous 3D data formats "
        "and imports XYZ points from 3D formats."),
     "Yeti <yeti@gwyddion.net>",
-    "1.0",
+    "1.1",
     "David Nečas (Yeti)",
     "2020",
 };
@@ -359,6 +359,7 @@ module_register(void)
                                NULL,
                                fmt->export_ ? formats3d_export : NULL);
     }
+    gwy_file_func_set_is_detectable("rawxyz", FALSE);
 
     return TRUE;
 }
@@ -546,7 +547,7 @@ detect3d_stl(const GwyFileDetectInfo *fileinfo,
     gdouble block[12];
 
     if (only_name)
-        g_str_has_suffix(fileinfo->name_lowercase, ".stl") ? 30 : 0;
+        return g_str_has_suffix(fileinfo->name_lowercase, ".stl") ? 30 : 0;
 
     /* 80 bytes + 50 bytes * n-of-triangles */
     if (fileinfo->file_size < 134
