@@ -1,6 +1,6 @@
 /*
- *  $Id: gsffile.c 20676 2017-12-18 18:19:09Z yeti-dn $
- *  Copyright (C) 2009 David Necas (Yeti).
+ *  $Id: gsffile.c 22877 2020-07-10 15:31:35Z yeti-dn $
+ *  Copyright (C) 2009-2020 David Necas (Yeti).
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -90,7 +90,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Reads and exports Gwyddion Simple Field files."),
     "Yeti <yeti@gwyddion.net>",
-    "1.2",
+    "1.3",
     "David Nečas (Yeti)",
     "2010",
 };
@@ -130,7 +130,7 @@ gsf_load(const gchar *filename,
          GError **error)
 {
     GwyContainer *container = NULL, *meta = NULL;
-    GwyDataField *dfield = NULL;
+    GwyDataField *dfield = NULL, *mask;
     GwyTextHeaderParser parser;
     GwySIUnit *unit;
     guchar *p, *value, *buffer = NULL, *header = NULL;
@@ -138,6 +138,7 @@ gsf_load(const gchar *filename,
     GHashTable *hash = NULL;
     gsize size, expected_size;
     GError *err = NULL;
+    GQuark quark;
     gdouble xreal, yreal, xoff, yoff;
     guint i, xres, yres;
     gdouble *d;
@@ -201,21 +202,29 @@ gsf_load(const gchar *filename,
         *(d++) = gwy_get_gfloat_le(&datap);
 
     container = gwy_container_new();
-    gwy_container_set_object(container, gwy_app_get_data_key_for_id(0), dfield);
+    quark = gwy_app_get_data_key_for_id(0);
+    gwy_container_set_object(container, quark, dfield);
+    if ((mask = gwy_app_channel_mask_of_nans(dfield, TRUE))) {
+        quark = gwy_app_get_mask_key_for_id(0);
+        gwy_container_set_object(container, quark, mask);
+        g_object_unref(mask);
+    }
     g_object_unref(dfield);
 
-    if ((value = g_hash_table_lookup(hash, "Title"))) {
-        /* FIXME: Ensure valid UTF-8 */
-        gwy_container_set_string_by_name(container, "/0/data/title",
-                                         g_strdup(value));
+    if ((value = g_hash_table_lookup(hash, "Title"))
+        && g_utf8_validate(value, -1, NULL)) {
+        quark = gwy_app_get_data_title_key_for_id(0);
+        gwy_container_set_const_string(container, quark, value);
     }
     else
         gwy_app_channel_title_fall_back(container, 0);
 
     meta = gwy_container_new();
     g_hash_table_foreach(hash, add_meta, meta);
-    if (gwy_container_get_n_items(meta))
-        gwy_container_set_object_by_name(container, "/0/meta", meta);
+    if (gwy_container_get_n_items(meta)) {
+        quark = gwy_app_get_data_meta_key_for_id(0);
+        gwy_container_set_object(container, quark, meta);
+    }
     g_object_unref(meta);
 
     gwy_file_channel_import_log_add(container, 0, NULL, filename);
