@@ -1,6 +1,6 @@
 /*
- *  $Id: gwyzip.h 22685 2019-11-21 12:41:41Z yeti-dn $
- *  Copyright (C) 2015-2019 David Necas (Yeti).
+ *  $Id: gwyzip.h 24034 2021-08-20 14:56:24Z yeti-dn $
+ *  Copyright (C) 2015-2021 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -60,6 +60,7 @@ static guchar*    gwyzip_get_file_content    (GwyZipFile zipfile,
  ****************************************************************************/
 #ifdef HAVE_MINIZIP1
 #define HAVE_GWYZIP 1
+#include <errno.h>
 #include <unzip.h>
 
 struct _GwyZipFile {
@@ -345,16 +346,25 @@ gwyzip_get_file_content(GwyZipFile zipfile, gsize *contentsize,
 
 /****************************************************************************
  *
- * Minizip 2.x wrapper
+ * Minizip 2.x (3.x, etc.) wrapper
  *
  ****************************************************************************/
 #ifdef HAVE_MINIZIP2
 #define HAVE_GWYZIP 1
 /* This either includes stdint.h or replicates its typedefs. */
+#if defined(HAVE_MINIZIP_MZ_H)
+#include <minizip/mz.h>
+#include <minizip/mz_zip.h>
+#include <minizip/mz_strm.h>
+#include <minizip/mz_strm_mem.h>
+#elif defined(HAVE_MZ_H)
 #include <mz.h>
 #include <mz_zip.h>
 #include <mz_strm.h>
 #include <mz_strm_mem.h>
+#endif
+/* If we have neither things break, but then I looked everywhere and I still
+ * have no fucking idea where minizip put its headers this time. */
 
 struct _GwyZipFile {
     GMappedFile *mfile;
