@@ -1,5 +1,5 @@
 /*
- *  $Id: leica.c 22562 2019-10-10 14:45:41Z yeti-dn $
+ *  $Id: leica.c 24205 2021-09-28 08:57:51Z yeti-dn $
  *  Copyright (C) 2014 Daniil Bratashov (dn2010), David Necas (Yeti)..
  *
  *  E-mail: dn2010@gmail.com.
@@ -175,7 +175,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Imports Leica CLSM image files (LIF)."),
     "Daniil Bratashov <dn2010@gmail.com>",
-    "0.4",
+    "0.5",
     "Daniil Bratashov (dn2010), David Necas (Yeti)",
     "2016",
 };
@@ -282,10 +282,9 @@ lif_load(const gchar *filename,
 
     remaining -= 13;
 
-    header->xmlheader = g_convert((const gchar*)p, 2 * header->xmllen,
-                                  "UTF-8", "UTF-16", NULL, NULL, NULL);
+    header->xmlheader = gwy_utf16_to_utf8((const gunichar2*)p, header->xmllen,
+                                          GWY_BYTE_ORDER_LITTLE_ENDIAN);
     p += header->xmllen * 2;
-
     remaining -= header->xmllen * 2;
 
     // Uncomment to see large XML header
@@ -294,8 +293,7 @@ lif_load(const gchar *filename,
     /* Parse XML header */
     xmldata = g_new0(XMLParserData, 1);
     xmldata->file = g_new0(LIFFile, 1);
-    xmldata->file->elements = g_array_new(FALSE, TRUE,
-                                          sizeof(LIFElement));
+    xmldata->file->elements = g_array_new(FALSE, TRUE, sizeof(LIFElement));
     xmldata->elements = g_ptr_array_new();
 
     context = g_markup_parse_context_new(&parser,
@@ -789,8 +787,8 @@ lif_read_memblock(const guchar *buffer, gsize *size, gint version)
     gwy_debug("skipped %d bytes", i);
     memblock->desclen = gwy_get_guint32_le(&p);
     gwy_debug("description length = %d", memblock->desclen);
-    memblock->memid = g_convert((const gchar*)p, 2 * memblock->desclen,
-                                "UTF-8", "UTF-16", NULL, NULL, NULL);
+    memblock->memid = gwy_utf16_to_utf8((const gunichar2*)p, memblock->desclen,
+                                        GWY_BYTE_ORDER_LITTLE_ENDIAN);
     gwy_debug("description = %s", memblock->memid);
     p += memblock->desclen * 2;
     memblock->data = (gpointer)p;
@@ -979,7 +977,7 @@ header_start_element(G_GNUC_UNUSED GMarkupParseContext *context,
         }
 
         element = (LIFElement *)g_ptr_array_index(data->elements,
-                                               data->elements->len - 1);
+                                                  data->elements->len - 1);
 
         if (!(element->metadata)) {
             element->metadata = gwy_container_new();
@@ -999,7 +997,6 @@ header_start_element(G_GNUC_UNUSED GMarkupParseContext *context,
     }
 
 fail_xml:
-    user_data = (gpointer)data;
     return;
 }
 
@@ -1017,7 +1014,7 @@ header_end_element(G_GNUC_UNUSED GMarkupParseContext *context,
     // gwy_debug("End name = %s", element_name);
     if (gwy_strequal(element_name, "Element")) {
         element = (LIFElement *)g_ptr_array_index(data->elements,
-                                               data->elements->len - 1);
+                                                  data->elements->len - 1);
         if (!(element->memid)) {
             gwy_debug("Wrong XML: Element has no MemID");
             err_FILE_TYPE(error, "Leica LIF");
@@ -1028,7 +1025,6 @@ header_end_element(G_GNUC_UNUSED GMarkupParseContext *context,
                                      data->elements->len - 1);
         }
     }
-    user_data = (gpointer)data;
 }
 
 static void
