@@ -1,6 +1,6 @@
 /*
- *  $Id: nanonis.c 21601 2018-11-07 08:52:33Z yeti-dn $
- *  Copyright (C) 2006,2015-2018 David Necas (Yeti), Petr Klapetek.
+ *  $Id: nanonis.c 21958 2019-04-03 15:00:27Z yeti-dn $
+ *  Copyright (C) 2006,2015-2019 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -125,7 +125,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Imports Nanonis SXM data files."),
     "Yeti <yeti@gwyddion.net>",
-    "1.2",
+    "1.3",
     "David Nečas (Yeti) & Petr Klapetek",
     "2006",
 };
@@ -409,7 +409,7 @@ read_data_field(GwyContainer *container,
     GwyContainer *meta;
     GwyDataField *dfield, *mfield = NULL;
     gdouble *data, *mdata;
-    gint j;
+    gint j, n;
     gchar *s;
     gboolean flip_vertically = FALSE, flip_horizontally = FALSE;
 
@@ -421,25 +421,26 @@ read_data_field(GwyContainer *container,
     gwy_data_field_set_yoffset(dfield, sxmfile->yoff - 0.5*sxmfile->yreal);
     data = gwy_data_field_get_data(dfield);
 
-    for (j = 0; j < sxmfile->xres*sxmfile->yres; j++) {
+    n = sxmfile->xres*sxmfile->yres;
+    for (j = 0; j < n; j++) {
         /* This is not a perfect NaN check, but Nanonis uses ff as the payload
          * so look only for these. */
         if (G_UNLIKELY(((*p)[0] & 0x7f) == 0x7f && (*p)[1] == 0xff))
             break;
 
-        *(data++) = gwy_get_gfloat_be(p);
+        data[j] = gwy_get_gfloat_be(p);
     }
 
-    if (j < sxmfile->xres*sxmfile->yres) {
+    if (j < n) {
         mfield = gwy_data_field_new_alike(dfield, TRUE);
         mdata = gwy_data_field_get_data(mfield);
-        while (j < sxmfile->xres*sxmfile->yres) {
+        while (j < n) {
             if (((*p)[0] & 0x7f) == 0x7f && (*p)[1] == 0xff) {
                 mdata[j] = -1.0;
                 *p += sizeof(gfloat);
             }
             else
-                *(data++) = gwy_get_gfloat_be(p);
+                data[j] = gwy_get_gfloat_be(p);
             j++;
         }
         gwy_data_field_add(mfield, 1.0);
