@@ -1,5 +1,5 @@
 /*
- *  $Id: nanoscan.c 20676 2017-12-18 18:19:09Z yeti-dn $
+ *  $Id: nanoscan.c 23651 2021-05-10 10:05:19Z yeti-dn $
  *  Copyright (C) 2009 David Necas (Yeti).
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -190,7 +190,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Imports NanoScan XML files."),
     "Yeti <yeti@gwyddion.net>",
-    "0.7",
+    "0.8",
     "David Nečas (Yeti)",
     "2009",
 };
@@ -586,9 +586,9 @@ add_multicurve_model(NanoScanFile *nfile,
     if (start >= channel->ndata)
         return;
 
-    npts = MAX(channel->ndata - start, nfile->xres);
+    npts = MIN(channel->ndata - start, nfile->xres);
     real = (axis0->stop - axis0->start)*npts/nfile->xres;
-    dline = gwy_data_line_new(nfile->xres, real, TRUE);
+    dline = gwy_data_line_new(npts, real, TRUE);
     gwy_data_line_set_offset(dline, axis0->start);
     if (axis0->units) {
         unit = gwy_data_line_get_si_unit_x(dline);
