@@ -1,5 +1,5 @@
 /*
- *  $Id: netcdf.c 22626 2019-10-30 09:14:30Z yeti-dn $
+ *  $Id: netcdf.c 23265 2021-03-15 14:50:56Z yeti-dn $
  *  Copyright (C) 2006 David Necas (Yeti), Petr Klapetek, Niv Levy.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net, nivl2000@gmail.com.
  *
@@ -177,7 +177,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Imports network Common Data Form (netCDF) files created by GXSM."),
     "Yeti <yeti@gwyddion.net>",
-    "0.8",
+    "0.9",
     "David Nečas (Yeti), Petr Klapetek & Niv Levy",
     "2006",
 };
@@ -238,87 +238,6 @@ err_CDF_INTEGRITY(GError **error, const gchar *field_name)
                 field_name);
 }
 
-/**
- * gwy_brick_invert:
- * @brick: A brick.
- * @x: %TRUE to reflect about YZ plane.
- * @y: %TRUE to reflect about XZ plane.
- * @z: %TRUE to reflect about XY plane.
- * Reflects a brick around one of the three axes.
- * Note : xz and yz inversions are not implemented.
- * Note : this is not exactly analogous to the datafield funciton,
- * since brick inversion exists in a separate function (volume_invert)
- * Should move eventually to a public location, but for now only used here
- * and mostly untested.
- **/
-static void
-gwy_brick_invert(GwyBrick *brick,
-                      gboolean x,
-                      gboolean y,
-                      gboolean z)
-{
-    gint i, j, k, n, n_layer;
-    gdouble *data, *flip;
-
-    g_return_if_fail(GWY_IS_BRICK(brick));
-    n = brick->xres * brick->yres * brick->zres;
-    n_layer = brick->xres * brick->yres;
-
-    // not implementing xz or yz flips given that we're not doing true 3D data
-    // x&y&z is odd as well, but easy
-    if (x && y && z) {
-        data = brick->data;
-        flip = data + n-1;
-        for (i = 0; i < n/2; i++, data++, flip--)
-            GWY_SWAP(gdouble, *data, *flip);
-    }
-    else if (x && y) {
-        for (k = 0; k < brick->zres; k++) {
-            data = brick->data + k * n_layer;
-            flip = data + n_layer -1;
-            for (i = 0; i < n_layer/2; i++, data++, flip--)
-                GWY_SWAP(gdouble, *data, *flip);
-        }
-    }
-    else if ((x && z) || (y && z)) {
-      return;
-    }
-    else if (z) { // TEST
-        for (i = 0; i < brick->xres; i++) {
-            for (j = 0; j < brick->yres; j++) {
-                data = brick->data + i + j * brick->xres;
-                flip = data + (brick->zres -1) * n_layer;
-                for (k = 0; k < brick->zres/2; k++, data+=n_layer, flip-=n_layer)
-                    GWY_SWAP(gdouble, *data, *flip);
-            }
-        }
-    }
-    else if (y) {
-        for (k = 0; k < brick->zres; k++) {
-            for (i = 0; i < brick->yres; i++) {
-                data = brick->data + i * brick->xres + k * n_layer;
-                flip = data + brick->xres-1;
-                for (j = 0; j < brick->xres/2; j++, data++, flip--)
-                    GWY_SWAP(gdouble, *data, *flip);
-            }
-        }
-    }
-    else if (x) {
-        for (k = 0; k < brick->zres; k++) {
-            for (j = 0; j < brick->yres/2; i++) {
-                data = brick->data + j*brick->xres + k * n_layer;
-                flip = brick->data + (brick->yres - 1 - j) * brick->xres + k * n_layer;
-                for (i = 0; i < brick->xres; i++, data++, flip++)
-                    GWY_SWAP(gdouble, *data, *flip);
-            }
-        }
-    }
-
-    else
-        return;
-}
-
-
 /*TODO:
  * deal with fast scan (just issue a warning statement for now)
  * deal with rotated scans
@@ -495,7 +414,7 @@ gxsm_load(const gchar *filename,
              */
             if ((real = (values[1] - values[0]) * dim_value) < 0 ) {
                 g_warning("Flipping brick since values have negative step");
-                gwy_brick_invert(dbrick, FALSE, FALSE, TRUE);
+                gwy_brick_invert(dbrick, FALSE, FALSE, TRUE, FALSE);
                 real = -real;
                 offset = values[dim_value-1];
                 gwy_container_set_string_by_name(meta, "Z flipped",
@@ -630,7 +549,7 @@ gxsm_load(const gchar *filename,
                 gwy_debug("gxsm netcdf: flip data field since basename contains "
                             "'-Xm-' and not '-Xp-'");
                 g_warning("netcdf brick: inverting across y");
-                gwy_brick_invert(dbrick, FALSE, TRUE, FALSE);
+                gwy_brick_invert(dbrick, FALSE, TRUE, FALSE, FALSE);
                 gwy_container_set_string_by_name(meta, "Fast scan",
                                                 g_strdup("right to left"));
             }
