@@ -1,6 +1,6 @@
 /*
- *  $Id: nrrdfile.c 21430 2018-09-11 11:46:00Z yeti-dn $
- *  Copyright (C) 2011 David Necas (Yeti).
+ *  $Id: nrrdfile.c 22562 2019-10-10 14:45:41Z yeti-dn $
+ *  Copyright (C) 2011-2019 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -179,7 +179,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Imports and exports nearly raw raster data (NRRD) files."),
     "Yeti <yeti@gwyddion.net>",
-    "0.7",
+    "0.8",
     "David Nečas (Yeti)",
     "2011",
 };
@@ -485,11 +485,7 @@ nrrdfile_load(const gchar *filename,
                                          fields, data_start);
         quark = gwy_app_get_brick_key_for_id(0);
         gwy_container_set_object(container, quark, brick);
-        dfield = gwy_data_field_new(1, 1, 1.0, 1.0, FALSE);
-        gwy_brick_mean_xy_plane(brick, dfield);
-        gwy_container_set_object_by_name(container, "/brick/0/preview", dfield);
         g_object_unref(brick);
-        g_object_unref(dfield);
 
         if ((value = g_hash_table_lookup(fields, "content"))) {
             gwy_container_set_const_string_by_name(container, "/brick/0/title",
