@@ -1,6 +1,6 @@
 /*
- *  $Id: oirfile.c 22655 2019-11-07 15:15:01Z yeti-dn $
- *  Copyright (C) 2019 David Necas (Yeti).
+ *  $Id: oirfile.c 22968 2020-11-26 13:53:48Z yeti-dn $
+ *  Copyright (C) 2019-2020 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -86,9 +86,10 @@ enum {
 };
 
 typedef enum {
-    OIR_CHUNK_XML = 1,
-    OIR_CHUNK_BMP = 2,
-    OIR_CHUNK_WTF = 3,
+    OIR_CHUNK_XML        = 1,
+    OIR_CHUNK_BMP        = 2,
+    OIR_CHUNK_WTF        = 3,
+    OIR_CHUNK_TERMINATOR = 96,
 } OIRChunkType;
 
 typedef struct {
@@ -240,7 +241,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Imports Olympus OIR data files."),
     "Yeti <yeti@gwyddion.net>",
-    "0.4",
+    "0.5",
     "David Nečas (Yeti)",
     "2019",
 };
@@ -418,6 +419,7 @@ oirfile_load_from_memory(GwyContainer *container,
     const guchar *p, *end;
     guint32 chunksize;
     OIRChunkType chunktype;
+    gboolean seen_wtf = FALSE, seen_images = FALSE;
     guint i;
 
 #ifdef DEBUG
@@ -432,54 +434,79 @@ oirfile_load_from_memory(GwyContainer *container,
         goto fail;
     gwy_debug("pos after header: %d", (gint)(p - buffer));
 
-    if (!chunk_size_and_type(p, end, &chunksize, &chunktype, error))
-        goto fail;
+    while (p < end &&
+           chunk_size_and_type(p, end, &chunksize, &chunktype, error)) {
+        if (chunktype == OIR_CHUNK_BMP) {
+            gwy_debug("skipping thumbnail chunk starting at %d",
+                      (gint)(p - buffer));
+            if (!skip_thumbnail(&p, end, error))
+                goto fail;
+        }
+        else if (chunktype == OIR_CHUNK_WTF) {
+            if (seen_wtf) {
+                g_set_error(error, GWY_MODULE_FILE_ERROR,
+                            GWY_MODULE_FILE_ERROR_DATA,
+                            _("Chunk type %u occured multiple times."),
+                            chunktype);
+                goto fail;
+            }
+            gwy_debug("reading triplet of strange images starting at %d",
+                      (gint)(p - buffer));
+            if (!read_image_data_block(&p, end, &oirfile.wtf1, "wtf1", error)
+                || !read_image_data_block(&p, end, &oirfile.wtf2, "wtf2", error)
+                || !read_image_data_block(&p, end, &oirfile.wtf3, "wtf3", error))
+                goto fail;
+            seen_wtf = TRUE;
+        }
+        else if (chunktype == OIR_CHUNK_XML) {
+            if (seen_images) {
+                g_set_error(error, GWY_MODULE_FILE_ERROR,
+                            GWY_MODULE_FILE_ERROR_DATA,
+                            _("Chunk type %u occured multiple times."),
+                            chunktype);
+                goto fail;
+            }
+            /* Before we get to image data, there is a short binary block with
+             * a bit of XML inside.  This one is important as it defines image
+             * type, dimensions, depth, etc. */
+            gwy_debug("reading first part of metadata starting at %d",
+                      (gint)(p - buffer));
+            if (!read_image_meta_data(&p, end, &oirfile.imgmeta, error))
+                goto fail;
 
-    /* Optional thumbnail. */
-    if (chunktype == OIR_CHUNK_BMP) {
-        if (!skip_thumbnail(&p, end, error))
-            goto fail;
-        gwy_debug("pos after thumbnail: %d", (gint)(p - buffer));
-        if (!chunk_size_and_type(p, end, &chunksize, &chunktype, error))
-            goto fail;
+            gwy_debug("reading images starting at %d (finally!)",
+                      (gint)(p - buffer));
+            if (!read_image_data_block(&p, end, &oirfile.red, "red", error)
+                || !read_image_data_block(&p, end, &oirfile.green, "green", error)
+                || !read_image_data_block(&p, end, &oirfile.blue, "blue", error))
+                goto fail;
+
+            gwy_debug("reading second part of metadata starting at %d",
+                      (gint)(p - buffer));
+            if (!read_more_meta_data(&p, end, &oirfile.moremeta, error))
+                goto fail;
+            seen_images = TRUE;
+        }
+        else if (chunktype == OIR_CHUNK_TERMINATOR) {
+            /* The last 140 bytes is some kind of nonsense apparently.  But
+             * it is nonsense we expect to see.  */
+            gwy_debug("found known terminator chunk or whatever it is");
+            gwy_debug("first 4 bytes are %02x %02x %02x %02x (expecting ffs)",
+                      p[0], p[1], p[2], p[3]);
+            break;
+        }
+        else {
+            gwy_debug("unknown chunk, aborting");
+            break;
+        }
+        gwy_debug("remaining data: %d", (gint)(end - p));
     }
 
-    /* Optional strange images. */
-    if (chunktype == OIR_CHUNK_WTF) {
-        if (!read_image_data_block(&p, end, &oirfile.wtf1, "wtf1", error)
-            || !read_image_data_block(&p, end, &oirfile.wtf2, "wtf2", error)
-            || !read_image_data_block(&p, end, &oirfile.wtf3, "wtf3", error))
-            goto fail;
-        gwy_debug("pos after strange images: %d", (gint)(p - buffer));
-        if (!chunk_size_and_type(p, end, &chunksize, &chunktype, error))
-            goto fail;
-    }
-
-    /* The main XML must be there.  I think.  */
-    if (chunktype != OIR_CHUNK_XML) {
-        g_set_error(error, GWY_MODULE_FILE_ERROR, GWY_MODULE_FILE_ERROR_DATA,
-                    _("Chunk type %u found instead of expected %u."),
-                    chunktype, OIR_CHUNK_XML);
+    if (!seen_images) {
+        err_NO_DATA(error);
         goto fail;
     }
 
-    /* Before we get to image data, there is a short binary block with a bit of
-     * XML inside.  This one is important as it defines image type, dimensions,
-     * depth, etc. */
-    if (!read_image_meta_data(&p, end, &oirfile.imgmeta, error))
-        goto fail;
-    gwy_debug("pos where we finally got to data: %d", (gint)(p - buffer));
-
-    if (!read_image_data_block(&p, end, &oirfile.red, "red", error)
-        || !read_image_data_block(&p, end, &oirfile.green, "green", error)
-        || !read_image_data_block(&p, end, &oirfile.blue, "blue", error))
-        goto fail;
-    gwy_debug("pos after nice images: %d", (gint)(p - buffer));
-
-    if (!read_more_meta_data(&p, end, &oirfile.moremeta, error))
-        goto fail;
-    gwy_debug("pos after more meta: %d", (gint)(p - buffer));
-
     parse_xml_to_hash(&oirfile.imgmeta.xml, &oirfile.xmldata);
     for (i = 0; i < oirfile.moremeta.nfragments; i++) {
         OIRXMLFragment *xml = oirfile.moremeta.fragments + i;
@@ -851,7 +878,7 @@ read_more_meta_data(const guchar **p, const guchar *end,
         append_xml_fragment(fragments, xml, q+1);
         identify_xml_fragment(&g_array_index(fragments,
                                              OIRXMLFragment, fragments->len-1));
-        *p = q;
+        *p = q + 1;
     }
 
     gwy_debug("remaining data: %u", (guint)(end - *p));
