@@ -1,5 +1,5 @@
 /*
- *  $Id: psppt.c 23843 2021-06-11 14:48:28Z yeti-dn $
+ *  $Id: psppt.c 24372 2021-10-14 13:03:37Z yeti-dn $
  *  Copyright (C) 2021 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -32,6 +32,7 @@
 #include <libgwymodule/gwymodule-file.h>
 #include <app/data-browser.h>
 #include <app/gwymoduleutils-file.h>
+#include <app/wait.h>
 #include <jansson.h>
 
 #include "get.h"
@@ -75,7 +76,7 @@ typedef struct {
     json_t *root;
     gint xres;
     gint yres;
-    gboolean forward;
+    gchar *direction;
     gdouble xreal;
     gdouble yreal;
 } PSPPTScanStart;
@@ -95,12 +96,14 @@ typedef struct {
     PSPPTParam param;
     guint nframes;           /* Real number; can be smaller than header.frames. */
     PSPPTFrame *frames;
-    guint nchannels;
     gchar **ids;
     gchar **units;
-    GString *xstr;
-    GString *ystr;
-    GwySpectra **spectra;
+    gdouble *power10;
+    gint *reorder;
+    GString *str;
+    GArray *databuf;
+    GwyLawn *lawn;
+    GwyContainer *meta;
 } PSPPTFile;
 
 static gboolean      module_register       (void);
@@ -120,7 +123,7 @@ static GwyModuleInfo module_info = {
     module_register,
     N_("Imports Park Systems PS-PPT data files."),
     "Yeti <yeti@gwyddion.net>",
-    "0.1",
+    "1.0",
     "David Nečas (Yeti)",
     "2021",
 };
@@ -313,9 +316,10 @@ static json_t*
 psppt_read_frame(PSPPTFrame *frame, const guchar *buf, GError **error)
 {
     json_error_t jerror;
+    const gchar *start = buf + frame->offset;
     json_t *root;
 
-    root = json_loadb(buf + frame->offset, frame->size, 0, &jerror);
+    root = json_loadb(start, frame->size, 0, &jerror);
     if (!root) {
         g_set_error(error, GWY_MODULE_FILE_ERROR, GWY_MODULE_FILE_ERROR_DATA,
                     _("JSON parsing error: %s"), jerror.text);
@@ -352,10 +356,10 @@ handle_scan_start(PSPPTScanStart *scanstart, json_t *root, GError **error)
     scanstart->yres = json_integer_value(pixel_height);
     scanstart->xreal = json_number_value(width) * 1e-6;
     scanstart->yreal = json_number_value(height) * 1e-6;
-    scanstart->forward = gwy_strequal(json_string_value(direction), "forward");
+    scanstart->direction = g_strdup(json_string_value(direction));
     gwy_debug("xres = %u, yres = %u", scanstart->xres, scanstart->yres);
     gwy_debug("xreal = %g, yreal = %g", scanstart->xreal, scanstart->yreal);
-    gwy_debug("direction = %s", json_string_value(direction));
+    gwy_debug("direction = %s", scanstart->direction);
 
     return TRUE;
 }
@@ -395,22 +399,42 @@ handle_param(PSPPTParam *param, json_t *root, GError **error)
     return TRUE;
 }
 
+static gboolean
+try_to_reorder(gchar **names, gint *order, gint n,
+               const gchar *name, gint movewhere)
+{
+    gint i;
+
+    if (movewhere < 0 || movewhere >= n)
+        return FALSE;
+    for (i = 0; i < n; i++) {
+        if (gwy_strequal(names[order[i]], name))
+            break;
+    }
+    if (i == n)
+        return FALSE;
+    if (i == movewhere)
+        return TRUE;
+
+    GWY_SWAP(gint, order[i], order[movewhere]);
+    return TRUE;
+}
+
 static gboolean
 handle_rtfd(PSPPTFile *pfile, json_t *root, GError **error)
 {
     json_t *type, *info, *numbers, *channels, *indices, *fast, *slow, *padding, *item;
-    guint n, i, nnum, col, row, npts, base64len = 0;
+    guint n, i, ri, nnum, col, row, npts, base64len = 0;
     gint power10;
-    gdouble xpos, ypos;
-    GwyDataLine *spec;
-    GString *str = pfile->xstr;
-    gboolean pad;
+    GString *str = pfile->str;
+    GwyLawn *lawn;
+    gboolean G_GNUC_UNUSED pad, lawn_is_new = FALSE;
     gdouble *d;
 
     if (!get_json_with_type(root, &type, "type", JSON_STRING, error)
         || !get_json_with_type(root, &info, "info", JSON_OBJECT, error)
-        || !get_json_with_type(info, &channels, "channels", JSON_ARRAY, error)
         || !get_json_with_type(root, &numbers, "numbers", JSON_ARRAY, error)
+        || !get_json_with_type(info, &channels, "channels", JSON_ARRAY, error)
         || !get_json_with_type(info, &indices, "index", JSON_OBJECT, error)
         || !get_json_with_type(info, &padding, "padding", JSON_TRUE, error)
         || !get_json_with_type(indices, &fast, "fast", JSON_INTEGER, error)
@@ -428,15 +452,24 @@ handle_rtfd(PSPPTFile *pfile, json_t *root, GError **error)
 
     /* The first time we encounter a spectrum set use it as a template.  All other sets must follow the same
      * structure. */
-    if (!n || n != nnum || (pfile->nchannels && n != pfile->nchannels))
+    lawn = pfile->lawn;
+    if (!n || n != nnum || (lawn && n != gwy_lawn_get_n_curves(lawn)))
         return err_INCONSISTENT(error);
 
-    if (!pfile->nchannels) {
-        pfile->nchannels = n;
-        pfile->spectra = g_new0(GwySpectra*, n);
+    if (!pfile->lawn) {
+        const PSPPTScanStart *ss = &pfile->scanstart;
+
+        lawn_is_new = TRUE;
+        gwy_debug("creating lawn xres=%d, yres=%d", ss->xres, ss->yres);
+        lawn = pfile->lawn = gwy_lawn_new(ss->xres, ss->yres, ss->xreal, ss->yreal, n, 0);
+        gwy_si_unit_set_from_string(gwy_lawn_get_si_unit_xy(lawn), "m");
+        /* These duplicates lawn's properties, but can be used with check_string_list_item(). */
         pfile->units = g_new0(gchar*, n+1);
         pfile->ids = g_new0(gchar*, n+1);
+        pfile->power10 = g_new0(gdouble, n);
+        pfile->reorder = g_new(gint, n);
     }
+
     for (i = 0; i < n; i++) {
         item = json_array_get(channels, i);
         if (!json_is_object(item))
@@ -457,32 +490,40 @@ handle_rtfd(PSPPTFile *pfile, json_t *root, GError **error)
             return err_INCONSISTENT(error);
     }
 
+    if (lawn_is_new) {
+        for (i = 0; i < n; i++)
+            pfile->reorder[i] = i;
+        try_to_reorder(pfile->ids, pfile->reorder, n, "Force", 0);
+        try_to_reorder(pfile->ids, pfile->reorder, n, "ZHeight", 0);
+        try_to_reorder(pfile->ids, pfile->reorder, n, "Lfm", n-1);
+        for (i = 0; i < n; i++) {
+            ri = pfile->reorder[i];
+            gwy_lawn_set_curve_label(lawn, ri, pfile->ids[i]);
+            gwy_si_unit_set_from_string_parse(gwy_lawn_get_si_unit_curve(lawn, ri), pfile->units[i], &power10);
+            pfile->power10[i] = pow10(power10);
+        }
+    }
+
+    g_array_set_size(pfile->databuf, 0);
     for (i = 0; i < n; i++) {
+        ri = pfile->reorder[i];
         item = json_array_get(numbers, i);
         g_string_assign(str, json_string_value(item));
         g_base64_decode_inplace(str->str, &str->len);
         npts = str->len/sizeof(gfloat);
-
-        if (!pfile->spectra[i]) {
-            GwySpectra *spectra = pfile->spectra[i] = gwy_spectra_new();
-            gwy_spectra_set_title(spectra, pfile->ids[i]);
-            gwy_spectra_set_spectrum_x_label(spectra, "sample");
-            gwy_spectra_set_spectrum_y_label(spectra, pfile->ids[i]);
-            gwy_si_unit_set_from_string(gwy_spectra_get_si_unit_xy(spectra), "m");
+        if (i) {
+            if (npts != pfile->databuf->len/n)
+                return err_INCONSISTENT(error);
         }
-
-        spec = gwy_data_line_new(npts, npts, FALSE);
-        gwy_si_unit_set_from_string_parse(gwy_data_line_get_si_unit_y(spec), pfile->units[i], &power10);
-
-        d = gwy_data_line_get_data(spec);
+        else
+            g_array_set_size(pfile->databuf, n*npts);
+        d = &g_array_index(pfile->databuf, gdouble, npts*pfile->reorder[i]);
         gwy_convert_raw_data(str->str, npts, 1, GWY_RAW_DATA_FLOAT, GWY_BYTE_ORDER_LITTLE_ENDIAN, d,
-                             pow10(power10), 0.0);
-
-        xpos = pfile->scanstart.xreal/pfile->scanstart.xres * (col + 0.5);
-        ypos = pfile->scanstart.yreal/pfile->scanstart.yres * (row + 0.5);
-        gwy_spectra_add_spectrum(pfile->spectra[i], spec, xpos, ypos);
-        g_object_unref(spec);
+                             pfile->power10[i], 0.0);
     }
+    npts = pfile->databuf->len/n;
+    gwy_debug("items per curve %u (%u items total)", npts, pfile->databuf->len);
+    gwy_lawn_set_curves(lawn, col, row, npts, &g_array_index(pfile->databuf, gdouble, 0), NULL);
 
     return TRUE;
 }
@@ -501,6 +542,43 @@ check_string_list_item(json_t *root, const gchar *name, gchar **values, guint i,
     return TRUE;
 }
 
+static void
+add_one_meta(GwyContainer *meta, json_t *object, GString *path)
+{
+    guint len = path->len;
+    const gchar *key;
+    void *iter;
+    json_t *value;
+
+    if (json_is_object(object)) {
+        g_string_append(path, "::");
+        for (iter = json_object_iter(object); iter; iter = json_object_iter_next(object, iter)) {
+            if ((value = json_object_iter_value(iter))) {
+                key = json_object_iter_key(iter);
+                if (gwy_strequal(key, "type"))
+                    continue;
+                g_string_append(path, key);
+                add_one_meta(meta, value, path);
+                g_string_truncate(path, len+2);
+            }
+        }
+        g_string_truncate(path, len);
+    }
+    else if (json_is_string(object))
+        gwy_container_set_const_string_by_name(meta, path->str, json_string_value(object));
+    else if (json_is_integer(object))
+        gwy_container_set_string_by_name(meta, path->str, g_strdup_printf("%ld", (glong)json_integer_value(object)));
+    else if (json_is_real(object))
+        gwy_container_set_string_by_name(meta, path->str, g_strdup_printf("%g", json_real_value(object)));
+    else if (json_is_true(object))
+        gwy_container_set_const_string_by_name(meta, path->str, "True");
+    else if (json_is_false(object))
+        gwy_container_set_const_string_by_name(meta, path->str, "False");
+    else {
+        g_warning("Unhandled metadata of type %d.", json_typeof(object));
+    }
+}
+
 static GwyContainer*
 psppt_load(const gchar *filename,
            G_GNUC_UNUSED GwyRunType mode,
@@ -512,6 +590,7 @@ psppt_load(const gchar *filename,
     guchar *buffer = NULL;
     GError *err = NULL;
     gsize pos, size = 0;
+    gboolean waiting = FALSE;
     guint i;
 
     if (!gwy_file_get_contents(filename, &buffer, &size, &err)) {
@@ -520,20 +599,33 @@ psppt_load(const gchar *filename,
     }
 
     gwy_clear(&pfile, 1);
-    pfile.xstr = g_string_new(NULL);
-    pfile.ystr = g_string_new(NULL);
+    pfile.str = g_string_new(NULL);
+    pfile.databuf = g_array_new(FALSE, FALSE, sizeof(gdouble));
 
     pos = 0;
     if (!psppt_read_header(&pfile.header, buffer, size, &pos, error))
         goto fail;
 
+    if (mode == GWY_RUN_INTERACTIVE) {
+        gwy_app_wait_start(NULL, _("Reading frame table..."));
+        waiting = TRUE;
+    }
+
     if (!psppt_read_frame_table(&pfile, buffer, size, &pos, error))
         goto fail;
 
+    if (waiting && !gwy_app_wait_set_message(_("Reading curve data..."))) {
+        err_CANCELLED(error);
+        goto fail;
+    }
     for (i = 0; i < pfile.nframes; i++) {
         PSPPTFrame *frame = pfile.frames + i;
         gboolean ok;
 
+        if (waiting && i % 100 == 0 && !gwy_app_wait_set_fraction((i + 0.5)/pfile.nframes)) {
+            err_CANCELLED(error);
+            goto fail;
+        }
         if (!(root = psppt_read_frame(frame, buffer, error)))
             goto fail;
 
@@ -552,11 +644,21 @@ psppt_load(const gchar *filename,
         root = NULL;
     }
 
+    pfile.meta = gwy_container_new();
+    g_string_assign(pfile.str, "Param");
+    add_one_meta(pfile.meta, pfile.param.root, pfile.str);
+    g_string_assign(pfile.str, "Scan");
+    add_one_meta(pfile.meta, pfile.scanstart.root, pfile.str);
+
     container = gwy_container_new();
-    for (i = 0; i < pfile.nchannels; i++)
-        gwy_container_set_object(container, gwy_app_get_spectra_key_for_id(i), pfile.spectra[i]);
+    gwy_container_set_object(container, gwy_app_get_lawn_key_for_id(0), pfile.lawn);
+    gwy_container_set_const_string(container, gwy_app_get_lawn_title_key_for_id(0), pfile.scanstart.direction);
+    gwy_container_set_object(container, gwy_app_get_lawn_meta_key_for_id(0), pfile.meta);
+    gwy_file_curve_map_import_log_add(container, 0, NULL, filename);
 
 fail:
+    if (waiting)
+        gwy_app_wait_finish();
     if (root)
         json_decref(root);
     if (pfile.scanstart.root)
@@ -565,16 +667,16 @@ fail:
         json_decref(pfile.scanstop.root);
     if (pfile.param.root)
         json_decref(pfile.param.root);
+    g_free(pfile.scanstart.direction);
+    g_free(pfile.power10);
+    g_free(pfile.reorder);
     g_strfreev(pfile.ids);
     g_strfreev(pfile.units);
     g_free(pfile.frames);
-    if (pfile.spectra) {
-        for (i = 0; i < pfile.nchannels; i++)
-            GWY_OBJECT_UNREF(pfile.spectra[i]);
-        g_free(pfile.spectra);
-    }
-    g_string_free(pfile.xstr, TRUE);
-    g_string_free(pfile.ystr, TRUE);
+    GWY_OBJECT_UNREF(pfile.lawn);
+    GWY_OBJECT_UNREF(pfile.meta);
+    g_array_free(pfile.databuf, TRUE);
+    g_string_free(pfile.str, TRUE);
     gwy_file_abandon_contents(buffer, size, NULL);
 
     return container;
