@@ -1,5 +1,5 @@
 /*
- *  $Id: pt3file.c 19948 2017-06-22 14:05:41Z yeti-dn $
+ *  $Id: pt3file.c 20788 2018-02-02 09:41:17Z yeti-dn $
  *  Copyright (C) 2009 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -335,6 +335,7 @@ pt3file_detect(const GwyFileDetectInfo *fileinfo,
     return score;
 }
 
+G_GNUC_UNUSED
 static inline const guchar*
 read_t2_record(PicoHarpT2Record *rec,
                const guchar *p)
@@ -484,9 +485,7 @@ pt3file_read_header(const guchar *buffer,
 
         pt3file->number_of_boards = MAX(pt3file->number_of_boards, 1);
         if (size < HEADER_MIN_SIZE + BOARD_SIZE*pt3file->number_of_boards) {
-            g_set_error(error, GWY_MODULE_FILE_ERROR,
-                        GWY_MODULE_FILE_ERROR_DATA,
-                        _("File header is truncated."));
+            err_TRUNCATED_HEADER(error);
             return 0;
         }
     }
@@ -587,8 +586,7 @@ pt3file_read_header(const guchar *buffer,
         return 0;
     }
     if ((p - buffer) + expected_size > size) {
-        g_set_error(error, GWY_MODULE_FILE_ERROR, GWY_MODULE_FILE_ERROR_DATA,
-                    _("File header is truncated."));
+        err_TRUNCATED_HEADER(error);
         return 0;
     }
 
