@@ -1,5 +1,5 @@
 /*
- *  $Id: renishaw.c 22959 2020-10-19 13:25:29Z yeti-dn $
+ *  $Id: renishaw.c 23130 2021-01-31 21:09:44Z dn2010 $
  *  Copyright (C) 2014 Daniil Bratashov (dn2010), David Necas (Yeti)..
  *  Data structures and constants are copyright (c) 2011 Renishaw plc.
  *
@@ -255,6 +255,31 @@ typedef enum {
        length.x contains number of points along line; length.y = 1 */
 } WdfMapAreaType;
 
+/* FIXME: It is only a small subset of known predefined keys */
+typedef enum {
+	WDF_PSET_KEYS_PROPERTIES = 403,
+	WDF_PSET_KEYS_LABEL      = 411,
+	WDF_PSET_KEYS_MAPTYPE    = 412,
+	WDF_PSET_KEYS_DATALIST0  = 420,
+	WDF_PSET_KEYS_DATALIST1  = 421,
+	WDF_PSET_KEYS_DATALIST2  = 422,
+	WDF_PSET_KEYS_OPERATOR   = 430,
+	WDF_PSET_KEYS_TIME       = 431,
+	WDF_PSET_KEYS_VERSION    = 432
+} WdfPsetPredefinedKeys;
+
+static const GwyEnum wdf_predefined_keys[] = {
+	{ "Properties",          WDF_PSET_KEYS_PROPERTIES },
+	{ "Label",               WDF_PSET_KEYS_LABEL      },
+	{ "MapType",             WDF_PSET_KEYS_MAPTYPE    },
+	{ "DataList0",           WDF_PSET_KEYS_DATALIST0  },
+	{ "DataList1",           WDF_PSET_KEYS_DATALIST1  },
+	{ "DataList2",           WDF_PSET_KEYS_DATALIST2  },
+	{ "Operator",            WDF_PSET_KEYS_OPERATOR   },
+	{ "Time",                WDF_PSET_KEYS_TIME       },
+    { "Version",             WDF_PSET_KEYS_VERSION    },
+};
+
 typedef struct {
     guint32 id;
     guint32 uid;
@@ -367,7 +392,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Imports Renishaw WiRE data files (WDF)."),
     "Daniil Bratashov <dn2010@gmail.com>",
-    "0.10",
+    "0.11",
     "Daniil Bratashov (dn2010), David Necas (Yeti), Renishaw plc.",
     "2014",
 };
@@ -423,17 +448,18 @@ wdf_load(const gchar *filename,
     GwyDataLine *cal;
     GwyGraphModel *gmodel;
     GwyGraphCurveModel *gcmodel;
-    GwySIUnit *siunitx, *siunity, *siunitz, *siunitw, *siunitsp;
+    GwySIUnit *siunitx, *siunity, *siunitz, *siunitw, *siunitsp, 
+              *siunitm;
     gdouble *ydata, *xdata, *data, *zdata = NULL, *xdatasp, *ydatasp;
     gint i, j, k, l, lsize, z, m;
     gint xres, yres, zres, xstart, xend, xstep, ystart, yend, ystep;
     gint width, height, rowstride, bpp;
     gint xunits = 0, yunits = 0, zunits = 0;
-    gint power10x, power10y, power10z, power10w;
+    gint power10x, power10y, power10z, power10w, power10m;
     gint magic, pset_size = 0;
     guint norigins, units, G_GNUC_UNUSED type;
     gchar origin_name[16];
-    gdouble xreal, yreal, xscale, yscale, zscale, wscale;
+    gdouble xreal, yreal, xscale, yscale, zscale, wscale, mscale;
     GdkPixbufLoader *loader;
     GdkPixbuf *pixbuf = NULL;
     guchar *pixels, *pix_p;
@@ -759,11 +785,70 @@ wdf_load(const gchar *filename,
         }
 
         g_object_unref(siunitz);
-        g_object_unref(siunitw);
+
         g_free(xdata);
         gwy_container_set_object_by_name(container, "/0/graph/graph/1",
                                          gmodel);
         g_object_unref(gmodel);
+        
+        for (m = 0; m < filedata.nummaps; m++) { /* z maps */
+			zres = filedata.maps[m]->numpoints;
+			
+            if (gwy_container_gis_string_by_name(filedata.maps[m]->pset,
+                                                 "/Label", &label)) {
+                title = g_strdup_printf("%s", label);
+            }
+            else 			
+				title = g_strdup_printf("Map %d", m + 1);
+
+			siunitm = NULL;
+            siunitm = gwy_si_unit_new_parse(unit, &power10m);
+            mscale = pow10(power10m);
+            if (!siunitm) {
+                siunitm = gwy_si_unit_new_parse("", &power10m);
+                mscale = 1.0;
+            }
+            				
+            gmodel = g_object_new(GWY_TYPE_GRAPH_MODEL,
+                                  "title", title,
+                                  "si-unit-x", siunitm,
+                                  "si-unit-y", siunitw,            
+                                  NULL);
+			g_object_unref(siunitm);
+			xdata = g_new0(gdouble, zres);
+			for (i = 0; i < zres; i++) {
+				if (zdata) {
+					xdata[i] = zdata[i] * mscale;
+				}
+				else { 
+					xdata[i] = i;
+				}
+			}
+            ydata = g_new(gdouble, zres);
+            gwy_convert_raw_data(filedata.maps[m]->data,
+                                 zres, 1,
+                                 GWY_RAW_DATA_FLOAT,
+                                 GWY_BYTE_ORDER_LITTLE_ENDIAN,
+                                 ydata, wscale, 0.0);	
+
+            gcmodel = g_object_new(GWY_TYPE_GRAPH_CURVE_MODEL,
+                                   "description", title,
+                                   "mode", GWY_GRAPH_CURVE_LINE,
+                                   NULL);            
+            // g_free(title);
+            gwy_graph_curve_model_set_data(gcmodel, xdata, ydata, zres);
+            g_free(xdata);
+            g_free(ydata);   
+            if (!gwy_graph_curve_model_is_ordered(gcmodel)) {
+                gwy_graph_curve_model_enforce_order(gcmodel);
+            }
+            gwy_graph_model_add_curve(gmodel, gcmodel);
+            g_object_unref(gcmodel); 
+            key = g_strdup_printf("/0/graph/graph/%d", m + 2);
+            gwy_container_set_object_by_name(container, key, gmodel);
+            g_object_unref(gmodel);
+		}
+		g_object_unref(siunitw);
     }
     else { /* some kind of scan */
         gwy_debug("length = %d %d %d",
@@ -1421,6 +1506,31 @@ wdf_read_maparea_block(const guchar *buffer,
     gwy_debug("linefocus_length=%d", maparea->linefocus_size);
 }
 
+static void
+set_standard_keys(gpointer key, 
+                  G_GNUC_UNUSED gpointer value, gpointer user_data)
+{
+    WdfPsetData *pdata;
+    gpointer keys_value;
+    gchar *key_text;
+
+    pdata = (WdfPsetData *)user_data;
+    keys_value = g_hash_table_lookup(pdata->keys, key);
+
+    if (!keys_value) {
+		key_text = (gchar *)gwy_enum_to_string(GPOINTER_TO_INT(key),
+		                                       wdf_predefined_keys, 9);
+		gwy_debug("key_text=%s", key_text);
+
+		if (gwy_strequal(key_text, "")) {
+			// g_free(key_text);
+			key_text = g_strdup_printf("Key%d", GPOINTER_TO_INT(key));
+		}
+	    g_hash_table_replace(pdata->keys, key,
+                             g_strdup_printf("/%s", key_text));
+    }
+}
+
 static void
 extract_metadata_from_values(gpointer key, gpointer value,
                              gpointer user_data)
@@ -1429,6 +1539,7 @@ extract_metadata_from_values(gpointer key, gpointer value,
     gpointer value_value;
 
     pdata = (WdfPsetData *)user_data;
+    gwy_debug("value = %s", (char *)value); 
     value_value = g_hash_table_lookup(pdata->values, key);
     if (value && value_value) {
         gwy_container_set_string_by_name(pdata->data,
@@ -1440,7 +1551,7 @@ static GwyContainer *
 wdf_read_pset(const guchar *buffer,
               gsize size)
 {
-    gint remaining;
+    gsize remaining, size2;
     gchar c;
     gint i, j;
     gint64 i64;
@@ -1449,7 +1560,7 @@ wdf_read_pset(const guchar *buffer,
     GHashTable *keys, *values;
     WdfPropertySet *pset;
     WdfPsetData *pdata = NULL;
-    GwyContainer *data = NULL, *nested;
+    GwyContainer *data = NULL, *nested = NULL;
 
     remaining = size;
     keys = g_hash_table_new(g_direct_hash, g_direct_equal);
@@ -1564,17 +1675,20 @@ wdf_read_pset(const guchar *buffer,
                     gwy_debug("b size=%d", pset->size);
                 break;
                 case WDF_PTYPE_NESTED:
-                    pset->size = gwy_get_guint32_le(&buffer);
+					pset->size = gwy_get_guint32_le(&buffer);
+					size2 = pset->size;
                     remaining -= 4;
+                    gwy_debug("buffer before = %p", buffer);
                     gwy_debug("p size=%d", pset->size);
                     nested = NULL;
-                    nested = wdf_read_pset(buffer, pset->size);
+                    nested = wdf_read_pset(buffer, size2);
                     if (nested) {
                         gwy_container_transfer(nested, data,
                                                "/", "/", FALSE);
                     }
-                    buffer += pset->size;
-                    remaining -= pset->size;
+                    gwy_debug("buffer after = %p", buffer);
+                    buffer += size2;
+                    remaining -= size2;
                     g_object_unref(nested);
                 break;
                 case WDF_PTYPE_KEY:
@@ -1711,12 +1825,17 @@ wdf_read_pset(const guchar *buffer,
                     goto fail;
             } /* switch */
         } /* if (pset->flag == WDF_PFLAG_ARRAY) */
+        else if (pset->flag == WDF_PFLAG_COMPRESSED) {
+			buffer += pset->size;
+			remaining -= pset->size;
+		}
     }
 
     pdata = g_new(WdfPsetData, 1);
     pdata->keys = keys;
     pdata->values = values;
     pdata->data = data;
+    g_hash_table_foreach(values, set_standard_keys, (gpointer)pdata);
     g_hash_table_foreach(keys, extract_metadata_from_values,
                          (gpointer)pdata);
 
@@ -1726,7 +1845,7 @@ wdf_read_pset(const guchar *buffer,
     if (pdata) {
         g_free(pdata);
     }
-    gwy_debug("remaining = %d", remaining);
+    gwy_debug("remaining = %"G_GSIZE_FORMAT"", remaining);
 
     return data;
 }
