@@ -1,5 +1,5 @@
 /*
- *  $Id: rhk-sm4.c 23862 2021-06-16 12:40:27Z yeti-dn $
+ *  $Id: rhk-sm4.c 24459 2021-11-03 17:28:15Z yeti-dn $
  *  Copyright (C) 2009-2021 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -248,12 +248,57 @@ typedef enum {
     RHK_STRING_NSTRINGS
 } RHKStringType;
 
+typedef enum {
+    RHK_PIEZO_TUBE_X_UNIT,
+    RHK_PIEZO_TUBE_Y_UNIT,
+    RHK_PIEZO_TUBE_Z_UNIT,
+    RHK_PIEZO_TUBE_Z_OFFSET_UNIT,
+    RHK_PIEZO_SCAN_X_UNIT,
+    RHK_PIEZO_SCAN_Y_UNIT,
+    RHK_PIEZO_SCAN_Z_UNIT,
+    RHK_PIEZO_ACTUATOR_UNIT,
+    RHK_PIEZO_TUBE_CALIBRATION,
+    RHK_PIEZO_SCAN_CALIBRATION,
+    RHK_PIEZO_ACTUATOR_CALIBRATION,
+    RHK_PIEZO_NSTRINGS
+} RHKPiezoStringType;
+
 typedef enum {
     RHK_DRIFT_DISABLED = 0,
     RHK_DRIFT_EACH_SPECTRA = 1,
     RHK_DRIFT_EACH_LOCATION = 2
 } RHKDriftOptionType;
 
+typedef struct {
+    guint64 start_time;
+    RHKDriftOptionType drift_opt;
+    guint nstrings;
+    gchar **strings;
+} RHKSpecDriftHeader;
+
+typedef struct {
+    gdouble tube_x;
+    gdouble tube_y;
+    gdouble tube_z;
+    gdouble tube_z_offset;
+    gdouble scan_x;
+    gdouble scan_y;
+    gdouble scan_z;
+    gdouble actuator;
+    guint string_count;
+    gchar *strings[RHK_PIEZO_NSTRINGS];
+} RHKPiezoSensitivity;
+
+typedef struct {
+    gdouble ftime;
+    gdouble x_coord;
+    gdouble y_coord;
+    gdouble dx;
+    gdouble dy;
+    gdouble cumulative_dx;
+    gdouble cumulative_dy;
+} RHKSpecInfo;
+
 typedef struct {
     RHKObjectType type;
     guint offset;
@@ -303,6 +348,9 @@ typedef struct {
     const guchar *data;
     gchar *strings[RHK_STRING_NSTRINGS];
     RHKObject *objects;
+    RHKSpecDriftHeader *drift_header;
+    RHKSpecInfo *spec_info;
+    RHKPiezoSensitivity *piezo_sensitivity;
 } RHKPage;
 
 typedef struct {
@@ -315,23 +363,6 @@ typedef struct {
     RHKPage page;
 } RHKPageIndex;
 
-typedef struct {
-    guint64 start_time;
-    RHKDriftOptionType drift_opt;
-    guint nstrings;
-    /* and then @nstrings rhk_strings follow but we do not know how to read that. */
-} RHKSpecDriftHeader;
-
-typedef struct {
-    gdouble ftime;
-    gdouble x_coord;
-    gdouble y_coord;
-    gdouble dx;
-    gdouble dy;
-    gdouble cumulative_dx;
-    gdouble cumulative_dy;
-} RHKSpecInfo;
-
 typedef struct {
     guint page_count;
     guint object_count;
@@ -343,70 +374,72 @@ typedef struct {
     RHKPageIndex *page_indices;
 } RHKFile;
 
-static gboolean            module_register                (void);
-static gint                rhk_sm4_detect                 (const GwyFileDetectInfo *fileinfo,
-                                                           gboolean only_name);
-static GwyContainer*       rhk_sm4_load                   (const gchar *filename,
-                                                           GwyRunType mode,
-                                                           GError **error);
-static gboolean            rhk_sm4_read_page_index_header (RHKPageIndexHeader *header,
-                                                           const RHKObject *obj,
-                                                           const guchar *buffer,
-                                                           gsize size,
-                                                           GError **error);
-static gboolean            rhk_sm4_read_page_index        (RHKPageIndex *header,
-                                                           const RHKObject *obj,
-                                                           const guchar *buffer,
-                                                           gsize size,
-                                                           GError **error);
-static gboolean            rhk_sm4_read_page_header       (RHKPage *page,
-                                                           const RHKObject *obj,
-                                                           RHKDataType data_type,
-                                                           const guchar *buffer,
-                                                           gsize size,
-                                                           GError **error);
-static gboolean            rhk_sm4_read_page_data         (RHKPage *page,
-                                                           const RHKObject *obj,
-                                                           const guchar *buffer,
-                                                           GError **error);
-static gboolean            rhk_sm4_read_string_data       (RHKPage *page,
-                                                           const RHKObject *obj,
-                                                           guint count,
-                                                           const guchar *buffer);
-static RHKSpecDriftHeader* rhk_sm4_read_drift_header      (const RHKObject *obj,
-                                                           const guchar *buffer);
-static RHKSpecInfo*        rhk_sm4_read_spec_info         (const RHKObject *obj,
-                                                           const guchar *buffer,
-                                                           gsize size,
-                                                           guint nspec);
-static RHKObject*          rhk_sm4_read_objects           (const guchar *buffer,
-                                                           const guchar *p,
-                                                           gsize size,
-                                                           guint count,
-                                                           RHKObjectType intype,
-                                                           GError **error);
-static RHKObject*          rhk_sm4_find_object            (RHKObject *objects,
-                                                           guint count,
-                                                           RHKObjectType type,
-                                                           RHKObjectType parenttype,
-                                                           GError **error);
-static const gchar*        rhk_sm4_describe_object        (RHKObjectType type);
-static void                rhk_sm4_free                   (RHKFile *rhkfile);
-static GwyDataField*       rhk_sm4_page_to_data_field     (const RHKPage *page);
-static GwyGraphModel*      rhk_sm4_page_to_graph_model    (const RHKPage *page);
-static GwyContainer*       rhk_sm4_get_metadata           (const RHKPageIndex *pi,
-                                                           const RHKPage *page,
-                                                           GwyContainer *basemeta);
-static void                rhk_sm4_add_ppl_pro_status_meta(const RHKPage *page,
-                                                           GwyContainer *meta);
-static GwyContainer*       rhk_sm4_read_prm               (const RHKObject *prmheader,
-                                                           const RHKObject *prm,
-                                                           const guchar *buffer);
-static gchar*              unpack_compressed_data         (const guchar *buffer,
-                                                           gsize size,
-                                                           gsize expected_size,
-                                                           gsize *datasize,
-                                                           GError **error);
+static gboolean             module_register                (void);
+static gint                 rhk_sm4_detect                 (const GwyFileDetectInfo *fileinfo,
+                                                            gboolean only_name);
+static GwyContainer*        rhk_sm4_load                   (const gchar *filename,
+                                                            GwyRunType mode,
+                                                            GError **error);
+static gboolean             rhk_sm4_read_page_index_header (RHKPageIndexHeader *header,
+                                                            const RHKObject *obj,
+                                                            const guchar *buffer,
+                                                            gsize size,
+                                                            GError **error);
+static gboolean             rhk_sm4_read_page_index        (RHKPageIndex *header,
+                                                            const RHKObject *obj,
+                                                            const guchar *buffer,
+                                                            gsize size,
+                                                            GError **error);
+static gboolean             rhk_sm4_read_page_header       (RHKPage *page,
+                                                            const RHKObject *obj,
+                                                            RHKDataType data_type,
+                                                            const guchar *buffer,
+                                                            gsize size,
+                                                            GError **error);
+static gboolean             rhk_sm4_read_page_data         (RHKPage *page,
+                                                            const RHKObject *obj,
+                                                            const guchar *buffer,
+                                                            GError **error);
+static gboolean             rhk_sm4_read_string_data       (RHKPage *page,
+                                                            const RHKObject *obj,
+                                                            guint count,
+                                                            const guchar *buffer);
+static RHKSpecDriftHeader*  rhk_sm4_read_drift_header      (const RHKObject *obj,
+                                                            const guchar *buffer);
+static RHKPiezoSensitivity* rhk_sm4_read_piezo_sensitivity (const RHKObject *obj,
+                                                            const guchar *buffer);
+static RHKSpecInfo*         rhk_sm4_read_spec_info         (const RHKObject *obj,
+                                                            const guchar *buffer,
+                                                            gsize size,
+                                                            guint nspec);
+static RHKObject*           rhk_sm4_read_objects           (const guchar *buffer,
+                                                            const guchar *p,
+                                                            gsize size,
+                                                            guint count,
+                                                            RHKObjectType intype,
+                                                            GError **error);
+static RHKObject*           rhk_sm4_find_object            (RHKObject *objects,
+                                                            guint count,
+                                                            RHKObjectType type,
+                                                            RHKObjectType parenttype,
+                                                            GError **error);
+static const gchar*         rhk_sm4_describe_object        (RHKObjectType type);
+static void                 rhk_sm4_free                   (RHKFile *rhkfile);
+static GwyDataField*        rhk_sm4_page_to_data_field     (const RHKPage *page);
+static GwyGraphModel*       rhk_sm4_page_to_graph_model    (const RHKPage *page);
+static GwyContainer*        rhk_sm4_get_metadata           (const RHKPageIndex *pi,
+                                                            const RHKPage *page,
+                                                            GwyContainer *basemeta);
+static void                 rhk_sm4_add_ppl_pro_status_meta(const RHKPage *page,
+                                                            GwyContainer *meta);
+static GwyContainer*        rhk_sm4_read_prm               (const RHKObject *prmheader,
+                                                            const RHKObject *prm,
+                                                            const guchar *buffer);
+static gchar*               unpack_compressed_data         (const guchar *buffer,
+                                                            gsize size,
+                                                            gsize expected_size,
+                                                            gsize *datasize,
+                                                            GError **error);
 
 static GwyModuleInfo module_info = {
     GWY_MODULE_ABI_VERSION,
@@ -557,6 +590,10 @@ rhk_sm4_load(const gchar *filename,
             || !rhk_sm4_read_string_data(page, obj, pi->page.string_count, buffer)) {
             g_warning("Failed to read string data in page %u", i);
         }
+        /* Page may contain piezo sensitivity */
+        if ((obj = rhk_sm4_find_object(page->objects, page->object_count,
+                                       RHK_OBJECT_PIEZO_SENSITIVITY, RHK_OBJECT_PAGE_HEADER, NULL)))
+            page->piezo_sensitivity = rhk_sm4_read_piezo_sensitivity(obj, buffer);
 
         /* Read the data */
         if (pi->data_type == RHK_DATA_IMAGE) {
@@ -598,8 +635,6 @@ rhk_sm4_load(const gchar *filename,
         }
         else if (pi->data_type == RHK_DATA_LINE) {
             GwyGraphModel *gmodel;
-            RHKSpecDriftHeader *drift_header = NULL;
-            RHKSpecInfo *spec_infos = NULL;
 
             gwy_debug("page_type %u", page->page_type);
             gwy_debug("line_type %u", page->line_type);
@@ -607,18 +642,15 @@ rhk_sm4_load(const gchar *filename,
             /* Page may contain drift header */
             if ((obj = rhk_sm4_find_object(page->objects, page->object_count,
                                            RHK_OBJECT_SPEC_DRIFT_HEADER, RHK_OBJECT_PAGE_HEADER, NULL)))
-                drift_header = rhk_sm4_read_drift_header(obj, buffer);
+                page->drift_header = rhk_sm4_read_drift_header(obj, buffer);
             if ((obj = rhk_sm4_find_object(page->objects, page->object_count,
                                            RHK_OBJECT_SPEC_DRIFT_DATA, RHK_OBJECT_PAGE_HEADER, NULL)))
-                spec_infos = rhk_sm4_read_spec_info(obj, buffer, size, page->y_size);
-
+                page->spec_info = rhk_sm4_read_spec_info(obj, buffer, size, page->y_size);
             if ((gmodel = rhk_sm4_page_to_graph_model(page))) {
                 graphid++;
                 gwy_container_set_object(container, gwy_app_get_graph_key_for_id(graphid), gmodel);
                 g_object_unref(gmodel);
             }
-            g_free(spec_infos);
-            g_free(drift_header);
         }
     }
 
@@ -807,37 +839,38 @@ rhk_sm4_read_page_data(RHKPage *page, const RHKObject *obj,
     return TRUE;
 }
 
+static gchar*
+rhk_sm4_read_string(const guchar **p, const guchar *end)
+{
+    gchar *s;
+    guint len;
+
+    if (end - *p < sizeof(guint16))
+        return NULL;
+
+    len = gwy_get_guint16_le(p);
+    if (len > (end - *p)/sizeof(gunichar2))
+        return NULL;
+
+    s = gwy_utf16_to_utf8((const gunichar2*)*p, len, GWY_BYTE_ORDER_LITTLE_ENDIAN);
+    *p += len*sizeof(gunichar2);
+
+    return s;
+}
+
 static gboolean
 rhk_sm4_read_string_data(RHKPage *page, const RHKObject *obj,
                          guint count, const guchar *buffer)
 {
-    const guchar *p;
-    gchar *s;
-    guint i, len;
+    const guchar *p = buffer + obj->offset, *end = p + obj->size;
+    guint i;
 
     gwy_debug("count: %u, known strings: %u", count, RHK_STRING_NSTRINGS);
     count = MIN(count, RHK_STRING_NSTRINGS);
-    p = buffer + obj->offset;
     for (i = 0; i < count; i++) {
-        /* Not enough strings */
-        if (p - buffer + 2 > obj->offset + obj->size)
+        if (!(page->strings[i] = rhk_sm4_read_string(&p, end)))
             return FALSE;
-
-        len = gwy_get_guint16_le(&p);
-        if (!len)
-            continue;
-
-        /* String does not fit */
-        if (p - buffer + 2*len > obj->offset + obj->size)
-            return FALSE;
-
-        s = page->strings[i] = g_new0(gchar, 6*len + 1);
-        while (len--)
-            s += g_unichar_to_utf8(gwy_get_guint16_le(&p), s);
-
-        if (s != page->strings[i]) {
-            gwy_debug("string[%u]: <%s>", i, page->strings[i]);
-        }
+        gwy_debug("string[%u]: <%s>", i, page->strings[i]);
     }
 
     return TRUE;
@@ -847,7 +880,8 @@ static RHKSpecDriftHeader*
 rhk_sm4_read_drift_header(const RHKObject *obj, const guchar *buffer)
 {
     RHKSpecDriftHeader *drift_header = NULL;
-    const guchar *p = buffer + obj->offset;
+    const guchar *p = buffer + obj->offset, *end = p + obj->size;
+    guint i, nstrings;
 
     if (obj->size < 16)
         return drift_header;
@@ -855,12 +889,63 @@ rhk_sm4_read_drift_header(const RHKObject *obj, const guchar *buffer)
     drift_header = g_new0(RHKSpecDriftHeader, 1);
     drift_header->start_time = gwy_get_guint64_le(&p);
     drift_header->drift_opt = gwy_get_gint16_le(&p);
-    drift_header->nstrings = gwy_get_guint16_le(&p);
-    /* TODO: Read the strings. */
+    drift_header->nstrings = nstrings = gwy_get_guint16_le(&p);
+    gwy_debug("nstrings = %u", nstrings);
+    drift_header->strings = g_new0(gchar*, nstrings+1);
+    for (i = 0; i < nstrings; i++) {
+        if (!(drift_header->strings[i] = rhk_sm4_read_string(&p, end))) {
+            g_strfreev(drift_header->strings);
+            g_free(drift_header);
+            return NULL;
+        }
+        gwy_debug("string[%u] = <%s>", i, drift_header->strings[i]);
+    }
 
     return drift_header;
 }
 
+static RHKPiezoSensitivity*
+rhk_sm4_read_piezo_sensitivity(const RHKObject *obj, const guchar *buffer)
+{
+    RHKPiezoSensitivity *piezo_sensitivity = NULL;
+    const guchar *p = buffer + obj->offset, *end = p + obj->size;
+    guint i, nstrings;
+
+    if (obj->size < 8*sizeof(gdouble) + sizeof(guint16))
+        return piezo_sensitivity;
+
+    piezo_sensitivity = g_new0(RHKPiezoSensitivity, 1);
+    piezo_sensitivity->tube_x = gwy_get_gdouble_le(&p);
+    piezo_sensitivity->tube_y = gwy_get_gdouble_le(&p);
+    piezo_sensitivity->tube_z = gwy_get_gdouble_le(&p);
+    gwy_debug("tube x %g, y %g, z %g",
+              piezo_sensitivity->tube_x, piezo_sensitivity->tube_y, piezo_sensitivity->tube_z);
+    piezo_sensitivity->tube_z_offset = gwy_get_gdouble_le(&p);
+    piezo_sensitivity->scan_x = gwy_get_gdouble_le(&p);
+    piezo_sensitivity->scan_y = gwy_get_gdouble_le(&p);
+    piezo_sensitivity->scan_z = gwy_get_gdouble_le(&p);
+    gwy_debug("scan x %g, y %g, z %g",
+              piezo_sensitivity->scan_x, piezo_sensitivity->scan_y, piezo_sensitivity->scan_z);
+    piezo_sensitivity->actuator = gwy_get_gdouble_le(&p);
+    piezo_sensitivity->string_count = gwy_get_guint32_le(&p);
+    gwy_debug("string_count = %u", piezo_sensitivity->string_count);
+    nstrings = MIN(piezo_sensitivity->string_count, RHK_PIEZO_NSTRINGS);
+    /* XXX: This never reads anything because obj->size is always just 68, i.e. only large
+     * enough to hold the doubles and string count.  Even if there seem to be actually some
+     * strings.  Other objects report their size correctly.  Why? */
+    for (i = 0; i < nstrings; i++) {
+        if (!(piezo_sensitivity->strings[i] = rhk_sm4_read_string(&p, end))) {
+            while (i--)
+                g_free(piezo_sensitivity->strings[i]);
+            g_free(piezo_sensitivity);
+            return NULL;
+        }
+        gwy_debug("string[%u] = <%s>", i, piezo_sensitivity->strings[i]);
+    }
+
+    return piezo_sensitivity;
+}
+
 static RHKSpecInfo*
 rhk_sm4_read_spec_info(const RHKObject *obj,
                        const guchar *buffer, gsize size, guint nspec)
@@ -1008,6 +1093,16 @@ rhk_sm4_free(RHKFile *rhkfile)
             page = &rhkfile->page_indices[i].page;
             for (j = 0; j < RHK_STRING_NSTRINGS; j++)
                 g_free(page->strings[j]);
+            if (page->drift_header) {
+                g_strfreev(page->drift_header->strings);
+                g_free(page->drift_header);
+            }
+            if (page->piezo_sensitivity) {
+                for (j = 0; j < RHK_PIEZO_NSTRINGS; j++)
+                    g_free(page->piezo_sensitivity->strings[j]);
+                g_free(page->piezo_sensitivity);
+            }
+            g_free(page->spec_info);
         }
         g_free(rhkfile->page_indices);
     }
