@@ -1,5 +1,5 @@
 /*
- *  $Id: sensofarx.c 19118 2016-10-23 12:22:32Z yeti-dn $
+ *  $Id: sensofarx.c 22001 2019-04-16 13:58:04Z yeti-dn $
  *  Copyright (C) 2015 David Necas (Yeti).
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -134,7 +134,7 @@ sensofarx_detect(const GwyFileDetectInfo *fileinfo,
     /* We have to realy look inside.  And since index.xml is a popular name
      * for the main XML document within such files, we also have to see if
      * we find "<IMAGE_SIZE_X>" somewehre near the begining of the file. */
-    if ((zipfile = gwyzip_open(fileinfo->name))) {
+    if ((zipfile = gwyzip_open(fileinfo->name, NULL))) {
         if (gwyzip_locate_file(zipfile, "index.xml", 1, NULL)) {
             if ((content = gwyzip_get_file_content(zipfile, NULL, NULL))) {
                 if (g_strstr_len(content, 4096, "<IMAGE_SIZE_X>"))
@@ -176,13 +176,8 @@ sensofarx_load(const gchar *filename,
     PLUxFile pluxfile;
     GwyZipFile zipfile;
 
-    zipfile = gwyzip_open(filename);
-    if (!zipfile) {
-        g_set_error(error, GWY_MODULE_FILE_ERROR,
-                    GWY_MODULE_FILE_ERROR_SPECIFIC,
-                    _("Minizip cannot open the file as a ZIP file."));
+    if (!(zipfile = gwyzip_open(filename, error)))
         return NULL;
-    }
 
     gwy_clear(&pluxfile, 1);
     if (!sensofarx_parse_index(zipfile, &pluxfile, error))
