@@ -1,5 +1,5 @@
 /*
- *  $Id: spmlabf.c 22660 2019-11-08 09:12:55Z yeti-dn $
+ *  $Id: spmlabf.c 23822 2021-06-10 06:58:57Z yeti-dn $
  *  Copyright (C) 2008 David Necas (Yeti).
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -78,7 +78,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Imports SPMLab floating-point files."),
     "Yeti <yeti@gwyddion.net>",
-    "0.5",
+    "0.6",
     "David Nečas (Yeti)",
     "2008",
 };
@@ -303,7 +303,7 @@ add_metadata(GHashTable *hash,
         if ((value = g_hash_table_lookup(hash, key))) {
             if (!meta)
                 meta = gwy_container_new();
-            v = g_convert(value, -1, "iso-8859-1", "utf-8", NULL, NULL, NULL);
+            v = g_convert(value, -1, "UTF-8", "ISO-8859-1", NULL, NULL, NULL);
             if (v)
                 gwy_container_set_string_by_name(meta, key, v);
         }
