@@ -1,5 +1,5 @@
 /*
- *  $Id: wipfile.c 22562 2019-10-10 14:45:41Z yeti-dn $
+ *  $Id: wipfile.c 23266 2021-03-15 14:54:21Z yeti-dn $
  *  Copyright (C) 2010-2011 David Necas (Yeti), Petr Klapetek,
  *  Daniil Bratashov (dn2010)
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net, dn2010@gmail.com
@@ -280,7 +280,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Imports WItec Project data files."),
     "Daniil Bratashov <dn2010@gmail.com>",
-    "0.9",
+    "0.10",
     "David Nečas (Yeti) & Petr Klapetek & Daniil Bratashov",
     "2010",
 };
@@ -1502,10 +1502,7 @@ wip_read_image(GNode *node)
     gwy_data_field_set_si_unit_xy(dfield, siunitxy);
     g_object_unref(siunitz);
     g_object_unref(siunitxy);
-
-    if (mirrorx || mirrory) {
-        gwy_data_field_invert(dfield, mirrorx, mirrory, FALSE);
-    }
+    gwy_data_field_invert(dfield, mirrory, mirrorx, FALSE);
 
     return dfield;
 }
@@ -1569,9 +1566,7 @@ wip_read_bitmap(GNode *node)
     }
     else {
         gwy_data_field_set_si_unit_xy(dfield, siunitxy);
-        if (mirrory || mirrorx) {
-            gwy_data_field_invert(dfield, mirrorx, mirrorx, FALSE);
-        }
+        gwy_data_field_invert(dfield, mirrory, mirrorx, FALSE);
     }
 
     g_object_unref(siunitxy);
