@@ -1,5 +1,5 @@
 /*
- *  $Id: graph_fit.c 20677 2017-12-18 18:22:52Z yeti-dn $
+ *  $Id: graph_fit.c 24083 2021-09-06 16:37:12Z yeti-dn $
  *  Copyright (C) 2003-2017 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -181,7 +181,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Fit graph with function"),
     "Petr Klapetek <klapetek@gwyddion.net>",
-    "2.10",
+    "2.11",
     "David Nečas (Yeti) & Petr Klapetek",
     "2004",
 };
@@ -193,9 +193,9 @@ module_register(void)
 {
     gwy_graph_func_register("graph_fit",
                             (GwyGraphFunc)&fit,
-                            N_("/_Fit Function..."),
+                            N_("/Measure _Features/_Fit Function..."),
                             GWY_STOCK_GRAPH_FUNCTION,
-                            GWY_MENU_FLAG_GRAPH,
+                            GWY_MENU_FLAG_GRAPH_CURVE,
                             N_("Fit a function on graph data"));
 
     return TRUE;
