@@ -1,5 +1,5 @@
 /*
- *  $Id: axis.c 21763 2019-01-01 22:09:12Z yeti-dn $
+ *  $Id: axis.c 23054 2021-01-12 12:21:09Z yeti-dn $
  *  Copyright (C) 2003-2006 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -142,7 +142,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Layer allowing selection of horizontal or vertical lines."),
     "Yeti <yeti@gwyddion.net>",
-    "2.8",
+    "2.9",
     "David Nečas (Yeti) & Petr Klapetek",
     "2004",
 };
@@ -441,11 +441,12 @@ gwy_layer_axis_draw_object(GwyVectorLayer *layer,
                            gint i)
 {
     GwyDataView *data_view;
-    gint coord, width, height, res;
-    gdouble xy[OBJECT_SIZE], real;
+    gint xi0, yi0, xi1, yi1, width, height;
+    gdouble xy[OBJECT_SIZE], xreal, yreal;
     gboolean has_object;
 
     data_view = GWY_DATA_VIEW(GWY_DATA_VIEW_LAYER(layer)->parent);
+    gwy_data_view_get_real_data_sizes(data_view, &xreal, &yreal);
 
     has_object = gwy_selection_get_object(layer->selection, i, xy);
     g_return_if_fail(has_object);
@@ -453,49 +454,22 @@ gwy_layer_axis_draw_object(GwyVectorLayer *layer,
     gdk_drawable_get_size(drawable, &width, &height);
     switch (GWY_SELECTION_AXIS(layer->selection)->orientation) {
         case GWY_ORIENTATION_HORIZONTAL:
-        switch (target) {
-            case GWY_RENDERING_TARGET_SCREEN:
-            gwy_data_view_coords_real_to_xy(data_view,
-                                            0.0, xy[0], NULL, &coord);
-            break;
-
-            case GWY_RENDERING_TARGET_PIXMAP_IMAGE:
-            gwy_data_view_get_real_data_sizes(data_view, &real, NULL);
-            gdk_drawable_get_size(drawable, &res, NULL);
-            coord = floor(xy[0]*res/real);
-            break;
-
-            default:
-            g_return_if_reached();
-            break;
-        }
-        gdk_draw_line(drawable, layer->gc, 0, coord, width, coord);
+        gwy_vector_layer_transform_line_to_target(layer, drawable, target,
+                                                  0.0, xy[0], xreal, xy[0],
+                                                  &xi0, &yi0, &xi1, &yi1);
         break;
 
         case GWY_ORIENTATION_VERTICAL:
-        switch (target) {
-            case GWY_RENDERING_TARGET_SCREEN:
-            gwy_data_view_coords_real_to_xy(data_view,
-                                            xy[0], 0.0, &coord, NULL);
-            break;
-
-            case GWY_RENDERING_TARGET_PIXMAP_IMAGE:
-            gwy_data_view_get_real_data_sizes(data_view, NULL, &real);
-            gdk_drawable_get_size(drawable, NULL, &res);
-            coord = floor(xy[0]*res/real);
-            break;
-
-            default:
-            g_return_if_reached();
-            break;
-        }
-        gdk_draw_line(drawable, layer->gc, coord, 0, coord, height);
+        gwy_vector_layer_transform_line_to_target(layer, drawable, target,
+                                                  xy[0], 0.0, xy[0], yreal,
+                                                  &xi0, &yi0, &xi1, &yi1);
         break;
 
         default:
         g_assert_not_reached();
         break;
     }
+    gdk_draw_line(drawable, layer->gc, xi0, yi0, xi1, yi1);
 }
 
 static gboolean
