@@ -1,5 +1,5 @@
 /*
- *  $Id: cross.c 22230 2019-07-12 15:47:55Z yeti-dn $
+ *  $Id: cross.c 23054 2021-01-12 12:21:09Z yeti-dn $
  *  Copyright (C) 2019 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -151,7 +151,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Layer allowing selection of combined horizontal and vertical lines."),
     "Yeti <yeti@gwyddion.net>",
-    "1.1",
+    "1.2",
     "David Nečas (Yeti)",
     "2019",
 };
@@ -420,29 +420,16 @@ gwy_layer_cross_draw_horizontal(GwyVectorLayer *layer,
     gdouble xreal, yreal, ym;
 
     gwy_data_view_get_real_data_sizes(data_view, &xreal, &yreal);
+    gwy_data_view_get_pixel_data_sizes(data_view, &xsize, &ysize);
     gdk_drawable_get_size(drawable, &width, &height);
 
-    switch (target) {
-        case GWY_RENDERING_TARGET_SCREEN:
-        gwy_data_view_coords_real_to_xy(data_view, 0.0, xy[1], &xl0, &yl0);
-        gwy_data_view_coords_real_to_xy(data_view, xreal, xy[1], &xl1, &yl1);
-        gwy_data_view_coords_xy_clamp(data_view, &xl0, &yl0);
-        gwy_data_view_coords_xy_clamp(data_view, &xl1, &yl1);
-        gwy_data_view_get_pixel_data_sizes(data_view, &xsize, &ysize);
+    gwy_vector_layer_transform_line_to_target(layer, drawable, target,
+                                              0.0, xy[1], xreal, xy[1],
+                                              &xl0, &yl0, &xl1, &yl1);
+    if (target == GWY_RENDERING_TARGET_SCREEN)
         ym = height/(ysize*(gwy_data_view_get_vexcess(data_view) + 1.0));
-        break;
-
-        case GWY_RENDERING_TARGET_PIXMAP_IMAGE:
+    else
         ym = (gdouble)height/yreal;
-        yl0 = yl1 = floor(xy[1]*ym);
-        xl0 = 0;
-        xl1 = width;
-        break;
-
-        default:
-        g_return_if_reached();
-        break;
-    }
 
     layer_cross = GWY_LAYER_CROSS(layer);
     thickness = layer_cross->thickness;
@@ -483,29 +470,16 @@ gwy_layer_cross_draw_vertical(GwyVectorLayer *layer,
     gdouble xreal, yreal, xm;
 
     gwy_data_view_get_real_data_sizes(data_view, &xreal, &yreal);
+    gwy_data_view_get_pixel_data_sizes(data_view, &xsize, &ysize);
     gdk_drawable_get_size(drawable, &width, &height);
 
-    switch (target) {
-        case GWY_RENDERING_TARGET_SCREEN:
-        gwy_data_view_coords_real_to_xy(data_view, xy[0], 0.0, &xl0, &yl0);
-        gwy_data_view_coords_real_to_xy(data_view, xy[0], yreal, &xl1, &yl1);
-        gwy_data_view_coords_xy_clamp(data_view, &xl0, &yl0);
-        gwy_data_view_coords_xy_clamp(data_view, &xl1, &yl1);
-        gwy_data_view_get_pixel_data_sizes(data_view, &xsize, &ysize);
+    gwy_vector_layer_transform_line_to_target(layer, drawable, target,
+                                              xy[0], 0.0, xy[0], yreal,
+                                              &xl0, &yl0, &xl1, &yl1);
+    if (target == GWY_RENDERING_TARGET_SCREEN)
         xm = width/(xsize*(gwy_data_view_get_hexcess(data_view) + 1.0));
-        break;
-
-        case GWY_RENDERING_TARGET_PIXMAP_IMAGE:
+    else
         xm = (gdouble)width/xreal;
-        xl0 = xl1 = floor(xy[0]*xm);
-        yl0 = 0;
-        yl1 = height;
-        break;
-
-        default:
-        g_return_if_reached();
-        break;
-    }
 
     layer_cross = GWY_LAYER_CROSS(layer);
     thickness = layer_cross->thickness;
