@@ -1,5 +1,5 @@
 /*
- *  $Id: line.c 22237 2019-07-13 19:10:54Z yeti-dn $
+ *  $Id: line.c 23054 2021-01-12 12:21:09Z yeti-dn $
  *  Copyright (C) 2003-2019 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -179,7 +179,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Layer allowing selection of arbitrary straight lines."),
     "Yeti <yeti@gwyddion.net>",
-    "3.7",
+    "3.8",
     "David Nečas (Yeti) & Petr Klapetek",
     "2004",
 };
@@ -480,25 +480,9 @@ gwy_layer_line_draw_object(GwyVectorLayer *layer,
     gwy_data_view_get_real_data_sizes(data_view, &xreal, &yreal);
     gdk_drawable_get_size(drawable, &width, &height);
 
-    switch (target) {
-        case GWY_RENDERING_TARGET_SCREEN:
-        gwy_data_view_coords_real_to_xy(data_view, xy[0], xy[1], &xi0, &yi0);
-        gwy_data_view_coords_real_to_xy(data_view, xy[2], xy[3], &xi1, &yi1);
-        gwy_data_view_coords_xy_clamp(data_view, &xi0, &yi0);
-        gwy_data_view_coords_xy_clamp(data_view, &xi1, &yi1);
-        break;
-
-        case GWY_RENDERING_TARGET_PIXMAP_IMAGE:
-        xi0 = floor(xy[0]*width/xreal);
-        yi0 = floor(xy[1]*height/yreal);
-        xi1 = floor(xy[2]*width/xreal);
-        yi1 = floor(xy[3]*height/yreal);
-        break;
-
-        default:
-        g_return_if_reached();
-        break;
-    }
+    gwy_vector_layer_transform_line_to_target(layer, drawable, target,
+                                              xy[0], xy[1], xy[2], xy[3],
+                                              &xi0, &yi0, &xi1, &yi1);
     gdk_draw_line(drawable, layer->gc, xi0, yi0, xi1, yi1);
 
     layer_line = GWY_LAYER_LINE(layer);
@@ -516,48 +500,16 @@ gwy_layer_line_draw_object(GwyVectorLayer *layer,
         xd *= layer_line->thickness/h *xreal/xres/2;
         yd *= layer_line->thickness/h *yreal/yres/2;
 
-        switch (target) {
-            case GWY_RENDERING_TARGET_SCREEN:
-            gwy_data_view_coords_real_to_xy(data_view, xy[0] + xd, xy[1] + yd,
-                                            &xl0, &yl0);
-            gwy_data_view_coords_real_to_xy(data_view, xy[0] - xd, xy[1] - yd,
-                                            &xl1, &yl1);
-            gwy_data_view_coords_xy_cut_line(data_view, &xl0, &yl0, &xl1, &yl1);
-            break;
-
-            case GWY_RENDERING_TARGET_PIXMAP_IMAGE:
-            xl0 = floor((xy[0] + xd)*width/xreal);
-            yl0 = floor((xy[1] + yd)*height/yreal);
-            xl1 = floor((xy[0] - xd)*width/xreal);
-            yl1 = floor((xy[1] - yd)*height/yreal);
-            break;
-
-            default:
-            g_return_if_reached();
-            break;
-        }
+        gwy_vector_layer_transform_line_to_target(layer, drawable, target,
+                                                  xy[0] + xd, xy[1] + yd,
+                                                  xy[0] - xd, xy[1] - yd,
+                                                  &xl0, &yl0, &xl1, &yl1);
         gdk_draw_line(drawable, layer->gc, xl0, yl0, xl1, yl1);
 
-        switch (target) {
-            case GWY_RENDERING_TARGET_SCREEN:
-            gwy_data_view_coords_real_to_xy(data_view, xy[2] + xd, xy[3] + yd,
-                                            &xl0, &yl0);
-            gwy_data_view_coords_real_to_xy(data_view, xy[2] - xd, xy[3] - yd,
-                                            &xl1, &yl1);
-            gwy_data_view_coords_xy_cut_line(data_view, &xl0, &yl0, &xl1, &yl1);
-            break;
-
-            case GWY_RENDERING_TARGET_PIXMAP_IMAGE:
-            xl0 = floor((xy[2] + xd)*width/xreal);
-            yl0 = floor((xy[3] + yd)*height/yreal);
-            xl1 = floor((xy[2] - xd)*width/xreal);
-            yl1 = floor((xy[3] - yd)*height/yreal);
-            break;
-
-            default:
-            g_return_if_reached();
-            break;
-        }
+        gwy_vector_layer_transform_line_to_target(layer, drawable, target,
+                                                  xy[2] + xd, xy[3] + yd,
+                                                  xy[2] - xd, xy[3] - yd,
+                                                  &xl0, &yl0, &xl1, &yl1);
         gdk_draw_line(drawable, layer->gc, xl0, yl0, xl1, yl1);
     }
 
