@@ -1,5 +1,5 @@
 /*
- *  $Id: rectangle.c 22236 2019-07-13 13:43:58Z yeti-dn $
+ *  $Id: rectangle.c 23054 2021-01-12 12:21:09Z yeti-dn $
  *  Copyright (C) 2003-2019 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -113,7 +113,6 @@ static void     gwy_layer_rectangle_draw_object    (GwyVectorLayer *layer,
                                                     GwyRenderingTarget target,
                                                     gint i);
 static void     gwy_layer_rectangle_draw_rectangle (GwyVectorLayer *layer,
-                                                    GwyDataView *data_view,
                                                     GdkDrawable *drawable,
                                                     GwyRenderingTarget target,
                                                     const gdouble *xy);
@@ -150,7 +149,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Layer allowing selection of rectangular areas."),
     "Yeti <yeti@gwyddion.net>",
-    "2.11",
+    "2.12",
     "David Nečas (Yeti) & Petr Klapetek",
     "2004",
 };
@@ -377,7 +376,7 @@ gwy_layer_rectangle_draw_object(GwyVectorLayer *layer,
     has_object = gwy_selection_get_object(layer->selection, i, xy);
     g_return_if_fail(has_object);
 
-    gwy_layer_rectangle_draw_rectangle(layer, data_view, drawable, target, xy);
+    gwy_layer_rectangle_draw_rectangle(layer, drawable, target, xy);
     if (GWY_LAYER_RECTANGLE(layer)->draw_reflection) {
         gwy_data_view_get_real_data_sizes(data_view, &xreal, &yreal);
         xy[0] = xreal - xy[0];
@@ -400,41 +399,21 @@ gwy_layer_rectangle_draw_object(GwyVectorLayer *layer,
                                             &xy[2], &xy[3]);
         }
 
-        gwy_layer_rectangle_draw_rectangle(layer, data_view,
-                                           drawable, target, xy);
+        gwy_layer_rectangle_draw_rectangle(layer, drawable, target, xy);
     }
 }
 
 static void
 gwy_layer_rectangle_draw_rectangle(GwyVectorLayer *layer,
-                                   GwyDataView *data_view,
                                    GdkDrawable *drawable,
                                    GwyRenderingTarget target,
                                    const gdouble *xy)
 {
     gint xmin, ymin, xmax, ymax, width, height;
-    gdouble xreal, yreal;
-
-    switch (target) {
-        case GWY_RENDERING_TARGET_SCREEN:
-        gwy_data_view_coords_real_to_xy(data_view, xy[0], xy[1], &xmin, &ymin);
-        gwy_data_view_coords_real_to_xy(data_view, xy[2], xy[3], &xmax, &ymax);
-        break;
-
-        case GWY_RENDERING_TARGET_PIXMAP_IMAGE:
-        gwy_data_view_get_real_data_sizes(data_view, &xreal, &yreal);
-        gdk_drawable_get_size(drawable, &width, &height);
-        xmin = floor(xy[0]*width/xreal);
-        ymin = floor(xy[1]*height/yreal);
-        xmax = floor(xy[2]*width/xreal);
-        ymax = floor(xy[3]*height/yreal);
-        break;
-
-        default:
-        g_return_if_reached();
-        break;
-    }
 
+    gwy_vector_layer_transform_line_to_target(layer, drawable, target,
+                                              xy[0], xy[1], xy[2], xy[3],
+                                              &xmin, &ymin, &xmax, &ymax);
     if (xmax < xmin)
         GWY_SWAP(gint, xmin, xmax);
     if (ymax < ymin)
