@@ -1,5 +1,5 @@
 /*
- *  $Id: acf2d.c 22720 2020-01-27 16:14:58Z yeti-dn $
+ *  $Id: acf2d.c 23556 2021-04-21 08:00:51Z yeti-dn $
  *  Copyright (C) 2007-2019 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -324,7 +324,7 @@ acf2d_dialogue(ACFArgs *args,
                             GWY_DATA_ITEM_MASK_COLOR,
                             GWY_DATA_ITEM_REAL_SQUARE,
                             0);
-    controls.view = create_preview(controls.mydata, 0, PREVIEW_SIZE, TRUE);
+    controls.view = gwy_create_preview(controls.mydata, 0, PREVIEW_SIZE, TRUE);
     controls.selection = create_vector_layer(GWY_DATA_VIEW(controls.view), 0,
                                              "Point", TRUE);
     gwy_selection_set_max_objects(controls.selection, NLINES);
