@@ -1,5 +1,5 @@
 /*
- *  $Id: angle_dist.c 20677 2017-12-18 18:22:52Z yeti-dn $
+ *  $Id: angle_dist.c 21784 2019-01-03 13:00:48Z yeti-dn $
  *  Copyright (C) 2004 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -433,10 +433,10 @@ make_datafield(G_GNUC_UNUSED GwyDataField *old,
     gwy_data_field_set_xoffset(dfield, -gwy_data_field_get_xreal(dfield)/2);
     gwy_data_field_set_yoffset(dfield, -gwy_data_field_get_yreal(dfield)/2);
 
-    unit = gwy_si_unit_new("");
+    unit = gwy_si_unit_new(NULL);
     gwy_data_field_set_si_unit_z(dfield, unit);
     g_object_unref(unit);
-    unit = gwy_si_unit_new("");
+    unit = gwy_si_unit_new(NULL);
     gwy_data_field_set_si_unit_xy(dfield, unit);
     g_object_unref(unit);
 
