@@ -1,5 +1,5 @@
 /*
- *  $Id: arithmetic.c 22215 2019-07-10 14:05:43Z yeti-dn $
+ *  $Id: arithmetic.c 23556 2021-04-21 08:00:51Z yeti-dn $
  *  Copyright (C) 2003-2019 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -279,7 +279,7 @@ arithmetic_dialog(GwyContainer *data,
                             GWY_DATA_ITEM_MASK_COLOR,
                             GWY_DATA_ITEM_REAL_SQUARE,
                             0);
-    controls.view = create_preview(controls.mydata, 0, PREVIEW_SIZE, TRUE);
+    controls.view = gwy_create_preview(controls.mydata, 0, PREVIEW_SIZE, TRUE);
     ensure_mask_color(controls.mydata, 0);
     gtk_box_pack_start(GTK_BOX(vbox), controls.view, FALSE, FALSE, 0);
 
@@ -478,8 +478,7 @@ arithmetic_expr_changed(GtkWidget *entry,
 
     combo = GTK_COMBO_BOX(entry);
     args = controls->args;
-    g_free(args->expression);
-    args->expression = g_strdup(gtk_combo_box_get_active_text(combo));
+    gwy_assign_string(&args->expression, gtk_combo_box_get_active_text(combo));
     args->err = ARITHMETIC_OK;
 
     if (gwy_expr_compile(args->expr, args->expression, &error)) {
@@ -513,8 +512,7 @@ static void
 arithmetic_userunits_changed(GtkEntry *entry,
                              ArithmeticControls *controls)
 {
-    g_free(controls->args->userunits);
-    controls->args->userunits = g_strdup(gtk_entry_get_text(entry));
+    gwy_assign_string(&controls->args->userunits, gtk_entry_get_text(entry));
 }
 
 static void
