@@ -1,5 +1,5 @@
 /*
- *  $Id: averaging.c 20677 2017-12-18 18:22:52Z yeti-dn $
+ *  $Id: averaging.c 23665 2021-05-10 21:19:38Z yeti-dn $
  *  Copyright (C) 2011, David Necas (Yeti), Petr Klapetek, Daniil Bratashov
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net, dn2010@gmail.com
  *
@@ -141,7 +141,7 @@ averaging_dialog(GwyContainer *data)
     label = gtk_label_new(_("Select the sample area below"));
     gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, FALSE, 0);
 
-    view = create_preview(data, 0, PREVIEW_SIZE, FALSE);
+    view = gwy_create_preview(data, 0, PREVIEW_SIZE, FALSE);
     zselection = create_vector_layer(GWY_DATA_VIEW(view), 0, "Rectangle", TRUE);
     gwy_selection_set_max_objects(zselection, 1);
     gtk_box_pack_start(GTK_BOX(vbox), view, FALSE, FALSE, 0);
@@ -233,25 +233,27 @@ averaging_do(GwyContainer *data, GwySelection *selected)
     height = gwy_data_field_get_yres(kernel);
     for (i = 0; i < maxima->len; i++) {
         maximum = g_array_index(maxima, GwyMaximum, i);
-        xtop = maximum.col - width / 2;
-        ytop = maximum.row - height / 2;
+        xtop = maximum.col - width/2;
+        ytop = maximum.row - height/2;
         kernel = gwy_data_field_area_extract(dfield, xtop, ytop,
                                              width, height);
-        gwy_data_field_multiply(kernel, maximum.zvalue);
-        gwy_data_field_sum_fields(res_kernel, res_kernel, kernel);
+        gwy_data_field_linear_combination(res_kernel,
+                                          1.0, res_kernel,
+                                          maximum.zvalue, kernel,
+                                          0.0);
+        g_object_unref(kernel);
         divider += maximum.zvalue;
     }
     if (divider <= 0.0)
         divider = 1.0;
-    gwy_data_field_multiply(res_kernel, 1.0 / divider);
-    g_object_unref(kernel);
+    gwy_data_field_multiply(res_kernel, 1.0/divider);
 
     result = gwy_data_field_new_alike(dfield, FALSE);
     gwy_data_field_copy(dfield, result, TRUE);
     for (i = 0; i < maxima->len; i++) {
         maximum = g_array_index(maxima, GwyMaximum, i);
-        xtop = maximum.col - width / 2;
-        ytop = maximum.row - height / 2;
+        xtop = maximum.col - width/2;
+        ytop = maximum.row - height/2;
         gwy_data_field_area_copy(res_kernel, result, 0, 0,
                                  width, height, xtop, ytop);
     }
