@@ -1,5 +1,5 @@
 /*
- *  $Id: classify.c 23017 2020-12-23 09:05:30Z yeti-dn $
+ *  $Id: classify.c 23556 2021-04-21 08:00:51Z yeti-dn $
  *  Copyright (C) 2003-2019 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -274,7 +274,7 @@ classify_dialog(GwyContainer *data,
                             GWY_DATA_ITEM_MASK_COLOR,
                             GWY_DATA_ITEM_REAL_SQUARE,
                             0);
-    controls.view = create_preview(controls.mydata, 0, PREVIEW_SIZE, TRUE);
+    controls.view = gwy_create_preview(controls.mydata, 0, PREVIEW_SIZE, TRUE);
     ensure_mask_color(controls.mydata, 0);
     gtk_box_pack_start(GTK_BOX(vbox), controls.view, FALSE, FALSE, 0);
 
