@@ -1,5 +1,5 @@
 /*
- *  $Id: convolution_filter.c 20835 2018-03-13 10:54:57Z yeti-dn $
+ *  $Id: convolution_filter.c 23556 2021-04-21 08:00:51Z yeti-dn $
  *  Copyright (C) 2003 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -257,7 +257,7 @@ convolution_filter_dialog(ConvolutionArgs *args,
                             GWY_DATA_ITEM_PALETTE,
                             GWY_DATA_ITEM_REAL_SQUARE,
                             0);
-    controls.view = create_preview(controls.mydata, 0, PREVIEW_SIZE, FALSE);
+    controls.view = gwy_create_preview(controls.mydata, 0, PREVIEW_SIZE, FALSE);
     gtk_container_add(GTK_CONTAINER(align), controls.view);
 
     notebook = gtk_notebook_new();
