@@ -1,5 +1,5 @@
 /*
- *  $Id: correct_affine.c 22674 2019-11-14 19:08:11Z yeti-dn $
+ *  $Id: correct_affine.c 23556 2021-04-21 08:00:51Z yeti-dn $
  *  Copyright (C) 2013-2017 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -377,7 +377,7 @@ affcor_dialog(AffcorArgs *args,
     alignment = gtk_alignment_new(0.0, 0.0, 0.0, 0.0);
     gtk_box_pack_start(GTK_BOX(hbox), alignment, FALSE, FALSE, 4);
 
-    controls.view = create_preview(controls.mydata, 0, PREVIEW_SIZE, FALSE);
+    controls.view = gwy_create_preview(controls.mydata, 0, PREVIEW_SIZE, FALSE);
     controls.selection = create_vector_layer(GWY_DATA_VIEW(controls.view),
                                              0, "Lattice", TRUE);
     g_object_ref(controls.selection);
