@@ -1,5 +1,5 @@
 /*
- *  $Id: correct_perspective.c 23666 2021-05-10 21:56:10Z yeti-dn $
+ *  $Id: correct_perspective.c 24365 2021-10-13 12:45:57Z yeti-dn $
  *  Copyright (C) 2021 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -137,7 +137,7 @@ define_module_params(void)
     gwy_param_def_add_boolean(paramdef, PARAM_FIXRES, "fixres", _("Specify output _dimensions"), FALSE);
     gwy_param_def_add_int(paramdef, PARAM_XRES, "xres", _("_X resolution"), 2, 32768, 512);
     gwy_param_def_add_int(paramdef, PARAM_YRES, "yres", _("_Y resolution"), 2, 32768, 512);
-    gwy_param_def_add_gwyenum(paramdef, PARAM_IMAGE_MODE, NULL, _("Display"),
+    gwy_param_def_add_gwyenum(paramdef, PARAM_IMAGE_MODE, NULL, gwy_sgettext("verb|Display"),
                               image_modes, G_N_ELEMENTS(image_modes), IMAGE_DATA);
     return paramdef;
 }
