@@ -1,5 +1,5 @@
 /*
- *  $Id: fft_filter_2d.c 22404 2019-08-18 19:59:52Z yeti-dn $
+ *  $Id: fft_filter_2d.c 23557 2021-04-22 07:34:37Z yeti-dn $
  *  Copyright (C) 2005 Christopher Anderson, Molecular Imaging Corp.
  *  E-mail: Chris Anderson (sidewinder.asu@gmail.com)
  *  Copyright (C) 2011 David Necas (Yeti).
@@ -209,7 +209,8 @@ run_main(GwyContainer *data, GwyRunType run)
     fft = gwy_data_field_new_alike(dfield, FALSE);
     do_fft(dfield, fft);
 
-    mfield = create_mask_field(fft);
+    mfield = gwy_data_field_new_alike(fft, TRUE);
+    gwy_si_unit_set_from_string(gwy_data_field_get_si_unit_z(mfield), NULL);
     filtered = gwy_data_field_new_alike(dfield, TRUE);
     diff = gwy_data_field_new_alike(dfield, TRUE);
 
@@ -434,7 +435,7 @@ run_dialog(ControlsType *controls)
     gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox), hbox, TRUE, TRUE, 4);
 
     /* Setup the GwyDataView, base and mask layers */
-    controls->view = create_preview(controls->mydata, 0, PREVIEW_SIZE, TRUE);
+    controls->view = gwy_create_preview(controls->mydata, 0, PREVIEW_SIZE, TRUE);
     controls->view_layer
         = gwy_data_view_get_base_layer(GWY_DATA_VIEW(controls->view));
     controls->mask_layer
