@@ -1,5 +1,5 @@
 /*
- *  $Id: grain_cross.c 22996 2020-12-03 14:06:04Z yeti-dn $
+ *  $Id: grain_cross.c 23599 2021-04-30 22:26:31Z yeti-dn $
  *  Copyright (C) 2007-2019 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -66,14 +66,12 @@ typedef struct {
 static gboolean       module_register           (void);
 static void           grain_cross               (GwyContainer *data,
                                                  GwyRunType run);
-static void           require_same_units_dialog (GwyContainer *data,
-                                                 gint id);
 static gboolean       grain_cross_dialog        (GrainCrossArgs *args,
                                                  GwyDataField *dfield);
 static void           axis_quantity_changed     (GrainCrossControls *controls);
 static void           different_ordinate_changed(GtkToggleButton *toggle,
                                                  GrainCrossControls *controls);
-static gboolean       filter_other_image        (GwyContainer *data,
+static gboolean       other_image_filter        (GwyContainer *data,
                                                  gint id,
                                                  gpointer user_data);
 static void           other_image_changed       (GwyDataChooser *chooser,
@@ -164,7 +162,8 @@ grain_cross(GwyContainer *data, GwyRunType run)
         oflags = gwy_grain_value_get_flags(ordinate);
         if ((aflags | oflags) & GWY_GRAIN_VALUE_SAME_UNITS) {
             if (run == GWY_RUN_IMMEDIATE) {
-                require_same_units_dialog(data, id);
+                gwy_require_image_same_units(dfield, data, id,
+                                             _("Grain Correlations"));
                 return;
             }
 
@@ -193,25 +192,6 @@ grain_cross(GwyContainer *data, GwyRunType run)
     g_free(args.grains);
 }
 
-static void
-require_same_units_dialog(GwyContainer *data, gint id)
-{
-    GtkWidget *dialog;
-
-    dialog = gtk_message_dialog_new(gwy_app_find_window_for_channel(data, id),
-                                    GTK_DIALOG_DESTROY_WITH_PARENT,
-                                    GTK_MESSAGE_ERROR,
-                                    GTK_BUTTONS_OK,
-                                    _("Grain correlation: Lateral dimensions "
-                                      "and value must be the same physical "
-                                      "quantity for the selected grain "
-                                      "properties."));
-    gtk_dialog_run(GTK_DIALOG(dialog));
-    gtk_widget_destroy(dialog);
-
-    return;
-}
-
 static gboolean
 grain_cross_dialog(GrainCrossArgs *args,
                    GwyDataField *dfield)
@@ -279,7 +259,7 @@ grain_cross_dialog(GrainCrossArgs *args,
     controls.other_image = gwy_data_chooser_new_channels();
     chooser = GWY_DATA_CHOOSER(controls.other_image);
     gwy_data_chooser_set_active(chooser, NULL, -1);
-    gwy_data_chooser_set_filter(chooser, filter_other_image, dfield, NULL);
+    gwy_data_chooser_set_filter(chooser, other_image_filter, dfield, NULL);
     gwy_data_chooser_set_active_id(chooser, &args->other_image);
     if (!gwy_data_chooser_get_active_id(chooser, &args->other_image))
         gtk_widget_set_sensitive(controls.different_ordinate, FALSE);
@@ -382,7 +362,7 @@ different_ordinate_changed(GtkToggleButton *toggle,
 }
 
 static gboolean
-filter_other_image(GwyContainer *data, gint id, gpointer user_data)
+other_image_filter(GwyContainer *data, gint id, gpointer user_data)
 {
     GwyDataField *dfield = (GwyDataField*)user_data, *otherfield;
     GQuark quark = gwy_app_get_data_key_for_id(id);
