@@ -1,5 +1,5 @@
 /*
- *  $Id: immerse.c 23766 2021-05-24 15:48:55Z yeti-dn $
+ *  $Id: immerse.c 24450 2021-11-01 14:32:53Z yeti-dn $
  *  Copyright (C) 2004-2021 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -210,6 +210,7 @@ immerse(GwyContainer *data, GwyRunType runtype)
 
     args.params = gwy_params_new_from_settings(define_module_params());
     outcome = run_gui(&args, data, id);
+    gwy_params_save_to_settings(args.params);
     if (outcome == GWY_DIALOG_CANCEL)
         goto end;
 
@@ -727,7 +728,7 @@ immerse_view_inside_detail(ModuleGUI *gui, gint x, gint y)
     gwy_data_view_coords_real_to_xy(GWY_DATA_VIEW(gui->view), xpos, ypos, &xoff, &yoff);
     w = gdk_pixbuf_get_width(gui->detail);
     h = gdk_pixbuf_get_height(gui->detail);
-    return (x >= xoff && x < xoff + w && y >= yoff && y < yoff + h);
+    return x >= xoff && x < xoff + w && y >= yoff && y < yoff + h;
 }
 
 static void
