@@ -1,5 +1,5 @@
 /*
- *  $Id: indent_analyze.c 22876 2020-07-07 21:09:56Z klapetek $
+ *  $Id: indent_analyze.c 23845 2021-06-11 14:56:00Z yeti-dn $
  *  Copyright (C) 2006 Lukas Chvatal, David Necas (Yeti), Petr Klapetek.
  *  E-mail: chvatal@physics.muni.cz, yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -49,12 +49,6 @@ enum {
     GWY_PLANE_ROTATE
 };
 
-typedef enum {
-    NORMAL,
-    CENTRAL,
-    DIRECTION
-} FloodFillMode;
-
 enum {
     GWY_HOW_MARK_NEW = 0,
     GWY_HOW_MARK_AND,
@@ -105,10 +99,6 @@ typedef struct {
                            of max-min */
     gdouble phi_tol;
 
-    gdouble plane_x;
-    gdouble plane_y;
-    gdouble plane_c;
-
     gdouble volume_above;
     gdouble volume_below;
     gdouble area_above;
@@ -182,10 +172,8 @@ typedef struct {
 } IndentAnalyzeControls;
 
 typedef struct {
-    FloodFillMode mode;
-    GwyVec v;                /* normal, direction or (centre-position) vector */
-    gdouble cos_t1, cos_t2;
-    gdouble cos_f1, cos_f2;
+    GwyVec v;                /* normal vector */
+    gdouble cos_f1;
     gint seed;               /* side of averaging sqare */
 } FloodFillInfo;
 
@@ -206,10 +194,6 @@ static void indentor_changed_cb(GtkWidget *item,
 static void set_mask_at(GwyDataField *mask, gint x, gint y, gdouble m,
                         gint how);
 static void level_data(IndentAnalyzeControls *c);
-static void gwy_data_field_get_min_pos(GwyDataField *dfield, gdouble *min, gint *posx,
-                            gint *posy);
-static void gwy_data_field_get_max_pos(GwyDataField *dfield, gdouble *max, gint *posx,
-                            gint *posy);
 static void data_field_average_normal_vector(GwyDataField *dfield, gint x,
                                              gint y, gint r, GwyVec *vec);
 static gdouble data_field_compute_ds(GwyDataField *dfield, gint x_pos,
@@ -235,12 +219,8 @@ static void sanitize_args(IndentAnalyzeArgs * args);
 
 static GwyVec gwy_vec_cross(GwyVec v1, GwyVec v2);
 static gdouble gwy_vec_dot(GwyVec v1, GwyVec v2);
-static GwyVec gwy_vec_times(GwyVec v, gdouble c);
 static gdouble gwy_vec_abs(GwyVec v);
-//static gdouble gwy_vec_arg_phi(GwyVec v);
-//static gdouble gwy_vec_arg_theta(GwyVec v);
 static gdouble gwy_vec_cos(GwyVec v1, GwyVec v2);
-static void gwy_vec_normalize(GwyVec *v);
 
 GwyEnum plane_correct_enum[] = {
     { N_("Do nothing"),   GWY_PLANE_NONE   },
@@ -285,9 +265,9 @@ GwyEnum indentor_enum[] = {
 static GwyModuleInfo module_info = {
     GWY_MODULE_ABI_VERSION,
     (GwyModuleRegisterFunc) &module_register,
-    N_("Analyses nanoindentation structure (volumes, surfaces, ...)."),
+    N_("Analyzes nanoindentation structure (volumes, surfaces, ...)."),
     "Lukáš Chvátal <chvatal@physics.muni.cz>",
-    "0.1.5",
+    "0.2",
     "Lukáš Chvátal",
     "2005",
 };
@@ -303,9 +283,7 @@ module_register(void)
                               GWY_STOCK_TIP_INDENT_ANALYZE,
                               INDENT_ANALYZE_RUN_MODES,
                               GWY_MENU_FLAG_DATA,
-                              /* XXX: Make it translatable once there's some
-                               * actual tooltip text. */
-                              "");
+                              _("Analyze indentation imprint"));
 
     return TRUE;
 }
@@ -356,7 +334,8 @@ create_preview_data(IndentAnalyzeControls *controls)
       dfield = gwy_data_field_duplicate(dfield);
 
       gwy_container_set_object_by_name(preview_container, "/0/data", dfield);
-      mask = create_mask_field(dfield);
+      mask = gwy_data_field_new_alike(dfield, TRUE);
+      gwy_si_unit_set_from_string(gwy_data_field_get_si_unit_z(mask), NULL);
       gwy_data_field_clear(mask);
       g_object_unref(dfield);
       gwy_container_set_object_by_name(preview_container, "/0/mask", mask);
@@ -642,67 +621,6 @@ indent_analyze_dialog(GwyContainer *data, IndentAnalyzeArgs * args)
 }
 
 
-static void
-get_field_slope_from_border(GwyDataField *dfield, gdouble *c, gdouble *bx,
-                            gdouble *by)
-{
-    gint size = 20;
-    gdouble cc;
-
-    gwy_data_field_area_fit_plane(dfield, NULL, 0, 0, dfield->xres - 1, size,
-                                  &cc, bx, NULL);
-    gwy_data_field_area_fit_plane(dfield, NULL, 0, 0, size, dfield->yres - 1,
-                                  c, NULL, by);
-    *c = (*c + cc)/2;
-}
-
-
-static void
-gwy_data_field_get_min_pos(GwyDataField *dfield,
-                           gdouble *min,
-                           gint *posx, gint *posy)
-{
-    gdouble mm = G_MAXDOUBLE;
-    const gdouble *data, *m;
-    gint i, xres, yres;
-
-    data = m = gwy_data_field_get_data_const(dfield);
-    xres = gwy_data_field_get_xres(dfield);
-    yres = gwy_data_field_get_yres(dfield);
-    for (i = xres*yres; i; i--, data++) {
-        if (G_UNLIKELY(*data < mm)) {
-            mm = *data;
-            m = data;
-        }
-    }
-    *min = mm;
-    *posx = (m - gwy_data_field_get_data_const(dfield)) % xres;
-    *posy = (m - gwy_data_field_get_data_const(dfield))/xres;
-}
-
-static void
-gwy_data_field_get_max_pos(GwyDataField *dfield,
-                           gdouble *max,
-                           gint *posx, gint *posy)
-{
-    gdouble mm = -G_MAXDOUBLE;
-    const gdouble *data, *m;
-    gint i, xres, yres;
-
-    data = m = gwy_data_field_get_data_const(dfield);
-    xres = gwy_data_field_get_xres(dfield);
-    yres = gwy_data_field_get_yres(dfield);
-    for (i = xres*yres; i; i--, data++) {
-        if (G_UNLIKELY(*data > mm)) {
-            mm = *data;
-            m = data;
-        }
-    }
-    *max = mm;
-    *posx = (m - gwy_data_field_get_data_const(dfield)) % xres;
-    *posy = (m - gwy_data_field_get_data_const(dfield))/xres;
-}
-
 static gdouble
 data_field_compute_ds(GwyDataField *dfield, gint x_pos, gint y_pos)
 {
@@ -794,22 +712,17 @@ set_mask_at(GwyDataField *mask, gint x, gint y, gdouble m, gint how)
 void
 level_data(IndentAnalyzeControls *c)
 {
-    gint iter = 3;
-    IndentAnalyzeArgs *args = c->args;
-    GwyDataField *dfield =
-        GWY_DATA_FIELD(gwy_container_get_object_by_name(c->mydata, "/0/data"));
-
-    get_field_slope_from_border(dfield, &(args->plane_c), &(args->plane_x),
-                                &(args->plane_y));
-
-
-    while (iter--) {
-        gwy_data_field_plane_level(dfield, args->plane_c, args->plane_x,
-                                   args->plane_y);
-        get_field_slope_from_border(dfield, &(args->plane_c), &(args->plane_x),
-                                    &(args->plane_y));
-    }
+    GwyDataField *dfield = GWY_DATA_FIELD(gwy_container_get_object_by_name(c->mydata, "/0/data"));
+    GwyDataField *mask = gwy_data_field_new_alike(dfield, TRUE);
+    gint xres = gwy_data_field_get_xres(dfield);
+    gint yres = gwy_data_field_get_yres(dfield);
+    gint wx = MAX(1, xres/12), wy = MAX(1, yres/12);
+    gdouble bx, by, a;
 
+    gwy_data_field_area_fill(mask, wx, wy, xres - 2*wx, yres - 2*wy, 1.0);
+    gwy_data_field_area_fit_plane_mask(dfield, mask, GWY_MASK_EXCLUDE, 0, 0, xres, yres, &a, &bx, &by);
+    gwy_data_field_plane_level(dfield, a, bx, by);
+    g_object_unref(mask);
 }
 
 typedef struct {
@@ -831,13 +744,10 @@ indentmask_flood_fill(GwyDataField *indentmask, gint i, gint j,
                       GwyDataField *dfield, FloodFillInfo * ffi)
 {
    gint test = 0;
-   gdouble c_f, c_t;
+   gdouble c_f;
    gint dfield_xres = gwy_data_field_get_xres(dfield);
    gint dfield_yres = gwy_data_field_get_yres(dfield);
    GwyVec v;
-   GwyVec e_z = { 0, 0, 1 };
-   GwyVec r;
-   GwyVec tmp;
    FFPoint *pq; /* points queue */
    FFPoint *tail, *head; /* head points on free position */
 
@@ -854,32 +764,9 @@ indentmask_flood_fill(GwyDataField *indentmask, gint i, gint j,
    while (head != tail) {
       data_field_average_normal_vector(dfield, tail->x, tail->y, ffi->seed, &v);
       test = 0;
-      switch (ffi->mode) {
-         case NORMAL:
-            c_f = gwy_vec_cos(v, ffi->v);
-            if ((c_f >= ffi->cos_f1) && (c_f <= ffi->cos_f2))
-               test = 1;
-            break;
-         case DIRECTION:
-            c_f = gwy_vec_cos(v, e_z);
-            v.z = 0;
-            c_t = gwy_vec_cos(v, ffi->v);
-            if ((c_f >= ffi->cos_f1) && (c_f <= ffi->cos_f2) && (c_t
-                  >= ffi->cos_t1) && (c_t <= ffi->cos_t2))
-               test = 1;
-            break;
-         case CENTRAL:
-            r.x = ffi->v.x - tail->x;
-            r.y = ffi->v.y - tail->y;
-            r.z = 0;
-            gwy_vec_normalize(&r);
-            tmp = gwy_vec_times(r, gwy_vec_dot(v, r));
-            tmp.z = v.z;
-            c_f = gwy_vec_cos(tmp, r);
-            if ((c_f >= ffi->cos_f1) && (c_f <= ffi->cos_f2))
-               test = 1;
-            break;
-      }
+      c_f = gwy_vec_cos(v, ffi->v);
+      if (c_f >= ffi->cos_f1)
+          test = 1;
 
       if (test) {
          gint rr, s;
@@ -952,7 +839,7 @@ indent_analyze_do_the_hard_work(IndentAnalyzeControls * controls)
     GwyDataLine *derdist;
 
     gdouble mark_it = 0.0;
-    gint i, j;
+    gint xres, yres, i, j;
     gdouble dx, dy, ds;
     gdouble sx;
     gdouble sy;
@@ -996,10 +883,15 @@ indent_analyze_do_the_hard_work(IndentAnalyzeControls * controls)
             break;
     }
 
-    gwy_data_field_get_min_pos(dfield, &args->min_val,
-                               &args->minx, &args->miny);
-    gwy_data_field_get_max_pos(dfield, &args->max_val,
-                               &args->maxx, &args->maxy);
+    xres = gwy_data_field_get_xres(dfield);
+    yres = gwy_data_field_get_yres(dfield);
+    gwy_data_field_get_local_maxima_list(dfield, &sx, &sy, &args->max_val, 1, 1, -G_MAXDOUBLE, FALSE);
+    args->maxx = GWY_ROUND(sx);
+    args->maxy = GWY_ROUND(sy);
+    gwy_data_field_get_local_minima_list(dfield, &sx, &sy, &args->min_val, 1, 1, -G_MAXDOUBLE, FALSE);
+    args->minx = GWY_ROUND(sx);
+    args->miny = GWY_ROUND(sy);
+
     if (args->what_mark == GWY_WHAT_MARK_POINTS) {
        gwy_data_field_area_fill(mask, args->minx - 2, args->miny - 2, 4, 4, 1.0);
        gwy_data_field_area_fill(mask, args->maxx - 2, args->maxy - 2, 4, 4, 1.0);
@@ -1043,11 +935,10 @@ indent_analyze_do_the_hard_work(IndentAnalyzeControls * controls)
         height = -1e10;
         side_r = 0;
         while (height < SURE_IMPRESSION_COEFF * args->min_val) {
-
-            sx = args->minx - side_r * cos(side_dir +
-                                           i * 2 * G_PI/args->nof_sides);
-            sy = args->miny - side_r * sin(side_dir +
-                                           i * 2 * G_PI/args->nof_sides);
+            sx = args->minx - side_r * cos(side_dir + i * 2 * G_PI/args->nof_sides);
+            sy = args->miny - side_r * sin(side_dir + i * 2 * G_PI/args->nof_sides);
+            if (sx < 0 || sx >= xres || sy < 0 || sy >= yres)
+                break;
             height = gwy_data_field_get_val(dfield, sx, sy);
             side_r++;
         }
@@ -1057,19 +948,16 @@ indent_analyze_do_the_hard_work(IndentAnalyzeControls * controls)
 
         }
         else {
-            ffi.mode = NORMAL;
             ffi.cos_f1 = cos_phi_tol;
-            ffi.cos_f2 = 1.0;
             ffi.v = avg_vec[i];
             ffi.seed = 2;
-            indentmask_flood_fill(indentmask, ROUND(sx), ROUND(sy), dfield,
-                                  &ffi);
+            indentmask_flood_fill(indentmask, GWY_ROUND(sx), GWY_ROUND(sy), dfield, &ffi);
         }
     }
 
     /* we do not expect we should use the last coords...ensurance for computing vectors for surface */
-    for (i = 1; i < dfield->xres - 1; i++) {
-        for (j = 1; j < dfield->yres - 1; j++) {
+    for (i = 1; i < xres - 1; i++) {
+        for (j = 1; j < yres - 1; j++) {
             height = gwy_data_field_get_val(dfield, i, j);
             mark_it = 0;
 
@@ -1569,51 +1457,16 @@ gwy_vec_dot(GwyVec v1, GwyVec v2)
     return v1.x * v2.x + v1.y * v2.y + v1.z * v2.z;
 }
 
-GwyVec
-gwy_vec_times(GwyVec v, gdouble c)
-{
-    GwyVec v1;
-
-    v1.x = v.x * c;
-    v1.y = v.y * c;
-    v1.z = v.z * c;
-
-    return v1;
-}
-
 gdouble
 gwy_vec_abs(GwyVec v)
 {
     return sqrt(gwy_vec_dot(v, v));
 }
 
-/*
-gdouble
-gwy_vec_arg_phi(GwyVec v)
-{
-    return atan2(v.z, v.x);
-}
-
-gdouble
-gwy_vec_arg_theta(GwyVec v)
-{
-    return atan2(v.y, v.x);
-}
-*/
 gdouble
 gwy_vec_cos(GwyVec v1, GwyVec v2)
 {
     return (gwy_vec_dot(v1, v2)/(gwy_vec_abs(v1) * gwy_vec_abs(v2)));
 }
 
-void
-gwy_vec_normalize(GwyVec * v)
-{
-    gdouble vabs = gwy_vec_abs(*v);
-
-    v->x /= vabs;
-    v->y /= vabs;
-    v->z /= vabs;
-}
-
 /* vim: set cin et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
