@@ -1,5 +1,5 @@
 /*
- *  $Id: level.c 23666 2021-05-10 21:56:10Z yeti-dn $
+ *  $Id: level.c 24463 2021-11-05 10:09:13Z yeti-dn $
  *  Copyright (C) 2003-2021 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -41,17 +41,13 @@ static GwyDialogOutcome run_gui             (GwyParams *params,
 static void             level_func          (GwyContainer *data,
                                              GwyRunType run,
                                              const gchar *funcname);
-static void             fix_zero            (GwyContainer *data,
-                                             GwyRunType run);
-static void             max_zero            (GwyContainer *data,
-                                             GwyRunType run);
 
 static GwyModuleInfo module_info = {
     GWY_MODULE_ABI_VERSION,
     &module_register,
     N_("Levels data by simple plane subtraction or by rotation, and fixes minimal or mean value to zero."),
     "Yeti <yeti@gwyddion.net>",
-    "3.0",
+    "3.1",
     "David Nečas (Yeti) & Petr Klapetek",
     "2003",
 };
@@ -76,7 +72,7 @@ module_register(void)
                               GWY_MENU_FLAG_DATA,
                               N_("Automatically level data by plane rotation"));
     gwy_process_func_register("fix_zero",
-                              (GwyProcessFunc)&fix_zero,
+                              &level_func,
                               N_("/_Level/Fix _Zero"),
                               GWY_STOCK_FIX_ZERO,
                               RUN_MODES,
@@ -90,7 +86,7 @@ module_register(void)
                               GWY_MENU_FLAG_DATA,
                               N_("Shift mean data value to zero"));
     gwy_process_func_register("zero_max",
-                              (GwyProcessFunc)&max_zero,
+                              &level_func,
                               N_("/_Level/Zero Ma_ximum Value"),
                               NULL,
                               RUN_MODES,
@@ -179,6 +175,13 @@ level_func(GwyContainer *data,
         }
         GWY_OBJECT_UNREF(mask);
     }
+    else if (gwy_strequal(funcname, "fix_zero")) {
+        if (mask)
+            gwy_data_field_area_get_min_max_mask(dfield, mask, masking, 0, 0, xres, yres, &c, NULL);
+        else
+            c = gwy_data_field_get_min(dfield);
+        gwy_data_field_add(dfield, -c);
+    }
     else if (gwy_strequal(funcname, "zero_mean")) {
         if (mask)
             c = gwy_data_field_area_get_avg_mask(dfield, mask, masking, 0, 0, xres, yres);
@@ -186,6 +189,13 @@ level_func(GwyContainer *data,
             c = gwy_data_field_get_avg(dfield);
         gwy_data_field_add(dfield, -c);
     }
+    else if (gwy_strequal(funcname, "zero_max")) {
+        if (mask)
+            gwy_data_field_area_get_min_max_mask(dfield, mask, masking, 0, 0, xres, yres, NULL, &c);
+        else
+            c = gwy_data_field_get_max(dfield);
+        gwy_data_field_add(dfield, -c);
+    }
     else {
         g_assert_not_reached();
     }
@@ -208,14 +218,18 @@ run_gui(GwyParams *params, const gchar *funcname)
         title = _("Plane Level");
     else if (gwy_strequal(funcname, "level_rotate"))
         title = _("Level Rotate");
+    else if (gwy_strequal(funcname, "fix_zero"))
+        title = _("Fix Zero");
     else if (gwy_strequal(funcname, "zero_mean"))
         title = _("Zero Mean Value");
+    else if (gwy_strequal(funcname, "zero_max"))
+        title = _("Zero Maximum Value");
     else {
         g_assert_not_reached();
     }
 
     dialog = GWY_DIALOG(gwy_dialog_new(title));
-    gwy_dialog_add_buttons(dialog, GWY_RESPONSE_RESET, GTK_RESPONSE_CANCEL, GTK_RESPONSE_OK, 0);
+    gwy_dialog_add_buttons(dialog, GTK_RESPONSE_CANCEL, GTK_RESPONSE_OK, 0);
     table = gwy_param_table_new(params);
     gwy_param_table_append_radio(table, PARAM_MASKING);
     gwy_dialog_add_content(dialog, gwy_param_table_widget(table), FALSE, FALSE, 0);
@@ -224,42 +238,4 @@ run_gui(GwyParams *params, const gchar *funcname)
     return gwy_dialog_run(dialog);
 }
 
-static void
-fix_zero(GwyContainer *data, GwyRunType run)
-{
-    GwyDataField *dfield;
-    GQuark quark;
-    gint id;
-
-    g_return_if_fail(run & RUN_MODES);
-    gwy_app_data_browser_get_current(GWY_APP_DATA_FIELD_KEY, &quark,
-                                     GWY_APP_DATA_FIELD, &dfield,
-                                     GWY_APP_DATA_FIELD_ID, &id,
-                                     0);
-    g_return_if_fail(dfield && quark);
-    gwy_app_undo_qcheckpoint(data, quark, NULL);
-    gwy_data_field_add(dfield, -gwy_data_field_get_min(dfield));
-    gwy_app_channel_log_add_proc(data, id, id);
-    gwy_data_field_data_changed(dfield);
-}
-
-static void
-max_zero(GwyContainer *data, GwyRunType run)
-{
-    GwyDataField *dfield;
-    GQuark quark;
-    gint id;
-
-    g_return_if_fail(run & RUN_MODES);
-    gwy_app_data_browser_get_current(GWY_APP_DATA_FIELD_KEY, &quark,
-                                     GWY_APP_DATA_FIELD, &dfield,
-                                     GWY_APP_DATA_FIELD_ID, &id,
-                                     0);
-    g_return_if_fail(dfield && quark);
-    gwy_app_undo_qcheckpoint(data, quark, NULL);
-    gwy_data_field_add(dfield, -gwy_data_field_get_max(dfield));
-    gwy_app_channel_log_add_proc(data, id, id);
-    gwy_data_field_data_changed(dfield);
-}
-
 /* vim: set cin columns=120 tw=118 et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
