@@ -1,5 +1,5 @@
 /*
- *  $Id: linecorrect.c 21371 2018-08-30 13:35:21Z yeti-dn $
+ *  $Id: linecorrect.c 22817 2020-05-14 07:05:40Z yeti-dn $
  *  Copyright (C) 2003-2018 David Necas (Yeti), Petr Klapetek, Luke Somers.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net, lsomers@sas.upenn.edu.
  *
@@ -53,7 +53,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Corrects line defects (mostly experimental algorithms)."),
     "Yeti <yeti@gwyddion.net>, Luke Somers <lsomers@sas.upenn.edu>",
-    "1.11",
+    "1.12",
     "David Nečas (Yeti) & Petr Klapetek & Luke Somers",
     "2004",
 };
@@ -173,6 +173,7 @@ line_correct_step(GwyContainer *data,
     GwyDataField *dfield, *mask;
     GwyDataLine *shifts;
     GQuark dquark;
+    gdouble avg;
     gint id;
 
     g_return_if_fail(run & LINECORR_RUN_MODES);
@@ -183,6 +184,7 @@ line_correct_step(GwyContainer *data,
     g_return_if_fail(dfield && dquark);
     gwy_app_undo_qcheckpointv(data, 1, &dquark);
 
+    avg = gwy_data_field_get_avg(dfield);
     shifts = gwy_data_field_find_row_shifts_trimmed_mean(dfield,
                                                          NULL, GWY_MASK_IGNORE,
                                                          0.5, 0);
@@ -196,6 +198,7 @@ line_correct_step(GwyContainer *data,
     g_object_unref(mask);
 
     gwy_data_field_filter_conservative(dfield, 5);
+    gwy_data_field_add(dfield, avg - gwy_data_field_get_avg(dfield));
     gwy_data_field_data_changed(dfield);
     gwy_app_channel_log_add_proc(data, id, id);
 }
