@@ -1,5 +1,5 @@
 /*
- *  $Id: mfm_current.c 21082 2018-05-08 13:20:36Z yeti-dn $
+ *  $Id: mfm_current.c 23811 2021-06-08 12:12:43Z yeti-dn $
  *  Copyright (C) 2017 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -31,6 +31,7 @@
 #include <libgwydgets/gwyradiobuttons.h>
 #include <libgwydgets/gwystock.h>
 #include <libgwymodule/gwymodule-process.h>
+#include <app/gwymoduleutils-synth.h>
 #include <app/gwyapp.h>
 #include "preview.h"
 #include "dimensions.h"
@@ -355,11 +356,11 @@ mfm_current_dialog(MfmCurrentArgs *args,
         gwy_app_sync_data_items(data, controls.mydata, id, 0, FALSE,
                                 GWY_DATA_ITEM_PALETTE,
                                 0);
-        controls.surface = gwy_synth_surface_for_preview(dfield_template,
-                                                         PREVIEW_SIZE);
+        controls.surface = gwy_synth_make_preview_data_field(dfield_template,
+                                                             PREVIEW_SIZE);
         controls.zscale = gwy_data_field_get_rms(dfield_template);
     }
-    controls.view = create_preview(controls.mydata, 0, PREVIEW_SIZE, FALSE);
+    controls.view = gwy_create_preview(controls.mydata, 0, PREVIEW_SIZE, FALSE);
     gtk_box_pack_start(GTK_BOX(vbox), controls.view, FALSE, FALSE, 0);
 
     gtk_box_pack_start(GTK_BOX(vbox),
