@@ -1,5 +1,5 @@
 /*
- *  $Id: mfm_field.c 22587 2019-10-20 08:06:42Z yeti-dn $
+ *  $Id: mfm_field.c 23556 2021-04-21 08:00:51Z yeti-dn $
  *  Copyright (C) 2003-2018 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -328,7 +328,7 @@ mfm_field_dialog(MfmFieldArgs *args, GwyContainer *data)
                             GWY_DATA_ITEM_RANGE,
                             GWY_DATA_ITEM_REAL_SQUARE,
                             0);
-    controls.view = create_preview(controls.mydata, 0, PREVIEW_SIZE, TRUE);
+    controls.view = gwy_create_preview(controls.mydata, 0, PREVIEW_SIZE, TRUE);
     gtk_box_pack_start(GTK_BOX(hbox), controls.view, FALSE, FALSE, 4);
 
     table = gtk_table_new(13, 3, FALSE);
