@@ -1,5 +1,5 @@
 /*
- *  $Id: multiprofile.c 23666 2021-05-10 21:56:10Z yeti-dn $
+ *  $Id: multiprofile.c 24365 2021-10-13 12:45:57Z yeti-dn $
  *  Copyright (C) 2020-2021 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -155,7 +155,7 @@ define_module_params(void)
     gwy_param_def_add_gwyenum(paramdef, PARAM_MODE, "mode", _("_Mode"),
                               modes, G_N_ELEMENTS(modes), MULTIPROF_MODE_PROFILES);
     gwy_param_def_add_target_graph(paramdef, PARAM_TARGET_GRAPH, "target_graph", NULL);
-    gwy_param_def_add_int(paramdef, PARAM_DISPLAY, NULL, _("Display"), 0, NARGS-1, 0);
+    gwy_param_def_add_int(paramdef, PARAM_DISPLAY, NULL, gwy_sgettext("verb|Display"), 0, NARGS-1, 0);
     /* The strings must be static so just ‘leak’ them. */
     for (i = 0; i < NARGS; i++) {
         gwy_param_def_add_image_id(paramdef, PARAM_IMAGE_0 + i,
