@@ -1,5 +1,5 @@
 /*
- *  $Id: neural.c 22887 2020-07-28 09:00:14Z yeti-dn $
+ *  $Id: neural.c 23556 2021-04-21 08:00:51Z yeti-dn $
  *  Copyright (C) 2012 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -485,7 +485,7 @@ neural_train_dialog(NeuralTrainArgs *args)
     vbox = gtk_vbox_new(FALSE, 4);
     gtk_box_pack_start(GTK_BOX(hbox), vbox, TRUE, TRUE, 4);
 
-    controls.view = create_preview(mydata, 0, PREVIEW_SMALL_SIZE, FALSE);
+    controls.view = gwy_create_preview(mydata, 0, PREVIEW_SMALL_SIZE, FALSE);
     gtk_box_pack_start(GTK_BOX(vbox), controls.view, FALSE, FALSE, 0);
 
     controls.gmodel = gwy_graph_model_new();
@@ -1058,8 +1058,7 @@ outunits_changed(NeuralTrainControls *controls, GtkEntry *entry)
     NeuralNetworkData *nndata = &controls->args->nn->data;
     if (controls->in_update)
         return;
-    g_free(nndata->outunits);
-    nndata->outunits = g_strdup(gtk_entry_get_text(entry));
+    gwy_assign_string(&nndata->outunits, gtk_entry_get_text(entry));
     GWY_RESOURCE(controls->args->nn)->is_modified = TRUE;
 }
 
@@ -1650,8 +1649,7 @@ static void
 neural_apply_sanitize_args(NeuralApplyArgs *args)
 {
     if (!gwy_inventory_get_item(gwy_neural_networks(), args->name)) {
-        g_free(args->name);
-        args->name = g_strdup(GWY_NEURAL_NETWORK_UNTITLED);
+        gwy_assign_string(&args->name, GWY_NEURAL_NETWORK_UNTITLED);
     }
     args->scale_output = !!args->scale_output;
 }
