@@ -1,5 +1,5 @@
 /*
- *  $Id: pid.c 23846 2021-06-11 14:58:40Z yeti-dn $
+ *  $Id: pid.c 24365 2021-10-13 12:45:57Z yeti-dn $
  *  Copyright (C) 2012-2021 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -146,7 +146,7 @@ define_module_params(void)
     gwy_param_def_add_int(paramdef, PARAM_TAU, "tau", _("_Integration steps"), 2, 1000, 100);
     gwy_param_def_add_double(paramdef, PARAM_FSTRENGTH, "fstrength", _("Force strength"), 0.0, 1000.0, 1.0);
     gwy_param_def_add_double(paramdef, PARAM_FSETPOINT, "fsetpoint", _("Force setpoint"), 0.0, 1000.0, 10.0);
-    gwy_param_def_add_gwyenum(paramdef, PARAM_DISPLAY, "display", _("Display"),
+    gwy_param_def_add_gwyenum(paramdef, PARAM_DISPLAY, "display", gwy_sgettext("verb|Display"),
                               displays, G_N_ELEMENTS(displays), DISPLAY_DATA);
     gwy_param_def_add_gwyflags(paramdef, PARAM_OUTPUT, "output", _("Output"),
                                outputs, G_N_ELEMENTS(outputs), (1 << OUTPUT_NTYPES)-1);
