@@ -1,5 +1,5 @@
 /*
- *  $Id: polylevel.c 23854 2021-06-14 16:36:54Z yeti-dn $
+ *  $Id: polylevel.c 23985 2021-08-16 12:27:37Z yeti-dn $
  *  Copyright (C) 2004-2021 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -94,7 +94,7 @@ static gchar*           format_coefficient          (ModuleGUI *gui,
 static void             save_coeffs                 (ModuleGUI *gui);
 static void             copy_coeffs                 (ModuleGUI *gui);
 static gchar*           create_report               (ModuleGUI *gui);
-static void             sanitise_params             (GwyParams *params);
+static void             sanitise_params             (ModuleArgs *args);
 
 /* We have just two modes distinguished by TRUE/FALSE, but technically it is an enum and we could have more modes. */
 static const GwyEnum types[] = {
@@ -169,7 +169,7 @@ poly_level(GwyContainer *data, GwyRunType runtype)
 
     args.bg = args.result = NULL;
     args.params = gwy_params_new_from_settings(define_module_params());
-    sanitise_params(args.params);
+    sanitise_params(&args);
 
     if (runtype == GWY_RUN_INTERACTIVE) {
         GwyDialogOutcome outcome = run_gui(&args, data, oldid);
@@ -660,8 +660,9 @@ create_report(ModuleGUI *gui)
 }
 
 static void
-sanitise_params(GwyParams *params)
+sanitise_params(ModuleArgs *args)
 {
+    GwyParams *params = args->params;
     if (gwy_params_get_int(params, PARAM_ROW_DEGREE) != gwy_params_get_int(params, PARAM_COL_DEGREE))
         gwy_params_set_boolean(params, PARAM_SAME_DEGREE, FALSE);
 }
