@@ -1,5 +1,5 @@
 /*
- *  $Id: preview.h 23006 2020-12-09 15:36:50Z yeti-dn $
+ *  $Id: preview.h 23557 2021-04-22 07:34:37Z yeti-dn $
  *  Copyright (C) 2015-2017 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -44,16 +44,16 @@ enum {
 };
 
 enum {
-    RESPONSE_RESET     = 1,
-    RESPONSE_PREVIEW   = 2,
-    RESPONSE_CLEAR     = 3,
-    RESPONSE_INIT      = 4,
-    RESPONSE_ESTIMATE  = 5,
-    RESPONSE_REFINE    = 6,
-    RESPONSE_CALCULATE = 7,
-    RESPONSE_LOAD      = 8,
-    RESPONSE_SAVE      = 9,
-    RESPONSE_COPY      = 10,
+    RESPONSE_RESET     = 101,
+    RESPONSE_PREVIEW   = 102,
+    RESPONSE_CLEAR     = 103,
+    RESPONSE_INIT      = 104,
+    RESPONSE_ESTIMATE  = 105,
+    RESPONSE_REFINE    = 106,
+    RESPONSE_CALCULATE = 107,
+    RESPONSE_LOAD      = 108,
+    RESPONSE_SAVE      = 109,
+    RESPONSE_COPY      = 110,
 };
 
 typedef struct {
@@ -62,42 +62,6 @@ typedef struct {
     gpointer filter_data;
 } TargetGraphFilterData;
 
-G_GNUC_UNUSED
-static GwyPixmapLayer*
-create_basic_layer(GwyDataView *dataview, gint id)
-{
-    GwyPixmapLayer *layer = gwy_layer_basic_new();
-    GQuark quark = gwy_app_get_data_key_for_id(id);
-    const gchar *key = g_quark_to_string(quark);
-    gchar buf[24];
-
-    gwy_pixmap_layer_set_data_key(layer, key);
-    key = g_quark_to_string(gwy_app_get_data_palette_key_for_id(id));
-    gwy_layer_basic_set_gradient_key(GWY_LAYER_BASIC(layer), key);
-    key = g_quark_to_string(gwy_app_get_data_range_type_key_for_id(id));
-    gwy_layer_basic_set_range_type_key(GWY_LAYER_BASIC(layer), key);
-    g_snprintf(buf, sizeof(buf), "/%d/base", id);
-    gwy_layer_basic_set_min_max_key(GWY_LAYER_BASIC(layer), buf);
-    gwy_data_view_set_base_layer(dataview, layer);
-
-    return layer;
-}
-
-G_GNUC_UNUSED
-static GwyPixmapLayer*
-create_mask_layer(GwyDataView *dataview, gint id)
-{
-    GwyPixmapLayer *layer = gwy_layer_mask_new();
-    GQuark quark = gwy_app_get_mask_key_for_id(id);
-    const gchar *key = g_quark_to_string(quark);
-
-    gwy_pixmap_layer_set_data_key(layer, key);
-    gwy_layer_mask_set_color_key(GWY_LAYER_MASK(layer), key);
-    gwy_data_view_set_alpha_layer(dataview, layer);
-
-    return layer;
-}
-
 G_GNUC_UNUSED
 static GwySelection*
 create_vector_layer(GwyDataView *dataview, gint id, const gchar *name,
@@ -127,27 +91,6 @@ create_vector_layer(GwyDataView *dataview, gint id, const gchar *name,
     return gwy_vector_layer_ensure_selection(layer);
 }
 
-G_GNUC_UNUSED
-static GtkWidget*
-create_preview(GwyContainer *data,
-               gint id, gint preview_size, gboolean have_mask)
-{
-    GQuark quark = gwy_app_get_data_key_for_id(id);
-    const gchar *key = g_quark_to_string(quark);
-    GwyDataView *dataview;
-    GtkWidget *widget;
-
-    widget = gwy_data_view_new(data);
-    dataview = GWY_DATA_VIEW(widget);
-    gwy_data_view_set_data_prefix(dataview, key);
-    create_basic_layer(dataview, id);
-    if (have_mask)
-        create_mask_layer(dataview, id);
-    gwy_set_data_preview_size(dataview, preview_size);
-
-    return widget;
-}
-
 G_GNUC_UNUSED
 static void
 ensure_mask_color(GwyContainer *data, gint id)
@@ -216,15 +159,6 @@ create_mask_color_button(GwyContainer *data, GtkWidget *dialog, gint id)
     return color_button;
 }
 
-G_GNUC_UNUSED
-static GwyDataField*
-create_mask_field(GwyDataField *dfield)
-{
-    dfield = gwy_data_field_new_alike(dfield, TRUE);
-    gwy_si_unit_set_from_string(gwy_data_field_get_si_unit_z(dfield), NULL);
-    return dfield;
-}
-
 static void
 mask_merge_enabled_changed(GtkToggleButton *toggle, GtkWidget *widget)
 {
@@ -499,7 +433,7 @@ set_up_wait_data_field_preview(GwyDataField *dfield,
 
     mydata = gwy_container_new();
     gwy_container_set_object(mydata, gwy_app_get_data_key_for_id(0), dfield);
-    preview = create_preview(mydata, 0, PREVIEW_SMALL_SIZE, FALSE);
+    preview = gwy_create_preview(mydata, 0, PREVIEW_SMALL_SIZE, FALSE);
     if (data && id >= 0) {
         gwy_app_sync_data_items(data, mydata, id, 0, FALSE,
                                 GWY_DATA_ITEM_GRADIENT,
