@@ -1,5 +1,5 @@
 /*
- *  $Id: psdf2d.c 22730 2020-01-31 12:32:51Z yeti-dn $
+ *  $Id: psdf2d.c 23556 2021-04-21 08:00:51Z yeti-dn $
  *  Copyright (C) 2009-2020 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -320,7 +320,7 @@ psdf2d_dialogue(PSDFArgs *args,
     gwy_app_sync_data_items(data, controls.mydata, id, 0, FALSE,
                             GWY_DATA_ITEM_REAL_SQUARE,
                             0);
-    controls.view = create_preview(controls.mydata, 0, PREVIEW_SIZE, FALSE);
+    controls.view = gwy_create_preview(controls.mydata, 0, PREVIEW_SIZE, FALSE);
     controls.selection = create_vector_layer(GWY_DATA_VIEW(controls.view), 0,
                                              "Point", TRUE);
     gwy_selection_set_max_objects(controls.selection, NLINES);
