@@ -1,5 +1,5 @@
 /*
- *  $Id: psf.c 22505 2019-09-20 11:28:31Z yeti-dn $
+ *  $Id: psf.c 23556 2021-04-21 08:00:51Z yeti-dn $
  *  Copyright (C) 2017-2019 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -396,7 +396,7 @@ psf_dialog(PSFArgs *args, GwyContainer *data)
                             GWY_DATA_ITEM_GRADIENT,
                             GWY_DATA_ITEM_REAL_SQUARE,
                             0);
-    controls.view = create_preview(controls.mydata, 0, PREVIEW_SIZE, FALSE);
+    controls.view = gwy_create_preview(controls.mydata, 0, PREVIEW_SIZE, FALSE);
     align = gtk_alignment_new(0.5, 0.0, 0, 0);
     gtk_container_add(GTK_CONTAINER(align), controls.view);
     gtk_box_pack_start(GTK_BOX(hbox), align, FALSE, FALSE, 4);
