@@ -1,5 +1,5 @@
 /*
- *  $Id: slope_dist.c 22996 2020-12-03 14:06:04Z yeti-dn $
+ *  $Id: slope_dist.c 23556 2021-04-21 08:00:51Z yeti-dn $
  *  Copyright (C) 2004 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -296,7 +296,7 @@ slope_dialog(SlopeArgs *args, gboolean same_units,
                             GWY_DATA_ITEM_RANGE,
                             GWY_DATA_ITEM_REAL_SQUARE,
                             0);
-    controls.view = create_preview(controls.mydata, 0, PREVIEW_SIZE, FALSE);
+    controls.view = gwy_create_preview(controls.mydata, 0, PREVIEW_SIZE, FALSE);
     gtk_box_pack_start(GTK_BOX(vbox), controls.view, FALSE, FALSE, 0);
     if (args->output_type != SLOPE_DIST_2D_DIST)
         gtk_widget_set_no_show_all(controls.view, TRUE);
