@@ -1,5 +1,5 @@
 /*
- *  $Id: stitch.c 21909 2019-02-25 10:31:51Z yeti-dn $
+ *  $Id: stitch.c 23556 2021-04-21 08:00:51Z yeti-dn $
  *  Copyright (C) 2017 David Necas (Yeti), Petr Klapetek, Petr Grolich.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net, pgrolich@cmi.cz.
  *
@@ -299,7 +299,7 @@ stitch_dialog(GwyContainer *container, gint id, StitchArgs *args)
                             GWY_DATA_ITEM_GRADIENT,
                             GWY_DATA_ITEM_REAL_SQUARE,
                             0);
-    controls.view = create_preview(controls.mydata, 0, PREVIEW_SIZE, FALSE);
+    controls.view = gwy_create_preview(controls.mydata, 0, PREVIEW_SIZE, FALSE);
     gtk_box_pack_start(GTK_BOX(vbox), controls.view, FALSE, FALSE, 0);
     gwy_set_data_preview_size(GWY_DATA_VIEW(controls.view), PREVIEW_SIZE);
 
