@@ -1,5 +1,5 @@
 /*
- *  $Id: straighten_path.c 23666 2021-05-10 21:56:10Z yeti-dn $
+ *  $Id: straighten_path.c 24442 2021-10-29 15:36:31Z yeti-dn $
  *  Copyright (C) 2016-2021 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -43,6 +43,7 @@ enum {
 enum {
     PARAM_CLOSED,
     PARAM_INTERP,
+    PARAM_ORIENTATION,
     PARAM_SLACKNESS,
     PARAM_THICKNESS,
 };
@@ -104,7 +105,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Extracts a straightened part of image along a curve."),
     "Yeti <yeti@gwyddion.net>",
-    "2.0",
+    "2.1",
     "David Nečas (Yeti)",
     "2016",
 };
@@ -138,6 +139,8 @@ define_module_params(void)
     gwy_param_def_add_boolean(paramdef, PARAM_CLOSED, "closed", _("C_losed curve"), FALSE);
     gwy_param_def_add_enum(paramdef, PARAM_INTERP, "interp", NULL, GWY_TYPE_INTERPOLATION_TYPE,
                            GWY_INTERPOLATION_LINEAR);
+    gwy_param_def_add_enum(paramdef, PARAM_ORIENTATION, "orientation", _("Out_put orientation"), GWY_TYPE_ORIENTATION,
+                           GWY_ORIENTATION_VERTICAL);
     gwy_param_def_add_double(paramdef, PARAM_SLACKNESS, "slackness", _("_Slackness"), 0.0, G_SQRT2, 1.0/G_SQRT2);
     gwy_param_def_add_int(paramdef, PARAM_THICKNESS, "thickness", _("_Thickness"), 3, 16384, 20);
     return paramdef;
@@ -149,7 +152,7 @@ straighten_path(GwyContainer *data, GwyRunType runtype)
     GwyDialogOutcome outcome;
     ModuleArgs args;
     GwyParams *params;
-    GwyDataField *field;
+    GwyDataField *field, *tmp;
     gint id, newid, yres;
     GwySelection *selection;
     gboolean closed;
@@ -198,6 +201,12 @@ straighten_path(GwyContainer *data, GwyRunType runtype)
     if (outcome != GWY_DIALOG_HAVE_RESULT)
         execute(&args, args.selection);
 
+    if (gwy_params_get_enum(params, PARAM_ORIENTATION) == GWY_ORIENTATION_HORIZONTAL) {
+        tmp = gwy_data_field_new_rotated_90(args.result, FALSE);
+        g_object_unref(args.result);
+        args.result = tmp;
+    }
+
     newid = gwy_app_data_browser_add_data_field(args.result, data, TRUE);
     gwy_app_set_data_field_title(data, newid, _("Straightened"));
     gwy_app_sync_data_items(data, data, id, newid, FALSE,
@@ -237,7 +246,7 @@ run_gui(ModuleArgs *args, GwyContainer *data, gint id)
     gwy_clear(&gui, 1);
     gui.args = args;
     gui.data = gwy_container_new();
-    gwy_container_set_object_by_name(gui.data, "/0/data", field);
+    gwy_container_set_object(gui.data, gwy_app_get_data_key_for_id(0), field);
     gwy_app_sync_data_items(data, gui.data, id, 0, FALSE,
                             GWY_DATA_ITEM_RANGE_TYPE,
                             GWY_DATA_ITEM_RANGE,
@@ -245,8 +254,8 @@ run_gui(ModuleArgs *args, GwyContainer *data, gint id)
                             GWY_DATA_ITEM_REAL_SQUARE,
                             0);
 
-    gwy_container_set_object_by_name(gui.data, "/1/data", args->result);
-    gwy_container_set_object_by_name(gui.data, "/1/mask", args->result_mask);
+    gwy_container_set_object(gui.data, gwy_app_get_data_key_for_id(1), args->result);
+    gwy_container_set_object(gui.data, gwy_app_get_mask_key_for_id(1), args->result_mask);
     gwy_app_sync_data_items(data, gui.data, id, 1, FALSE,
                             GWY_DATA_ITEM_RANGE_TYPE,
                             GWY_DATA_ITEM_RANGE,
@@ -284,6 +293,7 @@ run_gui(ModuleArgs *args, GwyContainer *data, gint id)
 
     table = gui.table = gwy_param_table_new(args->params);
     gwy_param_table_append_combo(table, PARAM_INTERP);
+    gwy_param_table_append_combo(table, PARAM_ORIENTATION);
     gwy_param_table_append_slider(table, PARAM_THICKNESS);
     gwy_param_table_slider_restrict_range(table, PARAM_THICKNESS, 3, maxthickness);
     gwy_param_table_set_unitstr(table, PARAM_THICKNESS, _("px"));
