@@ -1,5 +1,5 @@
 /*
- *  $Id: terracefit.c 23678 2021-05-12 16:02:34Z yeti-dn $
+ *  $Id: terracefit.c 24448 2021-11-01 14:19:24Z yeti-dn $
  *  Copyright (C) 2019-2021 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -293,7 +293,7 @@ define_module_params(void)
     gwy_param_def_add_boolean(paramdef, PARAM_USE_ONLY_MASK, "use_only_mask", _("Do not _segment, use only mask"),
                               FALSE);
     gwy_param_def_add_mask_color(paramdef, PARAM_MASK_COLOR, NULL, NULL);
-    gwy_param_def_add_gwyenum(paramdef, PARAM_DISPLAY, NULL, _("Display"),
+    gwy_param_def_add_gwyenum(paramdef, PARAM_DISPLAY, NULL, gwy_sgettext("verb|Display"),
                               previews, G_N_ELEMENTS(previews), PREVIEW_DATA);
     gwy_param_def_add_report_type(paramdef, PARAM_TERRACE_REPORT_STYLE, "terrace_report_style", _("Save Terrace Table"),
                                   GWY_RESULTS_EXPORT_TABULAR_DATA, GWY_RESULTS_REPORT_TABSEP);
@@ -2139,7 +2139,7 @@ format_report(gpointer user_data)
     GwySIUnit *zunit;
     GString *text;
     const gchar *k_header, *Apx_header;
-    gchar *retval, *h_header, *Delta_header, *r_header;
+    gchar *h_header, *Delta_header, *r_header;
     guint g, nterraces;
 
     text = g_string_new(NULL);
@@ -2172,11 +2172,9 @@ format_report(gpointer user_data)
                                       info->residuum/vfz->magnitude);
     }
 
-    retval = text->str;
     gwy_si_unit_value_format_free(vfz);
-    g_string_free(text, FALSE);
 
-    return retval;
+    return g_string_free(text, FALSE);
 }
 
 static gdouble
