@@ -1,5 +1,5 @@
 /*
- *  $Id: wrapvalue.c 22340 2019-07-25 10:23:59Z yeti-dn $
+ *  $Id: wrapvalue.c 23556 2021-04-21 08:00:51Z yeti-dn $
  *  Copyright (C) 2019 David Necas (Yeti)
  *  E-mail: yeti@gwyddion.net
  *
@@ -244,7 +244,7 @@ wrap_value_dialog(WrapValueArgs *args,
                             GWY_DATA_ITEM_PALETTE,
                             GWY_DATA_ITEM_REAL_SQUARE,
                             0);
-    controls.view = create_preview(controls.mydata, 0, PREVIEW_SIZE, FALSE);
+    controls.view = gwy_create_preview(controls.mydata, 0, PREVIEW_SIZE, FALSE);
     gtk_box_pack_start(GTK_BOX(hbox), controls.view, FALSE, FALSE, 4);
 
     if (gwy_strequal(s, "deg")) {
