@@ -1,5 +1,5 @@
 #!/usr/bin/python2
-# $Id: pygwy-fix-defs-2.py 22943 2020-09-16 06:42:32Z yeti-dn $
+# $Id: pygwy-fix-defs-2.py 24502 2021-11-09 15:10:45Z yeti-dn $
 # alter defs, fix parameters and return types
 import sys, re
 from optparse import OptionParser
@@ -183,6 +183,8 @@ gwy_brick_get_value_format_x(format)
 gwy_brick_get_value_format_y(format)
 gwy_brick_get_value_format_z(format)
 gwy_brick_get_value_format_w(format)
+gwy_lawn_get_value_format_xy(format)
+gwy_lawn_get_value_format_curve(format)
 gwy_brick_set_zcalibration(calibration)
 gwy_data_field_crosscorrelate_init(x_dist,y_dist,score)
 gwy_data_field_correlation_search(kernel_weight)
@@ -232,6 +234,8 @@ gwy_data_line_get_value_format_x(format=NULL)
 gwy_data_line_get_value_format_y(format=NULL)
 gwy_surface_get_value_format_xy(format=NULL)
 gwy_surface_get_value_format_z(format=NULL)
+gwy_lawn_get_value_format_xy(format=NULL)
+gwy_lawn_get_value_format_curve(format=NULL)
 '''
 
 default_args = '''
@@ -285,6 +289,8 @@ gwy_data_field_new_rotated_90
 gwy_data_line_duplicate
 gwy_data_line_new_alike
 gwy_data_line_new_resampled
+gwy_lawn_new_alike
+gwy_lawn_new_part
 gwy_file_load
 gwy_graph_curve_model_duplicate
 gwy_graph_curve_model_new_alike
@@ -319,6 +325,8 @@ gwy_data_line_get_value_format_x
 gwy_data_line_get_value_format_y
 gwy_surface_get_value_format_xy
 gwy_surface_get_value_format_z
+gwy_lawn_get_value_format_xy
+gwy_lawn_get_value_format_curve
 gwy_tip_dilation
 gwy_tip_erosion
 gwy_tip_cmap
