@@ -1,5 +1,5 @@
 /*
- *  $Id: corrlen.c 22806 2020-05-07 11:28:45Z yeti-dn $
+ *  $Id: corrlen.c 23305 2021-03-18 14:40:27Z yeti-dn $
  *  Copyright (C) 2020 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -433,7 +433,7 @@ gwy_tool_corr_len_init_dialog(GwyToolCorrLen *tool)
     gtk_button_set_image(GTK_BUTTON(tool->update), image);
     gwy_plain_tool_add_clear_button(GWY_PLAIN_TOOL(tool));
     gwy_tool_add_hide_button(GWY_TOOL(tool), TRUE);
-    gwy_help_add_to_tool_dialog(dialog, GWY_TOOL(tool), GWY_HELP_NO_BUTTON);
+    gwy_help_add_to_tool_dialog(dialog, GWY_TOOL(tool), GWY_HELP_DEFAULT);
 
     gtk_widget_set_sensitive(tool->update, !tool->args.instant_update);
 
