@@ -1,5 +1,5 @@
 /*
- *  $Id: distance.c 21801 2019-01-06 20:37:13Z yeti-dn $
+ *  $Id: distance.c 23305 2021-03-18 14:40:27Z yeti-dn $
  *  Copyright (C) 2003-2008 Nenad Ocelic, David Necas (Yeti), Petr Klapetek.
  *  E-mail: ocelic@biochem.mpg.de, yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -271,7 +271,7 @@ gwy_tool_distance_init_dialog(GwyToolDistance *tool)
 
     gwy_plain_tool_add_clear_button(GWY_PLAIN_TOOL(tool));
     gwy_tool_add_hide_button(GWY_TOOL(tool), TRUE);
-    gwy_help_add_to_tool_dialog(dialog, GWY_TOOL(tool), GWY_HELP_NO_BUTTON);
+    gwy_help_add_to_tool_dialog(dialog, GWY_TOOL(tool), GWY_HELP_DEFAULT);
 
     update_headers(tool);
 
