@@ -1,5 +1,5 @@
 /*
- *  $Id: grainmeasure.c 21769 2019-01-02 13:45:41Z yeti-dn $
+ *  $Id: grainmeasure.c 23305 2021-03-18 14:40:27Z yeti-dn $
  *  Copyright (C) 2007 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -306,7 +306,7 @@ gwy_tool_grain_measure_init_dialog(GwyToolGrainMeasure *tool)
 
     gwy_plain_tool_add_clear_button(GWY_PLAIN_TOOL(tool));
     gwy_tool_add_hide_button(GWY_TOOL(tool), TRUE);
-    gwy_help_add_to_tool_dialog(dialog, GWY_TOOL(tool), GWY_HELP_NO_BUTTON);
+    gwy_help_add_to_tool_dialog(dialog, GWY_TOOL(tool), GWY_HELP_DEFAULT);
 
     gtk_widget_show_all(dialog->vbox);
 }
