@@ -1,5 +1,5 @@
 /*
- *  $Id: grainremover.c 22549 2019-10-10 11:46:43Z yeti-dn $
+ *  $Id: grainremover.c 23305 2021-03-18 14:40:27Z yeti-dn $
  *  Copyright (C) 2003-2019 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -244,7 +244,7 @@ gwy_tool_grain_remover_init_dialog(GwyToolGrainRemover *tool)
     gtk_widget_set_sensitive(tool->method_label, sensitive);
 
     gwy_tool_add_hide_button(GWY_TOOL(tool), TRUE);
-    gwy_help_add_to_tool_dialog(dialog, GWY_TOOL(tool), GWY_HELP_NO_BUTTON);
+    gwy_help_add_to_tool_dialog(dialog, GWY_TOOL(tool), GWY_HELP_DEFAULT);
 
     gtk_widget_show_all(dialog->vbox);
 }
