@@ -1,5 +1,5 @@
 /*
- *  $Id: icolorange.c 21820 2019-01-09 16:35:17Z yeti-dn $
+ *  $Id: icolorange.c 23305 2021-03-18 14:40:27Z yeti-dn $
  *  Copyright (C) 2003-2018 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -456,7 +456,7 @@ gwy_tool_color_range_init_dialog(GwyToolColorRange *tool)
                        FALSE, FALSE, 0);
 
     gwy_tool_add_hide_button(GWY_TOOL(tool), TRUE);
-    gwy_help_add_to_tool_dialog(dialog, GWY_TOOL(tool), GWY_HELP_NO_BUTTON);
+    gwy_help_add_to_tool_dialog(dialog, GWY_TOOL(tool), GWY_HELP_DEFAULT);
 
     /* Switch to the default */
     gwy_container_gis_enum_by_name(gwy_app_settings_get(),
