@@ -1,5 +1,5 @@
 /*
- *  $Id: linestats.c 23305 2021-03-18 14:40:27Z yeti-dn $
+ *  $Id: linestats.c 24167 2021-09-20 17:02:41Z yeti-dn $
  *  Copyright (C) 2003-2018 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -165,7 +165,7 @@ static const GwyEnum sf_types[] =  {
     { N_("Minimum"),            GWY_LINE_STAT_MINIMUM,   },
     { N_("Maximum"),            GWY_LINE_STAT_MAXIMUM,   },
     { N_("Range"),              GWY_LINE_STAT_RANGE,     },
-    { N_("Length"),             GWY_LINE_STAT_LENGTH,    },
+    { N_("Developed length"),   GWY_LINE_STAT_LENGTH,    },
     { N_("Slope"),              GWY_LINE_STAT_SLOPE,     },
     { N_("tan β<sub>0</sub>"),  GWY_LINE_STAT_TAN_BETA0, },
     { N_("Variation"),          GWY_LINE_STAT_VARIATION, },
