@@ -1,5 +1,5 @@
 /*
- *  $Id: maskedit.c 22983 2020-11-30 16:01:07Z yeti-dn $
+ *  $Id: maskedit.c 23305 2021-03-18 14:40:27Z yeti-dn $
  *  Copyright (C) 2003-2017 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -666,7 +666,7 @@ gwy_tool_mask_editor_init_dialog(GwyToolMaskEditor *tool)
     row++;
 
     gwy_tool_add_hide_button(GWY_TOOL(tool), TRUE);
-    gwy_help_add_to_tool_dialog(dialog, GWY_TOOL(tool), GWY_HELP_NO_BUTTON);
+    gwy_help_add_to_tool_dialog(dialog, GWY_TOOL(tool), GWY_HELP_DEFAULT);
     gwy_radio_buttons_set_current(tool->style, style);
 
     g_object_unref(sizegroup);
