@@ -1,5 +1,5 @@
 /*
- *  $Id: profile.c 22053 2019-05-23 21:53:42Z yeti-dn $
+ *  $Id: profile.c 23307 2021-03-18 15:56:45Z yeti-dn $
  *  Copyright (C) 2003-2019 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -202,7 +202,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Profile tool, creates profile graphs from selected lines."),
     "Petr Klapetek <klapetek@gwyddion.net>",
-    "4.2",
+    "4.3",
     "David Nečas (Yeti) & Petr Klapetek",
     "2004",
 };
@@ -572,7 +572,7 @@ gwy_tool_profile_init_dialog(GwyToolProfile *tool)
                                         GTK_RESPONSE_APPLY);
     gtk_dialog_set_default_response(dialog, GTK_RESPONSE_APPLY);
     gtk_dialog_set_response_sensitive(dialog, GTK_RESPONSE_APPLY, FALSE);
-    gwy_help_add_to_tool_dialog(dialog, GWY_TOOL(tool), GWY_HELP_NO_BUTTON);
+    gwy_help_add_to_tool_dialog(dialog, GWY_TOOL(tool), GWY_HELP_DEFAULT);
 
     gtk_widget_show_all(dialog->vbox);
 }
@@ -1019,19 +1019,8 @@ gwy_tool_profile_update_curve(GwyToolProfile *tool,
         g_object_unref(gcmodel);
 
         if (i == 0) {
-            GwySIUnit *xunit, *yunit;
-
-            xunit = gwy_data_field_get_si_unit_xy(plain_tool->data_field);
-            xunit = gwy_si_unit_duplicate(xunit);
-            yunit = gwy_data_field_get_si_unit_z(plain_tool->data_field);
-            yunit = gwy_si_unit_duplicate(yunit);
-            g_object_set(tool->gmodel,
-                         "si-unit-x", xunit,
-                         "si-unit-y", yunit,
-                         NULL);
-            g_object_unref(xunit);
-            g_object_unref(yunit);
-
+            gwy_graph_model_set_units_from_data_field(tool->gmodel, data_field,
+                                                      1, 0, 0, 1);
             gwy_tool_profile_update_target_graphs(tool);
         }
 
