@@ -1,5 +1,5 @@
 /*
- *  $Id: readvalue.c 21882 2019-02-13 15:41:09Z yeti-dn $
+ *  $Id: readvalue.c 23306 2021-03-18 14:42:14Z yeti-dn $
  *  Copyright (C) 2003-2019 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -106,7 +106,6 @@ struct _GwyToolReadValue {
     GtkWidget *set_zero;
 
     gboolean same_units;
-    gboolean has_selection;
     gboolean complete;
     gboolean in_update;
 
@@ -468,7 +467,7 @@ gwy_tool_read_value_init_dialog(GwyToolReadValue *tool)
 
     gwy_plain_tool_add_clear_button(GWY_PLAIN_TOOL(tool));
     gwy_tool_add_hide_button(GWY_TOOL(tool), TRUE);
-    gwy_help_add_to_tool_dialog(dialog, GWY_TOOL(tool), GWY_HELP_NO_BUTTON);
+    gwy_help_add_to_tool_dialog(dialog, GWY_TOOL(tool), GWY_HELP_DEFAULT);
 
     gwy_tool_read_value_resize_detail(tool);
 
@@ -730,8 +729,6 @@ gwy_tool_read_value_selection_changed(GwyPlainTool *plain_tool,
         gtk_entry_set_text(GTK_ENTRY(tool->ypix), "");
     }
 
-    tool->has_selection = has_selection;
-
     tool->xr = xr;
     tool->yr = yr;
     tool->complete = complete;
