@@ -1,5 +1,5 @@
 /*
- *  $Id: roughness.c 22277 2019-07-19 05:40:52Z yeti-dn $
+ *  $Id: roughness.c 23305 2021-03-18 14:40:27Z yeti-dn $
  *  Copyright (C) 2006-2017 Martin Hason, David Necas (Yeti), Petr Klapetek.
  *  E-mail: hasonm@physics.muni.cz, yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -656,7 +656,7 @@ gwy_tool_roughness_init_dialog(GwyToolRoughness *tool)
     gtk_dialog_set_response_sensitive(dialog, GTK_RESPONSE_APPLY, FALSE);
     gwy_results_export_set_actions_sensitive(GWY_RESULTS_EXPORT(tool->rexport),
                                              FALSE);
-    gwy_help_add_to_tool_dialog(dialog, GWY_TOOL(tool), GWY_HELP_NO_BUTTON);
+    gwy_help_add_to_tool_dialog(dialog, GWY_TOOL(tool), GWY_HELP_DEFAULT);
 
     gtk_widget_show_all(dialog_vbox);
 }
