@@ -1,5 +1,5 @@
 /*
- *  $Id: rprofile.c 22340 2019-07-25 10:23:59Z yeti-dn $
+ *  $Id: rprofile.c 23307 2021-03-18 15:56:45Z yeti-dn $
  *  Copyright (C) 2003-2019 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -162,7 +162,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Creates angularly averaged profile graphs."),
     "Yeti <yeti@gwyddion.net>",
-    "1.3",
+    "1.4",
     "David Nečas (Yeti) & Petr Klapetek",
     "2018",
 };
@@ -473,7 +473,7 @@ gwy_tool_rprofile_init_dialog(GwyToolRprofile *tool)
                                         GTK_RESPONSE_APPLY);
     gtk_dialog_set_default_response(dialog, GTK_RESPONSE_APPLY);
     gtk_dialog_set_response_sensitive(dialog, GTK_RESPONSE_APPLY, FALSE);
-    gwy_help_add_to_tool_dialog(dialog, GWY_TOOL(tool), GWY_HELP_NO_BUTTON);
+    gwy_help_add_to_tool_dialog(dialog, GWY_TOOL(tool), GWY_HELP_DEFAULT);
 
     gtk_widget_show_all(dialog->vbox);
 }
@@ -664,19 +664,8 @@ gwy_tool_rprofile_update_curve(GwyToolRprofile *tool, gint i)
         g_object_unref(gcmodel);
 
         if (i == 0) {
-            GwySIUnit *xunit, *yunit;
-
-            xunit = gwy_data_field_get_si_unit_xy(plain_tool->data_field);
-            xunit = gwy_si_unit_duplicate(xunit);
-            yunit = gwy_data_field_get_si_unit_z(plain_tool->data_field);
-            yunit = gwy_si_unit_duplicate(yunit);
-            g_object_set(tool->gmodel,
-                         "si-unit-x", xunit,
-                         "si-unit-y", yunit,
-                         NULL);
-            g_object_unref(xunit);
-            g_object_unref(yunit);
-
+            gwy_graph_model_set_units_from_data_field(tool->gmodel, data_field,
+                                                      1, 0, 0, 1);
             gwy_tool_rprofile_update_target_graphs(tool);
         }
     }
