@@ -1,6 +1,6 @@
 /*
- *  $Id: selectionmanager.c 21794 2019-01-04 17:51:32Z yeti-dn $
- *  Copyright (C) 2009,2012 David Necas (Yeti).
+ *  $Id: selectionmanager.c 23305 2021-03-18 14:40:27Z yeti-dn $
+ *  Copyright (C) 2009-2021 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -38,6 +38,7 @@
 /* XXX: Copied from data browser. */
 #define page_id_key "gwy-app-data-browser-page-id"
 #define container_key "gwy-app-data-browser-container"
+
 enum {
     PAGENO_SHIFT = 16,
 };
@@ -48,7 +49,7 @@ enum {
 #define GWY_TOOL_SELECTION_MANAGER_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS((obj), GWY_TYPE_TOOL_SELECTION_MANAGER, GwyToolSelectionManagerClass))
 
 enum {
-    NLAYERTYPES = 8
+    NLAYERTYPES = 9
 };
 
 enum {
@@ -128,7 +129,7 @@ static GwyModuleInfo module_info = {
     N_("Grain removal tool, removes continuous parts of mask and/or "
        "underlying data."),
     "Yeti <yeti@gwyddion.net>",
-    "2.2",
+    "2.3",
     "David Nečas (Yeti)",
     "2009",
 };
@@ -141,6 +142,7 @@ static const gchar *const layer_types[NLAYERTYPES] = {
     "GwyLayerLine",
     "GwyLayerPath",
     "GwyLayerPoint",
+    "GwyLayerProjective",
     "GwyLayerRectangle",
 };
 
@@ -267,14 +269,15 @@ render_type(G_GNUC_UNUSED GtkTreeViewColumn *column,
         const gchar *humanname;
     }
     type_names[] = {
-        { "GwySelectionAxis",      N_("Horiz./vert. lines"), },
-        { "GwySelectionCross",     N_("Crosses"),            },
-        { "GwySelectionEllipse",   N_("Ellipses"),           },
-        { "GwySelectionLattice",   N_("Lattice"),            },
-        { "GwySelectionLine",      N_("Lines"),              },
-        { "GwySelectionPath",      N_("Spline path"),        },
-        { "GwySelectionPoint",     N_("Points"),             },
-        { "GwySelectionRectangle", N_("Rectangles"),         },
+        { "GwySelectionAxis",       N_("Horiz./vert. lines"),    },
+        { "GwySelectionCross",      N_("Crosses"),               },
+        { "GwySelectionEllipse",    N_("Ellipses"),              },
+        { "GwySelectionLattice",    N_("Lattice"),               },
+        { "GwySelectionLine",       N_("Lines"),                 },
+        { "GwySelectionPath",       N_("Spline path"),           },
+        { "GwySelectionPoint",      N_("Points"),                },
+        { "GwySelectionProjective", N_("Projective rectangles"), },
+        { "GwySelectionRectangle",  N_("Rectangles"),            },
     };
 
     GwySelection *sel;
@@ -417,7 +420,7 @@ gwy_tool_selection_manager_init_dialog(GwyToolSelectionManager *tool)
     gwy_tool_add_hide_button(GWY_TOOL(tool), TRUE);
     gtk_dialog_add_button(GTK_DIALOG(GWY_TOOL(tool)->dialog),
                           GTK_STOCK_CLEAR, GWY_TOOL_RESPONSE_CLEAR);
-    gwy_help_add_to_tool_dialog(dialog, GWY_TOOL(tool), GWY_HELP_NO_BUTTON);
+    gwy_help_add_to_tool_dialog(dialog, GWY_TOOL(tool), GWY_HELP_DEFAULT);
 
     gtk_widget_show_all(dialog->vbox);
 }
@@ -745,10 +748,16 @@ add_coordinate_header(GString *text, GwySelection *selection, GwySIUnit *unit)
                 ? g_strconcat(" [", unitstr, "]", NULL)
                 : g_strdup(""));
 
-    if (gwy_stramong(typename,
-                     "GwySelectionRectangle", "GwySelectionEllipse",
-                     "GwySelectionLine", "GwySelectionLattice",
-                     NULL)) {
+    if (gwy_stramong(typename, "GwySelectionProjective", NULL)) {
+        g_string_append_printf(text,
+                               "x0%s\ty0%s\tx1%s\ty1%s\t"
+                               "x2%s\ty2%s\tx3%s\ty3%s\n",
+                               s, s, s, s, s, s, s, s);
+    }
+    else if (gwy_stramong(typename,
+                          "GwySelectionRectangle", "GwySelectionEllipse",
+                          "GwySelectionLine", "GwySelectionLattice",
+                          NULL)) {
         g_string_append_printf(text,
                                "x0%s\ty0%s\tx1%s\ty1%s\n", s, s, s, s);
     }
@@ -794,6 +803,7 @@ gwy_tool_selection_manager_create_report(GwyToolSelectionManager *tool)
     guint i, j, n, objsize;
     gdouble *coords;
     const gchar *typename;
+    gchar buf[64];
 
     treesel = gtk_tree_view_get_selection(GTK_TREE_VIEW(tool->treeview));
     if (!gtk_tree_selection_get_selected(treesel, NULL, &iter))
@@ -828,7 +838,8 @@ gwy_tool_selection_manager_create_report(GwyToolSelectionManager *tool)
     for (i = 0; i < n; i++) {
         gwy_selection_get_object(selection, i, coords);
         for (j = 0; j < objsize; j++) {
-            g_string_append_printf(text, "%g", coords[j]);
+            g_ascii_formatd(buf, sizeof(buf), "%g", coords[j]);
+            g_string_append(text, buf);
             g_string_append_c(text, (j == objsize-1) ? '\n' : '\t');
         }
     }
