@@ -1,5 +1,5 @@
 /*
- *  $Id: spectro.c 20677 2017-12-18 18:22:52Z yeti-dn $
+ *  $Id: spectro.c 23305 2021-03-18 14:40:27Z yeti-dn $
  *  Copyright (C) 2003-2014 Owain Davies, David Necas (Yeti), Petr Klapetek.
  *  E-mail: owain.davies@blueyonder.co.uk, yeti@gwyddion.net,
  *          klapetek@gwyddion.net.
@@ -412,7 +412,7 @@ gwy_tool_spectro_init_dialog(GwyToolSpectro *tool)
                                         GTK_RESPONSE_APPLY);
     gtk_dialog_set_default_response(dialog, GTK_RESPONSE_APPLY);
     gtk_dialog_set_response_sensitive(dialog, GTK_RESPONSE_APPLY, FALSE);
-    gwy_help_add_to_tool_dialog(dialog, GWY_TOOL(tool), GWY_HELP_NO_BUTTON);
+    gwy_help_add_to_tool_dialog(dialog, GWY_TOOL(tool), GWY_HELP_DEFAULT);
 
     gtk_widget_show_all(dialog->vbox);
 }
