@@ -1,5 +1,5 @@
 /*
- *  $Id: spotremove.c 22635 2019-10-30 14:25:48Z yeti-dn $
+ *  $Id: spotremove.c 23305 2021-03-18 14:40:27Z yeti-dn $
  *  Copyright (C) 2003-2019 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -413,7 +413,7 @@ gwy_tool_spot_remover_init_dialog(GwyToolSpotRemover *tool)
                                         GTK_RESPONSE_APPLY);
     gtk_dialog_set_default_response(dialog, GTK_RESPONSE_APPLY);
     gtk_dialog_set_response_sensitive(dialog, GTK_RESPONSE_APPLY, FALSE);
-    gwy_help_add_to_tool_dialog(dialog, GWY_TOOL(tool), GWY_HELP_NO_BUTTON);
+    gwy_help_add_to_tool_dialog(dialog, GWY_TOOL(tool), GWY_HELP_DEFAULT);
 
     gtk_widget_set_sensitive(tool->clear, FALSE);
     gwy_tool_spot_remover_resize_detail(tool);
