@@ -1,6 +1,6 @@
 /*
- *  $Id: stats.c 22784 2020-04-29 21:33:02Z yeti-dn $
- *  Copyright (C) 2003-2018 David Necas (Yeti), Petr Klapetek.
+ *  $Id: stats.c 23305 2021-03-18 14:40:27Z yeti-dn $
+ *  Copyright (C) 2003-2021 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -60,7 +60,7 @@ static const gchar *guivalues[] = {
     "Sp", "Sv", "Sz",
     /* Hybrid */
     "projarea", "area", "volume",
-    "var",
+    "Sdq", "var",
     "theta", "phi",
     /* Other */
     "linedis",
@@ -151,7 +151,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Statistics tool."),
     "Petr Klapetek <klapetek@gwyddion.net>",
-    "3.4",
+    "3.6",
     "David Nečas (Yeti) & Petr Klapetek",
     "2003",
 };
@@ -297,6 +297,11 @@ gwy_tool_stats_init(GwyToolStats *tool)
                           "type", GWY_RESULTS_VALUE_FLOAT,
                           "power-x", 1, "power-y", 1,
                           NULL);
+    gwy_results_add_value(results, "Sdq", N_("Surface slope"),
+                          "type", GWY_RESULTS_VALUE_FLOAT,
+                          "power-x", -1, "power-z", 1,
+                          "symbol", "Sdq",
+                          NULL);
     gwy_results_add_value(results, "volume", N_("Volume"),
                           "type", GWY_RESULTS_VALUE_FLOAT,
                           "power-x", 1, "power-y", 1, "power-z", 1,
@@ -401,7 +406,7 @@ gwy_tool_stats_init_dialog(GwyToolStats *tool)
             header = _("Order-Based");
         else if (i == 12)
             header = gwy_sgettext("parameters|Hybrid");
-        else if (i == 18)
+        else if (i == 19)
             header = _("Other");
 
         if (header) {
@@ -449,7 +454,7 @@ gwy_tool_stats_init_dialog(GwyToolStats *tool)
     gtk_button_set_image(GTK_BUTTON(tool->update), image);
     gwy_plain_tool_add_clear_button(GWY_PLAIN_TOOL(tool));
     gwy_tool_add_hide_button(GWY_TOOL(tool), TRUE);
-    gwy_help_add_to_tool_dialog(dialog, GWY_TOOL(tool), GWY_HELP_NO_BUTTON);
+    gwy_help_add_to_tool_dialog(dialog, GWY_TOOL(tool), GWY_HELP_DEFAULT);
 
     gtk_widget_set_sensitive(tool->update, !tool->args.instant_update);
 
@@ -687,7 +692,7 @@ gwy_tool_stats_calculate(GwyToolStats *tool)
     StatsUncertanties unc;
     gdouble xoff, yoff, q;
     gdouble min, max, avg, median, Sa, rms, rms_gw, skew, kurtosis,
-            projarea, area, volume, var, phi, theta, linedis;
+            projarea, area, Sdq, volume, var, phi, theta, linedis;
     gint nn, col, row, w, h;
 
     plain_tool = GWY_PLAIN_TOOL(tool);
@@ -741,6 +746,8 @@ gwy_tool_stats_calculate(GwyToolStats *tool)
                                                  col, row, w, h);
     var = gwy_data_field_area_get_variation(field, mask, masking,
                                             col, row, w, h);
+    Sdq = gwy_data_field_area_get_surface_slope_mask(field, mask, masking,
+                                                     col, row, w, h);
 
     linedis = gwy_data_field_scan_line_discrepancy(field, mask, masking,
                                                    col, row, w, h);
@@ -787,6 +794,7 @@ gwy_tool_stats_calculate(GwyToolStats *tool)
                             "Sz", max - min,
                             "rms_gw", rms_gw,
                             "area", area,
+                            "Sdq", Sdq,
                             "volume", volume,
                             "var", var,
                             "linedis", linedis,
