@@ -12,6 +12,7 @@ static GwyModuleInfo module_info = {
 
 GWY_MODULE_QUERY(module_info)
 
+GwyModuleInfo* _gwy_module_query__corrlen(void);
 GwyModuleInfo* _gwy_module_query__cprofile(void);
 GwyModuleInfo* _gwy_module_query__crop(void);
 GwyModuleInfo* _gwy_module_query__distance(void);
@@ -34,6 +35,7 @@ GwyModuleInfo* _gwy_module_query__spectro(void);
 GwyModuleInfo* _gwy_module_query__stats(void);
 
 static const GwyModuleRecord modules[] = {
+  { _gwy_module_query__corrlen, "corrlen", },
   { _gwy_module_query__cprofile, "cprofile", },
   { _gwy_module_query__crop, "crop", },
   { _gwy_module_query__distance, "distance", },
