@@ -21,6 +21,7 @@ GwyModuleInfo* _gwy_module_query__volume_fdfit(void);
 GwyModuleInfo* _gwy_module_query__volume_invert(void);
 GwyModuleInfo* _gwy_module_query__volume_kmeans(void);
 GwyModuleInfo* _gwy_module_query__volume_kmedians(void);
+GwyModuleInfo* _gwy_module_query__volume_lawnize(void);
 GwyModuleInfo* _gwy_module_query__volume_linestat(void);
 GwyModuleInfo* _gwy_module_query__volume_mfmrecalc(void);
 GwyModuleInfo* _gwy_module_query__volume_outliers(void);
@@ -45,6 +46,7 @@ static const GwyModuleRecord modules[] = {
   { _gwy_module_query__volume_invert, "volume_invert", },
   { _gwy_module_query__volume_kmeans, "volume_kmeans", },
   { _gwy_module_query__volume_kmedians, "volume_kmedians", },
+  { _gwy_module_query__volume_lawnize, "volume_lawnize", },
   { _gwy_module_query__volume_linestat, "volume_linestat", },
   { _gwy_module_query__volume_mfmrecalc, "volume_mfmrecalc", },
   { _gwy_module_query__volume_outliers, "volume_outliers", },
