@@ -1,5 +1,5 @@
 /*
- *  $Id: volume_arithmetic.c 22215 2019-07-10 14:05:43Z yeti-dn $
+ *  $Id: volume_arithmetic.c 23556 2021-04-21 08:00:51Z yeti-dn $
  *  Copyright (C) 2018-2019 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -260,7 +260,7 @@ arithmetic_dialog(GwyContainer *data,
                                                "/0/base/palette", gradient);
     }
 
-    controls.view = create_preview(controls.mydata, 0, PREVIEW_SIZE, FALSE);
+    controls.view = gwy_create_preview(controls.mydata, 0, PREVIEW_SIZE, FALSE);
     gtk_box_pack_start(GTK_BOX(vbox), controls.view, FALSE, FALSE, 0);
 
     table = gtk_table_new(5 + NARGS, 3, FALSE);
