@@ -1,5 +1,5 @@
 /*
- *  $Id: volume_planelevel.c 21843 2019-01-20 19:30:52Z yeti-dn $
+ *  $Id: volume_planelevel.c 22340 2019-07-25 10:23:59Z yeti-dn $
  *  Copyright (C) 2018 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -21,7 +21,9 @@
 
 #include "config.h"
 #include <gtk/gtk.h>
-#include <libgwyddion/gwyddion.h>
+#include <libgwyddion/gwymacros.h>
+#include <libgwyddion/gwymath.h>
+#include <libgwyddion/gwythreads.h>
 #include <libprocess/brick.h>
 #include <libprocess/level.h>
 #include <libgwydgets/gwystock.h>
