@@ -1,5 +1,5 @@
 /*
- *  $Id: volume_slice.c 21501 2018-10-23 15:10:43Z yeti-dn $
+ *  $Id: volume_slice.c 24177 2021-09-21 13:45:29Z yeti-dn $
  *  Copyright (C) 2015-2018 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -422,7 +422,7 @@ slice_dialog(SliceArgs *args, GwyContainer *data, gint id)
 
     gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
     controls.multiselect
-        = gtk_check_button_new_with_mnemonic(_("Extract _multiple items"));
+        = gtk_check_button_new_with_mnemonic(_("Extract _multiple"));
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.multiselect),
                                  args->multiselect);
     gtk_table_attach(GTK_TABLE(table), controls.multiselect,
@@ -546,6 +546,7 @@ slice_dialog(SliceArgs *args, GwyContainer *data, gint id)
             gtk_widget_destroy(dialog);
             case GTK_RESPONSE_NONE:
             g_object_unref(controls.mydata);
+            g_object_unref(controls.store);
             gwy_si_unit_value_format_free(controls.xvf);
             gwy_si_unit_value_format_free(controls.yvf);
             gwy_si_unit_value_format_free(controls.zvf);
@@ -567,6 +568,7 @@ slice_dialog(SliceArgs *args, GwyContainer *data, gint id)
 
     gtk_widget_destroy(dialog);
     g_object_unref(controls.mydata);
+    g_object_unref(controls.store);
     gwy_si_unit_value_format_free(controls.xvf);
     gwy_si_unit_value_format_free(controls.yvf);
     gwy_si_unit_value_format_free(controls.zvf);
