@@ -1,5 +1,5 @@
 /*
- *  $Id: volume_strayfield.c 21843 2019-01-20 19:30:52Z yeti-dn $
+ *  $Id: volume_strayfield.c 22157 2019-06-10 13:03:11Z klapetek $
  *  Copyright (C) 2015-2018 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -656,7 +656,7 @@ compute_strayfield_brick(GwyBrick *brick, GwyBrick *result,
 
     for (level = zfrom; level<zto; level++) {
          gwy_data_field_mfm_shift_z(basefield, shiftedfield,
-                                    (level - zfrom)*dz);
+                                    -(level - zfrom)*dz);
          gwy_brick_set_xy_plane(result, shiftedfield, level);
          if (dialog
              && !gwy_app_wait_set_fraction(((gdouble)(level-zfrom))/(zto-zfrom))) {
