@@ -1,5 +1,5 @@
 /*
- *  $Id: volume_swaxes.c 21430 2018-09-11 11:46:00Z yeti-dn $
+ *  $Id: volume_swaxes.c 22242 2019-07-14 12:17:43Z yeti-dn $
  *  Copyright (C) 2017-2018 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -116,7 +116,7 @@ module_register(void)
     gwy_volume_func_register("volume_swaxes",
                              (GwyVolumeFunc)&volume_swaxes,
                              N_("/S_wap Axes..."),
-                             NULL,
+                             GWY_STOCK_VOLUME_SWAP_AXES,
                              SWAXES_RUN_MODES,
                              GWY_MENU_FLAG_VOLUME,
                              N_("Swap axes"));
